(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    173997,       4388]
NotebookOptionsPosition[    162123,       4071]
NotebookOutlinePosition[    162886,       4096]
CellTagsIndexPosition[    162843,       4093]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Appendix:",
 StyleBox[" Mathematica",
  FontSlant->"Italic"],
 ", Excel, Regression, and Matrix Algebra"
}], "Title",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 TextAlignment->Center],

Cell["Introduction", "Section",
 PageWidth->PaperWidth],

Cell[TextData[{
 "The purpose of this appendix is to look inside the regression process so \
that the reader may see the computations required to produce regression \
output. There are a variety of different ways to present many particular \
results. This appendix derives results several ways to illustrate the \
different presentations.  Readers should not view regression output as \
computer magic. Enhanced understanding comes with knowing the equations and \
the calculations that take place when one clicks on an icon or executes a \
regression command. (Even greater understanding comes from understanding the \
formal proof of these equations, something that exceeds the scope of this \
work).\nThis material draws heavily upon two sources. One is ",
 StyleBox["Econometric Analysis",
  FontVariations->{"Underline"->True}],
 ", 5th Ed., by William H. Greene. The other is ",
 StyleBox["The Classical Regression Model",
  FontSlant->"Italic"],
 ", lecture notes of Prof. Herman J. Bierens, \
http://econ.la.psu.edu/~hbierens/index.htm, of the Economics Department of \
the College of Liberal Arts at The Pennsylvania State University.\nThe \
example we use here elaborates the univariate case of ",
 "Chapter 6",
 " involving house prices and sizes.\nThe model is of the following form"
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "i"], TraditionalForm]]],
 " = \[Alpha] + ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]x", "i"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "i"], TraditionalForm]]],
 ", i = 1,...,n"
}], "NumberedEquation",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 TextAlignment->Center],

Cell["Where:", "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell["\<\
   \[FilledSmallSquare]  y = the regressand or dependent variable to be \
explained\
\>", "BulletText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell["\<\
   \[FilledSmallSquare]  x = the regressor or independent variable offering \
explanation\
\>", "BulletText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "   \[FilledSmallSquare]  \[Alpha] = intercept term where the function \
crosses the y axis (when ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]x", "i"], TraditionalForm]]],
 " = 0)"
}], "BulletText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell["\<\
   \[FilledSmallSquare]  \[Beta] = coefficient to be estimated indicating the \
effect of x on y in the form of a slope\
\>", "BulletText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell["\<\
   \[FilledSmallSquare]  \[Epsilon] = error or disturbance term\
\>", "BulletText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell["The model is estimated under the following assumptions", "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "   ",
 StyleBox["1.",
  FontWeight->"Bold"],
 " The model is in the correct functional form, in this case linear;"
}], "ItemizedText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{3.515809026098098*^9}],

Cell[TextData[{
 "   2",
 StyleBox[".",
  FontWeight->"Bold"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"E", "[", 
     SubscriptBox["\[Epsilon]", "i"], "]"}], " "}], TraditionalForm]]],
 "= 0 for all ",
 StyleBox["i",
  FontSlant->"Italic"],
 ", that is the mean of the disturbance terms is zero;"
}], "ItemizedText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5158090305620975`*^9, 3.5158090335610976`*^9}}],

Cell[TextData[{
 "   3",
 StyleBox[".",
  FontWeight->"Bold"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Var", "[", 
     SubscriptBox["e", "i"], "]"}], " ", "=", " ", 
    SuperscriptBox["\[Sigma]", "2"]}], TraditionalForm]]],
 ", a constant, for all ",
 StyleBox["i",
  FontSlant->"Italic"],
 ", the property of homoscedasticity;"
}], "ItemizedText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5158090409060974`*^9, 3.5158090416330976`*^9}}],

Cell[TextData[{
 "   4",
 StyleBox[".",
  FontWeight->"Bold"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Cov", "[", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "i"], ",", 
      SubscriptBox["\[Epsilon]", "j"]}], "]"}], " ", "=", " ", "0"}], 
   TraditionalForm]]],
 " if ",
 StyleBox["i",
  FontSlant->"Italic"],
 " \[NotEqual] ",
 StyleBox["j",
  FontSlant->"Italic"],
 ", meaning the error terms are independent of each other, not correlated \
with each other;"
}], "ItemizedText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.515809045657098*^9, 3.5158090458250976`*^9}}],

Cell[TextData[{
 "   5",
 StyleBox[".",
  FontWeight->"Bold"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Cov", "[", 
     RowBox[{
      SubscriptBox["x", "i"], ",", 
      SubscriptBox["\[Epsilon]", "i"]}], "]"}], " ", "=", " ", "0"}], 
   TraditionalForm]]],
 "for all ",
 StyleBox["i",
  FontSlant->"Italic"],
 " and ",
 StyleBox["j",
  FontSlant->"Italic"],
 ", meaning that the regressor and the disturbances are uncorrelated."
}], "ItemizedText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5158090493620977`*^9, 3.5158090495450974`*^9}}],

Cell["\<\
Although not strictly required, it is very common to futher assume\
\>", "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "   6",
 StyleBox[".",
  FontWeight->"Bold"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["\[Epsilon]", "i"],
     TraditionalForm], "~", 
    RowBox[{"N", "[", 
     RowBox[{"0", ",", 
      SuperscriptBox["\[Sigma]", "2"]}], "]"}], " "}], TraditionalForm]]],
 ", meaning that the error terms are normally distributed with a zero mean \
and a variance of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Sigma]", "2"], TraditionalForm]]],
 "."
}], "ItemizedText",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5158090692730975`*^9, 3.515809069473098*^9}}],

Cell["\<\
Assumptions #3 and #4, if they hold, mean that the data is independently and \
identically distributed, referred to as \"iid\". The idea is that the error \
term is the sum of many small effects that are individually unimportant, \
random, both positive and negative. Assumption #2 assumes that the sum of \
these have a zero effect on the system.
Assumptions #4 and #5 are hard to maintain for real estate. For instance, #4, \
the non-autocorrelation assumption, assumes that there is no relationship \
between the error terms.  Much financial data has evidence of \
autocorrelation. Also, as valuation in real estate sales usually depend on \
recent sales of nearby properties correlation may be based on proximity. \
There are tests to adjust results to consider autocorrelation and \
heteroscedasticity but these are beyond the scope of this primer.
For reasons found deep in probability theory, if data is distributed normally \
it is by definition independent. Thus, Assumption #6 is common. The point is \
that while normality is not required, independence is and when you assume \
normality independence comes with it. In several places in the text we \
question the validity of this assumption for real world data. It is \
mathematically convenient nonetheless.
It is our purpose here to consider the regression process in a critical way. \
Regression is very good for a host of purposes. The general notion of \
conditional probability underlying regression is a powerful concept. But like \
all tools it must be viewed in terms of its limitations and used correctly. \
To the extent assumptions cannot be maintained results will be distorted.  \
Conclusions based on distorted results obtained under incorrect assumptions \
can be wrong.\
\>", "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "A note about notation: Convention in most texts is to represent algebraic \
equations in standard font and matrix algebraic symbols in ",
 StyleBox["BOLD ",
  FontWeight->"Bold"],
 "and sometimes upper case. This conflicts with the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " convention of user defined variables being lower case and the \
capitalization of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " built-in variable names and rountines. To replicate the convention in most \
texts the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " convention may be violated at times.\n\nThe organization of this appendix \
is as follows: Working in reverse (from bottom to top) we present the four \
components of the Excel regression output in ",
 "Table 6-7",
 ". We begin with the Residual Output, then the parameter table, then the \
Analysis of Variance, concluding with the Summary. The reason for woking in \
reverse is that the creation of variable names in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " format is simplified. Where appropriate, for many results we show the \
algebraic equation, the matrix algebra notation equivalent and the matching \
output performed by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s routines.\nThis appendix is provided to only to show the calculations \
underlying regression output, not interpret or explain the output. For \
interpretation the reader is referred to Greene or any of the many fine \
econmetric or statistics text books that cover regression."
}], "Text",
 PageWidth->PaperWidth,
 CellChangeTimes->{3.515809188103098*^9}],

Cell[BoxData[{
 RowBox[{"$Post", ":=", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"MatrixQ", "[", "#1", "]"}], ",", 
     RowBox[{"MatrixForm", "[", "#1", "]"}], ",", "#1"}], "]"}], 
   "&"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<MultivariateStatistics`\>\""}], ";", 
  RowBox[{"<<", "\"\<ComputationalGeometry`\>\""}]}], "\[IndentingNewLine]", 
 RowBox[{"<<", "\"\<HypothesisTesting`\>\""}]}], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.497045723578125*^9, 3.497045763984375*^9}, {
  3.5158092648510976`*^9, 3.5158092849740973`*^9}}],

Cell["The Data", "Section",
 PageWidth->PaperWidth],

Cell["\<\
Using our House Price example as familiar input, here is the same information \
we saw in Chapter 6:\
\>", "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ydata", "=", 
   RowBox[{"{", 
    RowBox[{
    "195000", ",", "210000", ",", "225000", ",", "240000", ",", "275000", ",",
      "285000", ",", "190000", ",", "239000", ",", "249000", ",", "185000"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xdata", "=", 
   RowBox[{"{", 
    RowBox[{
    "1500", ",", "1750", ",", "1600", ",", "1700", ",", "1900", ",", "1875", 
     ",", "1650", ",", "1810", ",", "1975", ",", "1550"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"houses", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"xdata", ",", "ydata"}], "}"}], "]"}]}]}], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1500", "195000"},
     {"1750", "210000"},
     {"1600", "225000"},
     {"1700", "240000"},
     {"1900", "275000"},
     {"1875", "285000"},
     {"1650", "190000"},
     {"1810", "239000"},
     {"1975", "249000"},
     {"1550", "185000"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045600515625*^9, 3.49704577225*^9, 
  3.5158093077850976`*^9}]
}, Open  ]],

Cell[TextData[{
 "We need the ",
 "y",
 " values arranged as a vector named ",
 StyleBox["Y",
  FontWeight->"Bold"]
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Y", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Transpose", "[", "houses", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "}"}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"195000"},
     {"210000"},
     {"225000"},
     {"240000"},
     {"275000"},
     {"285000"},
     {"190000"},
     {"239000"},
     {"249000"},
     {"185000"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4970456008125*^9, 3.497045774859375*^9, 
  3.5158093217880974`*^9}]
}, Open  ]],

Cell[TextData[{
 "We create a matrix (",
 StyleBox["X",
  FontWeight->"Bold"],
 ") composed of a vector of 1's for the intercept (alpha) and vectors for \
each of the independent values ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["x", "i"], ")"}], TraditionalForm]]],
 ". \nVector length of ",
 StyleBox["X",
  FontWeight->"Bold"],
 " must match that of ",
 StyleBox["Y",
  FontWeight->"Bold"],
 "."
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"X", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", "10", "}"}]}], "]"}], ",", 
     RowBox[{
      RowBox[{"Transpose", "[", "houses", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1500"},
     {"1", "1750"},
     {"1", "1600"},
     {"1", "1700"},
     {"1", "1900"},
     {"1", "1875"},
     {"1", "1650"},
     {"1", "1810"},
     {"1", "1975"},
     {"1", "1550"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045600921875*^9, 3.497045778296875*^9, 
  3.5158093371600976`*^9}]
}, Open  ]],

Cell["\<\
We sometimes need the independent variables in the form of a vector that we \
will name \"size\".\
\>", "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"size", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Transpose", "[", "X", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "}"}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1500"},
     {"1750"},
     {"1600"},
     {"1700"},
     {"1900"},
     {"1875"},
     {"1650"},
     {"1810"},
     {"1975"},
     {"1550"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045601015625*^9, 3.497045780765625*^9, 
  3.515809357544098*^9}]
}, Open  ]],

Cell[TextData[{
 "For equations developed below we need to set values for n (number of \
observations) and k (the width of ",
 StyleBox["X, ",
  FontWeight->"Bold"],
 "one more than the number of independent variables). This makes ",
 StyleBox["X",
  FontWeight->"Bold"],
 " an ",
 StyleBox["n ",
  FontSlant->"Italic"],
 "x",
 StyleBox[" k",
  FontSlant->"Italic"],
 " matrix ( 10 x 2 in our example)."
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"Length", "[", "Y", "]"}]}], ";", 
  RowBox[{"k", "=", 
   RowBox[{"Length", "[", 
    RowBox[{"Transpose", "[", "X", "]"}], "]"}]}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The X matrix is \>\"", ",", "n", ",", "\"\< x \>\"", ",", "k"}], 
  "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The X matrix is \"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" x \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["The X matrix is ", 10, " x ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.49704560115625*^9, 3.49704578815625*^9, 
  3.5158093906750975`*^9}]
}, Open  ]],

Cell["Descriptive Statistics", "Section",
 PageWidth->PaperWidth],

Cell[TextData[{
 "We will compute two descriptive statistics, the mean and the variance for \
each variable.\nThe mean may be computed using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s function or directly"
}], "Text",
 PageWidth->PaperWidth],

Cell["\<\
Here is the mean of Y produced by Mathematic's built-in function\
\>", "MathCaption",
 PageWidth->PaperWidth],

Cell["Mean[Y][[1]]", "Input",
 PageWidth->PaperWidth],

Cell[BoxData["229300"], "Output",
 CellChangeTimes->{3.4970456013125*^9, 3.49704579753125*^9, 
  3.5158094162970977`*^9}],

Cell[TextData[{
 "Using ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "n"], 
     SubscriptBox["y", "i"]}], "n"], TraditionalForm]]],
 " we get the same answer. This time we name the result for future use"
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Mu]", "Y"], "=", 
  RowBox[{
   FractionBox[
    RowBox[{"Plus", "@@", "Y"}], "n"], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["229300"], "Output",
 CellChangeTimes->{3.497045601421875*^9, 3.497045801140625*^9, 
  3.515809416346098*^9}],

Cell["We follow the same procedure for the independent variables", \
"MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{"Mean", "[", 
  RowBox[{"X", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["1731"], "Output",
 CellChangeTimes->{3.49704560153125*^9, 3.49704580990625*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Mu]", "X"], "=", 
  RowBox[{
   FractionBox[
    RowBox[{"Plus", "@@", "X"}], "n"], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["1731"], "Output",
 CellChangeTimes->{3.497045601625*^9, 3.497045813140625*^9, 
  3.5158094322100973`*^9}],

Cell["\<\
Here are two presentations arriving at the same sample variance of the size \
vector , the sum of the squared differences between individual values of the \
independent variables and the mean, all divided by n-1.\
\>", "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "This is ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s automated output"
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"Variance", "[", "size", "]"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["25137.777777777777`"], "Output",
 CellChangeTimes->{3.497045601765625*^9, 3.497045821890625*^9, 
  3.5158094485260973`*^9}],

Cell[TextData[{
 "To produce it using an equation we must define ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    StyleBox["X",
     FontWeight->"Bold"], "_"], TraditionalForm]]],
 ", a vector of the mean of ",
 StyleBox["X",
  FontWeight->"Bold"],
 " having a length equal to ",
 StyleBox["X",
  FontWeight->"Bold"],
 " "
}], "Text",
 PageWidth->PaperWidth],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     OverscriptBox["X", "_"],
     TraditionalForm], "=", 
    SubscriptBox["\[Mu]", "X"]}], TraditionalForm]]],
 "*Table[i,{i,n},{i,1}];"
}], "Input",
 PageWidth->PaperWidth,
 AllowInlineCells->True],

Cell[TextData[{
 "This is the algebraic version, ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox[
     RowBox[{"\[CapitalSigma]", "(", 
      RowBox[{"x", "-", 
       OverscriptBox["x", "_"]}], ")"}], "2"], 
    RowBox[{"(", 
     RowBox[{"n", "-", "1"}], ")"}]], TraditionalForm]]]
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Plus", "@@", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"size", "-", 
         OverscriptBox["X", "_"]}], ")"}], "2"]}], ")"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], 
   RowBox[{"n", "-", "1"}]], "//", "N"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["25137.777777777777`"], "Output",
 CellChangeTimes->{3.497045601859375*^9, 3.497045831390625*^9, 
  3.515809493044098*^9}],

Cell["\<\
The mean and the variance are known as, respectively, the first and second \
moment of the distribution. Other useful measures are skewness and kurtosis, \
the third and fourth moments of the distribution. These, if significant, \
represent a deviation from normality because a normal distribution has a \
skewness of zero (it is symmetric) and an excess kurtosis of zero (it has \
light tails). Our Y data has a slight skewness and lighter than normal tails.\
\>", "Text",
 CellChangeTimes->{{3.515809513973098*^9, 3.515809650098098*^9}, {
  3.515809859004098*^9, 3.515809877308098*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Skewness", "[", "Y", "]"}], "//", "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Kurtosis", "[", "Y", "]"}], "-", "3"}], "//", "N"}]}], "Input",
 CellChangeTimes->{{3.515809697782098*^9, 3.5158097309370975`*^9}, {
  3.5158098218950977`*^9, 3.515809822039098*^9}}],

Cell[BoxData[
 RowBox[{"{", "0.2312267889256028`", "}"}]], "Output",
 CellChangeTimes->{{3.5158097200490975`*^9, 3.5158097338940973`*^9}, 
   3.515809824136098*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", "1.1421532422478862`"}], "}"}]], "Output",
 CellChangeTimes->{{3.5158097200490975`*^9, 3.5158097338940973`*^9}, 
   3.5158098241390977`*^9}]
}, Open  ]],

Cell["Regression", "Section",
 PageWidth->PaperWidth],

Cell["Preliminary calculations, matrices and the normal equations", \
"Subsection",
 PageWidth->PaperWidth],

Cell["\<\
Crucial to the regression process is the creation of some special matrices. \
\>", "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "For instance, the dot product of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"], 
    StyleBox["X",
     FontWeight->"Bold"]}], TraditionalForm]]],
 " must be a non-singular matrix. This means the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"], 
    StyleBox["X",
     FontWeight->"Bold"]}], TraditionalForm]]],
 " matrix must have an inverse. This property leads to a unique solution of \
the minimization problem required to solve for the least squares estimators."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", "X", "]"}], ".", "X"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"10", "17310"},
     {"17310", "30189850"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045602*^9, 3.497045841125*^9, 3.515809895190098*^9}],

Cell[TextData[{
 "The above creates a matrix with the ",
 StyleBox["sum of the squares",
  FontVariations->{"Underline"->True}],
 " of the individual vectors in X on the diagonal and the ",
 StyleBox["sum of the values",
  FontVariations->{"Underline"->True}],
 " of the independent variable on the off diagonal.  Note that this also \
produces the coefficients of the \"normal equations\". These are simultaneous \
equations which, when solved, produce the estimated a and b of the \
regression. The two equations in two unknowns, a and b, are shown as \
equations (4.1) and (4.2)."
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "n"], 
   SubscriptBox["y", "i"]}], "=", 
  RowBox[{
   RowBox[{"n", " ", "a"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "1"}], "n"], 
      SubscriptBox["x", "i"]}], ")"}], "b"}]}]}]], "NumberedEquation",
 PageWidth->PaperWidth,
 TextAlignment->Center],

Cell[BoxData[
 RowBox[{
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "n"], 
   RowBox[{
    SubscriptBox["x", "i"], 
    SubscriptBox["y", "i"]}]}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "1"}], "n"], 
      SubscriptBox["x", "i"]}], ")"}], "a"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "1"}], "n"], 
      SubscriptBox[
       SuperscriptBox["x", "2"], "i"]}], ")"}], "b"}]}]}]], "NumberedEquation",
 PageWidth->PaperWidth,
 TextAlignment->Center],

Cell["Let's unravel this notation one term at a time. ", "Text",
 PageWidth->PaperWidth],

Cell[TextData[{
 "On the left hand side of equation (4.1), the sum of the dependent variables \
(observed house prices), ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "n"], 
   SubscriptBox["y", "i"]}]]],
 " is"
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Plus", "@@", "Y"}], ")"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["2293000"], "Output",
 CellChangeTimes->{3.497045602109375*^9, 3.497045850625*^9, 
  3.5158099322720976`*^9}],

Cell[TextData[{
 "n is simple enough. Note that it is the upper left term in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"], 
    StyleBox["X",
     FontWeight->"Bold"]}], TraditionalForm]]],
 " matrix."
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData["n"], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{3.49704560221875*^9, 3.49704585553125*^9, 
  3.515809941452098*^9}],

Cell[TextData[{
 "The upper right and lower left (off diagonal) terms in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"], 
    StyleBox["X",
     FontWeight->"Bold"]}], TraditionalForm]]],
 "matrix is the sum of the independent variables (size of houses), ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "n"], 
   SubscriptBox["x", "i"]}]]],
 ". This is the coefficient of b on the right hand side of equation (4.1)."
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Plus", "@@", "size"}], ")"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["17310"], "Output",
 CellChangeTimes->{3.49704560240625*^9, 3.497045858359375*^9, 
  3.5158099518700976`*^9}],

Cell[TextData[{
 "Moving to equation (4.2), the term on the left hand side, ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "n"], 
   RowBox[{
    SubscriptBox["x", "i"], 
    SubscriptBox["y", "i"]}]}]]],
 ", is the sum of the product of each house price and its size"
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Transpose", "[", "Y", "]"}], ".", "size"}], ")"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["4009490000"], "Output",
 CellChangeTimes->{3.497045602625*^9, 3.4970458615625*^9, 
  3.515809961110098*^9}],

Cell[TextData[{
 "On the right side of equation (4.2) we again encounter the term in \
off-diagonal of the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"], 
    StyleBox["X",
     FontWeight->"Bold"]}], TraditionalForm]]],
 " matrix, the sum of the independent variables (size of houses), ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "n"], 
   SubscriptBox["x", "i"]}]]],
 ". This time it is the coefficient of a."
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Plus", "@@", "size"}], ")"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["17310"], "Output",
 CellChangeTimes->{3.497045602734375*^9, 3.497045865859375*^9, 
  3.5158099984460974`*^9}],

Cell[TextData[{
 "Finally, the lower right element in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"], 
    StyleBox["X",
     FontWeight->"Bold"]}], TraditionalForm]]],
 " matrix, the sum of the square of the size of each house, ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "n"], 
   SubscriptBox[
    SuperscriptBox["x", "2"], "i"]}]]],
 " is the coefficient of b in equation (4.2)."
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Transpose", "[", "size", "]"}], ".", "size"}], ")"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["30189850"], "Output",
 CellChangeTimes->{3.497045602859375*^9, 3.497045870078125*^9, 
  3.5158100062700977`*^9}],

Cell["\<\
Inserting the values we have found for the terms in equations (4.1) and (4.2) \
produce two equations in two unknowns.\
\>", "Text",
 PageWidth->PaperWidth],

Cell["\<\
2293000 = 10 a + 17310 b
4009490000 = 17310 a + 30189850 b\
\>", "Text",
 PageWidth->PaperWidth,
 TextAlignment->Center],

Cell[TextData[{
 "These can be combined into a pair of equations using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s Solve function to find the values for the a and b unknowns."
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Plus", "@@", "Y"}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"n", " ", "a"}], "+", 
         RowBox[{"b", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Plus", "@@", "size"}], ")"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Transpose", "[", "Y", "]"}], ".", "size"}], ")"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"(", 
             RowBox[{"Plus", "@@", "size"}], ")"}]}], "+", 
           RowBox[{"b", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Transpose", "[", "size", "]"}], ".", "size"}], ")"}],
               "[", 
              RowBox[{"[", "1", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}]}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"a", "\[Rule]", 
      RowBox[{"-", "79095.58433521923`"}]}], 
     RowBox[{"b", "\[Rule]", "178.16036067892503`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045603125*^9, 3.4970458793125*^9, 
  3.5158100222620974`*^9}],

Cell["\<\
Students are often confused by the different notation styles used to present \
equations and mathematical identities. One usually learns algebra and its \
symbols and then \"graduates\" to matrix algebra and its notation form. In \
time one recognizes the similarities between the two styles and moves easily \
between them. Until that time one may endure much frustration.\
\>", "Text",
 PageWidth->PaperWidth],

Cell["\<\
For instance, equation (1.1) may be expressed in matrix notation as\
\>", "Text",
 PageWidth->PaperWidth],

Cell[TextData[{
 StyleBox["Y",
  FontWeight->"Bold"],
 " = ",
 StyleBox["X",
  FontWeight->"Bold"],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "i"], TraditionalForm]],
  FontWeight->"Bold"],
 "+ ",
 StyleBox["\[Epsilon]",
  FontWeight->"Bold"]
}], "NumberedEquation",
 PageWidth->PaperWidth,
 AllowInlineCells->True,
 TextAlignment->Center],

Cell["Where the symbols stand for vectors and matrices.", "Text",
 PageWidth->PaperWidth],

Cell[TextData[{
 "In general, above we have used both methods to present the normal equations \
and solve for their two unknown coefficients.  This is easy enough when there \
are only two equations and two unknowns. But algebra becomes unwieldy in the \
multivariate case when the number of independent variables exceeds one. The \
multivariate case involves multiple coefficients ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["b", "i"], ",", " ", 
     RowBox[{"i", "=", 
      RowBox[{
       RowBox[{"1.", ".."}], "n"}]}]}], ")"}], TraditionalForm]]],
 " to allow for many independent variables (such as not only the size of the \
house but the size of the lot the house is on, the number of bedrooms, etc.). \
 This results in a system of many unknowns with an equal number of equations \
that is too cumbersome for the algebraic format.  Matrix algebra streamlines \
the notation in the multivariate case. "
}], "Text",
 PageWidth->PaperWidth],

Cell[TextData[{
 "Above we said that the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"], 
    StyleBox["X",
     FontWeight->"Bold"]}], TraditionalForm]]],
 " must have an inverse. ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      RowBox[{
       SuperscriptBox[
        StyleBox["X",
         FontWeight->"Bold"], "T"], 
       StyleBox["X",
        FontWeight->"Bold"]}],
      TraditionalForm], ")"}], 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "is the inverse of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"], 
    StyleBox["X",
     FontWeight->"Bold"]}], TraditionalForm]]],
 "."
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Inverse", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", "X", "]"}], ".", "X"}], "]"}], "]"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"13.344169908062234`", 
      RowBox[{"-", "0.007651166902404526`"}]},
     {
      RowBox[{"-", "0.007651166902404526`"}], "4.42008486562942`*^-6"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.49704560328125*^9, 3.497045889859375*^9, 
  3.5158100632190976`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Here are two ways ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \"picks\" the lower right corner term. We name the second one \"LwrRt\" \
for later use in forming the t-statistic for the estimated beta coefficient"
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"Inverse", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", "X", "]"}], ".", "X"}], "]"}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "2"}], "]"}], "]"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData["4.42008486562942`*^-6"], "Output",
 CellChangeTimes->{3.4970456034375*^9, 3.497045893265625*^9, 
  3.5158100748950977`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LwrRt", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], ".", 
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", "X", "]"}], ".", "X"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", "1", "}"}]}], "}"}]}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"{", "4.42008486562942`*^-6", "}"}]], "Output",
 CellChangeTimes->{3.497045603546875*^9, 3.497045896640625*^9, 
  3.5158100817620974`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "The product of the inverse matrix and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["X",
     FontWeight->"Bold"], "T"], TraditionalForm]]],
 " also produces a matrix. Using that matrix and the ",
 StyleBox["Y",
  FontWeight->"Bold"],
 " values produces a vector of parameter estimates (a and b) for the \
regression:"
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["N[Inverse[Transpose[X].X].Transpose[X]]", "Input",
 PageWidth->PaperWidth],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1.8674195544554455`", 
      RowBox[{"-", "0.045372171145685994`"}], "1.102302864214993`", 
      "0.3371861739745403`", 
      RowBox[{"-", "1.1930472065063649`"}], 
      RowBox[{"-", "1.0017680339462518`"}], "0.7197445190947667`", 
      RowBox[{"-", "0.5044421852899575`"}], 
      RowBox[{"-", "1.7668847241867043`"}], "1.4848612093352191`"},
     {
      RowBox[{"-", "0.001021039603960396`"}], "0.00008398161244695899`", 
      RowBox[{"-", "0.000579031117397454`"}], 
      RowBox[{"-", "0.00013702263083451203`"}], "0.000746994342291372`", 
      "0.0006364922206506364`", 
      RowBox[{"-", "0.00035802687411598305`"}], "0.0003491867043847242`", 
      "0.0010785007072135785`", 
      RowBox[{"-", "0.000800035360678925`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045603734375*^9, 3.497045901*^9, 3.515810093136098*^9}
  ]
}, Open  ]],

Cell[TextData[{
 "The parameter estimates are the solutions to a minimization problem. We \
present them as a vector, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "^"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       OverscriptBox["\[Alpha]", "^"]},
      {
       OverscriptBox["\[Beta]", "^"]}
     }], ")"}], TraditionalForm]]],
 ". The elements in this vector should be compared with values for a and b \
reached with the normal equations above and values for the intercept and \"SF\
\" shown in the parameter table of ",
 "Table 6-7",
 " of Chapter 6."
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "The matrix algebra equation for the parameter estimate vector is ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "^"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SuperscriptBox[
      RowBox[{"(", 
       FormBox[
        RowBox[{
         SuperscriptBox[
          StyleBox["X",
           FontWeight->"Bold"], "T"], 
         StyleBox["X",
          FontWeight->"Bold"]}],
        TraditionalForm], ")"}], 
      RowBox[{"-", "1"}]],
     TraditionalForm], 
    SuperscriptBox[
     StyleBox["X",
      FontWeight->"Bold"], "T"]}], TraditionalForm]]],
 StyleBox["Y",
  FontWeight->"Bold"]
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["\[Theta]", "^"], "=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", "X", "]"}], ".", "X"}], "]"}], ".", 
    RowBox[{"Transpose", "[", "X", "]"}], ".", "Y"}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.497045618640625*^9, 3.497045669390625*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "79095.58433521923`"}]},
     {"178.16036067892503`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.49704566321875*^9, 3.49704567003125*^9}, 
   3.497045905953125*^9, 3.5158101083650975`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " puts these in the form of a regression equation using the function \"Fit\""
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"Fit", "[", 
    RowBox[{"houses", ",", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", " ", "x"}], "}"}], ",", " ", "x"}], "]"}], "//", 
   "TraditionalForm"}],
  FormatType->StandardForm,
  FontFamily->"Courier New"]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"178.16036067892517`", " ", "x"}], "-", "79095.58433521951`"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.49704560421875*^9, 3.497045910703125*^9, 
  3.515810120513098*^9}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " also uses LinearModelFit to produce an object that can be used for a \
variety of diagnostics, listed below"
}], "Text",
 CellChangeTimes->{{3.5158101655730977`*^9, 3.5158101959640975`*^9}, {
  3.5158121573260975`*^9, 3.5158121603820972`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lmf", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"houses", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5158101293770976`*^9, 3.5158101511590977`*^9}, {
  3.5158102098300977`*^9, 3.515810211117098*^9}}],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{
     RowBox[{"-", "79095.58433521951`"}], "+", 
     RowBox[{
      RowBox[{"\[LeftSkeleton]", "19", "\[RightSkeleton]"}], " ", "x"}]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 CellChangeTimes->{3.515810152650098*^9, 3.5158102124360976`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lmf", "[", "\"\<Properties\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.515812126388098*^9, 3.515812135730098*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"AdjustedRSquared\"\>", ",", "\<\"AIC\"\>", 
   ",", "\<\"ANOVATable\"\>", ",", "\<\"ANOVATableDegreesOfFreedom\"\>", 
   ",", "\<\"ANOVATableEntries\"\>", ",", "\<\"ANOVATableFStatistics\"\>", 
   ",", "\<\"ANOVATableMeanSquares\"\>", ",", "\<\"ANOVATablePValues\"\>", 
   ",", "\<\"ANOVATableSumsOfSquares\"\>", ",", "\<\"BasisFunctions\"\>", 
   ",", "\<\"BetaDifferences\"\>", ",", "\<\"BestFit\"\>", 
   ",", "\<\"BestFitParameters\"\>", ",", "\<\"BIC\"\>", 
   ",", "\<\"CatcherMatrix\"\>", ",", "\<\"CoefficientOfVariation\"\>", 
   ",", "\<\"CookDistances\"\>", ",", "\<\"CorrelationMatrix\"\>", 
   ",", "\<\"CovarianceMatrix\"\>", ",", "\<\"CovarianceRatios\"\>", 
   ",", "\<\"Data\"\>", ",", "\<\"DesignMatrix\"\>", 
   ",", "\<\"DurbinWatsonD\"\>", ",", "\<\"EigenstructureTable\"\>", 
   ",", "\<\"EigenstructureTableEigenvalues\"\>", 
   ",", "\<\"EigenstructureTableEntries\"\>", 
   ",", "\<\"EigenstructureTableIndexes\"\>", 
   ",", "\<\"EigenstructureTablePartitions\"\>", 
   ",", "\<\"EstimatedVariance\"\>", ",", "\<\"FitDifferences\"\>", 
   ",", "\<\"FitResiduals\"\>", ",", "\<\"Function\"\>", 
   ",", "\<\"FVarianceRatios\"\>", ",", "\<\"HatDiagonal\"\>", 
   ",", "\<\"MeanPredictionBands\"\>", 
   ",", "\<\"MeanPredictionConfidenceIntervals\"\>", 
   ",", "\<\"MeanPredictionConfidenceIntervalTable\"\>", 
   ",", "\<\"MeanPredictionConfidenceIntervalTableEntries\"\>", 
   ",", "\<\"MeanPredictionErrors\"\>", 
   ",", "\<\"ParameterConfidenceIntervals\"\>", 
   ",", "\<\"ParameterConfidenceIntervalTable\"\>", 
   ",", "\<\"ParameterConfidenceIntervalTableEntries\"\>", 
   ",", "\<\"ParameterConfidenceRegion\"\>", ",", "\<\"ParameterErrors\"\>", 
   ",", "\<\"ParameterPValues\"\>", ",", "\<\"ParameterTable\"\>", 
   ",", "\<\"ParameterTableEntries\"\>", ",", "\<\"ParameterTStatistics\"\>", 
   ",", "\<\"PartialSumOfSquares\"\>", ",", "\<\"PredictedResponse\"\>", 
   ",", "\<\"Properties\"\>", ",", "\<\"Response\"\>", 
   ",", "\<\"RSquared\"\>", ",", "\<\"SequentialSumOfSquares\"\>", 
   ",", "\<\"SingleDeletionVariances\"\>", 
   ",", "\<\"SinglePredictionBands\"\>", 
   ",", "\<\"SinglePredictionConfidenceIntervals\"\>", 
   ",", "\<\"SinglePredictionConfidenceIntervalTable\"\>", 
   ",", "\<\"SinglePredictionConfidenceIntervalTableEntries\"\>", 
   ",", "\<\"SinglePredictionErrors\"\>", 
   ",", "\<\"StandardizedResiduals\"\>", ",", "\<\"StudentizedResiduals\"\>", 
   ",", "\<\"VarianceInflationFactors\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.515812138327098*^9}]
}, Open  ]],

Cell[TextData[{
 "Each of which can be separately researched. Example (follow link): ",
 ButtonBox["AIC",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Akaike_information_criterion"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Akaike_information_criterion"]
}], "Text",
 CellChangeTimes->{{3.5158124521350975`*^9, 3.515812504782098*^9}}],

Cell["\<\
The LinearModelFit object can be represented in standard form by wrapping it \
with \[OpenCurlyDoubleQuote]Normal\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.5158102194830976`*^9, 3.5158102440430975`*^9}, {
  3.5158122127260976`*^9, 3.5158122201090975`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"houseFit", "=", 
  RowBox[{"Normal", "[", "lmf", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"TraditionalForm", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.5158102488650975`*^9, 3.515810278827098*^9}, {
  3.5158106805780973`*^9, 3.5158106883780975`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "79095.58433521951`"}], "+", 
  RowBox[{"178.16036067892517`", " ", "x"}]}]], "Output",
 CellChangeTimes->{{3.5158102544110975`*^9, 3.5158102803420973`*^9}, 
   3.5158106901140976`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"178.16036067892517`", " ", "x"}], "-", "79095.58433521951`"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.5158102544110975`*^9, 3.5158102803420973`*^9}, 
   3.5158106901190977`*^9}]
}, Open  ]],

Cell[TextData[{
 "We pick the intercept and the parameter estimate, each, out of the vector \
of estimated parameters, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "^"], TraditionalForm]]],
 ", and name them for later use."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"a", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ".", 
   OverscriptBox["\[Theta]", "^"]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", "79095.58433521923`"}], "}"}]], "Output",
 CellChangeTimes->{3.49704560434375*^9, 3.4970459138125*^9, 
  3.515810489926098*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["b", "1"], "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ".", 
   OverscriptBox["\[Theta]", "^"]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"{", "178.16036067892503`", "}"}]], "Output",
 CellChangeTimes->{3.497045604578125*^9, 3.497045916*^9, 
  3.5158104965800977`*^9}],

Cell[TextData[{
 "Before continuing, it is important to relate all of this to the SP \
distribution issues of Chapter 6.  A central purpose of regression is to \
predict the conditional mean. For our example that is the average house value \
",
 StyleBox["conditioned upon knowing some other fact",
  FontSlant->"Italic"],
 ", in our case the size of the house). This prediction is dependent on the \
accurate estimate of \[Beta], shown as the value of ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["b", "1"],
    FontWeight->"Bold"], TraditionalForm]]],
 "above. After performing the regression, our claim is that the value of a \
house goes up by $178.16 for each added square foot.  This is only correct if \
we have correctly estimated the mean itself. Outliers, as we have said, have \
a significant affect on the mean. Thus, if the assumption of normality is \
violated by significant outliers in the distribution the estimated regression \
coefficient(s) are distorted.  For an excellent and quite technical \
explanation of this situation using a real estate example see McCulloch \
(1998)."
}], "Text",
 PageWidth->PaperWidth,
 CellChangeTimes->{{3.515810505973098*^9, 3.515810507716098*^9}}],

Cell["Residuals", "Subsection",
 PageWidth->PaperWidth],

Cell["\<\
The regression report in Table 6-7 of Chapter 6 is reproduced here for \
comparison to the results below.\
\>", "Text",
 PageWidth->PaperWidth],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002V@0@0006`000000000000003P4002]0P00
00000000002/8`00[aH00215CDH00040T2T00;40000:00000000000000000000H0T004D<003;0000
2@4000000000000000000?PH0`0X2`@0AP0002`0000P0000ADe6:`500@0L00004000004@`=/00000
;04002`100160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001H0000<0000600000X0000@0000
0000000000090000400003L4002^0P009@0000`0000>0020DP00070100010000c_ooo`0000000000
000009010000000014004U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
00000000000000000000000000000:000@0006bX0C20<1@0<3<D0040002/ia806:LJ02A4500XA1@0
000000D0001Lj180000005CR4P2`@A@0a[l4<80`502`@A@0000000000034DTL3H30D00000000Ib00
I>PB07Rl132<09`0a5970`0000000000a5970`000S3E_@@`8>DB060`500TgIT`h=bI<:RR6P1h0A@0
00000:RR6P2dhQ80E27eMoooooooo`60ool000l00H000?oo0000000800002000AaJ@0@000P860`D4
1@8318Mj0200002020000000003o0@00000005@0J@1]06D0I7H02000000U000030000040000B0000
30000040000H000030000000008Q0000200001h0000H000000000000000g1000[P8004H0000X0000
700004M4BD<20000oooooooooolj1000[`80000000160000:0T001`90015CDH[:T0002@0000H0000
0020?`00000000000020?`00000000008D0500`0000000009D00010000040000000002a0000T0000
6000099ORSl000200000P6fP;cl000200000P0Q000ET2000F0P0004@`=/200000P0002h8003GcLJJ
00000000>PB_0R`100000:Q@000100T000<G10001`0N0000000400000`4800D0000;0P0000050000
30:_0SX41@0000T2000000D000010_ooo`040000104=00@000020@800`0001h0100002L1ool30000
7P0400009`7oo`<0000N00D000010_ooo`0500002@800000100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F1;42?0Clooco100002L1ool300007P0500000@;oool01@0000T2000000L0
000F1;42?0Clooco70000?/2e_l00000002@0@0000000000@G9YHF`0000000000000000000000000
0000000000040000;@4000@000040@d0100000810@0N0000<PX400X03`000595DdU4ED5<84mEE51E
E00N01`0700<01h07P0L01L0300Q01h06P0L01h06P0L0000n`;Fo`00000009010@0000000011LVUQ
K0000000000000000000000000000000000000@0000]0@406000038:K`1W00/0001?HW=ULWIQM6U_
KU@Q01L05@0G00h05@0G00`02@0G01L07P00038:K`370@l0001@LVETJF=dIF@PD79YHfD0700>01L0
5`0901D0300G01L0300L00h02@0E01L05@00038:K`0m0`T0001BIG=YI7EQK7<P7P0G01D02@0G01L0
5`0901D0100002d100090000<PZS09410@0003495`0C0000<PZS04L22000034h>34d=Bh`5`0G01L0
5`0G01L0300G0100000b2Z<0/0<60000=SPe=Bh`5`0G01L05`0<01L02@00038:e`2A0@40000b2AL0
4`00038:e`170PP0000b<c8f>3D^<1L05`0G01L05`0G00`05`0C0000<P[G08/3200002db<SHh=Bh`
3P0G01L05`0G01L0300G00T0000b2P/1T@410000<`TG01<0000b2P/1A`880000<S0e>CHa;S0G01L0
5`0G01L05`0<01L04P00038:2`6I0`L0000a>C0c>Bh`<1L05`0G01L05`0<01L02@00038:?`6A0@40
000d2AL04`00038:?`570PP0000b<S<g=cL^<1L05`0G01L05`0G00`05`0B0000<PXo0IT31`00034f
<S8c;S0`5`0G01L05`0G00`05`090000<PYc0I410@0003D95`0C0000<PYc0DL22000038e>C@`>Bha
5`0G01L05`0G01L0300G0180000b2W<1V@<70000<CDe>C0^>C4G01L05`0G01L0300G00T0000b2ZL1
T@410000=PTG01<0000b2ZL1A`880000<SDd>CDe;S4G01L05`0G01L05`0<01L04P00038:Y`6I0`L0
000c<30d=2hi<AL05`0G01L05`0<01L02@00038:f`6A0@40000g2AL04`00038:f`570PP0000b<C@h
=ST^<1L05`0G01L05`0G00`05`0C0000<P[K0H/3200002db=3Pf>Bh`3P0G01L05`0G01L0300G00T0
000b2Pl2T@410000>0TG01<0000b2Pl2A`880000<S@c<cLd;SLG01L05`0G01L05`0<01L04P00038:
3`:R0`L0000]=3<g=2hg=`h05`0G01L05`0<01L02@00038:@`:A0@40000i2AL04`00038:@`970PP0
000b=c8g=c4^<AL05`0G01L05`0G00`05`0C0000<PY30X/3200002db<cLg<Bha3P0G01L05`0G01L0
300G01`0003k0Q001`000000_08000000@828U=iLgAUK@0000000000003dk1<00@000>@400000000
100002d10P0400009`7oo`<0000N00@0000]0@001@000042oooo00D000090P00000700005PBZ0SP4
M`8400@000040@d0100000810@0:0000<PYf0WX10P00034`5`0G01<0000b2WH2A`880000<CTg<3Dc
;S0G01L05`0G01L05`0<01L04`00038:MP:;0`P0000]<C8`=C<^<0h05`0G01L05`0G00`05`040000
;@4200@0000W0Ooo0`0001h0100002d1000500000@;oool01@0000T2000000L0000F1;42?0Clooco
100002d10P0400009`7oo`<0000N00@0000]0@001@000042oooo00D000090P00000700005PB^0ST4
000000L0003l0P0000000000100002d10`040000104=00@000020@80300004098@3`0000000000P0
=PAY008020000?X200000000000000@0000]0@@01@0001@2W`0200D0000C0Yl0>0@80000nP800000
00000000100002d11@0<0000@0TQ0?0000000000100f19l00P0<0000@0TQ0?0000000000200f1:P2
0P070000o0800000000000@0000]0@H010000?010`040000;@4200@0000W0Ooo0`0001h0100002d1
000500000@;oool01@0000T2000000L0000F1;42?0Clooco100002d10P040000l04000@0003`0@40
100002L1ool30000000000Q00@PT00006000004@`=/100000`00000000000000000001Y0040/0000
8000004000020000000000000000@8M40<0[A000003X0nP38@0000P0001R000030000040001;0000
40000000000500008@0000P0001R000030000040000A0000300000P0000:00004000000000000000
2@000100000j1000[`8000`0000@000000000000000;0000400003T4002^0P008@0000P0000U0000
300000L0080U000030000000080F000030000000000H000030000000000I000030000?ooo`0D0000
300000d0001B0000L0400080003>oooo0000000000000000T04000000007@00BE01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h0000000000000000000000000000000000000000000000000003P2Sl3
<93<0`00000000000000000000000000000000000007]/Qg000005L<8K@00040000@000000000000
000D0000000000000000000000000601000@00004P00000000000=3PH04NX`8`00000=3PH06aNAD`
000B08i60S3laa807<TB0?A2A`>8>1@0m4970`mID`?@2D03000000000000000034<D00a3500H@Q@0
648D000050000000m7l0000000010000000B0?ooogl100000000004000000000000000D00034DTL3
H30D06P`501TMP08000002D0000<00000P0000X0000@00000000000000090000400003X4002_0P00
600000`0000000006@0000`0003oool0500000`0000=00004P0000`0000200008@0000P0000R0000
30000?oooolQ000020000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N000060000?cooooloooo
?0@00;42000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
o?oooocoooll1000/@800580001`0@000`000=Koool0000000000000002@0@00000000L000110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
001U07<0801>06D0M`0P0580K`1]0640KP0000000000000000000000000000000000000000000000
00000>0:?`<`T<`300000000000000000000000000000000000000Nfb7L00000E``Q]0000@000100
00000000000001@0000000000000000000000000H0400100000B000000000000d>1P0AjS0S000000
d>1P0K5i5C0001800002<?c74P0LbA80m4970hPh503d@TL33eUC0m09@0<0000000000000000<@a@0
34<D01Q2500H@Q@0000D06Af00P000009@0000`000030000500000`0000=00004P0000`000010000
E0000:P0000:0000100009<1000b00000@00050e1d7HbPI12P0000@0000?0000C000000000000000
00000?ooooooooooK0000580A@1C04T0A01E0440C00P04l0E@1D0500E@1D0?l07P0001`0000L0000
300001h0000N0000700001L0000<00008@0001h0000J0000700001h0000J0000DP00070100040000
e_ooo`000000000000000901000100001`000440LP1Y0640K0000000000000000000000000000000
0000000000000000000000000000000000000000000000001kK8M`00001G326d0001000040000000
00000000500000000000000000000000001P0@004000018000000000003@h601DP1505<0B@1405D0
@@1<0200C`1E05@0D01E05@04P3d@TL3R3PD0?A2A`<?FE<3d0U00`004P000000/aKeMhP/7`1a5_Eg
>0PD08dFmGMF0OX5T2`O090/7`3@h6017Z<2<000003@h601/GTE<0004P00008`o<LB01c94P3d@TL3
R3PD0?A2A`<?FE<3d0U00`0000000000000000a3500<@a@0648D01Q2500001@0I7H02000000U0000
300000@0001D0000T00006L0001_0000A`4009h000010000D3D7@MS:1T5W0000K`0000/0001<0000
0000000000000000oooooooooomT0000C`1R07<0I@1b07H0H@1d06T0K`1^0?Qg8@0001L0000E0000
5`0000h0000E00005`0000`0000900005`0001L0001D0000Z0000<L1001_0000h@8009h000010000
D3D7@MS:1T770@00K`0000l0001<00000000000000000000oooooooooom/0000D01b06D0I01Y06<0
M01U06@0801@0780J@1S06D0000L00003P0001L0000G00002@0001D0000<00005`0001L0000<0000
700000h0000900005@0001L0001D0000Q00003`3001_0000l@<009h000010000D3D7@MS:1T4m0`00
K`0000T0001<00000000000000000000oooooooooomP0000DP1U07<0J@1T07D0H@1/07<0000N0000
5`0001D0000900005`0001L0000G00002@0001D0000U0000300000<0001D0000E0000941002S0000
Y`400=4000010000D3D7@MS:1T6A0@00X`000040001<00000000000000000000oooooooooom@0000
<@1X01L0001D0000O00004H2002S0000lP800=4000010000D3D7@MS:1T570P00X`0000P0001<0000
0000000000000000oooooooooomL0000<@0h03P0<@0d03D0;P0`01L0000G00005`0001L0000G0000
5`0000`0000G0000E0000700002_0`00X`0002d4003A00000@00050e1d7HbPI1/0<00:<000060000
C00000000000000000000?ooooooooooF00003H0>00e03D0;P0`01L0000G00005`0001L0000<0000
5`0005@0001D0000T@400=L0002W0@001@400040001@=@M1f<X6@I41003G00000@0004`000000000
00000000003ooooooooooe00000b00005`0005@0001l0000AP800=L0003b0P001@400040001@=@M1
f<X6@DL2003G0000200004`00000000000000000003ooooooooooe`0000b03<0<P0f03P0=@0^0300
5`0001L0000G00005`0001L0000G0000300001L0001D0000O00008X3003G0000;@@000D100010000
D3D7@MS:1T6;0`00e`0000P0001<00000000000000000000oooooooooomL0000;@0b0380=P0h03D0
;P0`00h0000G00005`0001L0000G00005`0000`0000G0000E00005@0002A0@002`400:L1000i0@00
0@00050e1d7HbPI1T@4000/100010000C00000000000000000000?ooooooooooD00003<0000G0000
E00007`000160P002`400?82000i0@000@00050e1d7HbPI1A`8000/100080000C000000000000000
00000?ooooooooooG0000380<00e03T0=P0a02h0<00G00005`0001L0000G00005`0001L0000<0000
5`0005@0001h0000V0<000/1000]1000>@400040001@=@M1f<X6@IT3000;0@001`0004`000000000
00000000003ooooooooooe`0000a03T0<00c03T0;P0`00005`0001L0000G00005`0001L0000<0000
5`0005@0001D0000T@4003l1002W0@00K@400040001@=@M1f<X6@I41000o0@000@0004`000000000
00000000003ooooooooooe00000d00005`0005@0001l0000AP8003l1003b0P00K@400040001@=@M1
f<X6@DL2000o0@00200004`00000000000000000003ooooooooooe`0000b0380<`0g03L0=`0^0300
5`0001L0000G00005`0001L0000G0000300001L0001D0000N00009P3000o0@00;@@006d100010000
D3D7@MS:1T6I0`00?`4000L0001<00000000000000000000oooooooooomL0000<@0f0380<P0c02h0
<00001L0000G00005`0001L0000G0000300001L0001D0000E0000941001b0@00Y`400:0100010000
D3D7@MS:1T6A0@00L`400040001<00000000000000000000oooooooooom@0000=@0001L0001D0000
O00004H2001b0@00lP800:0100010000D3D7@MS:1T570P00L`4000P0001<00000000000000000000
oooooooooomL0000<P0e03T0=00`03T0;P0a01L0000G00005`0001L0000G00005`0000`0000G0000
E00007P0002H0`00LP4002d4002P0@000@00050e1d7HbPI1V@<007<100070000C000000000000000
00000?ooooooooooG0000340=@0e03T0<00^03T0000G00005`0001L0000G00005`0000`0000G0000
E00005@0002A0@00YP400:L1003D0@000@00050e1d7HbPI1T@400:L100010000C000000000000000
00000?ooooooooooD00003H0000G0000E00007`000160P00YP400?82003D0@000@00050e1d7HbPI1
A`800:L100080000C00000000000000000000?ooooooooooG0000380=@0d03T0=@0e02h0<@0G0000
5`0001L0000G00005`0001L0000<00005`0005@0001h0000V0<00:H1000]1000e0400040001@=@M1
f<X6@IT3002W0@001`0004`00000000000000000003ooooooooooe`0000c0300<00d03@0;P0i0000
5`0001L0000G00005`0001L0000<00005`0005@0001D0000T@400=X1002W0@0020800040001@=@M1
f<X6@I41003K0@000@0004`00000000000000000003ooooooooooe00000g00005`0005@0001l0000
AP800=X1003b0P0020800040001@=@M1f<X6@DL2003K0@00200004`00000000000000000003ooooo
oooooe`0000b0340=00h03H0>@0^03005`0001L0000G00005`0001L0000G0000300001L0001D0000
O00008X3003J0@00;@@000P200010000D3D7@MS:1T6;0`00f`4000P0001<00000000000000000000
oooooooooomL0000;@0b03@0>00f03T0;P0`00h0000G00005`0001L0000G00005`0000`0000G0000
E00005@0002A0@003P800:L1000l0P000@00050e1d7HbPI1T@4000l200010000C000000000000000
00000?ooooooooooD00003P0000G0000E00007`000160P003P800?82000l0P000@00050e1d7HbPI1
A`8000l200080000C00000000000000000000?ooooooooooG0000380=00c03<0=`0d02h0=`0G0000
5`0001L0000G00005`0001L0000<00005`0005@0001h0000X@<000h2000]1000?0800040001@=@M1
f<X6@J83000?0P001`0004`00000000000000000003ooooooooooe`0000]03@0<`0g03@0;P0g0000
3P0001L0000G00005`0001L0000<00005`0005@0001D0000T@400482002W0@00L0800040001@=@M1
f<X6@I4100130P000@0004`00000000000000000003ooooooooooe00000i00005`0005@0001l0000
AP800482003b0P00L0800040001@=@M1f<X6@DL200130P00200004`00000000000000000003ooooo
oooooe`0000b03L0<P0g03L0<@0^03405`0001L0000G00005`0001L0000G0000300001L0001D0000
O00008X300120P00;@@0070200010000D3D7@MS:1T6;0`00@`8000P0001<00000000000000000000
oooooooooomL0000;@0b03<0=`0g0340;P0a00h0000G00005`0001L0000G00005`0000`0000G0000
DP00070100050000400000L00000000000000;`2000000001`828U<0N@1c07@0I@1]000000000000
00000000000000000000000000000000000000000000000000000000000005@0D01E05@04P3d@TL3
R3PD0?A2A`<?FE<3d0U00`004P000000/aKeMhP/7`1a5_Eg>0PD08dFmGMF0OX5T2`O090/7`3@h601
;@0b03<0=`0g0340;P0a07<0801@0780J@1S06D04P3d@TL3R3PD0?A2A`<?FE<3d0U00`004P000000
/aKeMg16aP=a5_EgN0LD08dFmGN01OX5N4K60gQ6aP?@h6017Z<2<000003@h601/GTE<0004P00008`
o<LB01c94P3d@TL3R3PD0?A2A`<?FE<3d0U00`0000000000000000a3500<@a@0648D01Q2500001@0
I7H02000000U0000300000D0000R000030000?oooolQ0000200002D0000<00000`0001T0000<0000
oooo01P0000<0000000001h0000H0000100007L2000h1000ZP8001@0000<00003@000180000<0000
0@0005@0001H0000NP4007H2002W0@00X`800040001@=@M1f<X6@GX1001f0P000P0004`000000000
00000000003ooooooooooe00000a03005`0001L0001D0000O00004H2001f0P00lP800:<200010000
D3D7@MS:1T570P00MP8000P0001<00000000000000000000oooooooooomL0000<@0i03L0<00e03<0
;P0`01L0000G00005`0001L0000G00005`0000`0000G0000E00007`0002:0`00MP8002d4002S0P00
0@00050e1d7HbPI1R`<007H200080000C00000000000000000000?ooooooooooG00002d0<@0b0300
=@0c02h0<00>00005`0001L0000G00005`0001L0000<00005`0002D0000<00001@000280000<0000
ooooob40000800009@0000`0000300006@0000`0003oool0600000`0000000007P0001P0003loooo
o?oooc`4002a0P009@0000`0000500008P0000`0003ooooo8@0000P0000U0000300000<0000I0000
30000?ooo`0H000030000000000N00006000000000000000>@@00:h2000W0000600000H000000000
00000000000U0000300000H0000D0000300000d0000B000030000080001<0000I0000080001Y0000
=P@0070000020000J@0003H4000800008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009P0001`0000700000000000000000000000002D0000<0000
1`0001/0000@00000P0009l0000f0000400003P4002O00009P0001`0000800000000000000000000
000002D0000<0000200004`0001T00000P0009l0000f1000XP000080002O0000=P@000@0000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000001<0000
I0000080002W0P00=P@00:`200020000Z08003H4000800008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009`0001P0000900000000000000000000
9@0000`000090000:00000`0000600009@0000`0000500008P0000`0003ooooo8@0000P0000U0000
300000<0000I000030000?ooo`0H000030000000000N000060000?cooooloooo?0@00;42000U0000
300000D0000X0000300000<0000X0000300000@0000R000030000?oooolU0000300000L0080U0000
30000000080`0000300000l0080U000030000040001;00004000000000050000:00000`000050000
:00000`000070000:00000`000080000:00000`0000900009@0000`0000000209@0000`000070020
8P0000`0003ooooo9@0000`0000=0020:00000`0000200008P0000`0003ooooo8P0000`0003ooooo
AP0003P0000/0000ADe6:bI0000@000010000000000Q@0L0300000000004@0003000000000160000
500000P00017A4U30`000280000<0000oooooe@0001D000000000000003oooooooooo`40001EE@M1
9_d6@CT4002^0P000@0004`00004000000000000000g1000[P800500000P00005P0002D0000<0000
3P00P4H0000d0000:00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080Q0000
20000680000<00000@0004`0001T000000000000000h1000[@80000000000000>@@00:h2000Y0:X0
000000000000080o000000000000080o0000000000000000000000000000000000000000000R0000
30000?oooom60000700001000015CDH[0T0000`0000000003P0001@000000000400001@0
\>"], "Graphics",
 PageWidth->PaperWidth,
 ImageSize->{236.625, 149.875},
 ImageMargins->{{151, 0}, {0, 0}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will also perform the above as part of diagnostics and analysis for lmf"
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5158106024180975`*^9, 3.5158106155850973`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"resids", "=", 
  RowBox[{
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"houses", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], "[", 
   "\"\<FitResiduals\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.497045990203125*^9, 3.4970460020625*^9}, 
   3.497046061484375*^9, {3.5158107809280977`*^9, 3.5158107834320974`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6855.043316831754`", ",", 
   RowBox[{"-", "22685.04685289954`"}], ",", "19039.00724893922`", ",", 
   "16222.971181046712`", ",", "15590.89904526167`", ",", 
   "30044.908062234812`", ",", 
   RowBox[{"-", "24869.010785007034`"}], ",", 
   RowBox[{"-", "4374.66849363505`"}], ",", 
   RowBox[{"-", "23771.128005657694`"}], ",", 
   RowBox[{"-", "12052.974717114499`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.49704600309375*^9, 3.49704606234375*^9, 
  3.5158107157200975`*^9, 3.5158107868840976`*^9}]
}, Open  ]],

Cell[TextData[{
 "The values predicted by the model, our estimated house values ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    StyleBox["Y",
     FontWeight->"Bold"], "^"], TraditionalForm]]],
 ", are the product of the vector of independent variables and the vector of \
parameters, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     OverscriptBox[
      StyleBox["Y",
       FontWeight->"Bold"], "^"],
     TraditionalForm], "=", 
    RowBox[{
     OverscriptBox[
      StyleBox["X",
       FontWeight->"Bold"], "^"], " ", 
     OverscriptBox["\[Theta]", "^"]}]}], TraditionalForm]]]
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  OverscriptBox["Y", "^"], "=", 
  RowBox[{"X", ".", 
   OverscriptBox["\[Theta]", "^"]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"188144.9566831683`"},
     {"232685.04685289957`"},
     {"205960.9927510608`"},
     {"223777.02881895332`"},
     {"259409.10095473833`"},
     {"254955.0919377652`"},
     {"214869.01078500706`"},
     {"243374.66849363508`"},
     {"272771.1280056577`"},
     {"197052.97471711456`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045605046875*^9, 3.497046091375*^9, 
  3.5158107306370974`*^9}],

Cell[TextData[{
 StyleBox["Our model is expected to differ from reality. The regression \
residuals, the error terms, are the result of subtracting the predicted \
values ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    OverscriptBox[
     StyleBox["Y",
      FontWeight->"Bold"], "^"], ")"}], TraditionalForm]]],
 StyleBox[" from the actual (",
  FontColor->GrayLevel[0]],
 StyleBox["Y",
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox[") values.",
  FontColor->GrayLevel[0]]
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "The equation for the error terms is \[Epsilon] = ",
 StyleBox["Y",
  FontWeight->"Bold"],
 " - ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    StyleBox["Y",
     FontWeight->"Bold"], "^"], TraditionalForm]]],
 " = ",
 StyleBox["Y",
  FontWeight->"Bold"],
 " - ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["X",
     FontWeight->"Bold"], " ", 
    OverscriptBox["\[Theta]", "^"]}], TraditionalForm]]],
 " "
}], "MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{"\[Epsilon]", "=", 
  RowBox[{"Y", "-", 
   RowBox[{"X", ".", 
    OverscriptBox["\[Theta]", "^"]}]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"6855.043316831696`"},
     {
      RowBox[{"-", "22685.04685289957`"}]},
     {"19039.00724893919`"},
     {"16222.971181046683`"},
     {"15590.89904526167`"},
     {"30044.908062234812`"},
     {
      RowBox[{"-", "24869.010785007064`"}]},
     {
      RowBox[{"-", "4374.668493635079`"}]},
     {
      RowBox[{"-", "23771.128005657694`"}]},
     {
      RowBox[{"-", "12052.974717114557`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045605140625*^9, 3.4970461035*^9, 
  3.515810750933098*^9, 3.5158108061260977`*^9, 3.5158108433570976`*^9}],

Cell["\<\
Notice these are the same as the residuals\
\>", "Text",
 CellChangeTimes->{{3.5158108562450976`*^9, 3.5158108695070972`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"resids", "-", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.515810808129098*^9, 3.515810831117098*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0"},
     {"0"},
     {"0"},
     {"0"},
     {"0"},
     {"0"},
     {"0"},
     {"0"},
     {"0"},
     {"0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5158108142550974`*^9, 3.5158108481600976`*^9}]
}, Open  ]],

Cell["Analysis of Variance", "Subsection",
 PageWidth->PaperWidth],

Cell["\<\
From Table 6-7 of Chapter 6 we reproduce for reference the analysis of \
variance table.\
\>", "Text",
 PageWidth->PaperWidth],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@00029/0@0006`000000000000000L7003g0000
00000000001i>`00=0P00215CDH00040K2800;80000:00000000000000000000H0T004D<003;0000
2@4000000000000000000?PH0`0X2`@0AP0002`0000P0000ADe6:`500@0L00004000004@`=/00000
;04002`100160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001H0000<0000600000X0000@0000
0000000000090000400000H7003h00009@0000`0000>00204P0000`000010000600000`000000002
DP00070100010000c_ooo`0000000000000009010000000014004U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^0000000000000000000000000000000000000000000000000:000@0006bX0C20<1@0
<3<D0040002/ia806:LJ02A4500XA1@0000000D0001Lj180000005CR4P2`@A@0a[l4<80`502`@A@0
000000000034DTL3H30D00000000Ib00I>PB07Rl132<09`0a5970`0000000000a5970`000S3E_@@`
8>DB060`500TgIT`h=bI<:RR6P1h0A@000000:RR6P2dhQ80E27eMoooooooo`60ool000l00H000?oo
0000000800002000AaJ@0@000P860`D41@8318Mj0200002020000000003o0@00000005@0J@1]06D0
I7H02000000U000030000040000Q0000200001h0000H00000000000000061`00n00004H0000X0000
700004M4BD<20000ooooooooool91`00n@00000000160000d0L00<@70015CDH[:T0002@0000H0000
0020?`00000000000020?`00000000008D0500`0000000009D00010000040000000002a0000T0000
600006IViSl000200000P=kMOCh000200000P0Q000D<1`0000L0004@`=/200000P000=P6003GcLJJ
00000000Y`L?0B`1000009E@000100T000=/0`001`0L0000000400000`4800D0000;0P0000050000
308?0JL71@0000T2000000D000010_ooo`040000104=00@000020@800`0001h0100002L1ool30000
7P0400009`7oo`<0000N00D000010_ooo`0500002@800000100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F1141Z@Olooco100002L1ool300007P0500000@;oool01@0000T2000000L0
000F1141Z@Olooco70000?/2e_l00000002@0@0000000000@G9YHF`0000000000000000000000000
0000000000040000;@4001`0003k0Q001`000000_08000000@828U=iLgAUK@0000000040003dk1<0
0@00010b5@000000100002d10@0400009`7oo`<0000N00@0000]0@001@000042oooo00D000090P00
000700005P@g0:D7100400@000040@d0100000810@0?0000<PX300X01@00045>CeI1MA`07P0Q01`0
70040000;@4100@0000W0Ooo0`0001h0100002d1000500000@;oool01@0000T2000000L0000F1141
Z@Olooco70000?/2e_l00000002@0@4000000000@G9YHF`000000000000000000000000000000000
00040000;@4200@000040@d0100000810@0:0000<PXk04<20P0006AV5`0<00X0000b2S/0O0<20000
De<L01`02P00038:>`2V1080001=Db<070090000<PXk0=<50@0004KB6P0L0000<PXk08<63P0005=Y
IfiYIVUSHFiSIB16700901L05`0900`02@0E01L05`0E01L0300J00@0000]0@005P00038:K`0:00X0
001BIFMbIG=cJFm^7P0G01L03P0G01@0500:01L05`090000<PY_0=d20@00037B5`0F0000<PY_04T3
2P0003La>34a<3Tf=CPG01L05`0G01L05`0G01L05`0G01H0000b2Vl0JP@:0000=c4h<C4`>CHe>1L0
5`0G01L05`0G01L05`0G01L05P00038:K`291@X0000a=Bhf<3Hi<3Li5`0G00`05`0G01L05`0G01L0
5`0H0000<PY_0:X62`00030^<30d<S<b=c0d01L0300G01L05`0G01L05`0G01L05`0C0000<PZS00X0
2000059ULfUTMF5/7P0G01@02P0G01L05`0:00T0000b2Z<0g@810000>=8G01H0000b2Z<0B@<:0000
<cHh<3Ti<3<d<QL05`0G01L05`0G01L05`0G01L06000038:X`1N10/0000d=S0a<S<g>C8^>00G01L0
5`0G01L05`0G01L05`0<01L0100002d10@0400009`7oo`<0000N00@0000]0@001@000042oooo00D0
00090P00000700005P@:0JD7e`0400@000040@d0100000810@0?0000<P[F00X01@0005A_M65/MAX0
5`0<01L02P090000<P[F0=d20@0003WB5`0H0000<P[F03832`00034`>3Hb<C0`<30`01L05`0G01L0
5`0G01L05`0G01L05`040000;@4100@0000W0Ooo0`0001h0100002d1000500000@;oool01@0000T2
000000L0000F1141Z@Olooco100002d10@0400009`7oo`<0000N00@0000]0@001@000042oooo00D0
00090P00000700005P@>0JH7000000L0003l0P0000000000100002d10`040000104=00@000020@80
300004098@3`0000000000P0X`Le008020000?X200000000000000@0000]0@@01@0001@2J`0200D0
000C0V/0Y@L80000nP80000000000000100002d11@0<0000@0TQ0?0000000000102S1f/00P0<0000
@0TQ0?0000000000202S1`P10P070000o0800000000000@0000]0@H010000?010`040000;@4100@0
000W0Ooo0`0001h0100002d1000500000@;oool01@0000T2000000L0000F1141Z@Olooco100002d1
0@040000l04000@0003`0@80100002L1ool300000008@048900001P000014<3K0@0000<000000000
00000000000J@010;0000200000100000P000000000000000>3dA020Qd<00000j0?X0b4000080000
HP0000`000010000B`000100000000001@00024000080000HP0000`0000100004@0000`000080000
2P00010000000000000000T0000@0000Y`L000l1000<000040000000000000002`00010000081`00
n0000240000800009@0000`0000700209@0000`0000000205P0000`000000000600000`000000000
6@0000`0003oool0500000`0000=0000DP00070100020000c_ooo`00000000000000090100000000
1d004U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^000000000000000000000000000000000000
0000000000000000h0Xo0c2@c0<00000000000000000000000000000000000001kK8M`00003]4b4j
000100004000000000000000500000000000000000000000001P0@004000018000000000003@h601
7Z<2<000003@h601/GTE<0004P2>AP8`o<LB01c94P1d6106R3PD07@H40K1:4P3d0U00`0000000000
000000a3500<@a@0648D01Q2500001@000000?Ao000000000@0000004P3ooomo0@00000000010000
0000000000050000Y;Y70f0`501X<1@0I7H02000000U000030000080000:00004000000000000000
2@000100002W1`003`4001P0000<0000000001T0000<0000oooo01@0000<00003@000180000<0000
0P000240000800008P0000`0003ooooo8@0000P0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<000000000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0003looooo?ooojT7000A0@008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N000060000?coooolooooZ@L00141001B0000L04000<0003Foooo0000000000000000
T040000000070000@@1b06T0H@1/0000000000000000000000000000000000000000000000000000
000000000000000000000000I@1c0200CP1U07L0801B06l0K@1Q06h0000000000000000000000000
000000000000000000000000003P2Sl3<93<0`00000000000000000000000000000000000007]/Qg
00000>dC8CX00040000@000000000000000D0000000000000000000000000601000@00004P000000
00000=3PH04NX`8`00000=3PH06aNAD`000B00000S3laa807<TB07@H40J8>1@0M1P@1/4XB0?@2D03
000000000000000034<D00a3500H@Q@0648D0000501TMP08000002D0000<00000`000580001`0@00
100001000007000000000000002l0P00000000L20R9C07T0L`1d06D0K@0000000000000000000000
000000000000000000000000000000000000000000000000000000Nfb7L00000kA<Q>P000@000100
00000000000001@0000000000000000000000000H0400100000B000000000000d>1P0AjS0S000000
d>1P0K5i5C0001800002<?c74P0LbA80M1P@1XPh501d6106`BQ80m09@0<0000000000000000<@a@0
34<D01Q2500H@Q@0000D06Af00P00000d>1P0AjS0S000000d>1P0K5i5C0001800002<?c74P0LbA80
M1P@1XPh501d6106`BQ80m09@0<0000000000000000<@a@034<D01Q2500H@Q@0000D06Af00P00000
9@0000`0000400008P0000`0003ooooo8@0000P0000U0000300000<0000I000030000?ooo`0H0000
30000000000N0000600000@000040000Y@L003L0000D0000300000d0000B000030000040001D0000
K00000T000040000T00002d000010000a;;h@84@md0:00000`0000D0001<00000000000000000000
oooooooooomH0000@@1>04l0EP110800700001h0000Q0000700001`0000U0000300000@0000R0000
30000?oooolQ0000200002D0000<00000`0001T0000<0000oooo01P0000<0000000001h0000H0000
o?oooocooonY1`004@400580001`0@001@000=Koool0000000000000002@0@000@0000L000110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
0002<?c74P0LbA80M1P@1XPh501d6106`BQ80m09@0<0000000000000000<@a@034<D01Q2500H@Q@0
000D06Af00P00000d>1P0D40CP1?05H0@@1P0K5i5C0001800002<?c74P0LbA80M1P@1XPh501d6106
`BQ80m09@0<0018000000;<FmGM@BR<0LAKeMdP7502=5_Ega07k1EQ:8`1HBR<0d>1P0AjS0S000000
d>1P0K5i5C0001800002<?c74P0LbA80^Ao7MkTOagO4l?eo0>3mO`000000000000000000002M:lMg
0P000=dG1:kM5`00R2[7MfAf00P000009@0000`000050000500000`0000=00004P0000`000010000
E00005P0000D0P00=P0003P2001Q00000@000<Bbn4214?M0@`8003/000020000C000000000000000
00000?ooooooooooD00006@0IP0G0000300005@0001H0000=0<003H0001W0`00H@0000400034/_Q0
PA3g@7`3000k00000P0004`00000000000000000003ooooooooooe00001C05<0700001`0001D0000
F00004D4000f0000OP@0064000010000a;;h@84@md2V1000>`000080001<00000000000000000000
oooooooooom@0000C@1C02<0000L0000E00005@0001J1@00=P000785001Q00000@000<Bbn4214?M0
d`D003/000010000C00000000000000000000?ooooooooooD00004H0N00J0000E0000:00003l1@00
=P000>d6001Q00000@000<Bbn4214?M0P`H003/0000>0000C00000000000000000000?oooooooooo
J00005<0J@1W06h0J@1V06T0H`1Q06h0H`1U0200AP0L00002@0001L0000G00002@0000`000090000
5@0001L0000G00005@0001L0000<00006P0002D0000<00000`0005@0002800002@0006H000390000
T00000400034/_Q0PA3g@0X0001_00002P0004`00000000000000000003oooooooooof00001B06D0
I`1b06D0L`1c06T0K`1^01h0000G00005`0000h0000G0000500001@0000:00005`0001L0001D0000
E0000:82001V0000]`80090000010000a;;h@84@md3M0P00K`000040001<00000000000000000000
oooooooooom@0000<@0001L0001D0000R00000D3001V0000f0<0090000010000a;;h@84@md190`00
K`0000X0001<00000000000000000000oooooooooomP0000=`0a03P0<@0a0300>@0f03D0>00G0000
5`0001L0000G00005`0001L0000G00005`0001L0000G0000E00008P0000>1000IP000>44002@0000
0@000<Bbn4214?M0JP@006l0000:0000C00000000000000000000?ooooooooooH00003L0<@0h0340
<@0`03T0=P0e03P05`0001L0000G00005`0001L0000G00005`0001L0000G00005`0005@000280000
5PD006H0003O1@00T00000400034/_Q0PA3g@8T5001_00002P0004`00000000000000000003ooooo
ooooof00000a03D0;P0f0300=P0i0300=`0i01L0000G0000300001L0000G00005`0001L0000G0000
5`0001L0001D0000T0000206001V0000oPH0090000010000a;;h@84@md2Z1P00K`0000/0001<0000
0000000000000000oooooooooomT0000<00^0300<00d0380<`0b03L0<00d00005`0000`0000G0000
5`0001L0000G00005`0001L0000G00005`0001L0001D0000O00000T0002E0000W@000;l000010000
a;;h@84@md0:0000X`0000P0001<00000000000000000000oooooooooomL0000DP1U07<0J@1T07D0
H@1/01h0000G0000500000X0000G00005`0001L0000:0000E00005@0002R0P00U@000;L2002o0000
0@000<Bbn4214?M0g@800:<000010000C00000000000000000000?ooooooooooD00003P0000G0000
E00008P000050`00U@000=P3002o00000@000<Bbn4214?M0B@<00:<0000:0000C000000000000000
00000?ooooooooooH00003<0=P0h0300>@0i0300<`0d03805`0001L0000G00005`0001L0000G0000
5`0001L0000G00005`0005@0002@00000`@009D0003Q1000_`0000400034/_Q0PA3g@5h4002S0000
2`0004`00000000000000000003oooooooooof@0000d03H0<00a0380<`0g03T0<P0^03P0000G0000
5`0001L0000G00005`0001L0000G00005`0001L0000<00005`0002D0000<000010000280000<0000
ooooob40000800009@0000`0000300006@0000`0003oool0600000`0000000007P0001P000040000
e`000:D7000:0@00500000`0000=00004P0000`000010000E00006`000090000a@0005l0003^0000
0@000<Bbn4214?M02P000=H000050000C00000000000000000000?ooooooooooF00005@0K`1d0640
K00001X0000G0000300001L0000:0000E00005@0002R0P00a@000;L2003^00000@000<Bbn4214?M0
g@800=H000010000C00000000000000000000?ooooooooooD00003T0=@0G0000E0000900003`0P00
a@000=P3003^00000@000<Bbn4214?M0<P<00=H0000;0000C00000000000000000000?oooooooooo
I0000340<00h03H0<P0a0300<00`0300<00001L0000G00005`0001L0000G00005`0001L0000G0000
5`0001L0000G00009@0000`0000400008P0000`0003ooooo8@0000P0000U0000300000<0000I0000
30000?ooo`0H000030000000000N000060000?coooolooooZ@L00141000U0000300000@0000R0000
30000?oooolQ0000200002D0000<00000`0001T0000<0000oooo01P0000<0000000001h0000H0000
00000000002V1`003P4002L0000H00001P00000000000000000002D0000<00001P0001@0000<0000
3@000180000<00000P0004`0001T00000P00034000051`00=`000080000e0000X`L000P0000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000V0000
700000L00000000000000000000000009@0000`0000700006`00010000020000J`0003H0000@0000
Y@L006/0000V0000700000P00000000000000000000000009@0000`000080000C00006@000020000
HP0000D7001U00000P0006/0002S1`0010000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000004`0001T00000P000?8000051`00mP00008000080@00
X`L000P0000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000W0000600000T00000000000000000000U0000300000T0000X0000300000H0000U0000
300000@0000R000030000?oooolQ0000200002D0000<00000`0001T0000<0000oooo01P0000<0000
000001h0000H0000o?oooocooonY1`004@4002D0000<0000100002P0000<00000`0002P0000<0000
1@000280000<0000ooooobD0000<00001`00P2D0000<00000000P300000<00003`00P2D0000<0000
0@0004/0000@0000000000D0000X0000300000@0000X0000300000L0000X0000300000P0000X0000
300000T0000U000030000000080U0000300000L0080R000030000?oooolU0000300000d0080X0000
30000080000R000030000?oooolR000030000?oooom60000>00002`00015CDH[9T00010000040000
000002501`0<0000000000A0000<0000000004H0000D0000200004M4BD<300008P0000`0003ooooo
E00005@00000000000000?oooooooooo0@0005EE1d4Vo@I120L00?P000010000C00000@000000000
000000H7003h0000D0000200800F00009@0000`0000>0020AP0003@0000X0000ADe6:bY0000T0000
60000000P3l000200000P000P3l000200000P24000080000HP0000`000010000C00006@000000000
000000L7003g00000000000000081`00n00002T0ZP00000000000000P3l0000000000000P3l00000
0000000000000000000000000000000000000280000<0000ooooodH0000L0000400004E=AR/2@000
30000000000>000050000000000@00005000
\>"], "Graphics",
 PageWidth->PaperWidth,
 ImageSize->{372.063, 50.875},
 ImageMargins->{{86, 0}, {0, 0}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will produce the same ANOVA table, parts of which will will derive \
individually below."
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"houses", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], "[", 
  "\"\<ANOVATable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.497045990203125*^9, 3.4970460020625*^9}, 
   3.497046061484375*^9, {3.497046127671875*^9, 3.4970461298125*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"x", "1", "7.181109657885433`*^9", "7.181109657885433`*^9", 
      "15.60690790350773`", "0.004232703717357788`"},
     {"\<\"Error\"\>", "8", "3.6809903421145673`*^9", "4.601237927643209`*^8",
       "", ""},
     {"\<\"Total\"\>", "9", "1.08621`*^10", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.4970461305*^9, 3.5158108898640976`*^9}]
}, Open  ]],

Cell[TextData[{
 "We need a vector, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    StyleBox["Y",
     FontWeight->"Bold"], "_"], TraditionalForm]]],
 " in which each element is the mean of ",
 StyleBox["Y",
  FontWeight->"Bold"]
}], "Text",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["Y", "_"], "=", 
   RowBox[{
    SubscriptBox["\[Mu]", "Y"], "*", 
    RowBox[{"Table", "[", 
     RowBox[{"i", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1"}], "}"}]}], "]"}]}]}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[TextData[{
 "The sum of the squares of the regression (known both as SSR and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["b", "2"], 
    SubscriptBox["S", "xx"]}], TraditionalForm]]],
 ") is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       OverscriptBox["Y", "^"], "-", 
       OverscriptBox["Y", "_"]}], ")"}], "T"], 
    RowBox[{"(", 
     RowBox[{
      OverscriptBox["Y", "^"], "-", 
      OverscriptBox["Y", "_"]}], ")"}]}], TraditionalForm]]],
 "."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{"SSR", "=", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{
     OverscriptBox["Y", "^"], "-", 
     OverscriptBox["Y", "_"]}], "]"}], ".", 
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["Y", "^"], "-", 
     OverscriptBox["Y", "_"]}], ")"}]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"7.181109657885431`*^9"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045607453125*^9, 3.497046148234375*^9, 
  3.5158109130740976`*^9}],

Cell[TextData[{
 "The Sum of the Squared Errors (SSE aka ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalSigma]", "[", 
    SuperscriptBox[
     SubscriptBox["\[Epsilon]", "i"], "2"], "]"}], TraditionalForm]]],
 ")"
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{"SSE", "=", 
  RowBox[{
   RowBox[{"Transpose", "[", "\[Epsilon]", "]"}], ".", 
   "\[Epsilon]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"3.6809903421145687`*^9"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4970456075625*^9, 3.497046154078125*^9, 
  3.515810925315098*^9}],

Cell[TextData[{
 "The total sum of squares (known either as SST or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "yy"], TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"\[CapitalSigma]", "(", 
     RowBox[{
      SubscriptBox["y", "i"], "-", 
      OverscriptBox["y", "^"]}], ")"}], "2"], TraditionalForm]]],
 ") is the dot product ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Y", "-", 
       OverscriptBox["Y", "_"]}], ")"}], "T"], 
    RowBox[{"(", 
     RowBox[{"Y", "-", 
      OverscriptBox["Y", "_"]}], ")"}]}], TraditionalForm]]],
 "."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{"SST", "=", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Y", "-", 
     OverscriptBox["Y", "_"]}], "]"}], ".", 
   RowBox[{"(", 
    RowBox[{"Y", "-", 
     OverscriptBox["Y", "_"]}], ")"}]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"10862100000"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045607671875*^9, 3.49704615884375*^9, 
  3.5158109306120977`*^9}],

Cell["\<\
The Mean Square of the Regression (MSR) is the Sum of Squares of the \
Regression (SSR) divided by the degrees of freedom for the regression (k-1).\
\>", "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"MSR", "=", 
  RowBox[{"SSR", "/", 
   RowBox[{"(", 
    RowBox[{"k", "-", "1"}], ")"}]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"7.181109657885431`*^9"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045607765625*^9, 3.49704616190625*^9, 
  3.515810946695098*^9}],

Cell["\<\
The Mean Square of the Error terms (MSE) is the Sum of the Squared Errors \
divided by the degrees of freedom for the errors.\
\>", "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"MSE", "=", 
  RowBox[{"SSE", "/", 
   RowBox[{"(", 
    RowBox[{"n", "-", "k"}], ")"}]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"4.601237927643211`*^8"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045607875*^9, 3.497046169875*^9, 
  3.5158109579500976`*^9}],

Cell["\<\
The F-test for model utility (F-statistic) is the result of dividing the MSR \
by the MSE\
\>", "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"F", "=", 
  RowBox[{"MSR", "/", "MSE"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"15.60690790350772`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045607984375*^9, 3.497046179421875*^9, 
  3.5158109632740974`*^9}],

Cell["The Parameter Table", "Subsection",
 PageWidth->PaperWidth],

Cell["\<\
From Table 6-7 of Chapter 6 we reproduce for reference the parameter table of \
the regression output. This provides, in addition to paramater estimates, the \
standard errors, t-statistics and p values for each estimate.\
\>", "Text",
 PageWidth->PaperWidth],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001o<0@0006`000000000000006d6002R0000
00000000001S=P00HPD00215CDH00040c1l009`0000:00000000000000000000H0T004D<003;0000
2@4000000000000000000?PH0`0X2`@0AP0002`0000P0000ADe6:`500@0L00004000004@`=/00000
;04002`100160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001H0000<0000600000X0000@0000
0000000000090000400006d6002S00009@0000`0000>00204P0000`000010000600000`000000002
DP00070100010000c_ooo`0000000000000009010000000014004U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^0000000000000000000000000000000000000000000000000:000@0006bX0C20<1@0
<3<D0040002/ia806:LJ02A4500XA1@0000000D0001Lj180000005CR4P2`@A@0a[l4<80`502`@A@0
000000000034DTL3H30D00000000Ib00I>PB07Rl132<09`0a5970`0000000000a5970`000S3E_@@`
8>DB060`500TgIT`h=bI<:RR6P1h0A@000000:RR6P2dhQ80E27eMoooooooo`60ool000l00H000?oo
0000000800002000AaJ@0@000P860`D41@8318Mj0200002020000000003o0@00000005@0J@1]06D0
I7H02000000U000030000040000Q0000200001h0000H000000000000001]1P00X`0004H0000X0000
700004M4BD<20000oooooooooom_1P00Y00000000016000090L001P70015CDH[:T0002@0000H0000
0020?`00000000000020?`00000000008D0500`0000000009D00010000040000000002a0000T0000
600007fadSl000200000P:3C9Sh000200000P0Q000EP1P00E0H0004@`=/200000P0002`6003GcLJJ
00000000K`JT02`100000?I@000100T000<F0`001`0L0000000400000`4800D0000;0P0000050000
30:T06l61@0000T2000000D000010_ooo`040000104=00@000020@800`0001h0100002L1ool30000
7P0400009`7oo`<0000N00D000010_ooo`0500002@800000100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F1:H0L@Klooco100002L1ool300007P0500000@;oool01@0000T2000000L0
000F1:H0L@Klooco70000?/2e_l00000002@0@4000000000@G9YHF`0000000000000000000000000
0000000000040000;@4000@000040@d0100000810@0I0000<PX40>L1300004=_IFIVJF=YIFidLah0
5`0G00`0300901D02@0G01L0300E01`0000b2P@03`<>0000DgAQKVAQLV@PAG9bKg8L00`05`0G01L0
5`0>01L0300L00h03P0G00h04000038:102D10H0001d85=dHG@<00`0700<01L0300B0000<PX409X5
1`00050]MV5/MFD3700>01D05`0901L05`0L0000n`;Fo`0000000901000000000011LVUQK0000000
000000000000000000000000000000@0000]0@405@00038:>00:00T00019KWAULV=UL7A5300G00`0
5`0>01D05`0G00`06@00038:>03d0@`0000]=cT`>CD^=CPd<c@>01L05`0G01L05`0<01L05`0G01L0
5`0H0000<PXh03d32`0003Lh<cDg;STf<C4a=1L05`0G01L05`0<01L05`0G01L05`0I0000<PXh0504
300002da;S0`>C@a<cD`=`h05`0<01L05`0G01L05`0G01L05`0G01P0000b2SP0LPD;0000<2hc=38c
<SPd>C4g5`0<01L05`0G01L05`0G01L05`0G01`0003k0Q001`000000_08000000@828U=iLgAUK@00
00000000003dk1<00P000>@400000000100002d10P0400009`7oo`<0000N00@0000]0@401@000042
oooo00D000090P00000700005PBO06d6K00400@000040@d0100000810@0=0000<PY[00X0100005=Y
NVDL00X05@0G01P0000b2V/00P8;0000<CLh;S4f<3<f<3Lg5`0G01L0300G01L05`0G01L05`0G01P0
000b2V/0?@<;0000=3D^<3Tg=C4h>C8g5`0G00`05`0G01L05`0G01L05`0G01P0000b2V/0GP@;0000
<bhi=C0e=CLi<S<g5`0<01L05`0G01L05`0G01L05`0G01P0000b2V/0LPD;0000<2h`<3@b<c8g<3@g
5`0<01L05`0G01L05`0G01L05`0G00@0000]0@80100002L1ool300007P040000;@4100D000010_oo
o`0500002@8000001`0001H4YP1a1_coo?l40000;@4200@0000W0Ooo0`0001h0100002d10@050000
0@;oool01@0000T2000000L0000F1:<0KPH000001`000?`20000000000040000;@4300@000040@d0
100000810P0<0000@0TQ0?0000000000201[1_ko0P080000nP80000000000000100002d110050000
508d00801@0001<2=01]1PP0003j0P000000000000040000;@4500`000102B40l0000000000406/6
=00200`000102B40l0000000000806/6W@0200L0003l0P0000000000100002d11P040000l04300@0
000]0@80100002L1ool300007P040000;@4100D000010_ooo`0500002@8000001`0001H4YP1a1_co
o?l40000;@4200@0003`0@4010000?01000400009`7oo`<0000000Q00@PT00006000004@`=/10000
0`00000000000000000001Y0040/00008000004000020000000000000000h<e4000T@`00003X0nP3
8@0000P0001R000030000040001;000040000000000500008@0000P0001R000030000040000A0000
300000P0000:000040000000000000002@000100001_1P00Y00000`0000@000000000000000;0000
400006h6002S00008@0000P0000U0000300000L0080U000030000000080F000030000000000H0000
30000000000I000030000?ooo`0D0000300000d0001B0000L0400080003>oooo0000000000000000
T04000000007@00BE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0000000000000000000000000
000000000000000000000000002`3;/1<93<0`00000000000000000000000000000000000007]/Qg
000009h>8Hl00040000@000000000000000D0000000000000000000000000601000@00004P000000
00000=3PH04NX`8`00000=3PH06aNAD`000B08i60S3laa807<TB0=@_40J8>1@0e2l@1R=dQ@?@2D03
000000000000000034<D00a3500H@Q@0648D000050000000m7l0000000010000000B0?ooogl10000
0000004000000000000000D0001`>a06H30D06P`501TMP08000002D0000<00000P0000X0000@0000
0000000000090000400006l6002T0000600000`0000000006@0000`0003oool0500000`0000=0000
4P0000`0000200008@0000P0000R000030000?oooolQ000020000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N000060000?coooolooooL@H00:H0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H0000o?oooocoooma1P00YP000580001`0@000`000=Koool00000
00000000002@0@000@0000L000110780J@1Q06`00000000000000000000000000000000000000000
00000000000000000000000000000000001U07<0801>06D0M`0P0580K`1]0640KP00000000000000
0000000000000000000000000000000000000;0<^`4`T<`300000000000000000000000000000000
000000Nfb7L00000WPhQS`000@00010000000000000001@0000000000000000000000000H0400100
000B000000000000d>1P0AjS0S000000d>1P0K5i5C0001800002<?c74P0LbA80e2l@1XPh503D;a06
8gB50m09@0<0000000000000000<@a@034<D01Q2500H@Q@0000D06Af00P000009@0000`000030000
500000`0000=00004P0000`000010000E00009@0003W0@0010000<02000c00000@0004a01d5^:PI1
i`4000@0000<0000C00000000000000000000?ooooooooooI00004<0K`1U06H0IP1Y06<0J@1U06h0
M01c01h0000G00005`0000`0000<00002@0001D0000900005`0001L0000<00005@0005@0002P0000
3`<000@0000S1000<`000040001<@0M1KRX6@@l3000400003P0004`00000000000000000003ooooo
ooooofP0001C07@0H@1^06@0H@1b06@080150780LP1_0780700000`0000G00005`0001L0000G0000
3P0001L0000<0000700000h0000>00005`0000h0001D0000L00009<400040000m`@003<000010000
C407@FhZ1T6D1000100000H0001<00000000000000000000oooooooooomH0000M00P05<0M01Q07@0
300000`0000L0000300001L0000<0000E00007P0002I1@00100002D6000c00000@0004a01d5^:PI1
VPD000@000070000C00000000000000000000?ooooooooooG0000500;@1f0640K01e06D0P00L0000
3P0001D0000G00002@0001L0000G0000DP00070100040000e_ooo`00000000000000090100000000
1`000440LP1Y0640K000000000000000000000000000000000000000000000000000000000000000
00000000000000001kK8M`00002N3R6?000100004000000000000000500000000000000000000000
001P0@004000018000000000003@h601D00]07H0H@1/07D0I@1T0200A@1b0780K`1b01c94P3D;a06
R3PD0=@_40HSM8D3d0U00`004P000000/aKeMh1k7`1a5_EgN0LD08dFmGOH0O`5R7/O08Qk7`3@h601
7Z<2<000003@h601/GTE<0004P00008`o<LB01c94P3D;a06R3PD0=@_40HSM8D3d0U00`0000000000
000000a3500<@a@0648D01Q2500001@0I7H02000000U0000300000@0001D0000Q00000X0000h0000
[00006H000010000C407@FhZ1T4:0000>00000T0001<00000000000000000000oooooooooomP0000
B@1^07@0I@1b06<0I@1`07@0mGL<00005`0000`0000G00003P0001D0000G00005`0000`0001D0000
U0000?@1000h0000l`8006H000010000C407@FhZ1T7d0@00>00000`0001<00000000000000000000
oooooooooomT0000;@0g03T0<00i03D0;P0e03P0=00c03@03P0001L0000G00005`0001L0000G0000
300001L0000G00005`0001L0000G0000E0000900000m0`00>00002h4001V00000@0004a01d5^:PI1
?@<003P0000;0000C00000000000000000000?ooooooooooI00003L0>00c03D0=`0^03T0=P0a0340
<@1U01L0000G00005`0001L0000G0000300001L0000G00005`0001L0000G0000E00009@0001?1000
>00004h5001V00000@0004a01d5^:PI1D0@003P0000<0000C00000000000000000000?oooooooooo
I00002d0<@0^0300<00i03@0<@0c03D0<00g00h0000G0000300001L0000G00005`0001L0000G0000
5`0001L0000G00005`0005@0002@0000L@D003P0001R1P00IP000040001<@0M1KRX6@G85000h0000
2`0004`00000000000000000003oooooooooof@0000`02h0<`0d0380<`0b03P0=00i0340K`0G0000
300001L0000G00005`0001L0000G00005`0001L0000G00005`000580001`0@001@00010000070000
00000000002l0P00000000L20R9C07T0L`1d06D0K@00000000000000000000000000000000000000
00000000000000000000000000000000001b06l0LP0LbA80e2l@1XPh503D;a068gB50m09@0<00180
00000;<FmGN0Nal0LAKeMgP7502=5_Egf07l1HQk7`28Nal0d>1P0C00;P0c03@0<P0c0380>00d03T0
<@0g0?c74P0LbA80e2l@1XPh503D;a068gB50m09@0<0018000000;<FmGLHN1h0LAKeMmP7502=5_Eg
oP;l1B1h7P0PN1h0d>1P0AjS0S000000d>1P0K5i5C0001800002<?c74P0LbA80e2l@1XPh503D;a06
8gB50m09@0<0000000000000000<@a@034<D01Q2500H@Q@0000D06Af00P000009@0000`000050000
8P0000`0003ooooo8@0000P0000U0000300000@0000I000030000?ooo`0H000030000000000N0000
600000@0001/0000K@H009l0000D0000300000d0000B000030000040001D0000I00000X0001[0000
F`0009P000010000C407@FhZ1T4:0000J`0000@0001<00000000000000000000oooooooooomD0000
D`1Y07X0I@0L00002P0001D0000G0000E000090000020P00J`000?<2002H00000@0004a01d5^:PI1
0P8006/0000;0000C00000000000000000000?ooooooooooI0000340=`0h02h0<@0f0300<`0f0300
=`3ooaL0000G00005`0000`0000G00005`0001L0000G00005`0001L0000G0000E0000900000m0`00
J`0002h4002H00000@0004a01d5^:PI1?@<006/0000;0000C00000000000000000000?oooooooooo
I00003@0=@0^0300>@0g03D0<@0h03T0<P0^01L0000G0000300001L0000G00005`0001L0000G0000
5`0001L0000G0000E0000900001M1000J`0004h5002H00000@0004a01d5^:PI1GP@006/0000;0000
C00000000000000000000?ooooooooooI00003<0;P0i03D0<00e03D0=`0i0380<`1U01L0000<0000
5`0001L0000G00005`0001L0000G00005`0001L0000G0000E0000900001a1@00J`000686002H0000
0@0004a01d5^:PI1LPD006/0000;0000C00000000000000000000?ooooooooooI0000300;P0`0300
=00b03<0<P0g0300=00001L0000<00005`0001L0000G00005`0001L0000G00005`0001L0000G0000
9@0000`0000500008P0000`0003ooooo8@0000P0000U0000300000@0000I000030000?ooo`0H0000
30000000000N000060000?coooolooooL@H00:H0000U0000300000D0000R000030000?oooolQ0000
200002D0000<0000100001T0000<0000oooo01P0000<0000000001h0000H000000000000001^1P00
X`0002L0000H00001P00000000000000000002D0000<00001P0001@0000<00003@000180000<0000
0P0004`0001T00000P000000001[1P001@000080003nooooJ`H000P0000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000V0000700000L000000000
00000000000000009@0000`0000700006`00010000020000=00003H0000@0000K@H003@0000V0000
700000P00000000000000000000000009@0000`000080000C00006@000020000=00006/6000g0000
0P0003@0001[1P0010000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000004`0001T00000P0009`0001[1P00X@000080002M0000J`H000P0000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000W0000
600000T00000000000000000000U0000300000T0000X0000300000H0000U0000300000D0000R0000
30000?oooolQ0000200002D0000<0000100001T0000<0000oooo01P0000<0000000001h0000H0000
o?oooocoooma1P00YP0002D0000<00001@0002P0000<0000100002P0000<00000`000280000<0000
ooooobD0000<00001`00P2D0000<00000000P300000<00003`00P2D0000<00000@0004/0000@0000
000000D0000X0000300000D0000X0000300000L0000X0000300000P0000X0000300000T0000U0000
30000000080U0000300000L0080R000030000?oooolU0000300000d0080X000030000080000R0000
30000?oooolR000030000?oooom60000>00002`00015CDH[9T00010000040000000002501`0<0000
000000A0000<0000000004H0000D0000200004M4BD<300008P0000`0003oooooE00005@000000000
00000?oooooooooo0@0005EE1d4Vo@I1KPH00:<000010000C00000@000000000000006d6002S0000
D0000200000F00009@0000`0000>0020AP0003@0000X0000ADe6:bY0000T000060000000P3l00020
0000P000P3l000200000P24000080000HP0000`000010000C00006@000000000000006d6002R0000
00000000001^1P00X`0002T0ZP00000000000000P3l0000000000000P3l000000000000000000000
000000000000000000000280000<0000ooooodH0000L0000400004E=AR/2@00030000000000>0000
50000000000@00005000
\>"], "Graphics",
 PageWidth->PaperWidth,
 ImageSize->{353.375, 34.625},
 ImageMargins->{{136.5, 0.}, {0., 7.75}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s parameter table produces the same information.  We will compute these \
individually for the independent variable only."
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"houses", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], "[", 
  "\"\<ParameterTable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.497045990203125*^9, 3.4970460020625*^9}, 
   3.497046061484375*^9, {3.49704626715625*^9, 3.497046269546875*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"1", 
      RowBox[{"-", "79095.58433521951`"}], "78357.96111046486`", 
      RowBox[{"-", "1.00941350711914`"}], "0.3423284908337697`"},
     {"x", "178.16036067892517`", "45.09751891970982`", "3.9505579230670356`",
       "0.0042327037173577825`"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.49704627028125*^9, 3.5158109767690973`*^9}]
}, Open  ]],

Cell[TextData[{
 "The standard error of the b coefficient uses SSE and the square root of the \
lower right element in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      RowBox[{
       SuperscriptBox[
        StyleBox["X",
         FontWeight->"Bold"], "T"], 
       StyleBox["X",
        FontWeight->"Bold"]}],
      TraditionalForm], ")"}], 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ". We will shortly see that the term on the left, Sqrt[SSE/(n-k)], is also \
known as the Standard Error of the regression, S."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["S", 
   SubscriptBox["b", "1"]], "=", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    RowBox[{"SSE", "/", 
     RowBox[{"(", 
      RowBox[{"n", "-", "k"}], ")"}]}], "]"}], "*", 
   RowBox[{"Sqrt", "[", "LwrRt", "]"}]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"45.0975189197098`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045608234375*^9, 3.497046293234375*^9, 
  3.515810993754098*^9}],

Cell["\<\
The t-stat for the b coefficient test of the null hypothesis that \[Beta] = 0 \
is the ratio of the coefficient to its stardard error. This is sometimes \
referred to as a \"signal to noise ratio\". Depending on the asymptotic \
properties of the distribution we view the size of this measure as a level of \
confidence that the value of our estimator did not occur by chance. A large \
value indicates that our coefficient provides more \"signal than noise\"\
\>", "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{3.4970464543125*^9},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   OverscriptBox["t", "^"], 
   SubscriptBox["b", "1"]], " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["b", "1"], "/", 
      RowBox[{"(", 
       SubscriptBox["S", 
        SubscriptBox["b", "1"]], ")"}]}], ")"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["3.9505579230670342`"], "Output",
 CellChangeTimes->{3.497045608359375*^9, 3.49704629775*^9, 
  3.5158110090160975`*^9}],

Cell["Summary Output", "Subsection",
 PageWidth->PaperWidth],

Cell["\<\
Finally, the Summary Output below is provided from the Table 6-7\
\>", "Text",
 PageWidth->PaperWidth],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001lX0@0006`00000000000000?d2002Y0@00
0000000000156@005Ph00215CDH00040:1l009/0000:00000000000000000000H0T004D<003;0000
2@4000000000000000000?PH0`0X2`@0AP0002`0000P0000ADe6:`500@0L00004000004@`=/00000
;04002`100160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001H0000<0000600000X0000@0000
000000000009000040000?`2002Z0@009@0000`0000>00204P0000`000010000600000`000000002
DP00070100010000c_ooo`0000000000000009010000000014004U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^0000000000000000000000000000000000000000000000000:001P000?B?<`<8@9/3
2S014S009U01036@J04jL3HRYP0l<04O/=0_8;3P?B6`L0PR/:058i1@1bB@X0DU/0005k2P1AR`F@5g
0RChM`00003ooooo000009Qcj`6DkmD;neG<MmSn6`1X^Al0f5G<MfRi7`000000J;TO0000e@^JELag
6?3E2i/Wc7O/kmD;LbS<Mnc_e@]PlMD;k33<Mf3ae@_`B@1cZ??E2oooooooo`60ool1P0l00H000?oo
0000000800002000AaJ@0@000P860`D41@8318Mj0200002020000000003o0@00000005@0J@1]06D0
I7H02000000U000030000040000Q0000200001h0000H000000000000003l0P00ZP4004H0000X0000
700004M4BD<20000oooooooooooo0P00Z`4000000016000040L000@70015CDH[:T0002@0000H0000
0020?`00000000000020?`00000000008D0500`0000000009D00010000040000000002a0000T0000
600004hKA3l000200000P24RfSh000200000P0Q000E<1P00@0H0004@`=/200000P0001H6003GcLJJ
00000000o`:[0Bd1000006QE000100T000<;0`001`0W0000000400000`4800D0000;0P0000050000
30:[0Ol21@0000T2000000D000010_ooo`040000104=00@000020@800`0001h0100002L1ool30000
7P0400009`7oo`<0000N00D000010_ooo`0500002@800000100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F1:d10@?looco100002L1ool300007P0500000@;oool01@0000T2000000L0
000F1:d10@?looco70000?/2e_l00000002@0@0000000000@G9YHF`0000000000000000000000000
0000000000040000;@4000@000040@d0100000810@0L0000<PX400X03P0005=ECDe1DUTPCeEDD5ED
700N02<08`0L01h0700<02407P0J01`07P0J01`0003k0]Ko00000000T04100000000045bJF5/0000
00000000000000000000000000000000100002d10@0W0000<PY_0;X05@00059UIg9ULg=YKfhPDgAQ
M6UcM6USL`4N01L05`0>01L05@0E00T05`0G00`0700<01L0300901D0300901D05@040000;@4001H0
000b2Z<02P0:0000CGE/M6U`K6DPDR<05`0:00`02P0G00X05`0<01h06000038:X`020P/0000`;SPa
<c0i<3@h>E0G00`05`0G01L05`0G01L05`0G01L04`00038:e`0:00P0001B85=aMF5bIAh0300L01L0
5`0G00h05`0H0000<P[G00822`00030^=SHa<C4f<C@cD1L0300G01L05`0G01L05`0G01L05`0Q0000
<PX;0@X04@00045TJWEcM6ET858PDg5eHG9UM1`05`0:01L0500<01L05`0<01h0300L01L05`0G00h0
5`0H0000<PX;0@822`00030^=S4h=cDe=SHaD1L0300G01L05`0G01L05`0G01L05`0L0000<PXo0@X0
3P0005=dHFiTHG9T84EbLVmb700<01L05`0G01L03P0G00`0700>00h05`0>01P0000b2Sl10P8;0000
<S4d=C0^=3Tf<c=b5`0G01L05`0G00`05`0G01L05`0G01`0003k0Q001`000000_08000000@828U=i
LgAUK@0000000000003dk1<00@000>@400000000100002d10P0400009`7oo`<0000N00@0000]0@00
1@000042oooo00D000090P00000700005PBV0Od2L`4400@000040@d0100000810@0I0000<PYb0@X0
300004mRLfEbMV5dJFm^Lb405`0D01L03P0G01L0300:01L05`0D00X0000b2W81aP820000<C0G01L0
100002d10P0400009`7oo`<0000N00@0000]0@001@000042oooo00D000090P00000700005PB]0@43
o?olo`@0000]0@80100002L1ool300007P040000;@4000D000010_ooo`0500002@8000001`0001H4
ZP7n0P0000070000o0800000000000@0000]0@<0100000@13@0400000P4200`000102B40l0000000
00080?/2J@0200P0003j0P000000000000040000;@4400D0000D0Yl00P0500004`:O0?d220000?X2
00000000000000@0000]0@D0300004098@3`0000000000@0n`:O0080300004098@3`0000000000P0
n`:T0@801`000?`20000000000040000;@4600@0003`0@<0100002d10P0400009`7oo`<0000N00@0
000]0@001@000042oooo00D000090P00000700005PB]0@43o?olo`@0000]0@8010000?0100040000
l04100@0000W0Ooo0`0000000008@048900001P000014<3K0@0000<00000000000000000000J@010
;0000200000100000P000000000000000<0oA020eD<00000j0?X0b4000080000HP0000`000010000
B`000100000000001@00024000080000HP0000`0000100004@0000`0000800002P00010000000000
000000T0000@0000o`800:/1000<000040000000000000002`000100003n0P00ZP40024000080000
9@0000`0000700209@0000`0000000205P0000`000000000600000`0000000006@0000`0003oool0
500000`0000=0000DP00070100020000c_ooo`000000000000000901000000001d004U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^0000000000000000000000000000000000000000000000000000
h0Xk3:3fkP7FPW9dn2hL0>3[6@000@00XX9bM>3[6@0000001kK8M`00001l426W00010000403e5_Eg
cAOeM`/HmGL00000C3<L004000000000H0YD0`00000G0000K;XB0?]C0S010000E`000>CU0C3Laa80
]U42<0004P2>AP8`o<LB01c94P202E@3@<PB0809E0<4000000000?DFmGL20000j0HD000050144000
0@00000000000000801=0040002000000000032n4P3Fe04`J30D0:Q4@@4100000000000000050000
Z4A10F0`501X<1@0I7H02000000U000030000080000:000040000000000000002@000100003o0P00
Z`4001P0000<0000000001T0000<0000oooo01@0000<00003@000180000<00000P00024000080000
8P0000`0003ooooo8@0000P0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
00000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0003loooo
o?ooo`43002]0@008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
60000?cooooloooo0@<00:d1001B0000L04000<0003Foooo0000000000000000T040000000070000
@@1b06T0H@1/00000000000000000000000000000000000000000000000000000000000000000000
00000000I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
00000000003P2S/<X?K^0MJ2LWCh;Q`0h>/I0001002RPW9dh>/I00000007]/Qg000007`@8JL00040
000@0?DFmGO=5oEg003eM`00001<<a`00@000000001P2U@3000001L0001/^Q80ne<2<040001G0000
i>D1<=c74P2fD@8`000B00000S3laa807<TB0809E0=0b180P0UD0`@000000000mAKeM`80003X1Q@0
000D04@@0001000000000000001TMP08000002D0000<00000`0001@0000<00003@000180000<0000
0@0005@0002P00002P0000@0002H0@00<P000040000Y:0M1=j`6@@X0000400003P0004`000000000
00000000003oooooooooofP0001C05D0C@1=0440DP1I0200C`1E05@0D01E05@0700001h0000S0000
8`0001`0000N0000700000`0000Q00007P0001X0000L00007P0001X0001B0000L04000@0003Foooo
0000000000000000T040004000070000@@1b06T0H@1/000000000000000000000000000000000000
00000000000000000000000000000000000000000007]/Qg000007`@8JL00040000@0?DFmGO=5oEg
003eM`00001<<a`00@000000001P2U@3000001L0001/^Q80ne<2<040001C05D0C@1=0440DP1I0200
C`1E05@0D01E05@07<TB0809E0=0b180P0UD0`@000000000000B0000002c5_EgJ0`I074FmGL821@0
SAKeMe@1c01`31T0L0`I0040001G0000i>D1<=c74P2fD@8`000B00000S3laa807<TB0809E0=0b180
P0UD0`@000000000mAKeM`80003X1Q@0000D04@@0001000000000000001TMP08000002D0000<0000
100005@0003<0000^P0006l0000o0P00WP000040000Y:0M1=j`6@KX0001_00005@0004`000000000
00000000003oooooooooogP0001B06D0I`1b06D0L`1c06T0K`1^0200D`1d0640M01Y07<0M01Y06<0
L`0001h0000G00005`0000h0000G00005@0001D0000900005`0001L0000<0000700000`0000G0000
300000T0000E0000300000T0000E00005@0002D0000<00000`0005@0002800002P000:<000350000
d@000040000Y:0M1=j`6@@X0002S00002P0004`00000000000000000003oooooooooof00001=07D0
K01d06T0L01/06D0801B02<0000G00002P0000`0000:00005`0000X0000G0000300001h0001D0000
T0000042002S0000lP800=4000010000:BP7@CN/1T420P00X`0000/0001<00000000000000000000
oooooooooomT0000<00^03P0<@0c0300>@0`03@0>00i01805`0000`0000G00005`0001L0000G0000
5`0001L0000G00005`0001L0001D0000O00000X0003G0000^@0000D100010000:BP7@CN/1T4:0000
e`0000P0001<00000000000000000000oooooooooomL0000DP0P05<0L@1e0640LP1U01h0000<0000
700001L0000G00005`0000h0000G0000E000090000010P00e`000?8200050@000@0002TX1d4g[0I1
0P800=L0000;0000C00000000000000000000?ooooooooooI0000300;P0f03H0<@0a0340=P0a03@0
<`0001L0000<00005`0001L0000G00005`0001L0000G00005`0001L0000G0000E0000;@0000:0000
2P4006L1000h0@000@0002TX1d4g[0I12P0000/1000A0000C00000000000000000000?oooooooooo
L0000440I01Z07D0L`1d06D0I00P0580801C0740M@1Q0780I@0001`0000G00002P0001L0000D0000
300001L0000G0000300001h0000<0000700001L0000G00005`0000h0000G0000E000090000010P00
2P400?82000h0@000@0002TX1d4g[0I10P8000/1000;0000C00000000000000000000?oooooooooo
I0000300;P0f0340>00g03D0=@0f03H0<@1b01L0000<00005`0001L0000G00005`0001L0000G0000
5`0001L0000G0000E0000:00000:0000?P4001`1001/0@000@0002TX1d4g[0I12P0003l1000>0000
C00000000000000000000?ooooooooooJ00005<0M01Q06h0I01Q0780I00P04D0LP1b06l0LP0L0000
300001L0000G00005`0001L0000>00005`0000`0000L00003P0000h0000G00003P0005@0002@0000
0@8003h1003b0P00K0400040000Y:0M1=j`6@@82000o0@002`0004`00000000000000000003ooooo
ooooof@0000b0340=00e0300;P0d03T0=P0c03<0000G00005`0001L0000G00005`0000`0000G0000
5`0001L0000G00005`000580001`0@001@0001000007000000000000002l0P00000000L20R9C07T0
L`1d06D0K@0000000000000000000000000000000000000000000000000000000000000000000000
001@05D0E00LbA80P0UD0d384P202E@3100000000000018000000;<FmGMX31T0LAKeM`P8502=5_Eg
E07<070<6@1`31T00@000380<@0d03D0<00^03@0>@0f03<0<`1b06l0LP1Q0780I@1d06T0H`1c05@3
100000000000018000000;<FmGN@7n`1LAKeMmP7502=5_EgO0?<09POk06H7n`10@0005L0003Ti@4`
g<LB0;IA0S0001800002<?c74P0LbA80P0UD0d384P202E@310000000003e5_Eg0P000>P6500001@0
A100004000000000000006Af00P000009@0000`0000500008P0000`0003ooooo8@0000P0000U0000
300000<0000I000030000?ooo`0H000030000000000N0000600000@0001c0@00o@800:H1000D0000
300000d0000B000030000040001D0000U00000X0001b0@00004009l100010000:BP7@CN/1T4:0000
LP4000`0001<00000000000000000000oooooooooomT0000C`1R07<0I@1b07H0H@1d06T0K`1^07<0
8@0001L0000D00005`0000h0000G00005`0000`0000:00005`0001L0000D0000E00005P000350P00
LP400?82002O0@000@0002TX1d4g[0I1aP80078100020000C00000000000000000000?oooooooooo
D0000340<00G00005`0002D0000<00001@000280000<0000ooooob40000800009@0000`000030000
6@0000`0003oool0600000`0000000007P0001P0003looooo?ooo`43002]0@009@0000`000050000
8P0000`0003ooooo8@0000P0000U0000300000<0000I000030000?ooo`0H000030000000000N0000
6000000000000000oP800:X1000W0000600000H00000000000000000000U0000300000H0000D0000
300000d0000B000030000080001<0000I0000080001Y0000n`80070000020000J@000?/200080000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9P0001`0000700000000000000000000000002D0000<00001`0001/0000@00000P0009l0000f0000
40000?d2002O00009P0001`0000800000000000000000000000002D0000<0000200004`0001T0000
0P0009l0003k0P00XP000080002O0000n`8000@0000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000001<0000I0000080002S0@00n`800:P100020000
Y0400?/2000800008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009`0001P00009000000000000000000009@0000`000090000:00000`000060000
9@0000`0000500008P0000`0003ooooo8@0000P0000U0000300000<0000I000030000?ooo`0H0000
30000000000N000060000?cooooloooo0@<00:d1000U0000300000D0000X0000300000<0000X0000
300000@0000R000030000?oooolU0000300000L0080U000030000000080`0000300000l0080U0000
30000040001;00004000000000050000:00000`000050000:00000`000070000:00000`000080000
:00000`0000900009@0000`0000000209@0000`0000700208P0000`0003ooooo9@0000`0000=0020
:00000`0000200008P0000`0003ooooo8P0000`0003oooooAP0003P0000/0000ADe6:bI0000@0000
10000000000Q@0L0300000000004@0003000000000160000500000P00017A4U30`000280000<0000
oooooe@0001D000000000000003oooooooooo`40001EE@M19_d6@Oh2002Z0@000@0004`000040000
00000000003l0P00ZP400500000P00005P0002D0000<00003P00P4H0000d0000:00004E=AR/Z@000
900001P00000080o0000P0000800080o0000P000080Q000020000680000<00000@0004`0001T0000
00000000003m0P00Z@40000000000000oP800:X1000Y0:X0000000000000080o000000000000080o
0000000000000000000000000000000000000000000R000030000?oooom60000700001000015CDH[
0T0000`0000000003P0001@000000000400001@0
\>"], "Graphics",
 PageWidth->PaperWidth,
 TextAlignment->Center,
 ImageSize->{178.938, 99.3125},
 ImageMargins->{{231.5, 0.}, {0., 12.5}}],

Cell[TextData[{
 "The sum of the squared differences between X and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["X", "_"], TraditionalForm]]],
 " (known both as ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "xx"], TraditionalForm]]],
 " and as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"\[CapitalSigma]", "(", 
     RowBox[{
      SubscriptBox["x", "i"], "-", 
      OverscriptBox["x", "_"]}], ")"}], "2"], TraditionalForm]]],
 ") is the product ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", 
       OverscriptBox["x", "_"]}], ")"}], "T"], ".", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      OverscriptBox["x", "_"]}], ")"}]}], TraditionalForm]]],
 "."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["S", "xx"], "=", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"size", "-", 
     OverscriptBox["X", "_"]}], "]"}], ".", 
   RowBox[{"(", 
    RowBox[{"size", "-", 
     OverscriptBox["X", "_"]}], ")"}]}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"226240"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045608484375*^9, 3.4970463085625*^9, 
  3.5158111869980974`*^9}],

Cell[TextData[{
 "There are several ways to compute the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]]],
 "value. the first is to have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " compute it as an option in the Regression Report."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"houses", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], "[", 
  "\"\<RSquared\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.497045990203125*^9, 3.4970460020625*^9}, 
   3.497046061484375*^9, {3.49704626715625*^9, 3.497046269546875*^9}, {
   3.49704634303125*^9, 3.49704634578125*^9}}],

Cell[BoxData["0.6611161430925359`"], "Output",
 CellChangeTimes->{3.4970463465*^9, 3.5158111974570975`*^9}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]]],
 " is the ratio of the sum of the squared regression to the total sum of \
squares."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"Rsqd", "=", 
  RowBox[{"SSR", "/", "SST"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.6611161430925356`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.49704560884375*^9, 3.49704636478125*^9, 
  3.515811201438098*^9}],

Cell["\<\
Or it is 1 minus the ratio of the sum of the squared errors to the total sum \
of squares.\
\>", "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"(", 
   RowBox[{"SSE", "/", "SST"}], ")"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.6611161430925356`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045608984375*^9, 3.49704636865625*^9, 
  3.515811213919098*^9}],

Cell[TextData[{
 "Or it is the product of the estimated coefficient, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]]],
 " and the ratio of the sum of the squared differences ",
 StyleBox["between ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["X",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" and ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   OverscriptBox["X", "_"], TraditionalForm]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 "and the total sum of squares, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["b", "2"], 
    RowBox[{
     SubscriptBox["S", "xx"], "/", 
     SubscriptBox["S", "yy"]}]}], TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["b", "2"], 
    RowBox[{
     SubscriptBox["S", "xx"], "/", "SST"}]}], TraditionalForm]]]
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   SuperscriptBox[
    SubscriptBox["b", "1"], "2"], ")"}], "*", 
  RowBox[{
   SubscriptBox["S", "xx"], "/", "SST"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.6611161430925356`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045609109375*^9, 3.4970463745*^9, 
  3.5158112187660975`*^9}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]]],
 " is also the square of the correlation coefficient"
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"Correlation", "[", 
    RowBox[{"xdata", ",", "ydata"}], "]"}], "^", "2"}], "]"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["0.6611161430925356`"], "Output",
 CellChangeTimes->{3.49704560925*^9, 3.497046381515625*^9, 
  3.515811229643098*^9}],

Cell["\<\
The standard error of  the regression (S) is the square root of the ratio of \
the SSE to the degrees of freedom (n-k):\
\>", "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{"S", "=", 
  RowBox[{"Sqrt", "[", 
   RowBox[{"SSE", "/", 
    RowBox[{"(", 
     RowBox[{"n", "-", "k"}], ")"}]}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"21450.49632909041`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.497045609375*^9, 3.49704638628125*^9, 
  3.5158112340340977`*^9}],

Cell["Notice that the square of S is also the Mean Squared Error", \
"MathCaption",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   SuperscriptBox["S", "2"], "\[Equal]", "MSE"}], "]"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.4970456095*^9, 3.497046486328125*^9, 
  3.5158112468870974`*^9}],

Cell[TextData[{
 "The standard deviation of the observed Y values, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "y"], TraditionalForm]]],
 ", may be computed by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s StandardDeviation function or as the square root of the ratio of the \
total sum of squares to (n-1)."
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"StandardDeviation", "[", "ydata", "]"}], "//", "N"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["34740.46631811381`"], "Output",
 CellChangeTimes->{3.49704560965625*^9, 3.4970464909375*^9, 
  3.515811254572098*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["S", "y"], "=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"SST", "/", 
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["34740.46631811381`"], "Output",
 CellChangeTimes->{3.49704560978125*^9, 3.49704986328125*^9, 
  3.515811265815098*^9}],

Cell["It is, of course, also the square root of the variance.", "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sqrt", "[", 
   RowBox[{"Variance", "[", "ydata", "]"}], "]"}], "//", "N"}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[BoxData["34740.46631811381`"], "Output",
 CellChangeTimes->{3.49704560990625*^9, 3.5158112723290977`*^9}],

Cell[TextData[{
 "Dividing the square of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "y"], TraditionalForm]]],
 " into the square of the standard error of the regression and subtracting \
the result from 1 gives the adjusted ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]]],
 ":"
}], "MathCaption",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"houses", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], "[", 
  "\"\<AdjustedRSquared\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.497045990203125*^9, 3.4970460020625*^9}, 
   3.497046061484375*^9, {3.49704626715625*^9, 3.497046269546875*^9}, {
   3.49704634303125*^9, 3.49704634578125*^9}, {3.49704980221875*^9, 
   3.497049803984375*^9}}],

Cell[BoxData["0.6187556609791028`"], "Output",
 CellChangeTimes->{3.49704980515625*^9, 3.5158112862590976`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"adjRsqd", "=", 
  RowBox[{"N", "[", 
   RowBox[{"1", "-", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["S", "2"], "/", 
      SuperscriptBox[
       SubscriptBox["S", "y"], "2"]}], ")"}]}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.49704982271875*^9, 3.4970498255625*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.6187556609791026`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.497045610265625*^9, {3.49704981834375*^9, 3.49704982615625*^9}, 
   3.497049866234375*^9, 3.5158112920810976`*^9}],

Cell["Alternate presentations", "Subsection",
 PageWidth->PaperWidth],

Cell[TextData[{
 "Here are some other ways to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to display regression output. \nWe can produce all the output options at \
once."
}], "Text",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"houses", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{
   "\"\<ANOVATable\>\"", ",", "\"\<ParameterTable\>\"", ",", 
    "\"\<FitResiduals\>\"", ",", 
    "\"\<SinglePredictionConfidenceIntervalTable\>\"", ",", 
    "\"\<ParameterConfidenceRegion\>\""}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.497045990203125*^9, 3.4970460020625*^9}, 
   3.497046061484375*^9, {3.49704626715625*^9, 3.497046269546875*^9}, {
   3.49704634303125*^9, 3.49704634578125*^9}, {3.49704980221875*^9, 
   3.497049803984375*^9}, {3.49704993275*^9, 3.497050043390625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   StyleBox[
    TagBox[GridBox[{
       {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
       {"x", "1", "7.181109657885433`*^9", "7.181109657885433`*^9", 
        "15.60690790350773`", "0.004232703717357788`"},
       {"\<\"Error\"\>", "8", "3.6809903421145673`*^9", 
        "4.601237927643209`*^8", "", ""},
       {"\<\"Total\"\>", "9", "1.08621`*^10", "", "", ""}
      },
      AutoDelete->False,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
      GridBoxDividers->{
       "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
        "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings->{
       "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
     "Grid"], "DialogStyle",
    StripOnInput->False], ",", 
   StyleBox[
    TagBox[GridBox[{
       {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
       {"1", 
        RowBox[{"-", "79095.58433521951`"}], "78357.96111046486`", 
        RowBox[{"-", "1.00941350711914`"}], "0.3423284908337697`"},
       {"x", "178.16036067892517`", "45.09751891970982`", 
        "3.9505579230670356`", "0.0042327037173577825`"}
      },
      AutoDelete->False,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
      GridBoxDividers->{
       "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
        "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings->{
       "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
     "Grid"], "DialogStyle",
    StripOnInput->False], ",", 
   RowBox[{"{", 
    RowBox[{"6855.043316831754`", ",", 
     RowBox[{"-", "22685.04685289954`"}], ",", "19039.00724893922`", ",", 
     "16222.971181046712`", ",", "15590.89904526167`", ",", 
     "30044.908062234812`", ",", 
     RowBox[{"-", "24869.010785007034`"}], ",", 
     RowBox[{"-", "4374.66849363505`"}], ",", 
     RowBox[{"-", "23771.128005657694`"}], ",", 
     RowBox[{"-", "12052.974717114499`"}]}], "}"}], ",", 
   StyleBox[
    TagBox[GridBox[{
       {"\<\"Observed\"\>", "\<\"Predicted\"\>", "\<\"Standard Error\"\>", \
"\<\"Confidence Interval\"\>"},
       {"195000", "188144.95668316825`", "24792.35846258606`", 
        RowBox[{"{", 
         RowBox[{"130973.67554698074`", ",", "245316.23781935574`"}], "}"}]},
       {"210000", "232685.04685289954`", "22513.78175392891`", 
        RowBox[{"{", 
         RowBox[{"180768.17302925533`", ",", "284601.9206765437`"}], "}"}]},
       {"225000", "205960.99275106078`", "23260.223069375985`", 
        RowBox[{"{", 
         RowBox[{"152322.82216730836`", ",", "259599.1633348132`"}], "}"}]},
       {"240000", "223777.0288189533`", "22540.866012448823`", 
        RowBox[{"{", 
         RowBox[{"171797.6985831632`", ",", "275756.35905474337`"}], "}"}]},
       {"275000", "259409.10095473833`", "23753.38165529416`", 
        RowBox[{"{", 
         RowBox[{"204633.70463254716`", ",", "314184.4972769295`"}], "}"}]},
       {"285000", "254955.0919377652`", "23415.993742474002`", 
        RowBox[{"{", 
         RowBox[{"200957.71353770522`", ",", "308952.4703378251`"}], "}"}]},
       {"190000", "214869.01078500703`", "22792.10046007973`", 
        RowBox[{"{", 
         RowBox[{"162310.33287407435`", ",", "267427.6886959397`"}], "}"}]},
       {"239000", "243374.66849363505`", "22777.81885506815`", 
        RowBox[{"{", 
         RowBox[{"190848.9240229164`", ",", "295900.4129643537`"}], "}"}]},
       {"249000", "272771.1280056577`", "25044.35401444542`", 
        RowBox[{"{", 
         RowBox[{"215018.74408482946`", ",", "330523.5119264859`"}], "}"}]},
       {"185000", "197052.9747171145`", "23932.510151579645`", 
        RowBox[{"{", 
         RowBox[{"141864.5073417561`", ",", "252241.4420924729`"}], "}"}]}
      },
      AutoDelete->False,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings->{
       "Columns" -> {{Automatic}}, "RowsIndexed" -> {2 -> 0.75}}],
     "Grid"], "DialogStyle",
    StripOnInput->False], ",", 
   RowBox[{"FittedModels`ParameterEllipsoid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "79095.58433521951`"}], ",", "178.16036067892517`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"233999.79487655134`", ",", "11.658403298808587`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9999998356225932`"}], ",", 
         "0.0005733714211099097`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0005733714211099097`"}], ",", 
         RowBox[{"-", "0.9999998356225932`"}]}], "}"}]}], "}"}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.497049952*^9, 3.4970499629375*^9}, 3.497050044328125*^9,
    3.5158113055190973`*^9}]
}, Open  ]],

Cell["\<\
We can name the errors and predicted values in separate lists and plot them \
together to get a visual look at whether there is a relationship such as \
bigger errors for larger predictions.\
\>", "Text",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"errors", " ", "=", " ", 
   RowBox[{
    RowBox[{"LinearModelFit", "[", 
     RowBox[{"houses", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], "[", 
    "\"\<FitResiduals\>\"", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "TableForm"}]}], "Input",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 8.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.497050158484375*^9, 3.497050186515625*^9}, 
   3.4970502215625*^9, {3.497050265625*^9, 3.4970502785625*^9}, {
   3.5158114497370977`*^9, 3.5158114519980974`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {"6855.043316831754`"},
     {
      RowBox[{"-", "22685.04685289954`"}]},
     {"19039.00724893922`"},
     {"16222.971181046712`"},
     {"15590.89904526167`"},
     {"30044.908062234812`"},
     {
      RowBox[{"-", "24869.010785007034`"}]},
     {
      RowBox[{"-", "4374.66849363505`"}]},
     {
      RowBox[{"-", "23771.128005657694`"}]},
     {
      RowBox[{"-", "12052.974717114499`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.49704561065625*^9, 3.497050129078125*^9, 3.49705017621875*^9, 
   3.49705022221875*^9, {3.49705026871875*^9, 3.497050279578125*^9}, 
   3.5158114052590976`*^9, 3.515811453525098*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"predValues", "=", " ", 
   RowBox[{
    RowBox[{"LinearModelFit", "[", 
     RowBox[{"houses", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], "[", 
    "\"\<PredictedResponse\>\"", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "TableForm"}]}], "Input",
 CellChangeTimes->{{3.5158116652500973`*^9, 3.5158116875750976`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {"188144.95668316825`"},
     {"232685.04685289954`"},
     {"205960.99275106078`"},
     {"223777.0288189533`"},
     {"259409.10095473833`"},
     {"254955.0919377652`"},
     {"214869.01078500703`"},
     {"243374.66849363505`"},
     {"272771.1280056577`"},
     {"197052.9747171145`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5158116898030977`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"errors", ",", "predValues"}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Min", "[", "errors", "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5158117249280977`*^9, 3.5158118748840976`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], 
    LineBox[{{1., 6855.043316831754}, {2., -22685.04685289954}, {3., 
     19039.00724893922}, {4., 16222.971181046712`}, {5., 15590.89904526167}, {
     6., 30044.908062234812`}, {7., -24869.010785007034`}, {
     8., -4374.66849363505}, {9., -23771.128005657694`}, {
     10., -12052.974717114499`}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], 
    LineBox[{{1., 188144.95668316825`}, {2., 232685.04685289954`}, {3., 
     205960.99275106078`}, {4., 223777.0288189533}, {5., 
     259409.10095473833`}, {6., 254955.0919377652}, {7., 
     214869.01078500703`}, {8., 243374.66849363505`}, {9., 
     272771.1280056577}, {10., 197052.9747171145}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, -24869.010785007034`},
  PlotRange->{{0., 10.}, {-24869.010785007034`, 272771.1280056577}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5158117445540977`*^9, 3.5158118020890975`*^9}, 
   3.5158118771460977`*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXQu4X9OVP+7/ca8kJJ7xzm29IhWPeDSiKoREiEc8JtoQImSCEo+ECKa0
KkYZqXZKZlQ6rdKiI0YbzGQ+GarlGx/9DJ9+4hvlY2iH6jBoWtM7/99ae521
ztmP/4mkde91fe65N+fsvfZ6r7XX3mefI2fOm3PGOTPnnTlrZvekC2aeN+fM
WRd2T5x7QetWbb0s6/h5lq13T3eGv3uyTC49rf/58jQuuP3nuPEQ/aplqxaP
y+S/Bl1r2ezl1JJ+LnHtepbPpqd4xveareuqzHTH02x5T89CebxqcVZ42vrX
4lU980oQ8V+HG7kFPh+5Rtd6Zppl4xav6mL8VwbwrweghPBfQPcAaHk2m8Fm
q1x7hkeI5s2EDtNM7rXAzXcj8ADEgRYmuNepHMox0n93MiH/ZghpkUf/6sgZ
gOYMcmGUkOLQNXvPDXtxoh0R7CibFyVFxiXGKH7KBVKHFjkPB8i5JCAr0TUB
2WOGz+XSQr9e6MsopchhLOPkiFblkuC2RY7z0I6iRwwGYhkLLAMckzsCArq4
xChwpF7Aiqm/OMHknGutcUK6VktwzbZrFMlhSnmoS5y6WhLppw0pykw3NA+1
wIATFVQrZmySlES5VaDkJ4Xm/EiGZoz4XpiS9Q3WRdsWVDE8W12j4Kyk7UVr
SIJxLULCowaEWMsCcZ+4KX5D0b9YMMqdb2tkN5q4UQGl4BqeN0ablCGtIQXW
Pi9xQzIBPUGXJfcA/nIRWo6i+gTRoSSzq2n+o6WhNZQ1VF88VI2rYLQuCzCj
7D7QPR4Xil4q4XoeMrJYvNyGxVqupRhqoWBqtLR1/5KweV4a8PxlJCCWFAEV
o8FKF0JzTeixUTbnwUKP09Q8dLt1f2FpPODaEcDrQifbVYUcxapEsyCI3PZn
Ly/E5kYhBXFIOKUtUn1ZyNYc9NysrddRZZ8fllXT3S5gMHu5S4IOZRxcIunY
iytdrjWNqE34UaX+faXRv/CDwx5/7OU59y57dtg776zO/p37jCUgxAdc/o46
ByFtW/HeNmvRd23u/TnG3YoVr/u1195+berR3+058IAleF7DH1nt/vnzloPH
1GiLtRhma7p2nvivK14ATDz72Zlzli1acvPjxzzy8Iskv60rwhoc14214ay7
17V69Qe4f+r9y3+RbdcHJbolXbvA0udOnv4DCPKhuefehzYjX3rpraWLrl75
/qETbulgCb847YTbz7vrzqdJApuvxbBOO7Z48813IVUoU+bGIFuEYuFffK/+
1KzT7r7h6zf+FNJHn+FrL3yXw0FfiXA3KrDJDgi0D927LHBvLMOFYhAjWzAB
nzjmojT+XvC9254CN4VqMPmm6697BEzP9g7A3ZfvAd87rrxiheFOE3AAD33B
IdAAe2kw8zA8QMOcYLl7rRmjXKoItt9z6cIHRTTUxiEPhECwYWxVRtWFGKgA
sOMgWwMdZPtKJ/kXEEEt9gyA3Eu1KudvTVHMfRPH+TpQxr0rlt76BGTl+IVu
0HvYNDDafc34xenzYCDw1hGTlwImhItBZEC5j0FJMagnS70O6UmnPVY9/8Yg
HgPChRRxOzPmiHEIxqyogtTAW4wPxmQb8DDjn3ryVdwDUwGzzsSjKbojTmLI
/eKEcnLSHPvsM6/DPkUxABA9WdkbIEFiBTQRHGV6xzAi8CfSF8hvoEYCJMpG
AsmQkcyIC7ugKJvwMEAT7fAM/Df0Qq2BBVDdx9BL5HK+2AQ6YL9gin4YglOx
BqgSJgA6RmMq9+Dhoc/SF2RtpNIqqzlMN8f+c2mpQlmIoy4ygwSQApLw3FEJ
lHALDABqe8alegHTC+XPQ3zrB94XPOAcs4E/BW9IBeQxvbspu/FAfOqmPBRw
BRuBkKUDiJF2Hl9Rqt08DDQB7ARv0NbRi5HRHAoORR8dp/c8pheAwHihF3+D
mUN4HGidPCKFxe1d+RloEosGHi44wdiBGpS+rMCkHsdUFO3OOgykgv6A6bwV
fIiQiSFHxkk9l0lFK3Eyoq9AdCiPA7bLI9J43B6lYgebxc7J6W+ldEiAsKpM
qRFaHB4w7JBoWVh1qADuAQeYlqNXEkEMh+F3iNN7DtOLllaVwUAAZxNsYAzR
1JwmArCzhnJRDSBC3nZb1WdgU9bn3NtO5HYQuORSQSE75w/YsCWYmyHa5j9o
0h0n+mwmGoOLgYrrhYqwHTaAj+gsgBOuBGAnRkQkCSkBwW5VagiUlNqEVvZ3
rRbji0K27QpCHlcMwYmUBahtE6f3LKYXWitSxG/8G8A5SW3AvEVx8RumzfSy
/tTBXTEGPNxB5VY2TvALPCBF+UxF+R7M7STqwmozQ6zNN7aIEzuHiQUUydZF
bdFzS7VSUVjQw3kPnn2yGHKBLR7urE63nI0LEaQgn64o3MP8kGtSDMmvJMXY
NE7vbFVm64GBFPDeRg1UhIRx2OPgWbcffPFwVFGZwSurzGAvtRgTFy74mgv3
aD/4llIMgJUUY1ic3jOYXnBGrFMCKJAdUdRVeUR9t/PjLhRttyIJVo8hvlyP
R8dFK06c2p3gx91AniFzxCFxUjldbYIh5bgL4KypDYwhj3SWgWdb+8EXBO6p
qgzyrSoXRLYLt7NzXNsun4qd5Adf6K9jDSezjqJBcWJnMrFgSTnyAuqOTGx8
amAM2wu/brII4xNGCiUQRT7p2T6u9AUJn6aRDTChbG7OECTtVCYNJlYOskDX
xdD4LGB4Isg6f4POZSEBCJSDUB6hwiwnlwVhzjdkEBUzNPmzwRIIwGJc1hNP
7jcPB8txqoTleb7gY5L29iK5OM7+kzSng76L6WMYDD1aFSecrm8aDn+fVaWS
KoadhedKtVlFzi+MUzBdszQb08BTMNDNn4IJ+MZ+OIPvPihu2xBFXgIeVpH9
l8WR/5wGKIlAogggiAsS4ZR6mB+bwO5D1BGDrmiNaEhFzn8xjvyJjDyGsZUK
iTY8FU7kxxv4IQeUcvSPVnBY93p63FaHmrA+NG+gsa6MU/AXTAEwsEEEKgvi
XS0OOhFOdgf7QQSMOyLO20LJpUNdZTlvKsjgqjgFx2tkCJUX9mcK4unr+kxB
OTIcVQznoSIKmom6izclqq6OY3scYxsrDhyg3iacf3aGnT2JeSqPF5pGFqbN
fx1Hb6q6c/FaklOg63gdXUYopotN351DV45XLQGlwqivMiKujlnekbR+AL+j
1VlDX6yzhhEeUvTFhfSu7vtpkPkK47BvblDxnUVdAYSOUt8r2iOZFgjnyWsi
CVsv7IBftVi1XxbuDGA2RR1reRoLbCczZvhTuJhnTH8MO9b/YqT2ceKqsNUn
hBe7huh0kx+H0x0uj1Ph1brL1yxe7bctkI42gNMkdX6hySDLNpy8/J5RgQaJ
34NmvV5Cpc2Om2aAP5PUn5VnbBDIVPUQXj7yO0YKIhdlhCX+qj1SdtNFCKmJ
6rbK0ypgcpz6hXKakb2nz4SLcCdkAusAMzb54CwI96ZlwfzhXb4tHAS3QMev
P4QmlfA5WMUXKhF+PounBDwRqksUQxfo3n8XfUG7PS4hm+N8LjrFOCkR5X9b
ZCCQhgG8sfYO6kBGCiSWHRRGOCURuH/DSIGL0g20vclI8aQnugkl5MYP0LgS
ckynJcLyG75Tgt7/Jh7bWjiEYhsXwoKlKUji9ETs/XXYG72VRQP9/gpNuCs1
IVcj86Lo62Hv8tv4IK60J+VJUvKzEhHx1YSrSAxzJ3eDBnih7JWwof9PHNpd
iQD0ctFCZcX1bQONgN2diBy/9A0KY70Tx+iHqn2SlOUu/z99SwC7/zcO7R8T
vvoFX5chqHfj0JaF/evzvkJCA96LA7qX0YI6e47xOV/zoDPvx6H9U8KjPetr
GdhKIyVA3pfwR88UtUy2K/wuDu1HKlOrIWR/E7g9JdwtAqiYOpSuNUgDVQr8
ZEPpWgO/QQBVxIfStWZDYdapUxTYNEGaEtbk1XGMf5zwP1xioDpAjnEHXRvQ
K8EYP9C5rBbA8lC6UgEUwoVGgzuTwuby+zii94fdl9tbBBUo4lgnNjZAlLAR
P1TA3YxZBxGVWQzWlUUB8ZRFxjNNh1unekT0p1klV36JJWAWOZoJYbP+Q5zq
BxJ+dbCqrmCHH3IgRH2dSbK5QbYJXRuQkWUL0M5qTC7QLfKSpUXzfkiMCkL1
ovqREzzQdzRQpA/i9D3IPcpOvoMxAeBcQB24bt4W/YaVFn4Is+nqa4AR+ZnW
eDXVTmiwaOc4388B9v/F6fhnvmfDSzYEV5ZBA5RYeyH7qgVU6dy4KsEP5aq0
r+88QcEf4yi6zZ7onSs485ncs2UZYXRVRaGP8X1e7uItOrqp9sg1EsZo9VDi
ifNCeE+cXLpOTXMTqkLc5IJ2XkyVerWZy8fHOD7NJzgp4pNbQAbHJS6AzwSj
o80Y05Icg8YJx8CmT3BrtBTnCg4QpFqbkaZX5Biv89dtoYHGw+16mzFmKMeg
z1GO8eoOLR9aMyQYjTZj8MoS1f+EY4AR4Zir9oMya02m+BUf6QzlGGzCcgzB
J+fYsISdVBpoTpxtAAi2keEOaWcwnW0GOrsS7+CzMUaXbzvQU4LUbuf93Iq8
q/u2AzaYSm98jAuibOu0bLPWwgvd6JdYu6Tr/DCreAdDLV/4z9tbZNUhuvdq
LBukCsYNEuvFdL1MfXvxQWI/Jl3p0sveSviYNVI1+Kgx6YuNWMGb/ktHXCEK
vRGUvxbt3Y60jtweVAU/1yizr4oVSmmuksVxOb1S0ajQpgqcKm1CpSyPuGGW
kOCLvfHaYdV346rCq9ouVCeMECbvvOv7lRUWR5KvTHfFef4hmhUHXgPC5I1f
+5phuiauA5bbNQvtzPNKj4ujUGLSKPrDa0qIm1dOqUWbtZiyCmi7Emb6vNLj
AOLteD9UZJu/72jeuPbhB9+YDVBh2wWoSD4ujlKJCrc1IFu1St+abrGCX6Zu
Fl6m7mtEhU7Z6Cycj9HLTKUaWfbtdwXQsEATC09VX8LuWMftKrmzIVZuTk7N
giz7aAAaUuZIZo59MX6jw2qOvyjWTD+ur9XjSinCBlHLKp6c0+HcSvDVbe92
5EXvyO1KiVpvTG4H5gcf80YDsu+XjQbE2i8bDYh1bRqVTwTDf2tw0t1HXukJ
ZelVTrbrk5WfOLHrLlHu1Ql6iAHrovTTl4pJcR58iNlvL6s3JWlb01pSry1J
rSmVa1B36UXVnQEq+441rk3gWVelp15d8vrYR17u+KEOKmxT0Proq2WRI2LX
rNw1UDMbmIl9jBsNyL5fNhoQa79sNCDWtWkUr5k1vHVrNKnRs1ohP+GcqZcV
znTi0g+3TYUIXt8S15+2UsWJ7Yfbq+LE9sEtV0li+u42rFDHLtGLPr01K14a
6GfbtdrXQPi/frCFK05qP97WFSJaCOt3W73a17P6wTawZGFrYHfYn7jRwCSr
XzYaEGu/bDQg1nXdyH2jZIt333w70PHweEd31M3SlVff8eLtJ3x5jzeef8V0
PCLe0R3EM2z1O+/dv3zekp4lB5z/1tLJC0sA2o7c6Ppg9R/ueXDhrQDw/i0T
5h/28mPPGQCTy2rD55PWgbB0OfGFFU9qj8PiQx7IfRc9fvOP0Bc/p/5i+ePa
d1K873juu+Cp21ZI3yueuPUB7Tsx3pePsarTWK4v4ZD3PTTel8/lqh/z4sNP
g1b0JdrzvofE+05gFoOlkA36gtVguWHxwXEADLsBoQoACBtCNwAOigPge42R
b730K6gXADx192nXlQCMjwNwBxF2v/3amwLguR9MX4R/GwDuHBcMk5uAe6M4
a/9N21Du9RHst5ukFgUegVSQDKIMqe6bNGgBkYx/9clVhlT8FnKZ1EGluWG0
stcXCo2HKYseuu/cv404ndFFUwUTofKOS/Y7qsUP7Ao+5c+E9q/tBu4ATXDE
Om5SJOXhp5iHsDNxO3Aj7jjwWoCH9fzaL/cGcigsxB0wRDk2ijsJT9Ew25DZ
ZctA4nj63sYlqqFyQK/f8NMbl4VDKH+FJo91r3336L+CSy5xwn5tuM9vOnSn
/VA64Hhy3tN3rlSeuINxwAfwQ5jGr8tqCcR8t/hDlyJ7S0XzqKIa+OnSjtxJ
7Alm416BdkWvTuJ7pHzbt5jhvhKCPDWcw23PDcihOOcCz1vih/2mck/RaHu5
6yjxg79/RXmp8OOOFVd8p5SXdjNTcFdSP4T0jSxTaoV1mnVdyu1NJWR3fvLY
15/5pU3FSzwbwT1lhoMsMeNvJWRO81PfjV7X6UdvSnuOZf4hVRQfHJiJuEO/
0ErcFv42LOzhsrCiUy9/vbpmjaT3b9F0Z2DbGRYYQ/OoWdweSoYJKM+tcI8P
1azJPAX65j63mFf7C0Vo5156yTZPPtCuAXLsTIsmle6DPSBX2CHz5rzOwKe0
ehMMx4DQNJY/nkQTl58tm7NYMiOauMxQy5ZnMs1tQWn9ldVg8Tc9ct1daMMC
4NNwvfw88UUt/mKGl/cTSD4TbxCgSS1GUATReArU5zy77FEwzGEFDMEDnYzz
GcTFHHizOErTFKVyXu0+UdKJYZFsCpFAGWOS33OZE2bI0EDIQTgGFJB8qH+8
gzlWTkwT6PEnXupgvKCG3ieoUSDNA0ZZB48KTPMChDM2UAPq0F3a4W/c00nX
bTxWOUXcPI4dn8heyDohH/ehDoitrL/g04aKPOBjFi0sQ3OwUcX5D9y4kKMN
NxgRQu7gUcp4TabHMb4JCq1WQ31wj22lhrEgTis6NAcl6pq/xUOU06Phceac
VBQ2fiAbztSbMT1336aGSUDoJFmHFPIT+AQeAdclPEQ5PUl8w+9kJcOmgYcX
NV2QKmj61io2IArkBTMgD2y1TnQTj2OTAHRMYOZcEATjJRcTdWigE1V3l3rg
39AF677wN+5p/Ph6OM5uGUfxFI3fgiKUl5TkkLTO76huAowCwwQzcevqJhYX
IxtIdF/rCqJ1ajh6EloHqQkIOGsCrmAArYJ2EUIdAX/PByzWgCZESqB/GI5A
CURnKqJezOOaehMMCpmF+5KgRADYp/UZeQjgj702bHkdIGCE7nR6L15tHUf4
NA2ZFmEKmbz40Al9iprMGPUw5eAAxcmDw39oELLEE5Ud6pG4xthq+f1ijIPo
ssRXSmeFwy6BG5s2LXaAPfkX4KE0sUhCMfPn1K7LyhgweUmlpweaBoG4rlCw
fIjvsXwoxTHRMUHY6T7f8sH2VYOUaCYGCeT2LwYhiiulIETe7AkeAlYgYPKK
uMuyAQPhxuYHUNJIPN02Tg9/cbRQ4APD9gobMVQC98YX45j1emiex7HHmBRb
AsjdV1OjkqiI+AmQ/p1iFKaQvV2cjr8sen+hfA+1cTsI+AmkDk2HPskCs5/4
No72ZEmc8DShAeCDPAfikMNSRgxcs1E8QcqcopeTEDtarV9yM8/6J6vTFO0U
k5GASSa4Mmz9iFZuWaUp5llOQb8VTgBGlBOkM/1cBOwbpUYABY4a/xSNq9Cm
aFxd4Tv43B650thEOwk1MsWAOP4+nDCMiEvmLO5RXpXk4m8TpIbs/lgNxCDR
BmLoZB6IH0jY/cZqj1bJMATIu1kTC0EMf3fHSeGzoMOLpDuoRoeMn+cvlOGD
rdYvAxQ4QhH8xwnj5/lHU2YSYhmiyN8MpCOfiBPzBT9LyhdsuVsTz0IeYLpG
ecivHOWhoxTl7014gOGqZ+KuZAgw6RssHJkqSNaSoIc/5B5eP96ughs4Rd0z
CCjPEDlnbrW4O+EGOEdplufn6A+4XwtnNp+ME3WuWqqoMIgi7ppEX8Ja0CvM
UjMAp0XY+A1h3pVwBsy3JpyJWBeGgUAx7A2B/Gb7ODFzw2kaEbOlP5J1B+6b
5uhqvZJo0/cTXqBbu9oEEO3gk64vZjMgHWqSIOM8JcNbWd487gWAnLM5GI0o
AMRKeN6esPzt1R5lSHmOvteGM5gd4jScr0rsrexuEh4MDAXD5qqdiUpKuSO7
LWHwO4UTPZmnXBNIXXaME3Chn4KB6cPU0K1XAW0wUELkfI3Vtg30Coh8O2Hf
u6guAW+Rk0xdrvbTFp1UBsmYxz3Ka6S8dk7zfJux4ndu2vNVX8SkIQ9Sw1sT
Nr1rOLuTicuXw6nKTnEa3LH/5TXNwWmLXqBqJK4S5BGbb0mYM29q8YquMkO5
MpyfJNC/yM+5QEqXWrJNHsSSL1UlssIDdUBjScKY99SuoenIF/20BAPubCgg
Ai5WxyXtwIRG2noZegN/itbgEeUeXAxqWHpy6+UPyHvlMJl4XB7IPUbGec7C
7yqXt7i00tMjyadJkHLrZQFTQd6GWOho9g31zJ7pjg3LU2YcC4v5BtQOwyVo
4O9UDCrnT9YvWHv9iu8a83TrawlzHafaIhN/m7osCKcUu8TxZkprdnVL0gax
TWqxiJECNGmH3xQiblADtVpEBuq+MxmaQADWRYGcYVQc20uVPowg5vdV1QKr
5bCn7Ho/yOa2N15zIRufZUpwYTgZSODnPjaSJ1v4cQhYhwgEaOp1bcLGeA+m
l9+TN8IKQjjKfyqOHF039J1prlyLEgYzUeVoc2ZJ0OcG4vWubVAZquHThh5J
J69KmAFP0oOZNbTuC+HI2w4h3iDQAL2iKoBONvAlX8fzXG2KH9tsXnymxlDx
NVqMiGOzsY4ooQ0j01rCFQmlPkrZWs5woclzwiGxHTabKNRQyn25n7ng0bHh
8COZ6hnh4LZbG1x45tsAv6UbyCBZLAzrMNq6tVQv5xSf7NasRaEoau3eBhXO
8GnaLLKFkCj9XRBWYHKZ05SdodRxZjj+WGz0VYjhGhNsBishdH5Cc3kpMJj9
of0M9TGCIdRvjzZM2dLXznzECxOae7IG5VAyd1IgVuzZBhVe16C8UmSAYUkd
zg/r7KnKznJCBnl8PhwU2iGytUK1/lOmGeck1HaWut5QsuU+gIeuotXoNqYN
QlzQLqR+EBKlfmcnNHe2CimUOZ0QCAR7tUFlOx3OS/7PTGive1ZOhKjfceEQ
0A6VESomm5tJIj87ob1nq5ishxRbOsaPAlCvvdsgxCWuQpERUiYxnR5W4Llh
CYmbOyocANohwmWpcKY9M6G9Zn5tzUk83ZRwCOAP0offwagX3sFYPjvrNUe3
cIklnOrNUCW3kYJsiuf93jqOhMnDi4EJMnYLZeE3N+wBN/3kjBgumtA+A2/6
cZI+81wET4ubsoBZTs0mheOsY278hQ/Zdck7VZuWs339gJqd1M7LWblLFwqJ
V+7+eAKcZzQ27YQnYr/ipRKfZk6HXgthK+snJ+GM1FBlAwN5hmlhN84pddOW
xGSOA0fB08NiNsRVjeBbI33gqJ0Q37hy4U2CaBJ4vEYdq6kUdXiCVFhPtItj
7p3MchJX4p9916QPnO6jRxWNVFu08RgaBuqnJkLRl7SrzVNlwde9RFtONvdj
xoVeSOkUa+pz5wdxuSBcDjg6EXO4tkfFCVtVgoVCycyL03mGzGW9PJDY91fy
veJ9/ZQi97Hy8lSZNogcmQgs16gYvCzffY2+nOWX2Glff4kfC9jnzkLaTU01
VJIJvHCHR1wr9aYpMpvkgOxNU/YvctR/d6ahcdAYecPS00fel6ErlzgKE728
xGRet/bizt8wd8tzLylh8LQmXxxDE3DacbfCizY1K4C+ftQT10zCa8e8BZa2
lcG6qerZQQX9ejlm8cZbb7eVzDB5yu/NMD+jPO+p+GZOHz1saozyp1wfhE7y
xJ/2VtG+RGQBjtPwHfDD+KG5Efrx7rF8A8yNDL08d0WkRBuWcXHuymtCFd73
6aWnXzHHwmvt7i1muFfhJiIVMbSDX5qwjiEbTNdOJLfCaXAdzaHMFAG/qU6l
vFcCQuU4UIf/Eb1HN8flaEFnH7U+W3UjN7aNRgGhAtSyWtDCoCCbbUAE1DGq
3IOQXVPgjN7Em2+rIpaniLDvXZV1dor42TZ07KtQQ2vvw4qOhGYOTr1hAYIz
BDmEScHgchtNHCnAJTcQ3kZPkzO7sCGTM7dFU5JveuviwDZ08OQjvBZfVyMT
FKAdQAw0O8WyRXNWLH5Qx/hoix+SI9FQkwV2+rmfhyjPmGS5kTcceDOmdkTt
p9mGVTKghXjKykPeAbdoP7cTDvRQaIUcH9VspzwxgUy5QORNTBIHxNDVbSi3
6mh3Yeda7pCCKQtSoInf6vHWISXV541aNcGXdkbaM290DcdNCmAmgE3e9UVW
iHLiSxVXLgt7iW/iQB260qVbZWLjgWSA26nt2wwwcdiPguYisbfHVkLNNuH0
pxLo7cNRXlbbtgpH+QlVQO+oDAntgdoiEMISZycp3J3Vb1vTlD1um4X9diXQ
I4uu1OY8cCCbhF1p4rQoBT0q7tpwb6OAa0ucYKVw3U4zu/pqHcyGYQdTCfRo
9Q02BMjmhCFh35A4s0tB7x62cNkiMihg4YlzxBSuy32Bh2fcXb5xQw8rwR0T
Nm5Z2muEjds7LE0B7q0MCK331cImPbkKrhy5B5XNmTKQ1hNry+BF4kg4hcnz
167yYikEI8UYCCtxPp3C2i9sv2KolWCMU4aLoULFp1Tp64JC4Wy+SoP2nuMF
/4SNsvX+H6qkKoU=\
\>"]]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.5158116791490974`*^9}],

Cell["References", "Subsection",
 PageWidth->PaperWidth],

Cell[TextData[{
 StyleBox["Greene, William H. (2002). ",
  FontSize->10],
 StyleBox["Econometric Analysis",
  FontSize->10,
  FontVariations->{"Underline"->True}],
 StyleBox[", 5th Ed., Upper Saddle River, NJ: Prentice Hall",
  FontSize->10],
 "\n",
 StyleBox["McCulloch, J. H. (1998). Linear Regression with Stable \
Disturbances. R. J. F. R. E. T. M. S. Adler (Editors), ",
  FontSize->10],
 StyleBox["A Practical Guide to Heavy Tails",
  FontSize->10,
  FontVariations->{"Underline"->True}],
 StyleBox[" (First ed., pp. 359-376). Boston, MA: Birkhauser.\nNolan, J. P.  \
(1997). Numerical Calculation of Stable Densities and Distribution Functions. \
",
  FontSize->10],
 StyleBox["Communications in Statistics - Stochastic Models, 13",
  FontSize->10,
  FontVariations->{"Underline"->True}],
 StyleBox["(4), 759-774.\n",
  FontSize->10],
 StyleBox["Young, M. S. , & Graff, R. A. (1995). Real Estate is Not Normal: A \
Fresh Look at Real Estate Return Distributions. ",
  FontSize->10],
 StyleBox["Journal of Real Estate Finance and Economics, 10",
  FontSize->10,
  FontVariations->{"Underline"->True}],
 StyleBox["(3), 225-259 (1995).",
  FontSize->10]
}], "Text"]
},
ScreenStyleEnvironment->"AllBrackets",
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{1008, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{"\[Copyright] 2003 Roger J. Brown", Inherited, Inherited}, {
  "\[Copyright] 2003 Roger J. Brown", Inherited, Inherited}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Manual.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 244, 8, 282, "Title"],
Cell[792, 30, 55, 1, 105, "Section"],
Cell[850, 33, 1392, 24, 380, "Text"],
Cell[2245, 59, 427, 16, 32, "NumberedEquation"],
Cell[2675, 77, 107, 2, 41, "Text"],
Cell[2785, 81, 198, 5, 32, "BulletText"],
Cell[2986, 88, 204, 5, 32, "BulletText"],
Cell[3193, 95, 309, 9, 32, "BulletText"],
Cell[3505, 106, 234, 5, 32, "BulletText"],
Cell[3742, 113, 178, 4, 32, "BulletText"],
Cell[3923, 119, 155, 2, 41, "Text"],
Cell[4081, 123, 279, 8, 32, "ItemizedText"],
Cell[4363, 133, 488, 17, 32, "ItemizedText"],
Cell[4854, 152, 522, 18, 32, "ItemizedText"],
Cell[5379, 172, 656, 24, 57, "ItemizedText"],
Cell[6038, 198, 622, 23, 32, "ItemizedText"],
Cell[6663, 223, 175, 4, 41, "Text"],
Cell[6841, 229, 666, 23, 108, "ItemizedText"],
Cell[7510, 254, 1857, 28, 1072, "Text"],
Cell[9370, 284, 1641, 36, 874, "Text"],
Cell[11014, 322, 645, 15, 94, "Input"],
Cell[11662, 339, 51, 1, 105, "Section"],
Cell[11716, 342, 209, 5, 58, "Text"],
Cell[CellGroupData[{
Cell[11950, 351, 746, 20, 145, "Input"],
Cell[12699, 373, 888, 27, 241, "Output"]
}, Open  ]],
Cell[13602, 403, 212, 8, 41, "Text"],
Cell[CellGroupData[{
Cell[13839, 415, 294, 8, 42, "Input"],
Cell[14136, 425, 810, 27, 241, "Output"]
}, Open  ]],
Cell[14961, 455, 515, 19, 90, "Text"],
Cell[CellGroupData[{
Cell[15501, 478, 413, 12, 43, "Input"],
Cell[15917, 492, 842, 27, 227, "Output"]
}, Open  ]],
Cell[16774, 522, 206, 5, 66, "Text"],
Cell[CellGroupData[{
Cell[17005, 531, 292, 8, 43, "Input"],
Cell[17300, 541, 790, 27, 227, "Output"]
}, Open  ]],
Cell[18105, 571, 500, 17, 90, "Text"],
Cell[18608, 590, 291, 8, 43, "Input"],
Cell[CellGroupData[{
Cell[18924, 602, 140, 4, 43, "Input"],
Cell[19067, 608, 335, 7, 32, "Print"]
}, Open  ]],
Cell[19417, 618, 65, 1, 105, "Section"],
Cell[19485, 621, 255, 7, 59, "Text"],
Cell[19743, 630, 119, 3, 62, "MathCaption"],
Cell[19865, 635, 53, 1, 43, "Input"],
Cell[19921, 638, 121, 2, 42, "Output"],
Cell[20045, 642, 326, 11, 74, "MathCaption"],
Cell[20374, 655, 263, 8, 68, "Input"],
Cell[20640, 665, 122, 2, 42, "Output"],
Cell[20765, 669, 107, 2, 62, "MathCaption"],
Cell[20875, 673, 160, 5, 43, "Input"],
Cell[21038, 680, 93, 1, 42, "Output"],
Cell[21134, 683, 263, 8, 68, "Input"],
Cell[21400, 693, 119, 2, 42, "Output"],
Cell[21522, 697, 321, 6, 90, "Text"],
Cell[21846, 705, 143, 6, 62, "MathCaption"],
Cell[21992, 713, 229, 6, 43, "Input"],
Cell[22224, 721, 137, 2, 42, "Output"],
Cell[22364, 725, 360, 15, 66, "Text"],
Cell[22727, 742, 267, 11, 43, "Input"],
Cell[22997, 755, 342, 12, 78, "MathCaption"],
Cell[23342, 769, 346, 12, 83, "Input"],
Cell[23691, 783, 135, 2, 42, "Output"],
Cell[23829, 787, 598, 9, 115, "Text"],
Cell[CellGroupData[{
Cell[24452, 800, 316, 7, 71, "Input"],
Cell[24771, 809, 164, 3, 42, "Output"],
Cell[24938, 814, 184, 4, 42, "Output"]
}, Open  ]],
Cell[25137, 821, 53, 1, 105, "Section"],
Cell[25193, 824, 107, 2, 40, "Subsection"],
Cell[25303, 828, 185, 4, 34, "Text"],
Cell[25491, 834, 719, 23, 105, "MathCaption"],
Cell[26213, 859, 170, 4, 43, "Input"],
Cell[26386, 865, 678, 18, 59, "Output"],
Cell[27067, 885, 680, 14, 164, "Text"],
Cell[27750, 901, 421, 15, 67, "NumberedEquation"],
Cell[28174, 918, 631, 23, 67, "NumberedEquation"],
Cell[28808, 943, 88, 1, 41, "Text"],
Cell[28899, 946, 299, 10, 87, "MathCaption"],
Cell[29201, 958, 152, 5, 43, "Input"],
Cell[29356, 965, 122, 2, 42, "Output"],
Cell[29481, 969, 315, 12, 62, "MathCaption"],
Cell[29799, 983, 51, 1, 43, "Input"],
Cell[29853, 986, 116, 2, 42, "Output"],
Cell[29972, 990, 571, 18, 108, "MathCaption"],
Cell[30546, 1010, 155, 5, 85, "Input"],
Cell[30704, 1017, 122, 2, 123, "Output"],
Cell[30829, 1021, 355, 11, 171, "MathCaption"],
Cell[31187, 1034, 244, 8, 85, "Input"],
Cell[31434, 1044, 121, 2, 123, "Output"],
Cell[31558, 1048, 567, 19, 214, "MathCaption"],
Cell[32128, 1069, 155, 5, 85, "Input"],
Cell[32286, 1076, 123, 2, 123, "Output"],
Cell[32412, 1080, 542, 19, 171, "MathCaption"],
Cell[32957, 1101, 247, 8, 85, "Input"],
Cell[33207, 1111, 126, 2, 123, "Output"],
Cell[33336, 1115, 166, 4, 132, "Text"],
Cell[33505, 1121, 130, 5, 132, "Text"],
Cell[33638, 1128, 231, 6, 169, "MathCaption"],
Cell[33872, 1136, 1498, 46, 240, "Input"],
Cell[35373, 1184, 725, 20, 123, "Output"],
Cell[36101, 1206, 421, 7, 280, "Text"],
Cell[36525, 1215, 115, 3, 82, "Text"],
Cell[36643, 1220, 356, 17, 64, "NumberedEquation"],
Cell[37002, 1239, 89, 1, 82, "Text"],
Cell[37094, 1242, 980, 20, 478, "Text"],
Cell[38077, 1264, 853, 36, 87, "Text"],
Cell[CellGroupData[{
Cell[38955, 1304, 235, 6, 85, "Input"],
Cell[39193, 1312, 797, 21, 168, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40027, 1338, 345, 8, 213, "MathCaption"],
Cell[CellGroupData[{
Cell[40397, 1350, 252, 8, 85, "Input"],
Cell[40652, 1360, 137, 2, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40826, 1367, 458, 14, 85, "Input"],
Cell[41287, 1383, 161, 3, 130, "Output"]
}, Open  ]]
}, Open  ]],
Cell[41475, 1390, 455, 14, 169, "MathCaption"],
Cell[CellGroupData[{
Cell[41955, 1408, 80, 1, 85, "Input"],
Cell[42038, 1411, 1379, 32, 160, "Output"]
}, Open  ]],
Cell[43432, 1446, 714, 22, 285, "Text"],
Cell[44149, 1470, 701, 28, 132, "MathCaption"],
Cell[CellGroupData[{
Cell[44875, 1502, 432, 11, 90, "Input"],
Cell[45310, 1515, 746, 20, 160, "Output"]
}, Open  ]],
Cell[46071, 1538, 247, 6, 126, "MathCaption"],
Cell[46321, 1546, 362, 11, 85, "Input"],
Cell[46686, 1559, 229, 6, 123, "Output"],
Cell[46918, 1567, 311, 7, 82, "Text"],
Cell[CellGroupData[{
Cell[47254, 1578, 303, 7, 85, "Input"],
Cell[47560, 1587, 333, 10, 175, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47930, 1602, 139, 2, 85, "Input"],
Cell[48072, 1606, 2567, 43, 991, "Output"]
}, Open  ]],
Cell[50654, 1652, 379, 8, 82, "Text"],
Cell[51036, 1662, 284, 5, 82, "Text"],
Cell[CellGroupData[{
Cell[51345, 1671, 283, 5, 138, "Input"],
Cell[51631, 1678, 224, 5, 123, "Output"],
Cell[51858, 1685, 239, 6, 123, "Output"]
}, Open  ]],
Cell[52112, 1694, 340, 9, 175, "MathCaption"],
Cell[52455, 1705, 237, 7, 90, "Input"],
Cell[52695, 1714, 171, 4, 123, "Output"],
Cell[52869, 1720, 259, 8, 90, "Input"],
Cell[53131, 1730, 153, 3, 123, "Output"],
Cell[53287, 1735, 1214, 24, 577, "Text"],
Cell[54504, 1761, 55, 1, 109, "Subsection"],
Cell[54562, 1764, 153, 4, 117, "Text"],
Cell[54718, 1770, 14553, 182, 474, "Graphics"],
Cell[69274, 1954, 307, 7, 82, "Text"],
Cell[CellGroupData[{
Cell[69606, 1965, 380, 9, 85, "Input"],
Cell[69989, 1976, 543, 11, 175, "Output"]
}, Open  ]],
Cell[70547, 1990, 701, 24, 180, "MathCaption"],
Cell[71251, 2016, 211, 6, 90, "Input"],
Cell[71465, 2024, 935, 27, 520, "Output"],
Cell[72403, 2053, 614, 20, 136, "Text"],
Cell[73020, 2075, 477, 22, 132, "MathCaption"],
Cell[73500, 2099, 222, 6, 90, "Input"],
Cell[73725, 2107, 1088, 32, 520, "Output"],
Cell[74816, 2141, 136, 3, 82, "Text"],
Cell[CellGroupData[{
Cell[74977, 2148, 151, 3, 85, "Input"],
Cell[75131, 2153, 739, 26, 520, "Output"]
}, Open  ]],
Cell[75885, 2182, 66, 1, 109, "Subsection"],
Cell[75954, 2185, 136, 4, 67, "Text"],
Cell[76093, 2191, 12085, 152, 177, "Graphics"],
Cell[88181, 2345, 254, 7, 132, "Text"],
Cell[CellGroupData[{
Cell[88460, 2356, 339, 8, 85, "Input"],
Cell[88802, 2366, 946, 21, 286, "Output"]
}, Open  ]],
Cell[89763, 2390, 268, 11, 82, "Text"],
Cell[90034, 2403, 408, 13, 85, "Input"],
Cell[90445, 2418, 663, 24, 184, "MathCaption"],
Cell[91111, 2444, 374, 12, 96, "Input"],
Cell[91488, 2458, 674, 18, 123, "Output"],
Cell[92165, 2478, 352, 11, 126, "MathCaption"],
Cell[92520, 2491, 218, 6, 85, "Input"],
Cell[92741, 2499, 671, 18, 123, "Output"],
Cell[93415, 2519, 770, 28, 181, "MathCaption"],
Cell[94188, 2549, 322, 10, 94, "Input"],
Cell[94513, 2561, 663, 18, 123, "Output"],
Cell[95179, 2581, 263, 5, 169, "MathCaption"],
Cell[95445, 2588, 210, 6, 85, "Input"],
Cell[95658, 2596, 671, 18, 123, "Output"],
Cell[96332, 2616, 241, 5, 169, "MathCaption"],
Cell[96576, 2623, 210, 6, 85, "Input"],
Cell[96789, 2631, 668, 18, 123, "Output"],
Cell[97460, 2651, 205, 5, 126, "MathCaption"],
Cell[97668, 2658, 161, 4, 85, "Input"],
Cell[97832, 2664, 671, 18, 123, "Output"],
Cell[98506, 2684, 65, 1, 109, "Subsection"],
Cell[98574, 2687, 269, 5, 166, "Text"],
Cell[98846, 2694, 11186, 141, 151, "Graphics"],
Cell[110035, 2837, 287, 7, 132, "Text"],
Cell[CellGroupData[{
Cell[110347, 2848, 344, 8, 85, "Input"],
Cell[110694, 2858, 938, 21, 237, "Output"]
}, Open  ]],
Cell[111647, 2882, 688, 21, 217, "MathCaption"],
Cell[112338, 2905, 350, 11, 85, "Input"],
Cell[112691, 2918, 668, 18, 123, "Output"],
Cell[113362, 2938, 646, 11, 300, "MathCaption"],
Cell[114011, 2951, 473, 16, 91, "Input"],
Cell[114487, 2969, 133, 2, 123, "Output"],
Cell[114623, 2973, 60, 1, 109, "Subsection"],
Cell[114686, 2976, 112, 3, 67, "Text"],
Cell[114801, 2981, 10988, 139, 360, "Graphics"],
Cell[125792, 3122, 870, 32, 169, "MathCaption"],
Cell[126665, 3156, 349, 11, 94, "Input"],
Cell[127017, 3169, 657, 18, 123, "Output"],
Cell[127677, 3189, 373, 11, 169, "MathCaption"],
Cell[CellGroupData[{
Cell[128075, 3204, 386, 9, 85, "Input"],
Cell[128464, 3215, 107, 1, 123, "Output"]
}, Open  ]],
Cell[128586, 3219, 279, 8, 126, "MathCaption"],
Cell[128868, 3229, 164, 4, 85, "Input"],
Cell[129035, 3235, 668, 18, 123, "Output"],
Cell[129706, 3255, 206, 5, 126, "MathCaption"],
Cell[129915, 3262, 185, 5, 85, "Input"],
Cell[130103, 3269, 669, 18, 123, "Output"],
Cell[130775, 3289, 1053, 38, 219, "MathCaption"],
Cell[131831, 3329, 255, 8, 94, "Input"],
Cell[132089, 3339, 667, 18, 123, "Output"],
Cell[132759, 3359, 248, 7, 126, "MathCaption"],
Cell[133010, 3368, 234, 6, 85, "Input"],
Cell[133247, 3376, 131, 2, 123, "Output"],
Cell[133381, 3380, 266, 6, 169, "MathCaption"],
Cell[133650, 3388, 242, 7, 85, "Input"],
Cell[133895, 3397, 667, 18, 123, "Output"],
Cell[134565, 3417, 107, 2, 126, "MathCaption"],
Cell[134675, 3421, 200, 5, 94, "Input"],
Cell[134878, 3428, 117, 2, 123, "Output"],
Cell[134998, 3432, 429, 12, 217, "MathCaption"],
Cell[135430, 3446, 183, 4, 85, "Input"],
Cell[135616, 3452, 131, 2, 123, "Output"],
Cell[135750, 3456, 414, 13, 85, "Input"],
Cell[136167, 3471, 132, 2, 123, "Output"],
Cell[136302, 3475, 163, 2, 126, "MathCaption"],
Cell[136468, 3479, 206, 5, 85, "Input"],
Cell[136677, 3486, 110, 1, 123, "Output"],
Cell[136790, 3489, 417, 13, 174, "MathCaption"],
Cell[CellGroupData[{
Cell[137232, 3506, 443, 10, 85, "Input"],
Cell[137678, 3518, 111, 1, 123, "Output"]
}, Open  ]],
Cell[137804, 3522, 389, 11, 94, "Input"],
Cell[138196, 3535, 720, 19, 123, "Output"],
Cell[138919, 3556, 69, 1, 109, "Subsection"],
Cell[138991, 3559, 222, 7, 117, "Text"],
Cell[CellGroupData[{
Cell[139238, 3570, 690, 15, 189, "Input"],
Cell[139931, 3587, 5240, 116, 1339, "Output"]
}, Open  ]],
Cell[145186, 3706, 238, 5, 181, "Text"],
Cell[CellGroupData[{
Cell[145449, 3715, 605, 14, 138, "Input"],
Cell[146057, 3731, 1145, 35, 520, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147239, 3771, 409, 10, 138, "Input"],
Cell[147651, 3783, 874, 27, 520, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148562, 3815, 394, 10, 85, "Input"],
Cell[148959, 3827, 11844, 201, 729, 996, 21, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[160818, 4031, 70, 1, 85, "Input"],
Cell[160891, 4034, 56, 1, 109, "Subsection"],
Cell[160950, 4037, 1169, 32, 312, "Text"]
}
]
*)

(* End of internal cache information *)
