(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.3' *)

(***************************************************************************)
(*                                                                         *)
(*                                                                         *)
(*  Under the Wolfram FreeCDF terms of use, this file and its content are  *)
(*  bound by the Creative Commons BY-SA Attribution-ShareAlike license.    *)
(*                                                                         *)
(*        For additional information concerning CDF licensing, see:        *)
(*                                                                         *)
(*         www.wolfram.com/cdf/adopting-cdf/licensing-options.html         *)
(*                                                                         *)
(*                                                                         *)
(***************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1088,         20]
NotebookDataLength[   1153165,      23034]
NotebookOptionsPosition[   1090344,      21927]
NotebookOutlinePosition[   1116942,      22519]
CellTagsIndexPosition[   1116353,      22498]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["11", "BookChapterNumber",
 CellChangeTimes->{{3.531942383769843*^9, 3.5319423839128513`*^9}, 
   3.5391770037216454`*^9},
 Background->RGBColor[
  0.9333333333333333, 0.1803921568627451, 
   0.1411764705882353],ExpressionUUID->"490f6bc5-578d-4fe8-a3aa-27c5f67fd3c2"],

Cell["The Management Problem", "BookChapterTitle",
 CellChangeTimes->{{3.5319424346317525`*^9, 3.531942438556977*^9}, 
   3.5391770037226453`*^9},
 TextAlignment->Center,
 CounterAssignments->{{
   "BookChapterNumber", 
    11}},ExpressionUUID->"523614c2-4ed0-452d-be92-07e3620deee7"],

Cell[TextData[StyleBox["\[OpenCurlyDoubleQuote]...all that can be required of \
a trustee is that he conduct himself faithfully and exercise sound discretion \
and observe how men of prudence, discretion and intelligence manage their own \
affairs-not in regard to speculation, but in regard to the permanent \
disposition of their funds, considering the probable income as well as the \
probable safety of the capital to be invested.\[CloseCurlyDoubleQuote]",
 FontSlant->"Italic",
 CharacterEncoding -> "WindowsANSI"]], "Epigraph",
 CellChangeTimes->{3.5319424834325438`*^9, 3.539177003723645*^9},
 TextAlignment->Center,ExpressionUUID->"159f5df2-1f8f-4042-989c-5cfc6e795fe4"],

Cell[TextData[{
 StyleBox["The Supreme Court of Massachusetts",
  FontWeight->"Bold",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" in Harvard College versus Amory (1830) articulating the Prudent \
Man Rule",
  CharacterEncoding -> "WindowsANSI"]
}], "EpigraphAuthor",
 CellChangeTimes->{3.53194250347369*^9, 3.539177003724645*^9},
 TextAlignment->Center,ExpressionUUID->"6750cc83-8604-4e10-9194-45e876d0a97f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Rasterize", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "350"}]}], "]"}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.411774246453125*^9, 3.411774263453125*^9}, {
   3.539176649435381*^9, 3.53917666533329*^9}, 3.539177003725645*^9, {
   3.58680863900413*^9, 
   3.58680863918614*^9}},ExpressionUUID->"e45e90ec-0f01-46ac-9eba-\
c18b52276273"],

Cell["11.1. Introduction", "Section",
 CellChangeTimes->{{3.5319425254599476`*^9, 3.531942527588069*^9}, 
   3.5391770037266455`*^9},ExpressionUUID->"2328d445-9881-4e61-975f-\
31aaa93f5457"],

Cell["\<\
This chapter addresses what is known as \"the agency problem\", recognizing \
that when an agent holds someone else's capital the agent's objectives are \
often different from the owner's. 
In this chapter we will\
\>", "Text",
 CellChangeTimes->{
  3.5391770037276454`*^9},ExpressionUUID->"d143e6ad-de63-400d-a590-\
66f44ea315a8"],

Cell["\<\
Describe the optimization problem that faces any manager of properties in \
multiple locations;\
\>", "Item1",
 CellChangeTimes->{{3.5319425577607946`*^9, 3.5319425596509027`*^9}, 
   3.5391770037276454`*^9, {3.5412488818198347`*^9, 
   3.541248882373866*^9}},ExpressionUUID->"08f56092-ce3a-4022-84ee-\
4608b23dcee6"],

Cell["\<\
Describe the owner's problem showing how his objectives differ; and\
\>", "Item1",
 CellChangeTimes->{
  3.531942561658018*^9, 3.5391770037306457`*^9, {3.541248885190027*^9, 
   3.541248887003131*^9}},ExpressionUUID->"91003fae-bdfb-449e-9bc3-\
bc96818466d2"],

Cell["\<\
Illustrate the misalignment of incentives and compensation arrangements \
common to the business of managing small investment properties.\
\>", "Item1",
 CellChangeTimes->{3.531942563203106*^9, 
  3.5391770037306457`*^9},ExpressionUUID->"c29adc24-8871-4722-89ac-\
a46d28282351"],

Cell["11.2. The unavoidable management issue", "Section",
 CellChangeTimes->{{3.531942814755494*^9, 3.531942823832013*^9}, 
   3.5391770037306457`*^9},ExpressionUUID->"7596808b-bb68-4cbd-a172-\
f6b412fa869f"],

Cell["\<\
There is little debate that the ownership of real estate involves management. \
The debate is about (1) who shall do the management, (2) what management \
costs, (3) how one accounts for that cost and (4) what management arrangement \
is the most efficient.  We observed in Chapter 8 that the owner may do his \
own management. If he does he adds to his investment with each hour of labor \
he applies to his rental property that he could have applied to other \
activities, profitable or otherwise. At a minimum, this has the effect of \
complicating the return calculation. Alternatively, to preserve both the \
integrity of the return calculation and the owner's peace of mind one may \
contract for management services with a third party whose fee becomes a part \
of the expense schedule. In this way management is charged against the \
property's income before the owner's return is calculated.\
\>", "Text",
 CellChangeTimes->{3.5333204885818696`*^9, 
  3.5391770037306457`*^9},ExpressionUUID->"f8ea72d1-b6c3-4123-bb98-\
f3b9144dde61"],

Cell[TextData[{
 "Things are rarely that simple.  Property size and location play a \
significant role. There is a suspicion that so-called \"professional\" \
property management really isn't.  Especially for small properties, the \
quality of property management can vary widely.  A significant literature \
exists on the subject of agency, studying the separation of ownership and \
control. ",
 StyleBox["Our story is about the ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["combination",
  PageWidth->WindowWidth,
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" of ownership and control.",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{{3.5333204885818696`*^9, 3.5333204898909445`*^9}, 
   3.5391770037306457`*^9},ExpressionUUID->"2fef7653-ba7c-4305-b11c-\
a8f91b129124"],

Cell[CellGroupData[{

Cell["11.3. The property manager\[CloseCurlyQuote]s dilemma", "Section",
 CellChangeTimes->{
  3.5319428510075674`*^9, {3.5337445250731697`*^9, 3.5337445417181215`*^9}, 
   3.5391770037306457`*^9},ExpressionUUID->"7d1d0a08-4129-42e7-bdc6-\
7d822c773c10"],

Cell["\<\
A company offering property management services, like any firm, wishes to \
maximize net profit by increasing revenue and lowering costs. The rule \
adopted to accomplish this is called the firm's \"production function\".  To \
create this function we assume that the firm generates revenue as management \
fees, and incurs two broad classes of expenses.  The first are in-house costs \
consisting primarily of accounting services rendered to owners. For \
simplicity these are assumed to be fixed. The second involves dispatching an \
employee to visit and inspect those properties under management.  These \
latter costs are variable and will be generally referred to as \"transaction \
costs\" because each visit to a property involves a transaction that incurs, \
at a minimum, some travel expense (hence these may also be considered \
\"transportation costs\"). Important factors in these variable costs are the \
number of properties the manager chooses to manage, the size of those \
properties and the distance between them.\
\>", "Text",
 CellChangeTimes->{
  3.531942871118718*^9, {3.534111038865348*^9, 3.534111039615391*^9}, 
   3.5391770037306457`*^9},ExpressionUUID->"aefcc9ed-fecd-4359-81d2-\
ce4dd41f2dbd"],

Cell[TextData[{
 "Initially we will assume that management fees ",
 StyleBox["realized",
  FontSlant->"Italic"],
 " are calculated as a rate per unit.  In actual practice the fee is ",
 StyleBox["charged",
  FontSlant->"Italic"],
 " as a percentage of income, something we shall address later.  For now \
realized fees are computed by multiplying",
 StyleBox[" a rate, ",
  Background->None],
 StyleBox["g",
  FontSlant->"Italic",
  Background->None],
 StyleBox[", times the number of units, ",
  Background->None],
 StyleBox["u",
  FontSlant->"Italic",
  Background->None],
 StyleBox[".",
  Background->None]
}], "Text",
 CellChangeTimes->{{3.531942871118718*^9, 3.5319428801702356`*^9}, 
   3.5391770037306457`*^9},ExpressionUUID->"41a413df-f927-42a6-b13d-\
802e26ad0209"],

Cell[TextData[{
 "Therefore, the first net profit function, ",
 StyleBox["np",
  FontSlant->"Italic"],
 ", we will use is:"
}], "Text",
 CellChangeTimes->{{3.531942871118718*^9, 3.531942881244297*^9}, 
   3.5391770037316456`*^9},ExpressionUUID->"3ac466cc-1059-424b-86eb-\
90ded96f419b"],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox["np",
    FontSlant->"Italic"], "=", 
   RowBox[{
    RowBox[{"g", " ", "u"}], "-", 
    StyleBox["ac",
     FontSlant->"Italic"], "-", 
    StyleBox["tc",
     FontSlant->"Italic"]}]}], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5319429021834946`*^9, 
  3.5391770037316456`*^9},ExpressionUUID->"e983adf2-dd10-4a55-8087-\
9694b9b9b204"],

Cell["Where:", "Text",
 CellChangeTimes->{{3.5319429104619684`*^9, 3.5319429212835875`*^9}, {
   3.531965259286248*^9, 3.5319652785323486`*^9}, {3.533319938189389*^9, 
   3.5333199514011445`*^9}, 
   3.5391770037326455`*^9},ExpressionUUID->"15a15b70-0e1b-4f25-bdfe-\
e5ffcf9115d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"np\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"u\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"ac\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"tc\",FontSlant->\"Italic\"]\)\>\""}], "}"}], 
        ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "5"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<net profits\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"rate\",Background->None]\)\!\(\*StyleBox[\" \
\",Background->None]\)\!\(\*StyleBox[\"per\",Background->None]\)\!\(\*\
StyleBox[\" \",Background->None]\)\!\(\*StyleBox[\"unit\",Background->None]\)\
\!\(\*StyleBox[\" \
\",Background->None]\)\!\(\*StyleBox[\"at\",Background->None]\)\!\(\*StyleBox[\
\" \",Background->None]\)\!\(\*StyleBox[\"which\",Background->None]\)\!\(\*\
StyleBox[\" \
\",Background->None]\)\!\(\*StyleBox[\"fee\",Background->None]\)\!\(\*\
StyleBox[\" \",Background->None]\)\!\(\*StyleBox[\"income\",Background->None]\
\)\!\(\*StyleBox[\" \
\",Background->None]\)\!\(\*StyleBox[\"is\",Background->None]\)\!\(\*StyleBox[\
\" \",Background->None]\)\!\(\*StyleBox[\"realized\",Background->None]\)\>\"",
           ",", "\"\<\!\(\*StyleBox[\"number\",Background->None]\)\!\(\*\
StyleBox[\" \",Background->None]\)\!\(\*StyleBox[\"of\",Background->None]\)\!\
\(\*StyleBox[\" \
\",Background->None]\)\!\(\*StyleBox[\"units\",Background->None]\)\!\(\*\
StyleBox[\" \
\",Background->None]\)\!\(\*StyleBox[\"managed\",Background->None]\)\>\"", 
          ",", "\"\<accounting costs\>\"", ",", 
          "\"\<transaction (transportation) costs, a function of the number \
of locations, \!\(\*StyleBox[\"loc\",FontSlant->\"Italic\"]\), a \
transportation rate, \!\(\*StyleBox[\"h\",FontSlant->\"Italic\"]\),and \
distance, \!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\), both between \
locations and from the office to various locations.\>\""}], "}"}]}], "}"}], 
      "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.5333200428873773`*^9, 3.533320208085826*^9}, 
   3.5391770037356462`*^9},ExpressionUUID->"a266a4fc-6be5-4a64-a64d-\
96140e026a1d"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"np\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"net profits\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"g\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", \
"\<\"\\!\\(\\*StyleBox[\\\"rate\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"\
 \\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"per\\\",Background->None]\\)\\\
!\\(\\*StyleBox[\\\" \
\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"unit\\\",Background->None]\\)\\\
!\\(\\*StyleBox[\\\" \
\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"at\\\",Background->None]\\)\\!\
\\(\\*StyleBox[\\\" \
\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"which\\\",Background->None]\\)\
\\!\\(\\*StyleBox[\\\" \
\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"fee\\\",Background->None]\\)\\!\
\\(\\*StyleBox[\\\" \
\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"income\\\",Background->None]\\)\
\\!\\(\\*StyleBox[\\\" \
\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"is\\\",Background->None]\\)\\!\
\\(\\*StyleBox[\\\" \\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"realized\\\
\",Background->None]\\)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"u\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"\\!\\(\\*StyleBox[\\\"number\\\",Background->None]\\)\\!\\(\
\\*StyleBox[\\\" \
\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"of\\\",Background->None]\\)\\!\
\\(\\*StyleBox[\\\" \
\\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"units\\\",Background->None]\\)\
\\!\\(\\*StyleBox[\\\" \\\",Background->None]\\)\\!\\(\\*StyleBox[\\\"managed\
\\\",Background->None]\\)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"ac\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"accounting costs\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"tc\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"transaction (transportation) costs, a function of the number \
of locations, \\!\\(\\*StyleBox[\\\"loc\\\",FontSlant->\\\"Italic\\\"]\\), a \
transportation rate, \
\\!\\(\\*StyleBox[\\\"h\\\",FontSlant->\\\"Italic\\\"]\\),and distance, \
\\!\\(\\*StyleBox[\\\"d\\\",FontSlant->\\\"Italic\\\"]\\), both between \
locations and from the office to various locations.\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.5333206306439953`*^9, 3.533685018765625*^9, 
  3.5337444779004717`*^9, 3.533756931421875*^9, 3.5337569815625*^9, 
  3.5391768120736837`*^9, 3.539177003737646*^9, 3.5400537831432266`*^9, 
  3.5400550127795577`*^9, 3.540128550913803*^9, 3.541248420075424*^9, 
  3.5412489658156385`*^9, 3.5412498929526677`*^9, 3.5416049012738547`*^9, 
  3.5433495043304777`*^9, 3.5868086131876535`*^9, 3.6983497463870363`*^9, 
  3.698349859112804*^9, 
  3.731421850432303*^9},ExpressionUUID->"e4bc0f35-2d30-43d0-b92f-\
0b4525892c8e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"np", ":=", 
  RowBox[{
   RowBox[{"g", " ", "u"}], " ", "-", "ac", "-", "tc"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.539177003738646*^9},ExpressionUUID->"1e3cd73b-54ec-449a-bade-\
b64979d2cd32"],

Cell["\<\
Transaction costs are modeled as an increasing function of location count and \
distance:\
\>", "Text",
 CellChangeTimes->{
  3.539177003738646*^9},ExpressionUUID->"a21b0567-8460-405d-9a2e-\
06ae2149c794"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"tc", "=", 
    FormBox[
     FractionBox[
      RowBox[{"h", " ", "u", " ", 
       FormBox[
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"d", " ", "loc"}]],
        TraditionalForm]}], "2"],
     TraditionalForm]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.531942958290704*^9, 
  3.539177003738646*^9},ExpressionUUID->"e58e6a32-ce7e-4d64-b5af-\
d7eb1aeff97a"],

Cell["Where:", "Text",
 CellChangeTimes->{{3.5333203336720095`*^9, 3.533320336568175*^9}, 
   3.539177003739646*^9},ExpressionUUID->"cd93dad0-3874-4771-8ad9-\
9ccd894c13c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"tc\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"h\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"loc\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\[ExponentialE]\>\""}], "}"}], ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "5"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<transaction costs\>\"", ",", 
          "\"\<a rate at which transaction costs are incurred\>\"", ",", 
          "\"\<a remoteness factor to provide for distance of each property \
from the office\>\"", ",", "\"\<number of locations\>\"", ",", 
          "\"\<the base of the natural log\>\""}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.5333200428873773`*^9, 3.53332013664974*^9}, {
   3.5333202708414154`*^9, 3.5333203156879807`*^9}, 
   3.5391770037406464`*^9},ExpressionUUID->"142fc510-057a-4758-92e0-\
c6d9487a2b14"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"tc\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"transaction costs\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"h\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"a rate at which transaction costs are incurred\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"d\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"a remoteness factor to provide for distance of each \
property from the office\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"loc\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"number of locations\"\>"},
     {"\<\"\[ExponentialE]\"\>", "\<\"=\"\>", "\<\"the base of the natural \
log\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 ShowCellLabel->False,
 CellChangeTimes->{3.533320318417137*^9, 3.5333204292194743`*^9, 
  3.533685018875*^9, 3.533744478330496*^9, 3.533756931546875*^9, 
  3.5337569816875*^9, 3.5391768126867185`*^9, 3.5391770037406464`*^9, 
  3.5400537837872634`*^9, 3.540055012847562*^9, 3.5401285515548396`*^9, 
  3.5412484209644747`*^9, 3.5412489983054967`*^9, 3.541249893773715*^9, 
  3.5416049018758893`*^9, 3.543349504392481*^9, 3.586808613197654*^9, 
  3.69834974641511*^9, 3.6983498591870017`*^9, 
  3.731421850464368*^9},ExpressionUUID->"3c37305f-7431-4306-a1d8-\
b25a30919ff5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"tc", ":=", 
  FractionBox[
   RowBox[{"h", " ", "u", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"d", " ", "loc"}]]}], "2"]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.5391770037416463`*^9},ExpressionUUID->"44c3878c-63e0-4d75-8cc7-\
272cec170ae2"],

Cell[TextData[{
 "Illustrating a model with many variables requires reducing their number by \
fixing some of the variables at specific values. We use several datasets to \
facilitate this. ",
 StyleBox["Table 11-1",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 "provides the datasets we will use in this chapter."
}], "Text",
 CellChangeTimes->{{3.531945543217553*^9, 3.531945554886221*^9}, {
   3.531945603555004*^9, 3.5319456048710794`*^9}, 3.5391768854668813`*^9, 
   3.5391770037416463`*^9},ExpressionUUID->"6e13381c-8207-498a-9a39-\
965cf76fff6b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"d1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ac", "\[Rule]", "10"}], ",", 
     RowBox[{"g", "\[Rule]", "500"}], ",", 
     RowBox[{"h", "\[Rule]", ".05"}], ",", 
     RowBox[{"u", "\[Rule]", "50"}], ",", 
     RowBox[{"d", "\[Rule]", ".6"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ac", "\[Rule]", "10"}], ",", 
     RowBox[{"g", "\[Rule]", "500"}], ",", 
     RowBox[{"h", "\[Rule]", ".05"}], ",", 
     RowBox[{"u", "\[Rule]", "50"}], ",", 
     RowBox[{"d", "\[Rule]", ".5"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ac", "\[Rule]", "10"}], ",", 
     RowBox[{"g", "\[Rule]", "500"}], ",", 
     RowBox[{"h", "\[Rule]", ".05"}], ",", 
     RowBox[{"d", "\[Rule]", ".5"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d4", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ac", "\[Rule]", "10"}], ",", 
     RowBox[{"g", "\[Rule]", "500"}], ",", 
     RowBox[{"h", "\[Rule]", ".05"}], ",", 
     RowBox[{"u", "\[Rule]", "50"}], ",", 
     RowBox[{"d", "\[Rule]", ".5"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", "1.25"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", ".05"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d5", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ac", "\[Rule]", "10"}], ",", 
     RowBox[{"h", "\[Rule]", ".05"}], ",", 
     RowBox[{"u", "\[Rule]", "50"}], ",", 
     RowBox[{"d", "\[Rule]", ".5"}], ",", 
     RowBox[{"loc", "\[Rule]", "3"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", "1.25"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", ".05"}], ",", 
     RowBox[{"mgt", "\[Rule]", ".1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d6", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fc", "\[Rule]", "50"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", "1.25"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", ".05"}], ",", 
     RowBox[{"mgt", "\[Rule]", ".1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d7", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ac", "\[Rule]", "10"}], ",", 
     RowBox[{"h", "\[Rule]", ".05"}], ",", 
     RowBox[{"u", "\[Rule]", "50"}], ",", 
     RowBox[{"d", "\[Rule]", ".5"}], ",", 
     RowBox[{"loc", "\[Rule]", "15"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", "1.25"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", ".05"}], ",", 
     RowBox[{"mgt", "\[Rule]", ".1"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PadRight", "[", 
         RowBox[{"#1", ",", "10", ",", "\"\<\>\""}], "]"}], "&"}], "/@", 
       RowBox[{"{", 
        RowBox[{
        "d1", ",", "d2", ",", "d3", ",", "d4", ",", "d5", ",", "d6", ",", 
         "d7"}], "}"}]}], "]"}], ",", 
     RowBox[{"TableHeadings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<d1\>\"", ",", "\"\<d2\>\"", ",", "\"\<d3\>\"", ",", 
          "\"\<d4\>\"", ",", "\"\<d5\>\"", ",", "\"\<d6\>\"", ",", 
          "\"\<d7\>\""}], "}"}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.531943090716278*^9, 3.531943091819341*^9}, {
   3.5319431372259383`*^9, 3.53194321086115*^9}, {3.5319432425509624`*^9, 
   3.531943497799562*^9}, {3.5319435685436087`*^9, 3.531943703619334*^9}, {
   3.5319448787335467`*^9, 3.5319449154086447`*^9}, 3.5319454281809735`*^9, {
   3.5319506965073047`*^9, 3.531950908380423*^9}, 3.531951062651247*^9, {
   3.5319512534421597`*^9, 3.5319512675969687`*^9}, 3.5319516469976697`*^9, {
   3.5319517024498415`*^9, 3.531951808867928*^9}, {3.5319518610449123`*^9, 
   3.531951874177664*^9}, {3.5319519220154*^9, 3.5319519397784157`*^9}, {
   3.5319519964736586`*^9, 3.531951999982859*^9}, {3.533320526910062*^9, 
   3.5333205394937816`*^9}, 
   3.5391770037456465`*^9},ExpressionUUID->"0955eda2-fd37-4f04-8c4b-\
a0d03944d36e"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"d1\"\>",
        HoldForm], 
       TagBox["\<\"d2\"\>",
        HoldForm], 
       TagBox["\<\"d3\"\>",
        HoldForm], 
       TagBox["\<\"d4\"\>",
        HoldForm], 
       TagBox["\<\"d5\"\>",
        HoldForm], 
       TagBox["\<\"d6\"\>",
        HoldForm], 
       TagBox["\<\"d7\"\>",
        HoldForm]},
      {
       RowBox[{"ac", "\[Rule]", "10"}], 
       RowBox[{"ac", "\[Rule]", "10"}], 
       RowBox[{"ac", "\[Rule]", "10"}], 
       RowBox[{"ac", "\[Rule]", "10"}], 
       RowBox[{"ac", "\[Rule]", "10"}], 
       RowBox[{"fc", "\[Rule]", "50"}], 
       RowBox[{"ac", "\[Rule]", "10"}]},
      {
       RowBox[{"g", "\[Rule]", "500"}], 
       RowBox[{"g", "\[Rule]", "500"}], 
       RowBox[{"g", "\[Rule]", "500"}], 
       RowBox[{"g", "\[Rule]", "500"}], 
       RowBox[{"h", "\[Rule]", "0.05`"}], 
       RowBox[{"\[Alpha]", "\[Rule]", "1.25`"}], 
       RowBox[{"h", "\[Rule]", "0.05`"}]},
      {
       RowBox[{"h", "\[Rule]", "0.05`"}], 
       RowBox[{"h", "\[Rule]", "0.05`"}], 
       RowBox[{"h", "\[Rule]", "0.05`"}], 
       RowBox[{"h", "\[Rule]", "0.05`"}], 
       RowBox[{"u", "\[Rule]", "50"}], 
       RowBox[{"\[Beta]", "\[Rule]", "0.05`"}], 
       RowBox[{"u", "\[Rule]", "50"}]},
      {
       RowBox[{"u", "\[Rule]", "50"}], 
       RowBox[{"u", "\[Rule]", "50"}], 
       RowBox[{"d", "\[Rule]", "0.5`"}], 
       RowBox[{"u", "\[Rule]", "50"}], 
       RowBox[{"d", "\[Rule]", "0.5`"}], 
       RowBox[{"mgt", "\[Rule]", "0.1`"}], 
       RowBox[{"d", "\[Rule]", "0.5`"}]},
      {
       RowBox[{"d", "\[Rule]", "0.6`"}], 
       RowBox[{"d", "\[Rule]", "0.5`"}], "\<\"\"\>", 
       RowBox[{"d", "\[Rule]", "0.5`"}], 
       RowBox[{"loc", "\[Rule]", "3"}], "\<\"\"\>", 
       RowBox[{"loc", "\[Rule]", "15"}]},
      {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
       RowBox[{"\[Alpha]", "\[Rule]", "1.25`"}], 
       RowBox[{"\[Alpha]", "\[Rule]", "1.25`"}], "\<\"\"\>", 
       RowBox[{"\[Alpha]", "\[Rule]", "1.25`"}]},
      {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
       RowBox[{"\[Beta]", "\[Rule]", "0.05`"}], 
       RowBox[{"\[Beta]", "\[Rule]", "0.05`"}], "\<\"\"\>", 
       RowBox[{"\[Beta]", "\[Rule]", "0.05`"}]},
      {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
       RowBox[{"mgt", "\[Rule]", "0.1`"}], "\<\"\"\>", 
       RowBox[{"mgt", "\[Rule]", "0.1`"}]},
      {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>"},
      {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {None, {"d1", "d2", "d3", "d4", "d5", "d6", "d7"}}]]],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{
  3.531951874978709*^9, {3.531951922696439*^9, 3.5319519407734723`*^9}, 
   3.5319520007729044`*^9, 3.5319520436423564`*^9, 3.5320235934310484`*^9, 
   3.532123277888673*^9, 3.5322123195815663`*^9, 3.5333204292944784`*^9, 
   3.53332054033883*^9, 3.533685019*^9, 3.533744478820524*^9, 
   3.533756931703125*^9, 3.5337569818125*^9, 3.5391768134217606`*^9, 
   3.5391770037476463`*^9, 3.5400537845063047`*^9, 3.540055012914565*^9, 
   3.5401285522628803`*^9, 3.5412484221465425`*^9, 3.541249894651765*^9, 
   3.541604902540927*^9, 3.5433495044534845`*^9, 3.586808613212655*^9, 
   3.698349746468251*^9, 3.6983498592170815`*^9, 3.7314218504994564`*^9},
 TextAlignment->Center,ExpressionUUID->"fd36026a-901a-40dd-9fcb-0d3e4e2f5c24"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table 11.1.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "TableTitleLabel"],
 "Seven datasets for examples"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{89.33333333333333, 10.}, {1., 7.}},
 CellChangeTimes->{{3.533320555300686*^9, 3.5333205577248244`*^9}, 
   3.5391770037476463`*^9},
 TextAlignment->Center,ExpressionUUID->"98137634-82bc-4121-8c07-fdb9511d6eb3"],

Cell[TextData[{
 "The first two datasets, ",
 StyleBox["d1",
  FontWeight->"Bold"],
 " and ",
 StyleBox["d2",
  FontWeight->"Bold"],
 " differ only in the value we give to the distance factor, ",
 StyleBox["d",
  FontSlant->"Italic"],
 ". As one might expect, at different remoteness factors, ",
 StyleBox["d",
  FontSlant->"Italic"],
 ", the steepness of the ",
 StyleBox["tc",
  FontSlant->"Italic"],
 " function varies over different numbers of locations in a portfolio \
containing a fixed number of units as we see in Figure 11.1."
}], "Text",
 CellChangeTimes->{{3.531945616710757*^9, 3.5319456308175635`*^9}, {
   3.5319526345141525`*^9, 3.5319526402404795`*^9}, {3.53195269094338*^9, 
   3.5319526956046467`*^9}, 
   3.5391770037486467`*^9},ExpressionUUID->"553944a8-e009-43c7-bf55-\
782bd4471eb1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Legended", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tc", "/.", "\[InvisibleSpace]", "d1"}], ",", 
       RowBox[{"tc", "/.", "\[InvisibleSpace]", "d2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"loc", ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", "Blue"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", "Red"}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<# locations\>\"", ",", "\"\<transportation\\ncosts\>\""}],
        "}"}]}]}], "]"}], ",", 
   RowBox[{"Placed", "[", 
    RowBox[{
     RowBox[{"LineLegend", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", "Blue"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", "Red"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.6\>\"", ",", 
         "\"\<\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.5\>\""}], 
        "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{".5", ",", ".7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.411774433*^9, 3.411774437296875*^9}, {
   3.411774480546875*^9, 3.41177450025*^9}, 3.411774532203125*^9, {
   3.531950950703844*^9, 3.5319509663767405`*^9}, 3.539177003749647*^9, {
   3.5412490463122425`*^9, 3.5412490607520685`*^9}, {3.5868087351416287`*^9, 
   3.5868087666524315`*^9}, {3.586808798771268*^9, 3.586808820436507*^9}, {
   3.5868088666091485`*^9, 3.586808917361051*^9}, {3.5868089594104567`*^9, 
   3.586808965987832*^9}, {3.5868090473554864`*^9, 3.5868091353885217`*^9}, 
   3.5868092130769653`*^9},ExpressionUUID->"e1d5caac-e80a-4565-973c-\
503295af8ec9"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
        AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwVkX041AcAx8/Jy93pnPt5O5ONvJ2IvHSH6vfNU6qF5W1kc4tqnp0WmdGS
1zmREc0sobutjahYI2pJehnSIVFHmXqQBxXn5c6cyuyPz/P95/PP9/mYR8YE
HKRSKBTfFf7fRy0TBhSKnAy3GX0s5lNRqDmYqKkhJwtKuWt1N1Gxx6drQIcu
J38VOxqmklR0yf4s5+jLSbtQ1Zt93lTcn0qycrGVk35PlVH2QVS0mDLdvtwj
J8Vq1F+GY6ioOeocJJXIyQ3CHas6K6nIcUo6fWbrDDkcJjwp4ajDft28wZZz
s2Tu1WH/x5xVGCELXrWPzJEjnYqbdgYa2F3kqZJbKMiIyMMdSUaakHzTpWud
rCQT/1rce2WzFrS/zkxEywJJixLydAXaCJ8xH4syWyRPcyplggoaDlztyrNP
UJGxog0pqYt0pPx47sSThiXSKP5o7tntOhC9Dc7OY78jG1iKSumt1RCnOj3j
hrwnH87dPlbjrItoL5Oo/T8tkzUXHSpfhrCg1654G5RIwcZIZvSckx4WlmKm
hcZq+CGzukOswUagIvygVpsaEi+MW7ctsJGd35sYF0eFZcAh5eAMgbb6MJc9
bHVwW32D/hjTx3FJcFz9LXUU12T5Zr4zgCcnMiw3YhUiTuYtDTKNEBsy/Pc4
SwOSnSYFTG9jpLhNdurf1IBdTiJ58gQHxRL11LpwTUzmRgsO3zGBZU9BXT9D
C9+2lYxSuKZoyncsjK3RQrStekJD9ho4vA5myHy1IUlpvmE3awZ9Xbn2PZU2
qqbiZt94fwSNW6W1a8touEfjnqpimeOQ640B2m46/J4V3g5VmuPSrkhJs5IO
nrWir2jEAspXJqyxYgbk2zH0/MFaNATuUC/apgNB90FLYZ8l0naKxPVjOrDo
P3C8S2YFi38+7j8vWo12M9mx4GFrePIyizjOTCjKXFRTerYIN+teVOtloqFW
Z6/AkwtlR95wbLouMicZyYx8O/hQHT247JUO17f4+T1dB/p0mL9aJAt1Y/LQ
h44O+L4Z1WXXWGC8/2zqbv16pAfVhhyh6SGjkHxO5TjBo1PmTYvQQ1ZjmYg+
64TnBtsytRv14BHKsPF8tAE0K3fDrVpskDyrvgeXnTFlOD6xScDGxIu5od5K
F4R2f8iOq2UjLSlZQS93RW1IaTZzmY1R8WSJdokbbt95iMPBBH4Obx1nXtuI
0Pl8X60KAtzAS1Of9PDQ2uXlFFNJ4MVQguunT3hwrVKyZRcI1FWdzQl/xoOu
QNBfcZHAObXeyJiXK36bw37vKwTS031k4kUe3EqlR0VNBLY2XVO5WPDB9qL/
pt5LwPvA7y128XykmTZnRfcRuN8YHRH4HR9TyiNf9T4mYH+hwzg5hY/7FwfW
n+8nsD1js7Q3e8U3qLruNUSgrDXKJ7+cj+nxHd3pEwSCG4+/5LXx8fndpSsT
kwTaq+MZcVI+Ospri/xfE/AXNu6+3MNHRYBRmPk0AY1TDFObQT4ETWOjLfME
pP/GU21n+JAWn22zVRKYT9mlFq3kw+OIX3XBArHyw9u0dokPA+uGmH0qAiXC
6koPTXdkUIQB7UsE6m1yjDMY7pA/XePm9I7AQH5aRQfLHYKrPUZn3hOouCf1
1zd0h/SUSLW8TCBBVWXyxQfu+A9Ofxzi
         "]]},
       Annotation[#, "Charting`Private`Tag$1122#1"]& ], 
      TagBox[
       {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
        AbsoluteDashing[{0, 0}], LineBox[CompressedData["
1:eJwVjXk01AkAx39DYxgxx88QOSIjZIYc24tev6/RsZFQI7JDjqh1RGrxtuRY
iopUansd2Hi61FSOls21HSg5kqONiBJlzaTwQs3aP77v88/nfb7GwdFbQpUI
gnCf3/98XjfKIwg5VaphsKDqIIGTKr3xKnQ5Vd1FKjyTCHhuanm5kCmnLlHC
4JEUAi3ddy/paskpWRAraNERAk3jB/h25nLqhxx3l8STBOr0NR3CPOXUKpHO
Vb9iArcSbMXNBXKq0cE7bGcbgUybA6fOOX+ibMfvbL/Hp8Fq+RfemrwJqqGA
dfTUWxqGqJyPjUOfKV/91HcueUpwy3WakZtMUg+j6Oz8n5RRsK+FZZY4Rc3y
4wePrlgA1ai0eNRNU1bbIgtTaXT4fzIe3mX4lWr2Yt/zHaNjZ3lLllXcDDXg
9768v1cFh07nHemqmKU6C0Pfpz1mIH3OOyOL+43yyFmyJqpFFflJNq8sfL5T
gYlXugxa1RAh0tsVckZBNc76eHe8YILTODknjidwzOsbmT6njunZaFn4IhrC
39HPv1usga2T/qGMBhpu7z4tiw7UREZ2R3xsrBLyojzam0pYaCjzs/PkKiMr
c6jvQTwbBwu8Y8tqlVGz2LJJU8iBk26w37GgBXgqMTnu0c9BjM/goxE2HXti
6sX7rnBxyOHDM61qOjJu0Dlx+0mcLVBOKvVXQZWK3UCRkxZM23NKe9QZCP9l
wuyiPg/3s61PxtxiwPTyRG/cNA+CMW/1bndV1HrvX5LfpQ0tllz14YwqSrdV
7Kl+rgN67QXp0otq6Ge2rWhrWIRI+79eqrkxUdIUGneiVxclG4MLaqaYuBk7
sFQxrYepj3rs4bPq2P2QH+qqro+KrRuUc9cuhL6h2QpnkQGSf0zPLxteCPlo
5aObMYYw6XPtKUzXgCSnTllRZASnlWm5uraaaB0/8PlW8hL4G7Z+pXVowtY1
k/nZwhhTT7IGY1JYkDDcevVHjbFJydrRgsvGRIeJsWGhCZgyPy9aMBtRPutq
mgOX4rcaXL/4JxtFt5dLeCtNkSKW+uxV46CsvV4QweDD8Vn3erUgDgZV5WPX
Jvjo561NU73Hge8fdcl5Q2ZQ46/SdmZwQcucS737bBnGtUdGVwdwYXTUwVG7
yxy+rUbcWCkXlW9Y2S7dFpD6XMjQVHBxWuwi+7XPEvV/t2GPNwliQtu/mm4F
3y/Z7oxiEkzrmB4pX4DHLSKb6Cskfq/sSm61FMD+2hS3+yqJ1ZJWltxaAFZA
QE/xDRK32bqDdo7zfoMgZP0dEq87D0kebxbA4UJzQvp9Elcpm2btBAG4ImaR
cgeJjNrD5WFPBUjWrzkc8YKEW6QoqbBNgPGpvT93dJI4z5Pav+kUoOnGS2Fh
D4nLhs4hOwbmfd61StFrEpYj7R1hkwLIRja0poySwBqNZZeNhJA8mL0z+oFE
825x7b+mQjy5JM31GiNRMzi8ztFSiOItOn7GMhLmfmcMu+yFCLg//LbuC4ls
NamSrqsQzWfPN5hPkdATvudEegjhuHfz9ZxpEjnHq9h1YiF4ZhXRgTMkuhNe
9YXvECKVCN/SOEtibntiSf1OIeT/GDjYfJv/WxwSoRs+3y9v1zn3ncTGmQq9
2Oj5/on0GYWChGhVYdXT/UL8B9WnFPU=
         "]]},
       Annotation[#, "Charting`Private`Tag$1122#2"]& ]}, {}, {}}, InsetBox[
     TemplateBox[{
      "\"\\!\\(\\*StyleBox[\\\"d\\\",FontSlant->\\\"Italic\\\"]\\) =.6\"",
       "\"\\!\\(\\*StyleBox[\\\"d\\\",FontSlant->\\\"Italic\\\"]\\) =.5\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    AbsoluteDashing[{2, 5}], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    AbsoluteDashing[{2, 5}], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    AbsoluteDashing[{0, 0}], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    AbsoluteDashing[{0, 0}], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& )], Scaled[{0.5, 0.7}], 
     ImageScaled[{1, 1}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox["\"# locations\"", TraditionalForm], 
     FormBox["\"transportation\\ncosts\"", TraditionalForm]},
   AxesOrigin->{1, 2.060901672493594},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{1, 5}, {2.060901672493594, 25.106919924257873`}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           AbsoluteDashing[{2, 5}], 
           RGBColor[0, 0, 1]], 
          Line[CompressedData["
1:eJwVkX041AcAx8/Jy93pnPt5O5ONvJ2IvHSH6vfNU6qF5W1kc4tqnp0WmdGS
1zmREc0sobutjahYI2pJehnSIVFHmXqQBxXn5c6cyuyPz/P95/PP9/mYR8YE
HKRSKBTfFf7fRy0TBhSKnAy3GX0s5lNRqDmYqKkhJwtKuWt1N1Gxx6drQIcu
J38VOxqmklR0yf4s5+jLSbtQ1Zt93lTcn0qycrGVk35PlVH2QVS0mDLdvtwj
J8Vq1F+GY6ioOeocJJXIyQ3CHas6K6nIcUo6fWbrDDkcJjwp4ajDft28wZZz
s2Tu1WH/x5xVGCELXrWPzJEjnYqbdgYa2F3kqZJbKMiIyMMdSUaakHzTpWud
rCQT/1rce2WzFrS/zkxEywJJixLydAXaCJ8xH4syWyRPcyplggoaDlztyrNP
UJGxog0pqYt0pPx47sSThiXSKP5o7tntOhC9Dc7OY78jG1iKSumt1RCnOj3j
hrwnH87dPlbjrItoL5Oo/T8tkzUXHSpfhrCg1654G5RIwcZIZvSckx4WlmKm
hcZq+CGzukOswUagIvygVpsaEi+MW7ctsJGd35sYF0eFZcAh5eAMgbb6MJc9
bHVwW32D/hjTx3FJcFz9LXUU12T5Zr4zgCcnMiw3YhUiTuYtDTKNEBsy/Pc4
SwOSnSYFTG9jpLhNdurf1IBdTiJ58gQHxRL11LpwTUzmRgsO3zGBZU9BXT9D
C9+2lYxSuKZoyncsjK3RQrStekJD9ho4vA5myHy1IUlpvmE3awZ9Xbn2PZU2
qqbiZt94fwSNW6W1a8touEfjnqpimeOQ640B2m46/J4V3g5VmuPSrkhJs5IO
nrWir2jEAspXJqyxYgbk2zH0/MFaNATuUC/apgNB90FLYZ8l0naKxPVjOrDo
P3C8S2YFi38+7j8vWo12M9mx4GFrePIyizjOTCjKXFRTerYIN+teVOtloqFW
Z6/AkwtlR95wbLouMicZyYx8O/hQHT247JUO17f4+T1dB/p0mL9aJAt1Y/LQ
h44O+L4Z1WXXWGC8/2zqbv16pAfVhhyh6SGjkHxO5TjBo1PmTYvQQ1ZjmYg+
64TnBtsytRv14BHKsPF8tAE0K3fDrVpskDyrvgeXnTFlOD6xScDGxIu5od5K
F4R2f8iOq2UjLSlZQS93RW1IaTZzmY1R8WSJdokbbt95iMPBBH4Obx1nXtuI
0Pl8X60KAtzAS1Of9PDQ2uXlFFNJ4MVQguunT3hwrVKyZRcI1FWdzQl/xoOu
QNBfcZHAObXeyJiXK36bw37vKwTS031k4kUe3EqlR0VNBLY2XVO5WPDB9qL/
pt5LwPvA7y128XykmTZnRfcRuN8YHRH4HR9TyiNf9T4mYH+hwzg5hY/7FwfW
n+8nsD1js7Q3e8U3qLruNUSgrDXKJ7+cj+nxHd3pEwSCG4+/5LXx8fndpSsT
kwTaq+MZcVI+Ospri/xfE/AXNu6+3MNHRYBRmPk0AY1TDFObQT4ETWOjLfME
pP/GU21n+JAWn22zVRKYT9mlFq3kw+OIX3XBArHyw9u0dokPA+uGmH0qAiXC
6koPTXdkUIQB7UsE6m1yjDMY7pA/XePm9I7AQH5aRQfLHYKrPUZn3hOouCf1
1zd0h/SUSLW8TCBBVWXyxQfu+A9Ofxzi
           "]]}, "Charting`Private`Tag$1122#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           AbsoluteDashing[{0, 0}], 
           RGBColor[1, 0, 0]], 
          Line[CompressedData["
1:eJwVjXk01AkAx39DYxgxx88QOSIjZIYc24tev6/RsZFQI7JDjqh1RGrxtuRY
iopUansd2Hi61FSOls21HSg5kqONiBJlzaTwQs3aP77v88/nfb7GwdFbQpUI
gnCf3/98XjfKIwg5VaphsKDqIIGTKr3xKnQ5Vd1FKjyTCHhuanm5kCmnLlHC
4JEUAi3ddy/paskpWRAraNERAk3jB/h25nLqhxx3l8STBOr0NR3CPOXUKpHO
Vb9iArcSbMXNBXKq0cE7bGcbgUybA6fOOX+ibMfvbL/Hp8Fq+RfemrwJqqGA
dfTUWxqGqJyPjUOfKV/91HcueUpwy3WakZtMUg+j6Oz8n5RRsK+FZZY4Rc3y
4wePrlgA1ai0eNRNU1bbIgtTaXT4fzIe3mX4lWr2Yt/zHaNjZ3lLllXcDDXg
9768v1cFh07nHemqmKU6C0Pfpz1mIH3OOyOL+43yyFmyJqpFFflJNq8sfL5T
gYlXugxa1RAh0tsVckZBNc76eHe8YILTODknjidwzOsbmT6njunZaFn4IhrC
39HPv1usga2T/qGMBhpu7z4tiw7UREZ2R3xsrBLyojzam0pYaCjzs/PkKiMr
c6jvQTwbBwu8Y8tqlVGz2LJJU8iBk26w37GgBXgqMTnu0c9BjM/goxE2HXti
6sX7rnBxyOHDM61qOjJu0Dlx+0mcLVBOKvVXQZWK3UCRkxZM23NKe9QZCP9l
wuyiPg/3s61PxtxiwPTyRG/cNA+CMW/1bndV1HrvX5LfpQ0tllz14YwqSrdV
7Kl+rgN67QXp0otq6Ge2rWhrWIRI+79eqrkxUdIUGneiVxclG4MLaqaYuBk7
sFQxrYepj3rs4bPq2P2QH+qqro+KrRuUc9cuhL6h2QpnkQGSf0zPLxteCPlo
5aObMYYw6XPtKUzXgCSnTllRZASnlWm5uraaaB0/8PlW8hL4G7Z+pXVowtY1
k/nZwhhTT7IGY1JYkDDcevVHjbFJydrRgsvGRIeJsWGhCZgyPy9aMBtRPutq
mgOX4rcaXL/4JxtFt5dLeCtNkSKW+uxV46CsvV4QweDD8Vn3erUgDgZV5WPX
Jvjo561NU73Hge8fdcl5Q2ZQ46/SdmZwQcucS737bBnGtUdGVwdwYXTUwVG7
yxy+rUbcWCkXlW9Y2S7dFpD6XMjQVHBxWuwi+7XPEvV/t2GPNwliQtu/mm4F
3y/Z7oxiEkzrmB4pX4DHLSKb6Cskfq/sSm61FMD+2hS3+yqJ1ZJWltxaAFZA
QE/xDRK32bqDdo7zfoMgZP0dEq87D0kebxbA4UJzQvp9Elcpm2btBAG4ImaR
cgeJjNrD5WFPBUjWrzkc8YKEW6QoqbBNgPGpvT93dJI4z5Pav+kUoOnGS2Fh
D4nLhs4hOwbmfd61StFrEpYj7R1hkwLIRja0poySwBqNZZeNhJA8mL0z+oFE
825x7b+mQjy5JM31GiNRMzi8ztFSiOItOn7GMhLmfmcMu+yFCLg//LbuC4ls
NamSrqsQzWfPN5hPkdATvudEegjhuHfz9ZxpEjnHq9h1YiF4ZhXRgTMkuhNe
9YXvECKVCN/SOEtibntiSf1OIeT/GDjYfJv/WxwSoRs+3y9v1zn3ncTGmQq9
2Oj5/on0GYWChGhVYdXT/UL8B9WnFPU=
           "]]}, "Charting`Private`Tag$1122#2"]}}, {}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {1, 2.060901672493594}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
      DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, 
      AxesLabel -> {"# locations", "transportation\ncosts"}, 
      AxesOrigin -> {1., 2.060901672493594}, DisplayFunction :> Identity, 
      Frame -> {{False, False}, {False, False}}, 
      FrameLabel -> {{None, None}, {None, None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, 
      PlotRange -> {{1, 5}, {2.060901672493594, 25.106919924257873`}}, 
      PlotRangeClipping -> True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[
         AbsoluteDashing[{2, 5}], 
         RGBColor[0, 0, 1]], 
        Directive[
         AbsoluteDashing[{0, 0}], 
         RGBColor[1, 0, 0]]}, {
       "\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.6", 
        "\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.5"}]], {{0.5, 0.7}, {
      1, 1}}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.586808918433112*^9, 3.5868089664948616`*^9, {3.586809062875374*^9, 
   3.586809135858548*^9}, 3.5868092148530664`*^9, 3.698349746658785*^9, 
   3.6983498593975616`*^9, 3.7314218507491317`*^9},
 TextAlignment->Center,ExpressionUUID->"2eb4ec3a-6c57-455b-ba8a-b5e4b93be2e4"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.1.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Transaction costs at two distance factors as the number of locations change"
}], "FigureCaption",
 CellChangeTimes->{3.5391770037926493`*^9, 3.5412491188473916`*^9},
 TextAlignment->Center,ExpressionUUID->"9fa08701-5f12-4fb7-8d63-88b408b9c414"],

Cell["\<\
As a consequence, of course, net profit is a decreasing function of the \
number of locations and the distance factor.\
\>", "Text",
 CellChangeTimes->{{3.53195234704871*^9, 3.531952347654745*^9}, 
   3.539177003793649*^9},ExpressionUUID->"41425822-b8f9-4b1b-a2d9-\
be39bc90856f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<Derivative with respect to location\>\"", ",", "Space", ",", 
       "\"\<Derivative with respect to distance\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "loc"], "np"}], ",", "Space", ",", 
       RowBox[{
        SubscriptBox["\[PartialD]", "d"], "np"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.531952395731495*^9, 3.5319523974435925`*^9}, {
   3.532123317150919*^9, 3.532123415064519*^9}, {3.5321234576139526`*^9, 
   3.532123466294449*^9}, 
   3.539177003793649*^9},ExpressionUUID->"14b51b68-ea71-4f8f-9614-\
f9e4f941719f"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Derivative with respect to location\"\>", "\<\" \"\>", \
"\<\"Derivative with respect to distance\"\>"},
    {
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", "d", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"d", " ", "loc"}]], " ", "h", " ", "u"}], "\<\" \"\>", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"d", " ", "loc"}]], " ", "h", " ", "loc", " ", "u"}]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellOpen->False,
 CellChangeTimes->{
  3.4119470373125*^9, 3.531952399459708*^9, 3.5320235956561756`*^9, 
   3.532123279217749*^9, {3.5321233313997335`*^9, 3.5321233457205524`*^9}, {
   3.532123386656894*^9, 3.5321234156715536`*^9}, {3.5321234615861797`*^9, 
   3.532123467114496*^9}, 3.532212321407671*^9, 3.5333204307125597`*^9, 
   3.533685021078125*^9, 3.5337444808736415`*^9, 3.53375693378125*^9, 
   3.533756983875*^9, 3.5391768157828956`*^9, 3.5391770037956495`*^9, 
   3.5400537870574503`*^9, 3.5400550140476303`*^9, 3.5401285549220324`*^9, 
   3.541248424991705*^9, 3.5412498985679893`*^9, 3.5416049052030797`*^9, 
   3.5433495055505476`*^9, 3.586808614451726*^9, 3.6983497467068977`*^9, 
   3.6983498594126015`*^9, 
   3.7314218507792015`*^9},ExpressionUUID->"f4e4e960-6074-41c9-84ef-\
b6b9952bd88f"]
}, Open  ]],

Cell["\<\
In Figure 11.2 the distance factor creates the difference between the two \
plots of net profits as the number of locations increases, all else taking \
fixed values.\
\>", "Text",
 CellChangeTimes->{{3.531952650541069*^9, 3.5319526533012266`*^9}, {
   3.53332069664277*^9, 3.533320715569853*^9}, 
   3.5391770037956495`*^9},ExpressionUUID->"3c1c0856-c84d-44f5-a74f-\
7393ae761cdb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Legended", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"np", "/.", "d1"}], ",", 
       RowBox[{"np", "/.", "d2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"loc", ",", "1", ",", "10"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", "Blue"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", "Red"}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<# locations\>\"", ",", "\"\<net profits\>\""}], "}"}]}], 
     RowBox[{"(*", 
      RowBox[{",", 
       RowBox[{"PlotLegend", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.6\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.5\>\""}], 
         "}"}]}]}], "*)"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "None"}], "}"}]}], 
     RowBox[{"(*", 
      RowBox[{",", 
       RowBox[{"LegendSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{".5", ",", ".2"}], "}"}]}], ",", 
       RowBox[{"LegendPosition", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", ".55"}], ",", 
          RowBox[{"-", ".1"}]}], "}"}]}]}], "*)"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], ",", 
   RowBox[{"Placed", "[", 
    RowBox[{
     RowBox[{"LineLegend", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", "Blue"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", "Red"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.6\>\"", ",", 
         "\"\<\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.5\>\""}], 
        "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{".5", ",", ".7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.411774666234375*^9, 3.53195257485874*^9, {3.5333207363080387`*^9, 
   3.533320784386789*^9}, {3.5333208336186047`*^9, 3.5333208413300457`*^9}, {
   3.5333208821653814`*^9, 3.5333208831204357`*^9}, {3.533320927949*^9, 
   3.5333209452029867`*^9}, 3.5391770037966495`*^9, {3.5412490919968557`*^9, 
   3.541249099957311*^9}, {3.586809229683915*^9, 
   3.586809381214582*^9}},ExpressionUUID->"86bda604-b261-403f-9007-\
210ca01e4957"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
        AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwV0X1QzHkcB/DfbNpTu7XFr9DTPtBmo0wPYrvJ7z2d8BPKbVtoWcWW8tDE
aoy7udOD00UiiRZlenDdIT0gptCgmMUUzZgvKg/DEsrWhOUu7tsfn3nP66/3
vOcjT8742SBgGCaU3liSoaVBDGPlprUwPw6mEHQ4nytcJrJygXbK0QHqphku
b4+7WzlWHHRtzPsNDyrVAVauL8QWOeafHsWz21ZZuYxKnn9PXdem//zqvJXr
nvoh9i317qLMK3fShriu0ZFoC3VwwGH+SPcw5+i7ZrCXWp5kaBC9/MhFaJyD
zdQtReMm5LXZuFJJsekCdbWTMKR8/7+c55tovwpqRd6BqsNl37jHiY+/5FKf
+mr8Y9ElBkt6RLWpY32zLC9CIwXwW1mji6IW78uXDt+0gyVWc0JK3W8oXtEQ
YA/2jkxrMxC4tK5VPz0vxHj+Wftt6sKiUneJYjyMphszj1A3Fox2S/IdcCi6
wSeJWi5QqX8Xi7DwhaJeSm351GKyZolh15Re8GQ9wcfUidVd351QtbXJ/k/q
M8zxwuxsCRJc08MDqXWiDrXJ6IIsx2hz5zqC/LiTzOk5rjAPeWatptbr6tpb
B1yhCKpYbEkmSKws77NvmgD7kTKblnrGr3+lNhsnQhD0xK05iaCGfTmYpmKR
foWvd6WOeicwawZYqPx7N/NrCQ7s0lbNq3ZD4Pxju3fo6X/+bnt/MMEdH/S/
mUvWEAy7OBd4eUyCRtfpnb2a4HlYkW9t5yRIrh3qT9LRPaZhdmPJZGyquykV
JhL0Fm8xlmqnIMpvoX7PSoIM3ufBdQcPNL+uVnxJIPCbV5+rvOcBVbfbd/d4
goKh7SF7cz2RIzTxsjiCtrlxmhVhXvh6mf/lv+UEXlfZWzqbF3ZGBKcYYgim
ChzUyWe9cXGn/2DjEoKYvKffyjN9EFijfb6FJ1C291/vmS7FZMeS7cIFBF1l
4s85PVJs01vCYiIJYh/mc/UxMnCytFOdEQTOXE1OxT8ytC67XChVE/R1NGb4
O8nxrpEN3xpCcPTo3ZL+zXJkh6dkBgcQ1PKMWnVbjvU/7NvYoCQwT/HdM85f
gYGRC7vu+xBsiF9+Rj9bgdBFkcq73gT/A4I7efs=
         "]]},
       Annotation[#, "Charting`Private`Tag$1307#1"]& ], 
      TagBox[
       {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
        AbsoluteDashing[{0, 0}], LineBox[CompressedData["
1:eJwV03s81XcYB/AzxdxvHZLOhO9UapGknKl+D7LGxlFobuVSqFnMy1n2Miq5
JveQXM4qKl0monjF2km5xMiOS9+EUs04Ljssd7HHH8/reb3/ej6v1/M8er7B
B/ykWCyWPdZyp+P2JiyWhDEJMtZe8KdQr3w32UFBwqiYJQ/Po8s3q4rzNSWM
0unummWn+ImucrdIGO1Ya69lW788yA51lzAV9x0K59AlQq/pvyskzL6YvRtn
0bGpIb83Hx9n/rGOMZhCb9uSZXuxfYI5/JA18i9az8evTOH9JBN6OiCkH12d
ulI9RjjDbJ/tzxehi5RkTAUp80xA04GHtWj9mLTCrEuLTGlILb2Lvj7Hj/u6
igVGjlXx+cvzjAfebreSgoNB5umxaMWkhHUTT1dAybO5pz+gh/wyXMu2SIND
xMwJJ7RqjTf3dYUMqPir8czQyanZmir6ssDnCn7WRN9L/NiukiAHstn2oZN+
mFfKkHtaUQHCrXpMW9EDU9W5kpOK0BjloHYdPRmwqqhtSQk8xTc8TqLvsPKT
o6JU4IivSrcV2lOhnpvLV4VVwv17lNEJzpdZt3eqQWcO58HzoxS8PEvqakbV
oHLsi6pUtMdVQZ90uTrIuodds0ZvjrgRUMlfBdLTOeHjRyhcY78fO27IhnMd
Y5EFaJthqSanUTYoltsVc9FpZ1wK9xRpQIupemC7L+7npnAk/TtNOOWYNuyH
nlBVTuRor4Yn73h173wo9O9INSh+vhpWSEcUHUZP5k6wAzO1YKy601foTaE3
I4if7bIGQs8NntFAB9vqiGrltGFSNUjs70Vhw57S6PUt2mCXrXP04mEKieM/
mZ6PXgshhZFTtYcoCM2dnVx3cEDtrXzca08KnEfsBs8ZDnR0Om77y4MCkZLj
+v72GdzihbXWuFPgxbxeFIToQIS3tBXfjcL6uqHano3r4MOCTAVxpdB2SXH6
bM86iBMtGlUfpODYlcCU8nQhSzH3prILBWXm2tlfb+lCOZ+3w9WJQl/9veBN
SnoQ1fr5osN+Cjk5f2YOndAD3WBGg8OjUGzL4ho26oGMf1Frz7cUmtYYxK/c
pA+VUeEft9pRsHp2xNk7Vh/WR/4o4u/D+6wtcZP06UPK8DbZ+L0UtF6JZTlA
4MQVyxcKlhTeimBnYy6BNp7gWMRuCoKN32geyifwQvikMRDtdsplcryAQNd2
F30PdJvh9+VrrxDwqi57zEU/OnPBOPgGAXtd2bKpXRTyjAY2aFYQCGjr5QWj
nRPPax1tIbBbKeMXDwu85zdZ0zOtBFpuaq20QzebXe5KbiNAp+/HmqOt+isy
K9sJDD4w5Gugt5r3qSp0E1gtLv7Y+iX+y8BWuXsDBCTdeUJAN1pYDH41SGBJ
yvqlETo63abh1RABy5wOMQc9t8s9VnqUQIfo9swMl8LghehP3P4jYF736lEp
umgo+c3oBwIFefECAdqLyfnj7BQBE6dPw5LQXeI7kXdmCVyXD1M/hs6ASk/L
eQJr3H06XdAO2Y8tuhYI9Biy063R8iPN2oGLmF+QZGOCrrPsml1aIsDubZjQ
Qf8P3CxGZw==
         "]]},
       Annotation[#, "Charting`Private`Tag$1307#2"]& ]}, {}, {}}, InsetBox[
     TemplateBox[{
      "\"\\!\\(\\*StyleBox[\\\"d\\\",FontSlant->\\\"Italic\\\"]\\) =.6\"",
       "\"\\!\\(\\*StyleBox[\\\"d\\\",FontSlant->\\\"Italic\\\"]\\) =.5\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    AbsoluteDashing[{2, 5}], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    AbsoluteDashing[{2, 5}], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    AbsoluteDashing[{0, 0}], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    AbsoluteDashing[{0, 0}], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& )], Scaled[{0.5, 0.7}], 
     ImageScaled[{1, 1}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox["\"# locations\"", TraditionalForm], 
     FormBox["\"net profits\"", TraditionalForm]},
   AxesOrigin->{1, 24695.189835138808`},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->350,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{1, 10}, {24695.189835138808`, 24987.93909822236}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, {}}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           AbsoluteDashing[{2, 5}], 
           RGBColor[0, 0, 1]], 
          Line[CompressedData["
1:eJwV0X1QzHkcB/DfbNpTu7XFr9DTPtBmo0wPYrvJ7z2d8BPKbVtoWcWW8tDE
aoy7udOD00UiiRZlenDdIT0gptCgmMUUzZgvKg/DEsrWhOUu7tsfn3nP66/3
vOcjT8742SBgGCaU3liSoaVBDGPlprUwPw6mEHQ4nytcJrJygXbK0QHqphku
b4+7WzlWHHRtzPsNDyrVAVauL8QWOeafHsWz21ZZuYxKnn9PXdem//zqvJXr
nvoh9i317qLMK3fShriu0ZFoC3VwwGH+SPcw5+i7ZrCXWp5kaBC9/MhFaJyD
zdQtReMm5LXZuFJJsekCdbWTMKR8/7+c55tovwpqRd6BqsNl37jHiY+/5FKf
+mr8Y9ElBkt6RLWpY32zLC9CIwXwW1mji6IW78uXDt+0gyVWc0JK3W8oXtEQ
YA/2jkxrMxC4tK5VPz0vxHj+Wftt6sKiUneJYjyMphszj1A3Fox2S/IdcCi6
wSeJWi5QqX8Xi7DwhaJeSm351GKyZolh15Re8GQ9wcfUidVd351QtbXJ/k/q
M8zxwuxsCRJc08MDqXWiDrXJ6IIsx2hz5zqC/LiTzOk5rjAPeWatptbr6tpb
B1yhCKpYbEkmSKws77NvmgD7kTKblnrGr3+lNhsnQhD0xK05iaCGfTmYpmKR
foWvd6WOeicwawZYqPx7N/NrCQ7s0lbNq3ZD4Pxju3fo6X/+bnt/MMEdH/S/
mUvWEAy7OBd4eUyCRtfpnb2a4HlYkW9t5yRIrh3qT9LRPaZhdmPJZGyquykV
JhL0Fm8xlmqnIMpvoX7PSoIM3ufBdQcPNL+uVnxJIPCbV5+rvOcBVbfbd/d4
goKh7SF7cz2RIzTxsjiCtrlxmhVhXvh6mf/lv+UEXlfZWzqbF3ZGBKcYYgim
ChzUyWe9cXGn/2DjEoKYvKffyjN9EFijfb6FJ1C291/vmS7FZMeS7cIFBF1l
4s85PVJs01vCYiIJYh/mc/UxMnCytFOdEQTOXE1OxT8ytC67XChVE/R1NGb4
O8nxrpEN3xpCcPTo3ZL+zXJkh6dkBgcQ1PKMWnVbjvU/7NvYoCQwT/HdM85f
gYGRC7vu+xBsiF9+Rj9bgdBFkcq73gT/A4I7efs=
           "]]}, "Charting`Private`Tag$1307#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           AbsoluteDashing[{0, 0}], 
           RGBColor[1, 0, 0]], 
          Line[CompressedData["
1:eJwV03s81XcYB/AzxdxvHZLOhO9UapGknKl+D7LGxlFobuVSqFnMy1n2Miq5
JveQXM4qKl0monjF2km5xMiOS9+EUs04Ljssd7HHH8/reb3/ej6v1/M8er7B
B/ykWCyWPdZyp+P2JiyWhDEJMtZe8KdQr3w32UFBwqiYJQ/Po8s3q4rzNSWM
0unummWn+ImucrdIGO1Ya69lW788yA51lzAV9x0K59AlQq/pvyskzL6YvRtn
0bGpIb83Hx9n/rGOMZhCb9uSZXuxfYI5/JA18i9az8evTOH9JBN6OiCkH12d
ulI9RjjDbJ/tzxehi5RkTAUp80xA04GHtWj9mLTCrEuLTGlILb2Lvj7Hj/u6
igVGjlXx+cvzjAfebreSgoNB5umxaMWkhHUTT1dAybO5pz+gh/wyXMu2SIND
xMwJJ7RqjTf3dYUMqPir8czQyanZmir6ssDnCn7WRN9L/NiukiAHstn2oZN+
mFfKkHtaUQHCrXpMW9EDU9W5kpOK0BjloHYdPRmwqqhtSQk8xTc8TqLvsPKT
o6JU4IivSrcV2lOhnpvLV4VVwv17lNEJzpdZt3eqQWcO58HzoxS8PEvqakbV
oHLsi6pUtMdVQZ90uTrIuodds0ZvjrgRUMlfBdLTOeHjRyhcY78fO27IhnMd
Y5EFaJthqSanUTYoltsVc9FpZ1wK9xRpQIupemC7L+7npnAk/TtNOOWYNuyH
nlBVTuRor4Yn73h173wo9O9INSh+vhpWSEcUHUZP5k6wAzO1YKy601foTaE3
I4if7bIGQs8NntFAB9vqiGrltGFSNUjs70Vhw57S6PUt2mCXrXP04mEKieM/
mZ6PXgshhZFTtYcoCM2dnVx3cEDtrXzca08KnEfsBs8ZDnR0Om77y4MCkZLj
+v72GdzihbXWuFPgxbxeFIToQIS3tBXfjcL6uqHano3r4MOCTAVxpdB2SXH6
bM86iBMtGlUfpODYlcCU8nQhSzH3prILBWXm2tlfb+lCOZ+3w9WJQl/9veBN
SnoQ1fr5osN+Cjk5f2YOndAD3WBGg8OjUGzL4ho26oGMf1Frz7cUmtYYxK/c
pA+VUeEft9pRsHp2xNk7Vh/WR/4o4u/D+6wtcZP06UPK8DbZ+L0UtF6JZTlA
4MQVyxcKlhTeimBnYy6BNp7gWMRuCoKN32geyifwQvikMRDtdsplcryAQNd2
F30PdJvh9+VrrxDwqi57zEU/OnPBOPgGAXtd2bKpXRTyjAY2aFYQCGjr5QWj
nRPPax1tIbBbKeMXDwu85zdZ0zOtBFpuaq20QzebXe5KbiNAp+/HmqOt+isy
K9sJDD4w5Gugt5r3qSp0E1gtLv7Y+iX+y8BWuXsDBCTdeUJAN1pYDH41SGBJ
yvqlETo63abh1RABy5wOMQc9t8s9VnqUQIfo9swMl8LghehP3P4jYF736lEp
umgo+c3oBwIFefECAdqLyfnj7BQBE6dPw5LQXeI7kXdmCVyXD1M/hs6ASk/L
eQJr3H06XdAO2Y8tuhYI9Biy063R8iPN2oGLmF+QZGOCrrPsml1aIsDubZjQ
Qf8P3CxGZw==
           "]]}, "Charting`Private`Tag$1307#2"]}}, {}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, {}}, 
      AxesOrigin -> {1, 24695.189835138808`}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
      DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, AxesLabel -> {"# locations", "net profits"}, 
      AxesOrigin -> {1., 24695.189835138808`}, DisplayFunction :> Identity, 
      Frame -> {{False, False}, {False, False}}, 
      FrameLabel -> {{None, None}, {None, None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImageSize -> 350, 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, 
      PlotRange -> {{1, 10}, {24695.189835138808`, 24987.93909822236}}, 
      PlotRangeClipping -> True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}}, Ticks -> {Automatic, None}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[
         AbsoluteDashing[{2, 5}], 
         RGBColor[0, 0, 1]], 
        Directive[
         AbsoluteDashing[{0, 0}], 
         RGBColor[1, 0, 0]]}, {
       "\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.6", 
        "\!\(\*StyleBox[\"d\",FontSlant->\"Italic\"]\) =.5"}]], {{0.5, 0.7}, {
      1, 1}}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.586809253166258*^9, 3.58680938239765*^9, 
  3.698349746805174*^9, 3.6983498594958496`*^9, 3.731421850886511*^9},
 TextAlignment->Center,ExpressionUUID->"d49ec413-23c5-4c87-8908-aa65d5f08ad0"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.2.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Net profits at two distance factors as the number of locations change"
}], "FigureCaption",
 CellChangeTimes->{3.539177003824651*^9, 3.5412491217325563`*^9},
 TextAlignment->Center,ExpressionUUID->"320efb51-ba45-435b-b700-b97c93c0fe8a"],

Cell[TextData[{
 "It may appear that what really matters is average building size. But does \
it?  Suppose that ",
 StyleBox["ac",
  FontSlant->"Italic"],
 " is a fixed resource that places an upper bound on the total number of \
units that may be managed.  The optimization problem becomes one of finding \
an appropriate size building, given the fixed number of units.  This involves \
finding the optimal building size expressed as the ratio, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    FractionBox[
     StyleBox["u",
      FontSlant->"Plain"], "loc"], "Text",
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "659befb0-3e42-479f-9b76-b7d8a50a0c75"],
 ". The optimal will always be the lowest number of locations.  The perfect \
job may be managing one large building, but the market does not ",
 StyleBox["always accommodate ",
  PageWidth->PaperWidth,
  CharacterEncoding -> "WindowsANSI"],
 "that perfect outcome.  Management usually involves multiple locations.  \
Inserting the transaction cost function, Equation 11.2, directly into the \
manager's net profit, Equation 11.1, we have:"
}], "Text",
 CellChangeTimes->{{3.5319654853961806`*^9, 3.531965520581193*^9}, {
  3.539177003824651*^9, 
  3.539177003826651*^9}},ExpressionUUID->"24c34107-dbcb-4895-858f-\
cca09af9a54a"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.531965396586101*^9, 3.531965396611102*^9}, 
   3.539177003826651*^9},ExpressionUUID->"31c96cb4-f514-4538-9744-\
b25a8e8f41b3"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"np", "=", 
    RowBox[{
     RowBox[{"g", " ", "u"}], "-", "ac", "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"d", " ", "loc"}]], " ", "h", " ", "u"}], "2"]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.531965401613388*^9, 3.5319654560215006`*^9}, 
   3.539177003826651*^9},ExpressionUUID->"12f90bd8-f00b-4577-891d-\
7ed995f22e3b"],

Cell[TextData[{
 "Providing fixed values for some of the inputs again, this time omitting a \
value for ",
 StyleBox["u",
  FontSlant->"Italic"],
 " which we wish to vary, we define a simpler function with real numbers and \
only the two arguments of interest, units and location:"
}], "Text",
 CellChangeTimes->{
  3.539177003826651*^9},ExpressionUUID->"dcf9dbad-bb12-4388-94e2-\
263ff5ac23ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"np1", "=", 
   RowBox[{"np", "/.", "d3"}]}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5319430829418335`*^9, 3.5319430841849046`*^9}, 
   3.5319655366761136`*^9, 
   3.539177003826651*^9},ExpressionUUID->"38e8aada-95da-48f6-a089-\
37c5212b8590"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{"500", " ", "u"}], "-", "10", "-", 
    FractionBox[
     RowBox[{"0.05", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"0.5`", " ", "loc"}]], " ", "u"}], "2"]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.531965553328066*^9, 3.5319655945604243`*^9}, 
   3.539177003827651*^9},ExpressionUUID->"3844815d-ce2b-44d5-b58f-\
1da091fe7b57"],

Cell[TextData[{
 "Our simplified story can be plotted in Figure 11.3 to show how net profit \
varies based solely on the number of units and locations, given fixed values \
for accounting costs, the fee per unit, distance and transaction rates from \
dataset ",
 StyleBox["d3",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.5319657203876214`*^9, 3.531965727491028*^9}, {
   3.531965760541918*^9, 3.531965765174183*^9}, 
   3.539177003827651*^9},ExpressionUUID->"5513c0b1-25e4-47e5-94ae-\
71d136dbeec9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{"np1", ",", 
   RowBox[{"{", 
    RowBox[{"loc", ",", "1", ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "50", ",", "150"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "locations", ",", "\"\<   units\>\"", ",", "\"\<net profit      \>\""}], 
     "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.411774746046875*^9, 3.5319656535918007`*^9, 
  3.539177003827651*^9},ExpressionUUID->"fc030d15-5450-4937-adca-\
a3d1a00d89bf"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nXk0ld/XwKVRRKNKUqIiDZpUKCdEkjKVqTIkKpSKJqRBA5VKojQYGikN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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[
        TagBox[{Polygon3DBox[CompressedData["
1:eJwtmgn4DlUbxufMmaESEYkiSYsULZZCSSSkEpVQ1oqQrZIiS0lIRXtfJaWQ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           "]], Polygon3DBox[CompressedData["
1:eJwtmgXYHEUWRVvqxyV4gEUS3CFoCBIcgrtbcNfg7r6Q4JrgFtw9wRZ3dwku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           "]], Polygon3DBox[CompressedData["
1:eJwt1nW8VVUWAODn41EDEkOP1IjAjIRBSYkgDg5INwYlIa1SkgYdykiKlCAh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           "]], 
          Polygon3DBox[{{1171, 777, 426, 427, 778, 1172}, {1157, 763, 396, 
           397, 764, 1158}, {1149, 756, 381, 382, 757, 1150}, {1222, 560, 346,
            345, 741, 1138}, {1225, 574, 367, 366, 747, 1142}, {1230, 588, 
           382, 381, 753, 1146}, {1165, 770, 411, 412, 771, 1166}, {1266, 667,
            472, 471, 793, 1179}, {1188, 811, 501, 502, 812, 1189}, {1194, 
           817, 516, 517, 818, 1195}, {1264, 654, 457, 456, 786, 1175}, {1270,
            680, 487, 486, 800, 1183}}]},
         Annotation[#, "Charting`Private`Tag$2015#1"]& ]],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0ckqxWEYB+DPPA/FxuyYN1yBaWEMCYlIQhYsnOxIsiQX4OQCnOxsyAWQ
tczzkI3sZeuRxe973re+et/v/4/MRoeXEkIIG9Kt+Ks7HB+cTwohn8us4Dqb
uM0W7rKf+5zkMRd5xlVecIsvjPGLcf7wiKnJIZzygIVm9silvpMtUpIYwpW+
lNcs4w3LecsK3rGS94zwgVWslkd1DZ9Yy2fW8YX1fGUD39hqpyIze+Vd38V2
idjtQl/AEybzkN/u7/GTO3ziJs+5wlMu8IgTjLOPMTZzi41cYzmjzPv75mbm
co45nGE2p5nFKWZykhkc55ikq0eZxhGmcogpHKS1wwCNCX307NCmKU74/++/
jQ03AA==
       "]]}, 
     {GrayLevel[0.2], 
      Line3DBox[{869, 1137, 1221, 1464, 868, 1311, 1058, 870, 1312, 1059, 871,
        1313, 1060, 872, 1314, 1061, 873, 1315, 1062, 874, 1316, 1063, 875, 
       1466, 1138, 1222, 1465, 1204, 1139, 1317, 1064, 1205, 1140, 1318, 1065,
        1206, 1141, 1319, 1066, 876, 1320, 1067, 877, 1321, 1068, 878, 1322, 
       1069, 879}], 
      Line3DBox[{881, 1223, 1388, 880, 1224, 1389, 882, 1323, 1070, 883, 1324,
        1071, 884, 1325, 1072, 885, 1326, 1073, 886, 1327, 1074, 887, 1468, 
       1142, 1225, 1467, 1207, 1143, 1226, 1469, 1208, 1144, 1328, 1075, 1209,
        1145, 1329, 1076, 888, 1330, 1077, 889, 1331, 1078, 890, 1332, 1079, 
       891}], Line3DBox[{893, 1227, 1390, 892, 1228, 1391, 894, 1229, 1392, 
       895, 1333, 1080, 896, 1334, 1081, 897, 1335, 1082, 898, 1336, 1083, 
       899, 1471, 1146, 1230, 1470, 1210, 1147, 1231, 1472, 1211, 1148, 1232, 
       1473, 900, 1337, 1084, 901, 1338, 1085, 902, 1339, 1086, 903, 1340, 
       1087, 904}], 
      Line3DBox[{906, 1233, 1393, 905, 1234, 1394, 907, 1235, 1395, 908, 1236,
        1396, 909, 1341, 1088, 910, 1342, 1089, 911, 1343, 1090, 912, 1474, 
       1149, 1150, 1499, 913, 1151, 1152, 1500, 914, 1153, 1154, 1475, 915, 
       1237, 1397, 916, 1344, 1091, 917, 1345, 1092, 918, 1346, 1093, 919}], 
      Line3DBox[{921, 1238, 1398, 920, 1239, 1399, 922, 1240, 1400, 923, 1241,
        1401, 924, 1242, 1402, 925, 1347, 1094, 926, 1476, 1155, 1156, 927, 
       1477, 1157, 1158, 1501, 928, 1159, 1160, 1502, 929, 1161, 1162, 1478, 
       930, 1243, 1403, 931, 1244, 1404, 932, 1348, 1095, 933, 1349, 1096, 
       934}], Line3DBox[{936, 1245, 1405, 935, 1246, 1406, 937, 1247, 1407, 
       938, 1248, 1408, 939, 1249, 1409, 940, 1250, 1410, 941, 1479, 1163, 
       1164, 942, 1480, 1165, 1166, 1503, 943, 1167, 1168, 1504, 944, 1169, 
       1411, 1303, 945, 1251, 1412, 946, 1252, 1413, 947, 1253, 1414, 948, 
       1350, 1097, 949}], 
      Line3DBox[{106, 434, 107, 435, 108, 436, 109, 437, 110, 438, 111, 439, 
       112, 440, 113, 441, 442, 114, 443, 115, 444, 116, 445, 117, 446, 118, 
       447, 119, 448, 120}], 
      Line3DBox[{951, 1254, 1415, 950, 1255, 1416, 952, 1256, 1417, 953, 1257,
        1418, 954, 1258, 1419, 955, 1259, 1420, 956, 1304, 1421, 1170, 957, 
       1481, 1171, 1172, 1505, 958, 1173, 1422, 1305, 959, 1174, 1423, 1306, 
       960, 1260, 1424, 961, 1261, 1425, 962, 1262, 1426, 963, 1263, 1427, 
       964}], Line3DBox[{966, 648, 965, 1351, 1098, 967, 1352, 1099, 968, 
       1353, 1100, 969, 1354, 1101, 970, 1355, 1102, 971, 1307, 1356, 1103, 
       1212, 1506, 1175, 1264, 1482, 1213, 1176, 1357, 1104, 1214, 1177, 1358,
        1105, 972, 1359, 1106, 973, 1360, 1107, 974, 1361, 1108, 975, 1362, 
       1109, 976}], 
      Line3DBox[{978, 1265, 1428, 977, 662, 979, 1363, 1110, 980, 1364, 1111, 
       981, 1365, 1112, 982, 1366, 1113, 983, 1483, 1178, 1114, 1215, 1507, 
       1179, 1266, 1484, 1216, 1180, 1267, 1485, 1217, 1181, 1367, 1115, 984, 
       1368, 1116, 985, 1369, 1117, 986, 1370, 1118, 987, 1371, 1119, 988}], 
      Line3DBox[{990, 1268, 1429, 989, 1269, 1430, 991, 676, 992, 1372, 1120, 
       993, 1373, 1121, 994, 1374, 1122, 995, 1486, 1182, 1123, 1218, 1508, 
       1183, 1270, 1487, 1219, 1184, 1271, 1488, 1220, 1185, 1272, 1489, 996, 
       1375, 1124, 997, 1376, 1125, 998, 1377, 1126, 999, 1378, 1127, 1000}], 
      Line3DBox[{1002, 1273, 1431, 1001, 1274, 1432, 1003, 1275, 1433, 1004, 
       690, 1005, 1379, 1128, 1006, 1380, 1129, 1007, 1490, 266, 311, 860, 
       267, 861, 312, 268, 1491, 1008, 1276, 1434, 1009, 1277, 1435, 1010, 
       1381, 1130, 1011, 1382, 1131, 1012, 1383, 1132, 1013}], 
      Line3DBox[{1015, 1278, 1436, 1014, 1279, 1437, 1016, 1280, 1438, 1017, 
       1281, 1439, 1018, 704, 1019, 1384, 1133, 1020, 1492, 1186, 1187, 1021, 
       1493, 1188, 1189, 1509, 1022, 1190, 1191, 1494, 1023, 1282, 1440, 1024,
        1283, 1441, 1025, 1284, 1442, 1026, 1385, 1134, 1027, 1386, 1135, 
       1028}], Line3DBox[{1030, 1285, 1443, 1029, 1286, 1444, 1031, 1287, 
       1445, 1032, 1288, 1446, 1033, 1289, 1447, 1034, 718, 1035, 1495, 1192, 
       1193, 1036, 1496, 1194, 1195, 1510, 1037, 1196, 1197, 1497, 1038, 1290,
        1448, 1039, 1291, 1449, 1040, 1292, 1450, 1041, 1293, 1451, 1042, 
       1387, 1136, 1043}], 
      Line3DBox[{1057, 1203, 1463, 1310, 1056, 1462, 1302, 1055, 1461, 1301, 
       1054, 1460, 1300, 1053, 1459, 1299, 1052, 1309, 1458, 1202, 1051, 825, 
       1201, 1498, 1050, 1200, 1457, 1308, 1049, 1456, 1298, 1048, 1455, 1297,
        1047, 1454, 1296, 1046, 1453, 1295, 1045, 1452, 1294, 1044, 821, 1198,
        1199}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{331, 554, 1311, 332, 1389, 568, 360, 1391, 582, 375, 1394, 
       596, 390, 1399, 610, 405, 1406, 623, 420, 1416, 636, 435, 649, 1351, 
       450, 662, 465, 1430, 675, 480, 1432, 688, 495, 1437, 701, 510, 1444, 
       714, 525, 1452, 727, 540}], 
      Line3DBox[{333, 555, 1312, 334, 569, 1323, 361, 1392, 583, 376, 1395, 
       597, 391, 1400, 611, 406, 1407, 624, 421, 1417, 637, 436, 650, 1352, 
       451, 663, 1363, 466, 676, 481, 1433, 689, 496, 1438, 702, 511, 1445, 
       715, 526, 1453, 728, 541}], 
      Line3DBox[{335, 556, 1313, 336, 570, 1324, 362, 584, 1333, 377, 1396, 
       598, 392, 1401, 612, 407, 1408, 625, 422, 1418, 638, 437, 651, 1353, 
       452, 664, 1364, 467, 677, 1372, 482, 690, 497, 1439, 703, 512, 1446, 
       716, 527, 1454, 729, 542}], 
      Line3DBox[{337, 557, 1314, 338, 571, 1325, 363, 585, 1334, 378, 599, 
       1341, 393, 1402, 613, 408, 1409, 626, 423, 1419, 639, 438, 652, 1354, 
       453, 665, 1365, 468, 678, 1373, 483, 691, 1379, 498, 704, 513, 1447, 
       717, 528, 1455, 730, 543}], 
      Line3DBox[{339, 558, 1315, 340, 572, 1326, 364, 586, 1335, 379, 600, 
       1342, 394, 614, 1347, 409, 1410, 627, 424, 1420, 640, 439, 653, 1355, 
       454, 666, 1366, 469, 679, 1374, 484, 692, 1380, 499, 705, 1384, 514, 
       718, 529, 1456, 731, 544}], 
      Line3DBox[{341, 559, 1316, 342, 573, 1327, 365, 587, 1336, 380, 601, 
       1343, 395, 761, 1476, 762, 410, 768, 1479, 769, 425, 1421, 775, 776, 
       440, 782, 783, 1356, 455, 789, 1483, 790, 470, 796, 1486, 797, 485, 
       803, 1490, 804, 500, 809, 1492, 810, 515, 815, 1495, 816, 530, 1457, 
       822, 823, 545}], 
      Line3DBox[{343, 739, 1466, 741, 345, 745, 1468, 747, 366, 751, 1471, 
       753, 381, 756, 1474, 758, 396, 763, 1477, 842, 765, 411, 770, 1480, 
       845, 772, 426, 777, 1481, 848, 779, 441, 784, 851, 1506, 786, 456, 791,
        854, 1507, 793, 471, 798, 857, 1508, 800, 486, 805, 860, 807, 501, 
       811, 1493, 862, 813, 516, 817, 1496, 864, 819, 531, 824, 1498, 866, 
       826, 546}], 
      Line3DBox[{347, 742, 833, 561, 1317, 348, 748, 836, 1469, 575, 368, 754,
        839, 1472, 589, 383, 759, 1500, 841, 603, 398, 766, 1502, 844, 616, 
       413, 773, 1504, 847, 629, 428, 1422, 780, 850, 642, 443, 787, 853, 655,
        1357, 458, 794, 856, 1485, 668, 473, 801, 859, 1488, 681, 488, 808, 
       1491, 694, 503, 814, 1494, 707, 518, 820, 1497, 720, 533, 1458, 827, 
       733, 548}], 
      Line3DBox[{349, 743, 834, 562, 1318, 350, 749, 837, 576, 1328, 369, 755,
        1473, 590, 384, 760, 1475, 604, 399, 767, 1478, 617, 414, 1411, 774, 
       630, 429, 1423, 781, 643, 444, 788, 656, 1358, 459, 795, 669, 1367, 
       474, 802, 1489, 682, 489, 1434, 695, 504, 1440, 708, 519, 1448, 721, 
       534, 1459, 734, 549}], 
      Line3DBox[{351, 744, 563, 1319, 352, 750, 577, 1329, 370, 591, 1337, 
       385, 1397, 605, 400, 1403, 618, 415, 1412, 631, 430, 1424, 644, 445, 
       657, 1359, 460, 670, 1368, 475, 683, 1375, 490, 1435, 696, 505, 1441, 
       709, 520, 1449, 722, 535, 1460, 735, 550}], 
      Line3DBox[{353, 564, 1320, 354, 578, 1330, 371, 592, 1338, 386, 606, 
       1344, 401, 1404, 619, 416, 1413, 632, 431, 1425, 645, 446, 658, 1360, 
       461, 671, 1369, 476, 684, 1376, 491, 697, 1381, 506, 1442, 710, 521, 
       1450, 723, 536, 1461, 736, 551}], 
      Line3DBox[{355, 565, 1321, 356, 579, 1331, 372, 593, 1339, 387, 607, 
       1345, 402, 620, 1348, 417, 1414, 633, 432, 1426, 646, 447, 659, 1361, 
       462, 672, 1370, 477, 685, 1377, 492, 698, 1382, 507, 711, 1385, 522, 
       1451, 724, 537, 1462, 737, 552}], 
      Line3DBox[{357, 566, 1322, 358, 580, 1332, 373, 594, 1340, 388, 608, 
       1346, 403, 621, 1349, 418, 634, 1350, 433, 1427, 647, 448, 660, 1362, 
       463, 673, 1371, 478, 686, 1378, 493, 699, 1383, 508, 712, 1386, 523, 
       725, 1387, 538, 1463, 828, 829, 830}], 
      Line3DBox[{539, 726, 821, 524, 713, 1443, 509, 700, 1436, 494, 687, 
       1431, 479, 674, 1429, 464, 661, 1428, 449, 648, 434, 635, 1415, 419, 
       622, 1405, 404, 609, 1398, 389, 595, 1393, 374, 581, 1390, 359, 567, 
       1388, 330, 553, 1464, 738, 831}], 
      Line3DBox[{547, 732, 867, 825, 532, 719, 865, 1510, 818, 517, 706, 863, 
       1509, 812, 502, 693, 861, 806, 487, 680, 1487, 858, 799, 472, 667, 
       1484, 855, 792, 457, 654, 1482, 852, 785, 442, 641, 849, 1505, 778, 
       427, 628, 846, 1503, 771, 412, 615, 843, 1501, 764, 397, 602, 840, 
       1499, 757, 382, 588, 1470, 838, 752, 367, 574, 1467, 835, 746, 346, 
       560, 1465, 832, 740, 344}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJx0nHc01//7/9EupagolFlmKSuRC0mF7D1fhQqVkZB4E7IpM9mVZI/ISh72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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["locations", TraditionalForm], 
    FormBox["\"   units\"", TraditionalForm], 
    FormBox["\"net profit      \"", TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  ImageSize->500,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{1, 20}, {50, 150}, {-7609.190319189147, 74983.81371990532}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4119470451875*^9, 3.531965648699521*^9, 
  3.5320235977562957`*^9, 3.5321232799297895`*^9, 3.5322123232867785`*^9, 
  3.533320432672672*^9, 3.533685022234375*^9, 3.5337444826567435`*^9, 
  3.533756934984375*^9, 3.5337569850625*^9, 3.539176819691119*^9, 
  3.539177003851652*^9, 3.5400537905436497`*^9, 3.540055014640664*^9, 
  3.540128558216221*^9, 3.5412484297419767`*^9, 3.5412499033832645`*^9, 
  3.5416049086292753`*^9, 3.5433495070016303`*^9, 3.586808615351777*^9, 
  3.6983497473897347`*^9, 3.6983498595971193`*^9, 3.7314218519232426`*^9},
 TextAlignment->Center,ExpressionUUID->"7a2f477c-b293-44c1-9baa-43377d3714d5"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.3.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Manager's net profit with changes in the number of units and locations"
}], "FigureCaption",
 CellChangeTimes->{3.539177003851652*^9, 3.54124921007961*^9},
 TextAlignment->Center,ExpressionUUID->"75c4cd99-f8d3-41ba-9a17-dc46d12fabbf"],

Cell["11.3.1. Is building size really important?", "Subsection",
 CellChangeTimes->{3.531966059532019*^9, 
  3.539177003851652*^9},ExpressionUUID->"e2043eb5-3d85-45a7-a3d0-\
97478abea2ea"],

Cell[TextData[{
 "We can define net profit a second way, ",
 StyleBox["np2",
  FontSlant->"Italic"],
 ", this time in terms of a new variable to represent building size, ",
 Cell[BoxData[
  FormBox[
   StyleBox["size",
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "b59dbfe6-5bef-47fb-b89f-8fac6e1ea343"],
 " = ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    FractionBox["u", "loc"], "Text",
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "a9fa8a7f-1d05-4510-9d78-bedfec09f11b"],
 "  Rearranging to express units in terms of this new size variable, ",
 StyleBox["u = size loc",
  FontSlant->"Italic"],
 ", we plot Equation 11.5 in Figure 11.4."
}], "Text",
 CellChangeTimes->{{3.5319659790164137`*^9, 3.531965981936581*^9}, {
  3.531966083200373*^9, 3.5319660934629602`*^9}, {3.531966157904646*^9, 
  3.531966161964878*^9}, {3.533321091394348*^9, 3.5333210977417116`*^9}, {
  3.5391770038526525`*^9, 
  3.539177003854653*^9}},ExpressionUUID->"c4272ec8-214e-46fb-a7ed-\
3a716de95cac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"np2", "=", 
   RowBox[{"np1", "/.", 
    RowBox[{"u", "\[Rule]", 
     RowBox[{"size", " ", "loc"}]}]}]}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.531965801429257*^9, 
  3.539177003854653*^9},ExpressionUUID->"e127bbd4-1798-4ad5-b185-\
c7d092fcd898"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"np2", "=", 
    RowBox[{
     RowBox[{"500", " ", "loc", " ", "size"}], "-", "10", "-", 
     RowBox[{"0.025`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"0.5`", " ", "loc"}]], " ", "loc", " ", "size"}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5319658098957405`*^9, 3.5319658250466075`*^9}, {
   3.5319659628544893`*^9, 3.5319659645645876`*^9}, 
   3.539177003854653*^9},ExpressionUUID->"b7efd1c8-1c18-4e60-aca9-\
7953138fa04d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig3", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{"np2", ",", 
    RowBox[{"{", 
     RowBox[{"loc", ",", "1", ",", "20"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"size", ",", "0", ",", "50"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "locations", ",", "\"\< size\>\"", ",", 
       "\"\<net profit          \>\""}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5333211536539097`*^9, 3.5333211547319713`*^9}, {
   3.5333213342192373`*^9, 3.533321334724266*^9}, 
   3.539177003855653*^9},ExpressionUUID->"8651a7ff-d7c0-4d5e-b1a8-\
e247c1d0e361"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxcnXc819/7/1/23quBClkNNEQpz5fMaGlpa5ciVGhZlVFRqVAolTSkgWiI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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[
        TagBox[{Polygon3DBox[CompressedData["
1:eJwtnHccV9Mbx+86934lkiIr2qhs8TNLiUhokMpOyZZd0bCFyEpSRtlEZSfK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           "]], Polygon3DBox[CompressedData["
1:eJwtnAn8FdMbxufOzJl7FSJpo5VKVKKyZGuxVYqijVDZl5StjVCUvZBdpMi+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           "]], Polygon3DBox[CompressedData["
1:eJwt13m8TuUaxvHX3va7t7FTp5ImOpQGQ3NxiArHkFKKzEppEkqmE1KZM8+U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           "]], 
          Polygon3DBox[{{1876, 881, 702, 701, 1037, 1646}, {1879, 889, 720, 
           719, 1052, 1652}}]},
         Annotation[#, "Charting`Private`Tag$2056#1"]& ]],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0rkvZlEYB+Bj/exUdGQaHf8AQrRUKhmdWMYyJEQymokttogSmX5GgpKI
kDCxTCNTDGPfRrQTvSXxnETx3uf3ntx7znu/+31o7m3oSQohzKg+Iea48MqO
tBAKYs8SDrCcQ6yKz7Ce39jEJS6rTnmXg/zNSZ5zng/8wUeu8YV7zEwP4Ygt
KSEcs5V/2cYTtvOUn3gWZ+M5O3nBLnarS/kzr9iYHEKd/Ud4ra9gtXd7Tg2h
UL6xNizXWLuN7+m5O45Zq7VW5J5/cXa5VRWa8Y8+wV0+2XuV//md95zjKSd4
yC/8yR3VIS/yIxdYx2lW8ivL2M/iOIMzMpzZr/L1vUyoX2bK08/KB3KuvM+c
+JszO57HLG4zk1vcVBnyBhNcZ3r8hvZZkx0bVrz3lD41fkuXcTklziyPym4L
pfLT+3/lDWmUSh8=
       "]]}, 
     {GrayLevel[0.2], 
      Line3DBox[{1385, 1642, 1659, 1717, 1875, 2160, 1658, 1643, 1721, 1800, 
       2164, 1559, 1660, 1644, 1722, 1278, 1560, 1661, 1645, 1723, 2181, 1801,
        1561, 1662, 1954, 1985, 1562, 1663, 1955, 1986, 1563, 1664, 1956, 
       1987, 1564, 1665, 2154, 1646, 1876, 2146, 1386, 1988, 1565, 1387, 1989,
        1566, 1388, 1990, 1567, 1389, 1959, 1991, 1733, 1568, 1666, 1808, 
       2182, 1979, 1732, 1569, 1667, 1974, 2161, 1718, 1703, 1570, 1668}], 
      Line3DBox[{1390, 1647, 1877, 2147, 1670, 1648, 1878, 2148, 1671, 1649, 
       1992, 1571, 1672, 1650, 1993, 1572, 1673, 1957, 1994, 1573, 1674, 1958,
        1995, 1574, 1675, 2155, 1651, 1575, 1391, 2150, 1652, 1879, 2149, 
       1392, 1880, 2064, 1393, 1996, 1576, 1394, 1676, 1772, 2171, 1577, 1704,
        555, 1997, 1734, 447, 572, 448, 1341, 619, 618, 1677, 2156, 1669, 
       1849, 1578, 1395}], 
      Line3DBox[{1397, 1881, 2065, 1396, 1653, 1882, 2151, 1398, 1654, 895, 
       1399, 1655, 1998, 1579, 1400, 1057, 1580, 1401, 2152, 1656, 1581, 1402,
        2153, 1657, 1582, 1403, 1999, 1883, 2066, 1404, 1884, 2067, 1405, 
       1853, 1885, 2191, 1854, 1678, 1773, 2185, 1817, 1827, 1818, 1705, 1756,
        1809, 1960, 2183, 1810, 1757, 1758, 1706, 1759, 1813, 2166, 1679, 
       1834, 1832, 1833, 1812, 2184, 1811, 1583, 1406}], 
      Line3DBox[{1408, 1886, 2068, 1407, 1887, 2069, 1409, 1888, 2070, 1410, 
       1889, 2071, 1411, 2000, 1584, 1412, 2001, 1585, 1413, 2002, 1586, 1414,
        2003, 1890, 2072, 1415, 1891, 2073, 1416, 279, 1160, 328, 280, 1328, 
       605, 329, 563, 1297, 281, 330, 1161, 282, 1417, 2004, 1587, 1418}], 
      Line3DBox[{1420, 1892, 2074, 1419, 1893, 2075, 1421, 1894, 2076, 1422, 
       1895, 2077, 1423, 1896, 2078, 1424, 2005, 1588, 1425, 2006, 1589, 1426,
        2007, 1897, 2079, 1427, 1898, 2080, 1428, 1680, 1681, 2158, 1429, 
       1845, 1682, 1846, 2190, 1961, 1828, 1775, 1776, 1774, 1814, 1962, 2172,
        1735, 1683, 1736, 1430, 2157, 1684, 1685, 1431, 2008, 1590, 1432}], 
      Line3DBox[{1434, 1899, 2081, 1433, 1900, 2082, 1435, 1901, 2083, 1436, 
       1902, 2084, 1437, 1903, 2085, 1438, 1904, 2086, 1439, 2009, 1591, 1440,
        2010, 1905, 2087, 1441, 1906, 2088, 1442, 1686, 2089, 1963, 1443, 
       1847, 1848, 1777, 2090, 1781, 1780, 1444, 1778, 1779, 2173, 1737, 1739,
        1738, 1445, 1964, 2091, 1687, 1446, 2011, 1592, 1447}], 
      Line3DBox[{1451, 2012, 1593, 1449, 2013, 1594, 1453, 2014, 1595, 1455, 
       2015, 1596, 1457, 2016, 1597, 1459, 2017, 1598, 1461, 2018, 1599, 1463,
        2020, 2021, 1600, 1465, 1856, 2022, 1601, 1857, 1688, 1788, 1980, 
       2176, 1602, 1819, 1760, 1761, 1725, 1975, 2165, 1804, 1603, 1803, 1762,
        2167, 1976, 1745, 1835, 1604, 1707, 1966, 2023, 1605, 1471, 2024, 
       1606, 1473}], 
      Line3DBox[{1472, 2103, 1915, 1470, 1689, 2102, 1965, 1469, 1743, 1744, 
       1740, 2175, 1787, 1786, 1468, 1784, 1802, 1785, 2101, 1724, 1742, 1741,
        1467, 1783, 2174, 1977, 1782, 1859, 1858, 1466, 1983, 2100, 1855, 
       1464, 2099, 1914, 2019, 1462, 2098, 1913, 1460, 2097, 1912, 1458, 2096,
        1911, 1456, 2095, 1910, 1454, 2094, 1909, 1452, 2093, 1908, 1448, 
       2092, 1907, 1450}], 
      Line3DBox[{1475, 1916, 2104, 1474, 2025, 1607, 1476, 2026, 1608, 1477, 
       2027, 1609, 1478, 2028, 1610, 1479, 2029, 1611, 1480, 2030, 1612, 1481,
        2031, 1917, 2105, 1482, 1860, 2032, 1613, 1861, 1690, 1789, 1981, 
       2177, 1614, 1820, 1763, 1764, 1726, 2168, 1765, 1806, 1615, 1805, 1766,
        1767, 2033, 1746, 1836, 1616, 1708, 1967, 2034, 1617, 1483, 2035, 
       1618, 1484}], 
      Line3DBox[{1486, 1918, 2106, 1485, 1919, 2107, 1487, 2036, 1619, 1488, 
       2037, 1620, 1489, 2038, 1621, 1490, 2039, 1622, 1491, 2040, 1623, 1492,
        2041, 1920, 2108, 1493, 1862, 1921, 2192, 1863, 1691, 1790, 2186, 
       1821, 1829, 1822, 1709, 1747, 1692, 1727, 2169, 1768, 1843, 1769, 1850,
        1710, 1823, 1770, 1815, 1968, 2188, 1839, 1837, 1838, 1711, 1969, 
       2042, 1624, 1494, 2043, 1625, 1495}], 
      Line3DBox[{1497, 1922, 2109, 1496, 1923, 2110, 1498, 1924, 2111, 1499, 
       2044, 1626, 1500, 2045, 1627, 1501, 2046, 1628, 1502, 2047, 1629, 1503,
        2048, 1925, 2112, 1504, 1864, 1926, 2193, 1865, 1693, 1791, 1982, 
       2187, 1830, 1824, 1712, 1748, 1694, 1728, 2170, 1771, 1844, 1852, 1851,
        1713, 1825, 1826, 1816, 1970, 2189, 1842, 1840, 1841, 1714, 2159, 
       1695, 1874, 1630, 1505, 2049, 1631, 1506}], 
      Line3DBox[{1508, 1927, 2113, 1507, 1928, 2114, 1509, 1929, 2115, 1510, 
       1930, 2116, 1511, 2050, 1632, 1512, 2051, 1633, 1513, 2052, 1634, 1514,
        2053, 1931, 2117, 1515, 674, 1376, 675, 307, 1335, 612, 349, 308, 
       1354, 641, 350, 570, 1304, 309, 657, 1364, 656, 1516, 2054, 1635, 
       1517}], Line3DBox[{1519, 1932, 2118, 1518, 1933, 2119, 1520, 1934, 
       2120, 1521, 1935, 2121, 1522, 996, 1523, 2055, 1636, 1524, 2056, 1637, 
       1525, 2057, 1936, 2122, 1526, 1866, 1867, 2194, 1527, 1868, 1696, 1792,
        1697, 2178, 1831, 1793, 1794, 1750, 1698, 1729, 2123, 1971, 1751, 
       1796, 1795, 1972, 2179, 1749, 1699, 1528, 2058, 1638, 1529, 2059, 1639,
        1530}], 
      Line3DBox[{1532, 1937, 2124, 1531, 1938, 2125, 1533, 1939, 2126, 1534, 
       1940, 2127, 1535, 1941, 2128, 1536, 1942, 2129, 1537, 2060, 1640, 1538,
        2061, 1943, 2130, 1539, 1869, 1870, 2195, 1540, 682, 1797, 2131, 527, 
       528, 440, 1730, 2132, 441, 529, 372, 2162, 1715, 1700, 1541, 1944, 
       2133, 1542, 2062, 1641, 1543}], 
      Line3DBox[{1545, 1945, 2134, 1544, 1946, 2135, 1546, 1947, 2136, 1547, 
       1948, 2137, 1548, 1949, 2138, 1549, 1950, 2139, 1550, 1951, 2140, 1551,
        2063, 1952, 2141, 1552, 1871, 2142, 1984, 1553, 1872, 1873, 1798, 
       1978, 2180, 1799, 1554, 1752, 1753, 1731, 2143, 1755, 1807, 1754, 1555,
        1719, 1720, 2163, 1716, 1701, 1556, 1953, 2144, 1557, 1973, 2145, 
       1702, 1558}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{693, 1198, 1029, 1067, 1030, 1985, 694, 1044, 1081, 1045, 
       1994, 716, 1056, 1057, 728, 905, 2000, 741, 2078, 917, 755, 2085, 929, 
       769, 2096, 941, 2016, 782, 952, 2028, 795, 963, 2038, 808, 974, 2045, 
       821, 985, 2050, 833, 996, 846, 2128, 1008, 859, 2138, 1020, 872}], 
      Line3DBox[{695, 1031, 1068, 1032, 1986, 696, 1046, 1082, 1047, 1995, 
       717, 1058, 2152, 1059, 729, 906, 2001, 742, 918, 2005, 756, 2086, 930, 
       770, 2097, 942, 2017, 783, 953, 2029, 796, 964, 2039, 809, 975, 2046, 
       822, 986, 2051, 834, 997, 2055, 847, 2129, 1009, 860, 2139, 1021, 
       873}], Line3DBox[{697, 1033, 1069, 1034, 1987, 698, 1048, 1083, 2155, 
       1049, 718, 1060, 2153, 1061, 730, 907, 2002, 743, 919, 2006, 757, 931, 
       2009, 771, 2098, 943, 2018, 784, 954, 2030, 797, 965, 2040, 810, 976, 
       2047, 823, 987, 2052, 835, 998, 2056, 848, 1010, 2060, 861, 2140, 1022,
        874}], Line3DBox[{699, 1035, 1070, 2154, 1037, 701, 1050, 2150, 1052, 
       719, 897, 1999, 731, 908, 2003, 744, 920, 2007, 758, 932, 2010, 772, 
       944, 2019, 2020, 785, 955, 2031, 798, 966, 2041, 811, 977, 2048, 824, 
       988, 2053, 836, 999, 2057, 849, 1011, 2061, 862, 1023, 2063, 875}], 
      Line3DBox[{703, 882, 1988, 704, 2064, 890, 721, 2067, 899, 733, 2073, 
       910, 746, 2080, 922, 760, 2088, 934, 774, 2100, 1367, 1368, 946, 2022, 
       787, 1369, 1370, 957, 2032, 800, 1371, 1372, 2192, 968, 813, 1373, 
       1374, 2193, 979, 826, 1375, 1376, 990, 838, 1377, 2194, 1378, 1001, 
       851, 1379, 2195, 1380, 1013, 864, 2142, 1381, 1382, 1025, 877}], 
      Line3DBox[CompressedData["
1:eJwVzktKgnEYhfG3i9gCmuenXbTbJM2sBTiIJlpBoyhoFBgRDSKSEgdhggto
Aa2joFmjFtAGEiIkokb+HDy85zzn4+OfHJ/VGmMRUcPzeMTFRMRrOuJFvpbf
5Hd5LxWxj95URJv/4KqTEffo6Z/6jtywd9xH7o8r6HW9iycujSbX1w+w5p8z
yOCWn7Z/8YcocgmyuLMltm/+BCUuhw4/667aBvwp1vUHfs6dx5bthz9HWV9A
HlX+l7tEy/cbXAGL2B29n6/zV26FW8Iyjmxt/p+/wSa3MnoDtjEEr4omuQ==

       "]], Line3DBox[CompressedData["
1:eJwVyssqBAAYhuF/TmZuwWnK1sah7KwsGAwLzcrGZGElSoghS2VjIbkDLkKS
zLAhcoqIsVASboCNx+Lt/f7v+9smZ8dmEhFRRjUZMZ+KOM1G1OTedMQ6VnUr
uYgb3Zu7Dx2ZiEZs6Ju4bnvXF+UCd3IzWvBl+9CNyJv+R+UuuRV5/Ng/de3/
m7skd/MZnyMhf3OPfZz73Rd8iQVd0r0vlzEgX/GS/ppT7gOeQkG+5WXbHafd
hzyNQfmeK7YHzriPeA5D8iM/oUE+5mF/i7yFZ7wga6tyyVbhbdTxipytxhO2
Nd7BLk6wh1/8AdivNJk=
       "]], Line3DBox[CompressedData["
1:eJwV0L0rxHEcwPEvEV0MHs/qL2D3zN3AQoqFxS1ucQp1Ch0ZLEwSRg//AMlD
kgy6qCullLJISQYhyej1G169P/f5/O76dY2pycFMUQghzXVxCE0lITSTLwvh
QFtKQ2ilzbxCOwW3mN2h+YUeKnxORM+Uh1BpzpuPeKWXKrs+7dAbPeaNec/3
a7X9gHbqrZ7wzoL7kNbYD2uXFvSUD3LuI1prP6rdeqdZ+zP9ZIw6+1T0rvrl
/e/N53wzTr19Wld9L2F+MF/wwwRxu4yuuSfNj+ZLfpmmwW5Gn7jij2XPZnWd
WXbYYo8ptzndiP4DdtlmP/o9t5xussgzS/wDSaA5bA==
       "]], 
      Line3DBox[{710, 1199, 1038, 1073, 1039, 1289, 2182, 1200, 1250, 1087, 
       1291, 1088, 1341, 1222, 1203, 1253, 1093, 1296, 2166, 1094, 1342, 1224,
        1205, 1099, 1161, 1100, 749, 1105, 2157, 1163, 1106, 763, 2091, 1111, 
       1165, 1112, 776, 2102, 1117, 1166, 1118, 2023, 789, 1123, 1167, 1124, 
       2034, 802, 1129, 1168, 1130, 2042, 815, 1135, 1169, 2159, 1136, 1383, 
       1384, 1362, 1364, 1363, 840, 1002, 2058, 853, 2133, 1014, 866, 2144, 
       1026, 878}], 
      Line3DBox[{711, 1181, 1182, 1074, 1184, 1183, 2161, 1157, 1075, 1089, 
       2156, 1076, 1359, 1360, 1361, 1295, 2184, 1294, 736, 912, 2004, 750, 
       924, 2008, 764, 936, 2011, 777, 2103, 947, 2024, 790, 958, 2035, 803, 
       969, 2043, 816, 980, 2049, 828, 991, 2054, 841, 1003, 2059, 854, 1015, 
       2062, 867, 2145, 1154, 1155, 1156}], 
      Line3DBox[{868, 1016, 2134, 855, 1004, 2124, 842, 992, 2118, 829, 981, 
       2113, 817, 970, 2109, 804, 959, 2106, 791, 948, 2104, 778, 2012, 937, 
       2092, 765, 925, 2081, 751, 913, 2074, 737, 901, 2068, 724, 893, 2065, 
       712, 885, 2147, 1077, 1040, 689, 879, 2160, 1178, 1063, 1180, 1179, 
       1062}], Line3DBox[{869, 1017, 2135, 856, 1005, 2125, 843, 993, 2119, 
       830, 982, 2114, 818, 971, 2110, 805, 960, 2107, 792, 2025, 949, 779, 
       2013, 938, 2093, 766, 926, 2082, 752, 914, 2075, 738, 902, 2069, 725, 
       894, 2151, 1053, 713, 886, 2148, 1078, 1041, 690, 2164, 880, 1276, 
       1064, 1193, 1192, 1191}], 
      Line3DBox[{870, 1018, 2136, 857, 1006, 2126, 844, 994, 2120, 831, 983, 
       2115, 819, 972, 2111, 806, 2036, 961, 793, 2026, 950, 780, 2014, 939, 
       2094, 767, 927, 2083, 753, 915, 2076, 739, 903, 2070, 726, 895, 1054, 
       714, 1992, 887, 1079, 1042, 691, 1278, 1277, 1065, 1027, 1195, 1194}], 
      Line3DBox[{871, 1019, 2137, 858, 1007, 2127, 845, 995, 2121, 832, 984, 
       2116, 820, 2044, 973, 807, 2037, 962, 794, 2027, 951, 781, 2015, 940, 
       2095, 768, 928, 2084, 754, 916, 2077, 740, 904, 2071, 727, 1998, 896, 
       1055, 715, 1993, 888, 1080, 1043, 692, 1280, 2181, 1279, 1066, 1028, 
       1197, 1196}], 
      Line3DBox[{876, 1024, 2141, 863, 1012, 2130, 850, 1000, 2122, 837, 989, 
       2117, 825, 978, 2112, 812, 967, 2108, 799, 956, 2105, 786, 2021, 945, 
       2099, 773, 933, 2087, 759, 921, 2079, 745, 909, 2072, 732, 898, 2066, 
       720, 889, 2149, 1051, 702, 881, 2146, 1036, 700}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxcnHk0Vf/3/81TmeeZi0LGkFTuLkqRBhJKGUqDoZKSoYmUDCFJSAoJpURF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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["locations", TraditionalForm], 
    FormBox["\" size\"", TraditionalForm], 
    FormBox["\"net profit          \"", TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  ImageSize->500,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{1, 20}, {0, 50}, {-50671.26415064477, 342417.1670987075}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.411947045453125*^9, 3.5319658435476656`*^9, 
  3.532023599859416*^9, 3.5321232800167947`*^9, 3.5322123240698233`*^9, 
  3.533320433440716*^9, 3.533321155680025*^9, 3.533685022453125*^9, 
  3.5337444834987917`*^9, 3.533756935203125*^9, 3.53375698534375*^9, 
  3.5391768208861876`*^9, 3.539177003878654*^9, 3.540053791756719*^9, 
  3.5400550147346697`*^9, 3.5401285592912817`*^9, 3.5412484310430517`*^9, 
  3.54124990470534*^9, 3.5416049096343327`*^9, 3.543349507132638*^9, 
  3.5868086153857794`*^9, 3.6983497475702085`*^9, 3.6983498596903667`*^9, 
  3.7314218520505824`*^9},
 TextAlignment->Center,ExpressionUUID->"a038d144-fc8e-4caa-b0fc-3dad7bbfa42e"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.4.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Net profit with changes in the number of locations and building size"
}], "FigureCaption",
 CellChangeTimes->{3.539177003878654*^9, 3.5412500211069975`*^9},
 TextAlignment->Center,ExpressionUUID->"6513bf7f-b0b3-435b-a8cc-24b49162ef76"],

Cell[TextData[{
 "The derivative with respect to location of this last net profit function \
demonstrates that the largest obtainable net profit, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["np2", "max"],
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "bc91384e-0c07-4ffc-813f-45225162a4e4"],
 ", is independent of building size. At first glance we note that ",
 StyleBox["np2",
  FontSlant->"Italic"],
 " is dependent on size because size is in its derivative. "
}], "Text",
 CellChangeTimes->{{3.531966202510197*^9, 3.531966206492425*^9}, 
   3.531966356807022*^9, {3.539177003878654*^9, 
   3.5391770038806543`*^9}},ExpressionUUID->"6ce66fa9-874a-4002-8eaf-\
393670956b4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dl", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "loc"], " ", "np2"}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.531966243351533*^9, 
  3.5391770038806543`*^9},ExpressionUUID->"08fe6670-d5bc-4692-b3d9-\
83a9f0e3d030"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", "np2"}], 
     RowBox[{"\[PartialD]", "loc"}]], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"500.", "\[InvisibleSpace]", "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.5`", " ", "loc"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "0.025`"}], "-", 
          RowBox[{"0.0125`", " ", "loc"}]}], ")"}]}]}], ")"}], " ", "size"}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.53196625343211*^9, 3.531966293575406*^9}, 
   3.5391770038806543`*^9},ExpressionUUID->"e258da06-2692-42cd-8a76-\
d1fce5e33bef"],

Cell[TextData[{
 "While this is true, it is not true that ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["np2", "max"],
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "f9884fb9-b416-43a5-9fa6-152b40779714"],
 " is dependent on size. Setting the derivative equal to zero and solving the \
implicit function, size and the constant -0.025 \"divide out\" leaving a \
function that has  location as its only variable. Solving Equation 11.7 for ",
 StyleBox["loc",
  FontSlant->"Italic"],
 " gives 15 locations (rounded because you can\[CloseCurlyQuote]t have a \
fractional location) as optimum under these conditions."
}], "Text",
 CellChangeTimes->{{3.531966202510197*^9, 3.531966206492425*^9}, 
   3.531966356807022*^9, {3.531966705778982*^9, 3.5319667636902947`*^9}, 
   3.5333216057267666`*^9, {3.5391770038816547`*^9, 
   3.539177003882654*^9}},ExpressionUUID->"19264a49-6a53-4878-bbb1-\
c4925302bd8c"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", "np2"}], 
     RowBox[{"\[PartialD]", "loc"}]], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"500.", "\[InvisibleSpace]", "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"0.5`", " ", "loc"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "0.025`"}], "-", 
           RowBox[{"0.0125`", " ", "loc"}]}], ")"}]}]}], ")"}], " ", "size"}],
      " ", "=", " ", "0"}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.531966403198676*^9, {3.5319666121936293`*^9, 3.5319666139777317`*^9}, 
   3.539177003882654*^9},ExpressionUUID->"3561cfe5-12ab-464d-afe8-\
b63eb1bd164b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CellPrint", "[", 
  RowBox[{"TextCell", "[", 
   RowBox[{
    RowBox[{"\"\<The optimal number of locations is \>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"Quiet", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{"dl", "\[Equal]", "0"}], ",", "loc"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "<>", 
     "\"\< \[TildeFullEqual] \>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"Quiet", "[", 
       RowBox[{"Round", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{"dl", "\[Equal]", "0"}], ",", "loc"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
    "\"\<Text\>\""}], "]"}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.533321844283411*^9, 3.5333219176126056`*^9}, 
   3.5391770038836546`*^9},ExpressionUUID->"e95b09b4-c7be-48c0-865b-\
3772ffcb0d08"],

Cell["The optimal number of locations is 15.4721 \[TildeFullEqual] 15", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731421852104754*^9},ExpressionUUID->"08426511-8682-41af-9807-\
b4e6871874a9"]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{3.5320282582898626`*^9, 
  3.5391770038836546`*^9},ExpressionUUID->"5a18046e-45fd-499c-9497-\
177bd291c6b7"],

Cell[TextData[{
 "We reach the surprising conclusion that under these conditions building \
size does not ",
 Cell[BoxData[
  FormBox[
   RowBox[{"matter", 
    SuperscriptBox[".", 
     ButtonBox["1",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote1"]]}], TraditionalForm]],ExpressionUUID->
  "a01e821a-8729-4ee3-a5bc-87a34b261f84"]
}], "Text",
 CellChangeTimes->{{3.531966789983799*^9, 3.5319668038095894`*^9}, {
  3.5319669806057014`*^9, 3.531967000545842*^9}, {3.539177003884654*^9, 
  3.5391770038856544`*^9}},ExpressionUUID->"72ea9e61-38a7-4515-9322-\
44f8edb6ead5"],

Cell["\<\
We can show the  relationship (always given the fixed inputs) of distance \
between properties and optimal number of locations. Optimal number of \
locations is found by multiplying a constant by the inverse of the distance \
factor.\
\>", "Text",
 CellChangeTimes->{
  3.5391770038856544`*^9},ExpressionUUID->"6feccb38-4222-496d-b4f0-\
03d0e75c5624"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"np3", "=", 
   RowBox[{"np", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ac", "\[Rule]", "10"}], ",", 
      RowBox[{"g", "\[Rule]", "500"}], ",", 
      RowBox[{"h", "\[Rule]", ".05"}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{"size", " ", "loc"}]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dl3", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "loc"], " ", "np3"}], "//", "Simplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Quiet", "[", 
   RowBox[{"optlocf", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"dl3", "\[Equal]", "0"}], ",", "loc"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.531967026676337*^9, 3.531967055767001*^9}, {
   3.531967449152501*^9, 3.5319674521446724`*^9}, 
   3.5391770038866544`*^9},ExpressionUUID->"e1ec6a4b-e986-4563-9e50-\
482e359a8c1f"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"optimal", " ", 
      RowBox[{"locations", "(", "d", ")"}]}], "=", 
     FractionBox["7.73603152491847`", "d"]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5319670581321363`*^9, 3.5319671001035366`*^9}, 
   3.5391770038866544`*^9},ExpressionUUID->"73da6945-bf2a-4486-a73d-\
a264dfe63213"],

Cell[TextData[{
 "When the distance between properties, ",
 StyleBox["d",
  FontSlant->"Italic"],
 ", increases, the number of optimal locations decreases as one might expect. \
The next result uses ",
 StyleBox["d",
  FontSlant->"Italic"],
 " = .7. Figure 11.5 shows the path of ",
 StyleBox["optlocf",
  FontSlant->"Italic"],
 " as distance increases. This suggests the intuitively satisfying result \
that dense urbanization offers more management efficiency than rural or \
sparsely urbanized areas, something we may have guessed from things we \
learned in Chapter 1."
}], "Text",
 CellChangeTimes->{{3.5319675545345287`*^9, 3.5319675958268905`*^9}, {
   3.531998390762538*^9, 3.531998391415575*^9}, {3.5333221533920913`*^9, 
   3.53332215861439*^9}, 
   3.5391770038866544`*^9},ExpressionUUID->"33e53099-e98c-4e94-9c7d-\
a557ac2d7be8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"np4", "=", 
   RowBox[{"np", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ac", "\[Rule]", "100"}], ",", 
      RowBox[{"g", "\[Rule]", "500"}], ",", 
      RowBox[{"h", "\[Rule]", ".05"}], ",", 
      RowBox[{"d", "\[Rule]", ".7"}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{"size", " ", "loc"}]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dl4", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "loc"], " ", "np4"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CellPrint", "[", 
  RowBox[{"TextCell", "[", 
   RowBox[{
    RowBox[{
    "\"\<When distance increases to .7 optimal locations falls to \>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"Quiet", "[", 
       RowBox[{"Round", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{"dl4", "\[Equal]", "0"}], ",", "loc"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
    "\"\<Text\>\""}], "]"}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5319671363066072`*^9, 3.531967142665971*^9}, {
   3.533322012993061*^9, 3.5333220143421383`*^9}, {3.533322180876663*^9, 
   3.533322481658867*^9}, {3.5333225380380917`*^9, 3.533322588323968*^9}, {
   3.533322659956065*^9, 3.533322737876522*^9}, 
   3.5391770038886547`*^9},ExpressionUUID->"e402c83b-c579-48a6-a098-\
7e919692c74a"],

Cell["When distance increases to .7 optimal locations falls to 11", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731421858337307*^9},ExpressionUUID->"938e4ca1-131f-4258-8386-\
81a456e8e40b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot[optlocf,{d,.00001,1},PlotRange->{0,100},AxesLabel->{\"distance\",\"\
optimal locations\"}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.41177488665625*^9, 3.5319672878822765`*^9, {3.531998206137978*^9, 
   3.531998314433172*^9}, 3.5391770038886547`*^9, {3.5412492456896467`*^9, 
   3.541249252010008*^9}},ExpressionUUID->"712774a8-7ad1-4e66-a632-\
fcc638e054d9"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwdjnk4lAsbh406ESkRJZnXGhmMLR1ZnsdkGXtmLIUW7crSlw5K2ilRhCwp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       "]]},
     Annotation[#, "Charting`Private`Tag$2613#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"distance\"", TraditionalForm], 
    FormBox["\"optimal locations\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.9999999795920408}, {0, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.41194704653125*^9, {3.53196728916035*^9, 3.5319673308717356`*^9}, 
   3.5319674607541647`*^9, {3.5319982077070675`*^9, 3.5319982820613203`*^9}, 
   3.5319983150872097`*^9, 3.5320236011354885`*^9, 3.5321232804508195`*^9, 
   3.5322123259229293`*^9, 3.533320435663843*^9, 3.533685022875*^9, 
   3.533744485513907*^9, 3.533756935609375*^9, 3.533756985765625*^9, 
   3.5391768236763473`*^9, 3.5391770039066553`*^9, 3.540053794774892*^9, 
   3.5400550149476814`*^9, 3.540128562214449*^9, 3.541248434448246*^9, 
   3.54124928542892*^9, 3.541249908222541*^9, 3.5416049123214865`*^9, 
   3.54334950734665*^9, 3.586808615500786*^9, 3.6983497478118567`*^9, 
   3.6983498598738556`*^9, 3.7314218584195213`*^9},
 TextAlignment->Center,ExpressionUUID->"e52a7867-ff99-4aa5-90c2-abb05f869abf"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.5.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Optimal locations as distance increases"
}], "FigureCaption",
 CellChangeTimes->{3.5391770039066553`*^9, 3.541249296661562*^9},
 TextAlignment->Center,ExpressionUUID->"39e7aa13-767a-4660-917a-5b7304935019"],

Cell["\<\
We set aside these insights for the moment to address the other party's \
problem.\
\>", "Text",
 CellChangeTimes->{
  3.5391770039066553`*^9},ExpressionUUID->"68a0bc5d-c907-403f-bc2d-\
97c93b4c1364"]
}, Open  ]],

Cell[CellGroupData[{

Cell["11.4. The property owner\[CloseCurlyQuote]s dilemma", "Section",
 CellChangeTimes->{
  3.5319984167710257`*^9, {3.5337446195985765`*^9, 3.5337446243928504`*^9}, 
   3.5391770039066553`*^9},ExpressionUUID->"c32ff3dd-b6a8-45c9-b84f-\
c37acf1bd9a4"],

Cell[TextData[{
 "Especially for small properties, management fees are calculated as a \
percentage of ",
 StyleBox["effective",
  FontSlant->"Italic"],
 " ",
 StyleBox["gross income",
  FontSlant->"Italic"],
 " (",
 StyleBox["egi",
  FontSlant->"Italic"],
 ") collected from tenants.  ",
 StyleBox["Egi",
  FontSlant->"Italic"],
 " is defined as the actual receipts after vacancy and credit losses.  The \
manager has a fiduciary obligation to maximize the owner's ",
 StyleBox["net",
  FontSlant->"Italic"],
 " income. With management fees a percentage of the collected rent, the \
manager's fee income is maximized by collecting the most rent from tenants.  \
This conflict introduces a perverse incentive because tenants paying the \
highest rent often subject the property to more intense use and often vacate \
after a short tenancy. While the manager shares in vacancy losses because his \
fee is based on ",
 StyleBox["collected",
  FontSlant->"Italic"],
 " income, increased expenses are borne solely by the owner.  The net income \
of both manager and owner are affected by vacancy rates.  But the owner's \
interest in maximizing net income considers expenses; the manager's interest \
in maximizing fee income does ",
 Cell[BoxData[
  FormBox[
   RowBox[{"not", 
    SuperscriptBox[".", 
     ButtonBox["2",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote2"]]}], TraditionalForm]],ExpressionUUID->
  "a7d8d5fd-a7ed-40c7-bf44-cec2dfd43c3a"]
}], "Text",
 CellChangeTimes->{
  3.5319984406473913`*^9, {3.531998517484786*^9, 3.5319985253112335`*^9}, {
   3.5391770039076557`*^9, 3.539177003909656*^9}, {3.5400551970930996`*^9, 
   3.540055207072671*^9}, 
   3.541250067931676*^9},ExpressionUUID->"489ceca1-bd04-4d86-b174-\
a1021bf403ba"],

Cell["11.4.1. The \[OpenCurlyDoubleQuote]No vacancy rate\
\[CloseCurlyDoubleQuote] approach", "Subsection",
 CellChangeTimes->{
  3.531998558356124*^9, {3.5337446409397964`*^9, 3.53374465061135*^9}, 
   3.539177003909656*^9},ExpressionUUID->"4427457a-d638-4001-be30-\
8883b5257216"],

Cell[TextData[{
 "For the moment we shall ignore the connection between higher rents and \
vacancy rates and deal only with the variable cost issue. Later we will \
include the vacancy factor to provide a more realistic result.\n\nThe owner's \
net operating income (",
 StyleBox["noi",
  FontSlant->"Italic"],
 ") is:"
}], "Text",
 CellChangeTimes->{
  3.539177003909656*^9},ExpressionUUID->"a4a4d0f9-3922-4ccd-ba84-\
438a17146866"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"noi", "=", 
    RowBox[{"r", "-", "fc", "-", "vc"}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.531998588501848*^9, 
  3.539177003910656*^9},ExpressionUUID->"a4a59e0c-2c10-4d98-88c4-\
6991cf8e23b3"],

Cell["Where:", "Text",
 CellChangeTimes->{{3.531998597257349*^9, 3.531998606380871*^9}, 
   3.5333253130498133`*^9, 
   3.539177003910656*^9},ExpressionUUID->"dd1be429-aef7-497b-804b-\
a11ebd48c066"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"noi\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"r\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"fc\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"vc\",FontSlant->\"Italic\"]\)\>\""}], "}"}], 
        ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "4"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<net operating income\>\"", ",", "\"\<rent collected\>\"", ",", 
          "\"\<fixed costs (not related to occupancy such as taxes and \
insurance)\>\"", ",", 
          "\"\<variable costs (occupancy-driven costs such as maintenance \
which for now will include vacancy)\>\""}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.5333200428873773`*^9, 3.53332013664974*^9}, {
   3.533325220241505*^9, 3.533325278034811*^9}, {3.5333253331429625`*^9, 
   3.5333253336479917`*^9}, 
   3.539177003911656*^9},ExpressionUUID->"9ceb9ab7-aaae-48c4-bcb7-\
0ebb502572a1"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"noi\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"net operating income\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"rent collected\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"fc\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"fixed costs (not related to occupancy such as taxes and \
insurance)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"vc\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"variable costs (occupancy-driven costs such as maintenance \
which for now will include vacancy)\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 ShowCellLabel->False,
 CellChangeTimes->{3.533325279643903*^9, 3.5333253379702387`*^9, 
  3.53368502296875*^9, 3.5337444859839334`*^9, 3.533756935703125*^9, 
  3.533756985953125*^9, 3.5391768243403854`*^9, 3.539177003912656*^9, 
  3.5400537953969274`*^9, 3.5400550152136965`*^9, 3.5401285628334846`*^9, 
  3.5412484376544294`*^9, 3.5412499090325875`*^9, 3.5412501126742353`*^9, 
  3.5416049129465227`*^9, 3.5433495074046535`*^9, 3.586808615510786*^9, 
  3.6983497478278675`*^9, 3.69834985991193*^9, 
  3.7314218584405775`*^9},ExpressionUUID->"d3b000da-0178-450a-86d0-\
46cf679a5a0d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"noi", ":=", 
  RowBox[{"r", "-", "fc", "-", "vc"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.539177003913656*^9},ExpressionUUID->"7628869f-08ae-4ade-aa93-\
8e64bf88a1c4"],

Cell["\<\
Variable costs, which include management fees, are modeled as an increasing \
function of rent:\
\>", "Text",
 CellChangeTimes->{
  3.539177003913656*^9},ExpressionUUID->"db2f12b0-e380-4f19-b224-\
cff2bc605577"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"vc", " ", "=", "  ", 
    FormBox[
     RowBox[{
      RowBox[{"100.", 
       RowBox[{"(", 
        RowBox[{"1", "-", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "0.025"}], " ", "r"}]]}], ")"}]}], "+", 
      RowBox[{"mgt", " ", "r"}]}],
     TraditionalForm]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5319986343934727`*^9, 3.531998634396473*^9}, 
   3.539177003913656*^9},ExpressionUUID->"f6056f63-f41f-4fe4-8fbb-\
c746b7655b94"],

Cell["Where:", "Text",
 CellChangeTimes->{3.533325362911665*^9, 
  3.539177003913656*^9},ExpressionUUID->"6c0a6905-6063-466f-9df5-\
61663fc676b4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"vc\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\[ExponentialE]\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"mgt\",CellOpen->False,FontSlant->\"Italic\"]\)\
\>\""}], "}"}], ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "3"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<variable costs\>\"", ",", "\"\<base of the natural log\>\"", 
          ",", "\"\<management fee, a percentage of rent\>\""}], "}"}]}], 
       "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.5333200428873773`*^9, 3.53332013664974*^9}, {
   3.5333253755173864`*^9, 3.533325414146596*^9}, 3.5333254613752975`*^9, {
   3.533325501534594*^9, 3.5333255069049015`*^9}, 
   3.5391770039146557`*^9},ExpressionUUID->"3708aa31-09b6-4c2b-8ee8-\
e58e7632292c"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"vc\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"variable costs\"\>"},
     {"\<\"\[ExponentialE]\"\>", "\<\"=\"\>", "\<\"base of the natural \
log\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"mgt\\\",CellOpen->False,FontSlant->\\\"\
Italic\\\"]\\)\"\>", "\<\"=\"\>", "\<\"management fee, a percentage of rent\"\
\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.533325508886015*^9, 3.533685023140625*^9, 
  3.5337444864209585`*^9, 3.533756935875*^9, 3.533756986078125*^9, 
  3.5391768249774218`*^9, 3.539177003915656*^9, 3.5400537960519648`*^9, 
  3.5400550153097024`*^9, 3.5401285635875278`*^9, 3.5412484385104785`*^9, 
  3.541249910079647*^9, 3.5412506450356846`*^9, 3.541604913531556*^9, 
  3.5433495074686575`*^9, 3.586808615519787*^9, 3.6983497478619576`*^9, 
  3.698349859940004*^9, 
  3.7314218584716606`*^9},ExpressionUUID->"3d282edb-88ce-4b15-b545-\
17908919d391"]
}, Open  ]],

Cell["Substituting Equation 11.9 into Equation 11.10 we have", "Text",
 CellChangeTimes->{{3.5319987663380194`*^9, 3.5319987862701597`*^9}, 
   3.539177003915656*^9},ExpressionUUID->"94dd4361-cb99-4873-ba13-\
3aebaf58b830"],

Cell[BoxData[
 RowBox[{"vc", ":=", 
  RowBox[{
   RowBox[{"100", 
    RowBox[{"(", 
     RowBox[{"1", "-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", ".025"}], " ", "r"}]]}], ")"}]}], " ", "+", 
   RowBox[{"mgt", " ", "r"}]}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.539177003915656*^9},ExpressionUUID->"df1b7405-5ef6-4b5d-bf29-\
5fc9c68b5dbb"],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox["noi",
    FontSlant->"Italic"], 
   StyleBox["=",
    FontSlant->"Italic"], 
   RowBox[{"r", "-", 
    RowBox[{
     StyleBox["mgt",
      FontSlant->"Italic"], " ", "r"}], "-", 
    StyleBox["fc",
     FontSlant->"Italic"], "-", 
    RowBox[{"100", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.025`"}], " ", "r"}]]}], ")"}]}]}]}], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5319986902736692`*^9, 3.531998733163122*^9}, {
   3.533325551535454*^9, 3.5333255530965433`*^9}, 
   3.5391770039166565`*^9},ExpressionUUID->"35bfe2ac-c683-4f6a-806c-\
c04503517d7e"],

Cell["\<\
For the purposes of illustration we will use a 10% management fee.  Figure \
11.6 reveals that variable costs rise at a constant rate after an initial \
steep rise.\
\>", "Text",
 CellChangeTimes->{{3.5319988878969727`*^9, 3.5319989199818077`*^9}, 
   3.5391770039166565`*^9},ExpressionUUID->"e7a6a46f-2ae5-4a97-8575-\
5bbf46051b15"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vcpl1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"vc", "/.", "\[InvisibleSpace]", 
      RowBox[{"mgt", "\[Rule]", "0.1`"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "500"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"rent", ",", "\"\<vc\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"250", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<250\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"500", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<500\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}]}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"20", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<20\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"80", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<80\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"140", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<140\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}]}], 
         "}"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"vcpl2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"vc", "/.", "\[InvisibleSpace]", 
      RowBox[{"mgt", "\[Rule]", "0.1`"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "2000"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"rent", ",", "\"\<vc\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"500", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<500\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2000", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<2000\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}]}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"50", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<50\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"175", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<175\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"300", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<300\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}]}], 
         "}"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"fig5", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"GraphicsRow", "[", 
     RowBox[{"{", 
      RowBox[{"vcpl1", ",", "vcpl2"}], "}"}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.411775244984375*^9, 3.4117752625625*^9}, 
   3.5319989465453267`*^9, 3.532023639354675*^9, 
   3.5391770039186563`*^9},ExpressionUUID->"dba24ba8-9882-49b8-a887-\
7fa3c7f93523"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwV0Xk01A0XB3Dh7SEtlEqS1JQQkTUeM/O1jWhsM8yisf3IlgylMDSTKNKj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           "]]},
         Annotation[#, "Charting`Private`Tag$2659#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["rent", TraditionalForm], 
        FormBox["\"vc\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 500}, {0., 149.99962631417958`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{{{250, 
          FormBox[
           StyleBox["\"250\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}, {500, 
          FormBox[
           StyleBox["\"500\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}}, {{20, 
          FormBox[
           StyleBox["\"20\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}, {80, 
          FormBox[
           StyleBox["\"80\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}, {140, 
          FormBox[
           StyleBox["\"140\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}}}], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVkHk81AkDxpG2rCtJK2WK2ewoG3JsFB5MbuMagzHucyRmfqlcoRKpUO5z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           "]]},
         Annotation[#, "Charting`Private`Tag$2703#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["rent", TraditionalForm], 
        FormBox["\"vc\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 2000}, {0., 299.9999959183674}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{{{500, 
          FormBox[
           StyleBox["\"500\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}, {2000, 
          FormBox[
           StyleBox["\"2000\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}}, {{50, 
          FormBox[
           StyleBox["\"50\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}, {175, 
          FormBox[
           StyleBox["\"175\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}, {300, 
          FormBox[
           StyleBox["\"300\"", FontSize -> 8, StripOnInput -> False], 
           TraditionalForm]}}}], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->500,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.411947047390625*^9, 3.5319989486354465`*^9, 
  3.531998986424608*^9, 3.5320236012584963`*^9, 3.5320236397556977`*^9, 
  3.5321232805618258`*^9, 3.5322123271650004`*^9, 3.533320436546893*^9, 
  3.53368502328125*^9, 3.533744487187003*^9, 3.533756936015625*^9, 
  3.533756986234375*^9, 3.539176825770467*^9, 3.5391770039556584`*^9, 
  3.5400537971110253`*^9, 3.5400550153837066`*^9, 3.5401285647035913`*^9, 
  3.5412484395755396`*^9, 3.541249911420724*^9, 3.5416049144296074`*^9, 
  3.543349507535661*^9, 3.5868086155647893`*^9, 3.6983497480043635`*^9, 
  3.698349860054308*^9, 3.7314218586110296`*^9},
 TextAlignment->Center,ExpressionUUID->"11489df0-82f3-407c-9432-6286c260857d"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.6.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Variable costs as rent increases"
}], "FigureCaption",
 CellChangeTimes->{3.5391770039566584`*^9, 3.5412506666789227`*^9},
 TextAlignment->Center,ExpressionUUID->"5b323a37-a1c1-4c95-8092-368ccf9203fb"],

Cell[TextData[{
 "Next we take the derivative of variable costs with respect to rent.  Taking \
the limit of that term as ",
 StyleBox["r",
  FontSlant->"Italic"],
 " increases without bound, we notice that variable costs approach the \
management fee ",
 StyleBox["rate",
  FontSlant->"Italic"],
 ". We confirm this graphically by plotting the derivative against rent in \
Figure 11.7. This suggests that after some point, variable costs become a \
constant percent of rent.  Stated differently, one could conclude that after \
some rent all variable costs other than management fee reach a maximum.  When \
those non-management costs level out (as above) the only component of \
variable cost increase is the increase in management fees which are a direct \
function of rent."
}], "Text",
 CellChangeTimes->{{3.5319990900585356`*^9, 3.53199909485981*^9}, 
   3.5391770039566584`*^9},ExpressionUUID->"23100fcb-fc31-4759-9f9a-\
38abfa0a8149"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dvcr", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], "vc"}], "/.", 
     RowBox[{"mgt", "\[Rule]", ".1"}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{"dvcr", ",", 
    RowBox[{"r", "\[Rule]", "\[Infinity]"}]}], "]"}], ";"}], "\n", 
 RowBox[{"Legended", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{"dvcr", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "500"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", ".5"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Rent\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \
\(r\)]\)\!\(\*StyleBox[\"vc\",FontSlant->\"Italic\"]\)\>\""}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", ".1", "}"}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"Placed", "[", 
    RowBox[{
     RowBox[{"LineLegend", "[", 
      RowBox[{
       RowBox[{"{", "Black", "}"}], ",", 
       RowBox[{
       "{", "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \
\(r\)]\)\!\(\*StyleBox[\"vc\",FontSlant->\"Italic\"]\) = \
0.1+2.5\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\(-0.025\)\\\ r\)]\)\>\"", 
        "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{".9", ",", ".7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.531999127320667*^9, {3.5319992008088703`*^9, 3.5319992307215805`*^9}, {
   3.5319992785163145`*^9, 3.5319993950549803`*^9}, {3.5319994288329124`*^9, 
   3.531999506209338*^9}, 3.539177003957659*^9, {3.586809450155525*^9, 
   3.586809528841026*^9}, {3.5868095803229704`*^9, 3.586809613401862*^9}, {
   3.5868096772945166`*^9, 3.586809698436726*^9}, {3.5868097463694677`*^9, 
   3.586809759008191*^9}, {3.5868098021866603`*^9, 3.5868098228798437`*^9}, {
   3.586810055568153*^9, 
   3.5868101076411314`*^9}},ExpressionUUID->"3e480f71-6ae5-432f-82a0-\
d3028f22774d"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13k81M8bAHBHKRQpJOlCJVclkdA8jiTpcuXKfVvXYu2yjhBSjkTJnTtf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         "]]},
       Annotation[#, "Charting`Private`Tag$2885#1"]& ]}, {}, {}}, InsetBox[
     TemplateBox[{
      "\"\\!\\(\\*SubscriptBox[\\(\[PartialD]\\), \
\\(r\\)]\\)\\!\\(\\*StyleBox[\\\"vc\\\",FontSlant->\\\"Italic\\\"]\\) = \
0.1+2.5\\!\\(\\*SuperscriptBox[\\(\[ExponentialE]\\), \\(\\(-0.025\\)\\\\ \
r\\)]\\)\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   GrayLevel[0], 
                   RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                 "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                 FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                 PlotRangePadding -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                StyleBox[
                 RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> False]],
                Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              GrayLevel[0], Editable -> False, Selectable -> False], "}"}], 
           ",", 
           RowBox[{"{", #, "}"}]}], "]"}]& )], Scaled[{0.9, 0.7}], 
     ImageScaled[{1, 1}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox["\"Rent\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(\[PartialD]\\), \
\\(r\\)]\\)\\!\\(\\*StyleBox[\\\"vc\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
      TraditionalForm]},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}},
   GridLines->{None, {0.1}},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->Automatic,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{0., 499.9999897959184}, {0, 0.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Line[CompressedData["
1:eJwd13k81M8bAHBHKRQpJOlCJVclkdA8jiTpcuXKfVvXYu2yjhBSjkTJnTtf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           "]]}, "Charting`Private`Tag$2885#1"]}}, {}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {None, {0.1}}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}}, PlotRangeClipping -> True, ImagePadding -> 
      All, DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, 
      AxesLabel -> {
       "Rent", "\!\(\*SubscriptBox[\(\[PartialD]\), \
\(r\)]\)\!\(\*StyleBox[\"vc\",FontSlant->\"Italic\"]\)"}, 
      AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
      Frame -> {{False, False}, {False, False}}, 
      FrameLabel -> {{None, None}, {None, None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, {0.1}}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, 
      PlotRange -> {{0., 499.9999897959184}, {0, 0.5}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {Automatic, Automatic}}, 
      Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        GrayLevel[0]}, {
       "\!\(\*SubscriptBox[\(\[PartialD]\), \
\(r\)]\)\!\(\*StyleBox[\"vc\",FontSlant->\"Italic\"]\) = \
0.1+2.5\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\(-0.025\)\\ r\)]\)"}]], {{
      0.9, 0.7}, {1, 1}}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.411947048234375*^9, 3.5319991373212385`*^9, 3.5319992382140093`*^9, 
   3.531999348793334*^9, {3.531999384626384*^9, 3.531999395559009*^9}, {
   3.5319994672811112`*^9, 3.531999508618476*^9}, 3.5320236027565813`*^9, 
   3.532123281927904*^9, 3.5322123284270725`*^9, 3.533320438389999*^9, 
   3.533685024734375*^9, 3.5337444887060895`*^9, 3.5337569375625*^9, 
   3.533756987859375*^9, 3.5391768279975944`*^9, 3.539177004002661*^9, 
   3.5400537990241346`*^9, 3.540055016352762*^9, 3.540128566319684*^9, 
   3.541248441383643*^9, 3.5412499131558237`*^9, 3.5412506996228065`*^9, 
   3.5416049161307044`*^9, 3.5433495084327126`*^9, 3.586808616585848*^9, 
   3.586809614620932*^9, {3.5868096838808937`*^9, 3.5868096988137474`*^9}, 
   3.5868097598752403`*^9, {3.586809811989221*^9, 3.586809824003908*^9}, {
   3.586810056728219*^9, 3.586810107991151*^9}, 3.698349748135717*^9, 
   3.6983498601556025`*^9, 3.7314218587874985`*^9},
 TextAlignment->Center,ExpressionUUID->"c9690214-d947-4f71-a639-8b363d5fec29"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.7.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "First derivative of vc with respect to r as rent increases"
}], "FigureCaption",
 CellChangeTimes->{3.539177004002661*^9, 3.541250731627637*^9},
 TextAlignment->Center,ExpressionUUID->"1df8ae19-13c6-4dfb-bfab-6e07940bd18c"],

Cell[TextData[{
 "Another way of saying the same thing is from the perspective of net \
operating income. The limit and the plot of the derivative of ",
 StyleBox["noi",
  FontSlant->"Italic"],
 " with respect to rent, Equation 11.12, in Figure 11.8 both show that the \
change in ",
 StyleBox["noi",
  FontSlant->"Italic"],
 " becomes a constant 90% (100% - the 10% management fee) after a certain \
rent level."
}], "Text",
 CellChangeTimes->{{3.532023817494864*^9, 3.532023824129243*^9}, {
   3.5320245499307566`*^9, 3.532024555737089*^9}, 
   3.539177004002661*^9},ExpressionUUID->"5a792228-ecfd-4336-9aca-\
0841c19a5609"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", "noi"}], "\[Delta]r"], "=", 
    RowBox[{"0.9`", "\[VeryThinSpace]", "-", 
     RowBox[{"2.5`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.025`"}], " ", "r"}]]}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5320237912413626`*^9, 3.532023808123328*^9}, {
   3.532023862115416*^9, 3.5320238663226566`*^9}, 
   3.539177004002661*^9},ExpressionUUID->"0366a229-5d56-471a-943e-\
2859c397610e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dnoi", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], "noi"}], "/.", 
    RowBox[{"mgt", "\[Rule]", ".1"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{"dnoi", ",", 
    RowBox[{"r", "\[Rule]", "\[Infinity]"}]}], "]"}], ";"}], "\n", 
 RowBox[{"Legended", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{".9", ",", "dnoi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "50", ",", "1000"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Red"}], "]"}], ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", ".2"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<rent\>\"", ",", "\"\<\[EmptyUpTriangle] noi\>\""}], 
       "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], ",", 
   RowBox[{"Placed", "[", 
    RowBox[{
     RowBox[{"LineLegend", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*FractionBox[RowBox[{\"\[PartialD]\", \
StyleBox[\"noi\",FontSlant->\"Italic\"]}], \"\[Delta]r\"]\)=0.9\
\[VeryThinSpace]-2.5 \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\(-0.025\) r\
\)]\)\>\"", ",", 
         "\"\<\!\(\*SubscriptBox[\(Limit\), \(r \[RightArrow] \
\[Infinity]\)]\)\!\(\*FractionBox[RowBox[{\"\[PartialD]\", \
StyleBox[\"noi\",FontSlant->\"Italic\"]}], \"\[Delta]r\"]\)\>\""}], "}"}]}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{".9", ",", ".7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.5320238869178343`*^9, 3.532023918779657*^9, 3.53202526716378*^9, {
   3.5333258375908155`*^9, 3.533325869505641*^9}, 3.5333259179704127`*^9, 
   3.539177004005661*^9, {3.5412507951912727`*^9, 3.5412508029617176`*^9}, {
   3.5868101809013214`*^9, 3.5868103241365137`*^9}, 
   3.58681035903551*^9},ExpressionUUID->"2e55ae85-25df-4cb9-8100-\
964461c4ee20"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQLfZ40SIGBk+Hs2dA4I39kunPGnJW+sL5kmpT9XM0
A+F8I4mKVCvzMDif31dzlvf7KDjfQ2Kmw6r+eDi/TSBkvqlXEpzvte3Q3O0L
U+D8y78YTmRpp8P5XV1yq11WZiLcY72Y1+FPNpzf3P19dk5jHpyfVHcz5G5u
AZw/647aDvGphXC+KVfMxqyrRXB+4wmXLD+GEjjfIEx0p5dLKZxf1hmaEtVU
Bufn+nqe/7WqHM4/9kDlwuY3FXD+BZYtE/5KVMH5tj+0nsfHVcP5jhMFZ12d
WwPnf9u1mufO8Vo4n2+Lruhvrno4//W8jXmhMg1w/mwzFkbzDQj+n61e95YE
NML52/5mSUc/Q/AVdesXz+1ogvMj9E/ffKneDOc///khv24Pgq+xhitwfmwL
nH9Q7d9Eji8IvlqJZmN1eyucb7PSY3eVehucv3qZY+ihPQj+6W49q2lx7XC+
s+XXuk1fEfz2nZ8Lb3R2wPk1is/Wd2l1wvmnAjf5th5A8E9mFpnxJHfB+VNC
ss7OYeqG87ez2xwpnY7g9yxiZLtt0QPn72RduLzjPIK/ybriu31yL5wfE+k8
qZm5D86Ps3/Rwz8TwZ/GEX+w/Q2Cf/7i1a//7fvhfABMrPWR
         "]]},
       Annotation[#, "Charting`Private`Tag$2970#1"]& ], 
      TagBox[
       {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwl13c8Vt8fAHAqkkKbBmlQCSlKqZxPUtnZe2Xv+djr8dgim0hlVUbZ2TKy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         "]]},
       Annotation[#, "Charting`Private`Tag$2970#2"]& ]}, {}, {}}, InsetBox[
     TemplateBox[{
      "\"\\!\\(\\*FractionBox[RowBox[{\\\"\[PartialD]\\\", StyleBox[\\\"noi\\\
\",FontSlant->\\\"Italic\\\"]}], \
\\\"\[Delta]r\\\"]\\)=0.9\[VeryThinSpace]-2.5 \\!\\(\\*SuperscriptBox[\\(\
\[ExponentialE]\\), \\(\\(-0.025\\) r\\)]\\)\"",
       "\"\\!\\(\\*SubscriptBox[\\(Limit\\), \\(r \[RightArrow] \
\[Infinity]\\)]\\)\\!\\(\\*FractionBox[RowBox[{\\\"\[PartialD]\\\", StyleBox[\
\\\"noi\\\",FontSlant->\\\"Italic\\\"]}], \\\"\[Delta]r\\\"]\\)\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               InterpretationBox[
                ButtonBox[
                 TooltipBox[
                  GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                   "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                   FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                   FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                   Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  StyleBox[
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                   False]], Appearance -> None, BaseStyle -> {}, 
                 BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                 ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                   If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                 Automatic, Method -> "Preemptive"], 
                RGBColor[0, 0, 1], Editable -> False, Selectable -> False], 
               ",", 
               InterpretationBox[
                ButtonBox[
                 TooltipBox[
                  GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                   "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                   FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                   FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                   Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  StyleBox[
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                   False]], Appearance -> None, BaseStyle -> {}, 
                 BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                 ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                   If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                 Automatic, Method -> "Preemptive"], 
                RGBColor[1, 0, 0], Editable -> False, Selectable -> False]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& )], Scaled[{0.9, 0.7}], 
     ImageScaled[{1, 1}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox["\"rent\"", TraditionalForm], 
     FormBox["\"\[EmptyUpTriangle] noi\"", TraditionalForm]},
   AxesOrigin->{0., 0.2},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->400,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{All, All},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Thickness[Large], 
           RGBColor[1, 0, 0]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGAwAWIQLfZ40SIGBk+Hs2dA4I39kunPGnJW+sL5kmpT9XM0
A+F8I4mKVCvzMDif31dzlvf7KDjfQ2Kmw6r+eDi/TSBkvqlXEpzvte3Q3O0L
U+D8y78YTmRpp8P5XV1yq11WZiLcY72Y1+FPNpzf3P19dk5jHpyfVHcz5G5u
AZw/647aDvGphXC+KVfMxqyrRXB+4wmXLD+GEjjfIEx0p5dLKZxf1hmaEtVU
Bufn+nqe/7WqHM4/9kDlwuY3FXD+BZYtE/5KVMH5tj+0nsfHVcP5jhMFZ12d
WwPnf9u1mufO8Vo4n2+Lruhvrno4//W8jXmhMg1w/mwzFkbzDQj+n61e95YE
NML52/5mSUc/Q/AVdesXz+1ogvMj9E/ffKneDOc///khv24Pgq+xhitwfmwL
nH9Q7d9Eji8IvlqJZmN1eyucb7PSY3eVehucv3qZY+ihPQj+6W49q2lx7XC+
s+XXuk1fEfz2nZ8Lb3R2wPk1is/Wd2l1wvmnAjf5th5A8E9mFpnxJHfB+VNC
ss7OYeqG87ez2xwpnY7g9yxiZLtt0QPn72RduLzjPIK/ybriu31yL5wfE+k8
qZm5D86Ps3/Rwz8TwZ/GEX+w/Q2Cf/7i1a//7fvhfABMrPWR
           "]]}, "Charting`Private`Tag$2970#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0, 0, 1]], 
          Line[CompressedData["
1:eJwl13c8Vt8fAHAqkkKbBmlQCSlKqZxPUtnZe2Xv+djr8dgim0hlVUbZ2TKy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           "]]}, "Charting`Private`Tag$2970#2"]}}, {}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {0., 0.2}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
      DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, AxesLabel -> {"rent", "\[EmptyUpTriangle] noi"}, 
      AxesOrigin -> {0., 0.2}, DisplayFunction :> Identity, 
      Frame -> {{False, False}, {False, False}}, 
      FrameLabel -> {{None, None}, {None, None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImageSize -> 400, 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{Automatic, Automatic}, {
        Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        RGBColor[0, 0, 1], 
        RGBColor[1, 0, 0]}, {
       "\!\(\*FractionBox[RowBox[{\"\[PartialD]\", \
StyleBox[\"noi\",FontSlant->\"Italic\"]}], \"\[Delta]r\"]\)=0.9\
\[VeryThinSpace]-2.5 \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\(-0.025\) r\
\)]\)", "\!\(\*SubscriptBox[\(Limit\), \(r \[RightArrow] \[Infinity]\)]\)\!\(\
\*FractionBox[RowBox[{\"\[PartialD]\", \
StyleBox[\"noi\",FontSlant->\"Italic\"]}], \"\[Delta]r\"]\)"}]], {{0.9, 
      0.7}, {1, 1}}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.532024031237089*^9, {3.532024069051252*^9, 3.5320240887283773`*^9}, 
   3.532024137675177*^9, 3.532024192260299*^9, 3.5320242815344057`*^9, {
   3.532024360256908*^9, 3.532024370655503*^9}, {3.532024492761487*^9, 
   3.5320245147717457`*^9}, 3.532123282888959*^9, 3.5322123295141344`*^9, 
   3.5333204396820726`*^9, {3.5333258404759803`*^9, 3.5333258708507175`*^9}, 
   3.533325922676682*^9, 3.533685025984375*^9, 3.533744489907158*^9, 
   3.533756938890625*^9, 3.533756989359375*^9, 3.539176829707692*^9, 
   3.5391770040586643`*^9, 3.540053800437216*^9, 3.540055017122806*^9, 
   3.540128567679762*^9, 3.541248442857727*^9, 3.5412499150299306`*^9, 
   3.541250773600038*^9, 3.5412508088160524`*^9, 3.541604917407778*^9, 
   3.5433495091867557`*^9, 3.5868086173968945`*^9, 3.586810276256776*^9, 
   3.58681032545459*^9, 3.586810360103571*^9, 3.6983497482520313`*^9, 
   3.69834986035714*^9, 3.731421858925867*^9},
 TextAlignment->Center,ExpressionUUID->"fbd90040-0c6c-454b-9b6e-caa5cda5c71e"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.8.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "First derivative of ",
 StyleBox["noi",
  FontSlant->"Italic"],
 " with respect to rent as rent increases"
}], "FigureCaption",
 CellChangeTimes->{3.5391770040586643`*^9, 3.539178938654317*^9, 
  3.5412507365939217`*^9},
 TextAlignment->Center,ExpressionUUID->"5af91dc9-53c0-45d5-912a-e639d82a86ce"],

Cell[TextData[{
 "This suggests that rents can be increased without bound and ",
 StyleBox["noi",
  FontSlant->"Italic"],
 " will continue to rise to infinity.  While perhaps mathematically possible, \
economics intervene. At some rent there will be no tenants.  More generally, \
fewer tenants are available as rent rises."
}], "Text",
 CellChangeTimes->{
  3.5391770040586643`*^9},ExpressionUUID->"c8e58a32-3797-4810-b986-\
e5b405ca6e24"],

Cell["11.4.2. Enter the vacancy rate", "Subsection",
 CellChangeTimes->{3.532025300009659*^9, 
  3.5391770040586643`*^9},ExpressionUUID->"06feed62-19d6-47ba-b9a5-\
6e793fc2e0af"],

Cell[TextData[{
 "We now introduce the idea of vacancy.  Collected rent, ",
 StyleBox["cr",
  FontSlant->"Italic"],
 ", is a percentage of the (hoped for) scheduled market rent. "
}], "Text",
 CellChangeTimes->{
  3.5391770040586643`*^9},ExpressionUUID->"b433bc84-6052-484d-b73b-\
134a91ea59b9"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"cr", "=", 
    RowBox[{"sr", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "vf"}], ")"}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5320253231519823`*^9, 
  3.5391770040586643`*^9},ExpressionUUID->"5e7a73fd-568a-4a10-9f62-\
bedcb50e16b2"],

Cell[TextData[{
 "The difference between scheduled rent and collected rent is the vacancy \
factor, ",
 StyleBox["vf",
  FontSlant->"Italic"],
 ". Rearranging Equation 11.13 we have"
}], "Text",
 CellChangeTimes->{{3.532025340176956*^9, 3.5320253455642643`*^9}, 
   3.5391770040596647`*^9},ExpressionUUID->"07cdc2e8-4924-4250-9c21-\
efeb58c405b1"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"vf", "=", 
    RowBox[{"1", "-", 
     FormBox[
      FractionBox["cr", "sr"],
      TraditionalForm]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.532025362005205*^9, 
  3.5391770040596647`*^9},ExpressionUUID->"5364d62b-f74e-445d-9e33-\
2fbf0b5660a2"],

Cell["Where:", "Text",
 CellChangeTimes->{{3.533325982151084*^9, 3.5333259890534787`*^9}, 
   3.5391770040596647`*^9},ExpressionUUID->"0a3bca0d-16bd-40f0-ab08-\
7748c495fe37"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"vf\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"cr\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"sr\",FontSlant->\"Italic\"]\)\>\""}], "}"}], 
        ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "3"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<vacancy factor, 0 < \
\!\(\*StyleBox[\"vf\",FontSlant->\"Italic\"]\) < 1\>\"", ",", 
          "\"\<collected rent\>\"", ",", "\"\<scheduled rent\>\""}], "}"}]}], 
       "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.5333200428873773`*^9, 3.53332013664974*^9}, {
   3.533325993601739*^9, 3.5333260312908945`*^9}, 
   3.539177004060664*^9},ExpressionUUID->"db9371fd-29c1-43f7-8f16-\
01906a0dddbd"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"vf\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"vacancy factor, 0 < \\!\\(\\*StyleBox[\\\"vf\\\",FontSlant->\
\\\"Italic\\\"]\\) < 1\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"cr\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"collected rent\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"sr\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"scheduled rent\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{
  3.5333260390753393`*^9, 3.533685026171875*^9, 3.5337444903951864`*^9, 
   3.53375693909375*^9, 3.53375698959375*^9, 3.53917683037173*^9, 
   3.539177004060664*^9, 3.5400538012132597`*^9, 3.540055017227812*^9, 
   3.5401285683508005`*^9, 3.5412484436497726`*^9, 3.5412499158879795`*^9, {
   3.5412508528975735`*^9, 3.5412508682154493`*^9}, 3.5416049180718155`*^9, 
   3.543349509276761*^9, 3.586808617412895*^9, 3.6983497482800694`*^9, 
   3.6983498603791714`*^9, 
   3.7314218589539413`*^9},ExpressionUUID->"753c3399-c64d-4a4d-bb5b-\
ca72c307697f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"vf", "=", 
   RowBox[{"1", "-", 
    FractionBox["cr", "sr"]}]}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.5391770040616646`*^9},ExpressionUUID->"ceb0b782-0924-424b-a422-\
2631f559d10b"],

Cell[TextData[{
 "It is convenient for expository purposes to introduce the vacancy factor \
through a function for collected rent dependent on scheduled rent.  Thus \
collected rent is scheduled rent scaled by the vacancy factor.  In dollars, \
collected rent, ",
 StyleBox["cr",
  FontSlant->"Italic"],
 ", is what remains after schedule rent, ",
 StyleBox["sr",
  FontSlant->"Italic"],
 ", has been reduced by vacancy. Equation 11.13 may also be expressed as"
}], "Text",
 CellChangeTimes->{{3.5320254320192094`*^9, 3.5320254431488457`*^9}, 
   3.5391770040616646`*^9},ExpressionUUID->"31756a4d-e912-43c8-9f0b-\
eb95d741a552"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"cr", "=", 
    RowBox[{"sr", "-", 
     RowBox[{"vf", " ", 
      RowBox[{"(", "sr", ")"}]}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5320254564156046`*^9, 
  3.5391770040616646`*^9},ExpressionUUID->"7157b7d1-6f3b-4138-9f93-\
5fd685676bde"],

Cell["Therefore, if we say that ", "Text",
 CellChangeTimes->{
  3.5391770040616646`*^9},ExpressionUUID->"0c19cee7-a6d7-4213-bbd4-\
baf68c1356d1"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"cr", "=", 
    RowBox[{"sr", "+", "1", "-", 
     FormBox[
      SuperscriptBox["\[Alpha]", 
       RowBox[{"\[Beta]", " ", "sr"}]],
      TraditionalForm]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.532025481424035*^9, 
  3.5391770040616646`*^9},ExpressionUUID->"24d4e8c1-f848-4f2c-8b25-\
979301679a0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cr", "=", 
   RowBox[{"sr", "+", "1", "-", 
    SuperscriptBox["\[Alpha]", 
     RowBox[{"\[Beta]", " ", "sr"}]]}]}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.5391770040626645`*^9},ExpressionUUID->"d5eac5e4-7534-4573-a26e-\
41697a904637"],

Cell[TextData[{
 "the term ",
 StyleBox["1-",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[Alpha]", 
     RowBox[{"\[Beta]", " ", "sr"}]],
    FontWeight->"Plain",
    FontSlant->"Plain"], TraditionalForm]], "Input",
  FontSlant->"Italic",ExpressionUUID->"29c9f0d7-eb26-4a8e-87f3-4ba555fe8e8c"],
 " is the dollar amount of vacancy suffered.  This term must be negative to \
make ",
 StyleBox["cr",
  FontSlant->"Italic"],
 " < ",
 StyleBox["sr",
  FontSlant->"Italic"],
 ".  Therefore, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Alpha]", 
    RowBox[{"\[Beta]", " ", "sr"}]], TraditionalForm]], "Text",
  ExpressionUUID->"8296fb9f-34ba-4f99-9e02-a179c0a3515c"],
 "must be > 1.  In equilibrium, a \"normal\" vacancy rate represents no more \
than the usual market frictions arising from tenant turnover. In healthy \
rental markets the vacancy rate should be around 5% due to these frictions.  \
Clearly, the choice of \[Alpha] and \[Beta] is important to achieve this \
result, but the size of ",
 StyleBox["sr",
  FontSlant->"Italic"],
 " is also involved.  In our present model, the interplay between these \
variables results in either an unrealistic rent or an unrealistic vacancy \
factor. "
}], "Text",
 CellChangeTimes->{
  3.5320254925456715`*^9, {3.5333261687987595`*^9, 3.5333261718239326`*^9}, {
   3.5391770040626645`*^9, 
   3.539177004065665*^9}},ExpressionUUID->"37c05bf1-2cd8-4e37-bb77-\
f45752ffbbcb"],

Cell[TextData[{
 "The best model is the simplest model.  While it might be possible to impose \
inequality constraints such that 0 \[LessEqual] ",
 StyleBox["sr",
  FontSlant->"Italic"],
 " \[LessEqual] 2000 and 0 \[LessEqual] ",
 StyleBox["vf",
  FontSlant->"Italic"],
 " \[LessEqual] .05 to improve realism, it would come at the expense of \
simplicity. The compromise is that the vacancy rate demonstrated in the \
illustration below is unrealistic.  Alternatively, by manipulating \[Alpha] \
and \[Beta], one could produce a more \"normal\" vacancy factor. Doing so \
makes ",
 StyleBox["sr",
  FontSlant->"Italic"],
 " quite high, a result that is perhaps acceptable if one considers ",
 StyleBox["sr",
  FontSlant->"Italic"],
 " to be an aggregate rent for a large building, not just a single unit."
}], "Text",
 CellChangeTimes->{{3.5320254925456715`*^9, 3.5320254938797474`*^9}, 
   3.5391770040666647`*^9},ExpressionUUID->"008ab9e0-78c1-402e-b7b5-\
ec2cd330f646"],

Cell[TextData[StyleBox["In the Appendix to this chapter we propose a \"cure\" \
for some of the unrealistic aspects discussed above.  After reading it one  \
wonders if the cure is worse than the disease.",
 FontWeight->"Plain"]], "Text",
 CellChangeTimes->{
  3.5391770040666647`*^9},ExpressionUUID->"13114382-a669-4efc-ae80-\
a0dfde679649"]
}, Open  ]],

Cell[CellGroupData[{

Cell["11.5. Reconciling the two problems", "Section",
 CellChangeTimes->{3.532025624798236*^9, 
  3.5391770040666647`*^9},ExpressionUUID->"6d1e3c9a-00f9-4a1e-a21a-\
f90fe7cab4b1"],

Cell[TextData[{
 "How do both parties both optimize?  The market sets rent under which both \
must operate and both parties benefit from the highest collected rent. \
Therefore, our procedure will be to first find the scheduled rent that \
results in the highest collected rent, given our definition of ",
 StyleBox["cr",
  FontSlant->"Italic"],
 ". We will then specify conditions under which each party optimizes their \
respective income at that scheduled rent. \nWe plot Equation 11.16, a \
function for collected rent that both depends on the scheduled rent and \
considers vacancy. "
}], "Text",
 CellChangeTimes->{{3.5320258864722023`*^9, 3.532025950952891*^9}, {
   3.5320260208188868`*^9, 3.532026023778056*^9}, {3.533326191767073*^9, 
   3.533326192328105*^9}, 
   3.5391770040666647`*^9},ExpressionUUID->"126907e2-8c49-4af7-8907-\
4abbcf9df289"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotCR", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"cr", "/.", "d4"}], ",", 
    RowBox[{"{", 
     RowBox[{"sr", ",", "0", ",", "500"}], "}"}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", ".9", "]"}], ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Scheduled Rent\>\"", ",", "\"\<Collected Rent\>\""}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.411775454734375*^9, {3.5319431158247147`*^9, 3.531943117188792*^9}, 
   3.5391770040666647`*^9},ExpressionUUID->"89073643-7b05-4684-943e-\
351c541eff94"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {Hue[0.9, 1, 1], AbsoluteThickness[2], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4lO0XB3DEG6kkKbSiZKtUlrJ+s2eNtFhClN2MmYeZeWYYEdJqKUqE
kCRtttKqSEoRldQrRevvDQlRiX63v+b6XHPN89z3uc99zhllP6brbjEREREZ
URGRyc+vg38crAM+moqIDEsv1/hoyj5Dr7U8XWeW+jk0RS24zown3RegePqZ
2fC7wwPfgp6ZCW4Xi4iffm/22yZG9V7Qe7Px43sdf+UPmQ3UNc9PChoyuy0+
ODSUPwWOX5eaLAyagkVGGjbf8+XAWrTi4qZAOTi11w98y1dF6ptvppd3qwJp
e6WtInUx0+/e26I1upAd2no5zd8UQ/LpU03/mMD0Bs8lZpYl5q68Xra20QL5
1O0Lnds3wrtP3TBh1BZdG9+0jVk7oSaKl81ocsRue36fX4sLFNOrzS/FuWDD
9VHxFoYbajoVn8bLuEH6WrfI/O6tiBviqzCYW6H13YZhnOyOvIK4KkMRdxjW
KNWaiHnh2dQbNp1+nri00WdZA9MbiXmB7s+rd+DWtFkTsvt9kfh7+lvZhb5Q
ulb87+W6nRhR8+NF2eyEyt4x1nUFf/DnHpG+n+wH7zVS6fsCdyHqHFXVeNcf
shqORfV5u/EmalaCzftdYJo4M8MGA3DFwHO6o1IALLP2aSesDEKkfLVE9PpA
1M8WFvyTGIwbzXK1r8OCwI1YUeDwIgRlXVtS7DODcVpe7piYTBg2jxX4MM+G
gNtRbarqHw57VvZZ80ehqO9J/bcin4HZHIk9us/DYNmqKibZwYRviWLyrGfh
uMa4HvH+WAQOPo630n3HwH4F4Sv+GhbsSn5XFj9jQqc1P9fmDQvaK5sUJYMj
MDCWpz6SwIbtaqb+kXcRCLO7ft5LmcJrhzyl83Ys3Dq79uDPRxQWvd2ho32V
hUfqjf4OwZHwO9u55Ig8G9/nrxeNF49CBJ3e0h7CRt9CqbHesijQMbq+zrfZ
OGMx3Cdjx0GT2YHQ82IUeGGrnWscOJhz3Wr81hQKdhmMy37OHFRYJz9pEafQ
/+kLu8qNg1LvNerf/6Ggf+DNqIcPB9pBf29oSlNofNogWhzJgYmy3HRajkLv
jix54zwOHveX1cSqUrid1M75eJoDJdNzAfRSCqmX5DqOFHHw4dUWa/YyCnqi
R052n+PAX399zs7lFIRF8Yv3VXLwQ5Z5XF+LgszXUI22hxyoGa6JqllDYQ3P
1CRomIPFIwaySzZQODrDV/hhhINGSjFtgHi4IO6O7y8ONGdIbq41p1D9pH6D
+wQHBZI3sndYUjBStbe2k+Tim6qeQYoNBcvmbc7aC7jw0/pk3+xIYetS1s4B
Cy6iDZpSatwpXK1JLwiz5iLSVfw8y4OCgnPl+y+2XJxIjhpX9yTnQo/u7nbk
wjw62zrDi4JPS0xI2zYuHB21fHf5UAjiH6AqQ7nQn5+0s3MXBcHTwkTeUS48
FmHRaiaFopcdjl8yyPMcjbc/Jm7umjF3+wkuljGNGwIiKKj0cYsNTnExpvnR
OItF4i3l8GCkmIsiWuHgMEVhjsWwZNR1LpjOSV4JPAplVZaHWN1kf22h2/6J
o9B+k3brfs+Fy9Ruv33Ef+suLnD5xMWo2XDm1HgKrm0KF3S+csFNiOFK7KXw
s7/3ybdhst4XLTKjCSQ+6hkyDEkeXiem2l1JpvDm5Mf0kFU8yFh/sI1NoWC+
6JCOzBoedHbuNeojLj69prlCl4eVbYkqHqkUIkpipcbX89A4dL1JJ42CeLXi
nhRLHsSeice0plPQanUMr3Tn4UGa9de3GSQ/3IanuXvxYPbD/YtxJjnPlydL
xr15MNnR3HqC+HbX5/fWu3jo39Ia6HicrL83zuMVgwfvVcNp505QoKdW20zs
5eFwYELoimwKXQe8PhYk8dC0cuF3HrH5zCl7bfbzUOTw0qOOeLr8ptupR3hg
zzre4ZZDIV/lP13VLB4yOQcZIacoSBSntj3I5sE5hPvPBeIQDYOIsFweTtg6
CvuJdXUSzlcV8qDhkinNyKXwwGSRiu1FHvI3lx32yaOgfbf+Tu9lHjwW/pTP
Ik61DN2RVsHDrB2f6FZiD/trJ15f4yGyMq7NNJ/ct+2uMuF1PAyX778qfZrC
5s6fZbINPCx/XzvDmPiaT55ddSMPVi3mRqHE8QG9iX+f8GC4YESxgVg+MulP
WgcPK1qq28MLKEjukuVL/cvDgpnONunEfzbnjO55Q/Znc+ZKFfGHteWDzB4e
KhffYv0i7lA1ifj8gYfSX5kNioUUHss19nl/JvGy9JFbT1w59OaLYy/ZH+t/
6ZHEJe+DAu7387Dpx936VOKcZ0Pvjb+TfFhR3XueeG+F1FutERK/hgUL3xJz
Co95Ff7k4a520dJR4pCji18rjfGQ48JaMrOInCel90JKhEZssfjQOmJr/1rX
ODEaQcZdjQ7Ehpvtn/4Up+HgtTTNh3ilRbtjxFQaWfq+9ixi5bU7mz5L0fB7
oDQaRzxHtdfWZzoNq/bOo2nEknLchvaZNFxHVirnE/8RE7N0kqXxJzEr9wLx
wOChu/flaPy8WCR9nfhDzzwzk7k0NAI6Au8Td7QV3KxUoJEaerO8hfjxvRWG
2vNpLLfr+NpBXFt+7WrhQhrt2ypmdxNXFljozV9CY1vVc7UvxCXpzeXpKjSU
nOqW9xPnxLvrTFtGY12HhPwQcQr7w4W45TScnqv0jxDH+zG1fmnQoA7nl/8i
5rj+LonQpjFXUcJvjDjEPFHty0oaA1vbxybtvWZWkc9qGm8HsmIn7aqSrfxy
LY03Hi96J39vPVstz0mfRmfbDIvRyXiKXVnQsI7GNd/GuMn3rxw0OmliREOx
fX/J5PpUehrmVZnQ8Gxur55c/9w2lwxt0BBcXFs2ub9p9zpnF5mTeBUtTX5F
PH4lMHW+FY36cyvsnk7G8/TgjKM2NFSEbd8n4/chLebgNDsamWWZwsn4dsRJ
SsU70GhMHv82Gf/HrKNJv5xoMFcdsJo8n9qdi8RZLjR0k+4IJ8+v0uVc3JfN
NPKNlmRPnm/26jvRL7fTcA4KF3gTH1G2++3kSWOeurep/WT8ZF9wG3aQfHgZ
36M/Ga/v/7Gr/Ghw1zAeT5uMV3fUgPZuGt3BBrJDJB9dW0UYRYE0Os6u13tN
bHhlbvDRMBo7P39VOEMsxTL3YXFoPP01Y8MK4nVvTMsX0iSeV4vPSBEHbTSS
eCSgcVhnZ/kHcp8alHXPq8SR/UuW3s0kjm9bNvrsII0apbgz/5H7esVUxW7P
ERoZ2YvX3yR+V7rolHYajZsWVcxDxGZ751kkZtJQf6dZp078Z61Uiv5pGheu
fBvYROqFVr5ET08hDS+R3/vnEXtMF9NLKaahJn6rtpPUl2sffr/+fJ7G+rEH
4v7EURm9alnVJL8KPJ97k3rVP9Jye6yJhoTv7bHZpP4t9H8sW9JMo2vceclk
fXRoadzl1kpD/NS7lyzi0rN3p11oJ89fZTX+6CSFwO0VW727abDTf8wIyyLr
r8nsrx2hEci8VBZE6rWM2tEN4b9ozJqovShKbJqeckzxD43K6/Xrski9zwlJ
NmSL8lHS/6y77hgF9/n8JNXpfHg+3Bo59SiFtugdi5KU+VjQOjFmTfrLI4/w
n8uW8vFbXSB4dITC3XUxbffV+PAaTE50IL48nJMkoc1H0pwcfYfDJB/COvsT
9PloXLv71/qDFOy9PO/steeTvnkioDmJ9APD0CxVJz6KEncaGxIbKgiouk18
aGUXphUlUtB8fnL5lK18+J+tvRpJ+qGkw+uUeF8+TmamdomR/llv5O4bF8XH
7kdioy+iKdxUDDZU5vGxzl6RqUFcMcqbc5fPR+QJI0+BgEJBxYlGkT18sFJu
HlLiU9ij1aGz5wAfqafsYc2lYDx/m2hsHh8d9z2tXEm/r/rtVhD9kI/XOePp
BmR+MLba6PWtiY/es4IVgf4U7qWYzPVr5sPV77JHhh+ZH5aqHbB5xseF+Nsh
fb4UvjiNsma/4cMnosf50A4KCwqzNpQM8GE4LnU6YSuFBPuud8/mCfDpX9tP
HmQempbZdtJaSYDxiUs5ntYU0t41uNUsEMB1hX2rhxWF3KhLjbnKAtT78cvd
LEh+5e25HKwlQKmEnrm+GZn/hlT2/DUV4Gt3n+hlfdK/cgIXawUIoCKRvXFy
/pvj/+RiW5AAXYHKVSvJfNiusdaUHyqAR27yhh4y53pcnfB6GCFAwLywGovF
FPzaMk4GCsj7U9OmDyiSeUKyXr4oVYBNby25fTMpHI5cMn3hDQFEP+j9jRxl
w8koKbv+lgAcD8uG3h9szBLr1QyrFWB7w0iq3zAbx1KubrxxX4CJlPgVtt/Z
yCl12uf+VIAzW64Hjf3HRum7aLHMjwKENW+eLdrFxgOHVz9nzopGZ+gRZvw9
NhT2qAbtnx2NbDlTi5e1bARVhL+cIh8NP+dOaN5hY5qSWPVPxWiSH4XVj26w
4fBZk+pRjUbj9fioH5VstMVF91UZRKMnKib5ezEbXdWLe7x8ohGpMbpKuJ+N
kSUBTaUXyfddPy7W2LIh01B3V+FKNExTb+mfsmZDPVT5WlJFNGbmfLsvtGTD
o6qzyO9aNHqt1UaNwMadjZuFSveikXSp9VCuARvJbKw+8CIaxx4m1E1RY0Op
Xul48B+yvpuFJraibJgFtvip28Ugt+qq0r4rLBxLzl3Z5BCDUtYUnbKLLHw5
F/473DkGjHKTS83nWUjtlU6vcIvBwPtTn6SLWehh2d419YmBaP2TuYEnWUiK
vrt4S2QMCm9LB+fFs9CcVtEZlxsD013O82RcWPC+eXzrv4MxCH/0vLrgYwTM
7ezFXH7EIPKVt/iWnggs65i40DAag7PTDz4UfxtB8mm3RPmfGKiUbKn26ogA
raVbmfyPEDp3Qn73PYrAsZNPZfWVhLg1fFEn41IEmnhST1I3CLF3m7NXPycC
6/QEFtapQswXt4icM8ZEu8BcU+KoEIftRFv1BpmIuiclW58hRNnIFJVN/2Oi
3PlE14ZsIX6Kix5lvmRCO6SKNikWQiayyNm9gokled8u6d4UItfedumLYCak
pHYtUP0ixKXZvbu3tDJQ4qw1pec/Iaz2O3OPPGDAOnPwf/l9Qtin/p1We4uB
BNW4q4uGhNCclVo6vZSBCZNcV6UJIdYNKPjbxzMwyO5Ilp0Ti155cdpzNQOp
NXnMp3NjsUdj9aDScgZWiQRuTVGMBSrEytsWMBB2+IfqjMWx4DQGjWhKMvDp
7Ow7kpqxsBS7vFzYFY6E/ldnHmjH4r+G6NC/5P+oqt7pQ0mrYlFcFfSS9zAc
vvdWeYjrxeJpnYGCW2U4JiRHUWcQC+0p/h+rzoXjlPPt5fGGsaguNWmSyQuH
cWbizA0msZCc8fn+zmPheN3p8OOvWSxuZkS3nt8fjv8DOWLXcA==
       "]]},
     Annotation[#, "Charting`Private`Tag$3047#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Collected Rent\"", TraditionalForm], None}, {
     FormBox["\"Scheduled Rent\"", TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {200., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {300., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {120., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {140., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {160., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {180., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {220., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {240., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {260., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {280., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {320., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {340., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {360., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {380., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {400., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {200., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {300., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {400., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {500., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {120., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {140., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {160., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {180., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {220., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {240., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {260., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {280., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {320., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {340., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {360., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {380., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {420., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {440., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {460., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {480., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {520., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {540., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {560., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {580., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {600., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{Automatic, Automatic},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 500}, {0., 314.31151946760565`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.411947048578125*^9, 3.5320261509833317`*^9, 
  3.5321232830659695`*^9, 3.532212330543194*^9, 3.5333204406311274`*^9, 
  3.533685026328125*^9, 3.533744491040223*^9, 3.533756939265625*^9, 
  3.53375698975*^9, 3.539176831625802*^9, 3.5391770040956664`*^9, 
  3.540053802471332*^9, 3.5400550173398185`*^9, 3.5401285695428686`*^9, 
  3.541248445233863*^9, 3.5412499173200617`*^9, 3.5416049189828677`*^9, 
  3.5433495093657656`*^9, 3.586808617431896*^9, 3.6983497484094534`*^9, 
  3.698349860481479*^9, 3.7314218590361605`*^9},
 TextAlignment->Center,ExpressionUUID->"e7b311ba-4be2-41ab-8c42-62dbb4253cda"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.9.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Plot of collected rent with change in scheduled rent"
}], "FigureCaption",
 CellChangeTimes->{3.5391770040956664`*^9, 3.541250885019411*^9},
 TextAlignment->Center,ExpressionUUID->"2e089009-ff3c-4690-bef6-eb6d65054f01"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CellPrint", "[", 
  RowBox[{"Cell", "[", 
   RowBox[{
    RowBox[{"TextData", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<Using data \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<d4\>\"", ",", "Bold"}], "]"}], ",", 
       "\"\< to fix certain values in Equation 11.16 we set the partial \
derivative of \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<cr\>\"", ",", "Italic"}], "]"}], ",", 
       RowBox[{
       "\"\< with respect to scheduled rent to zero and find the optimum \
scheduled rent to be $\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"Quiet", "[", 
           RowBox[{
            SubscriptBox["sr", "crmax"], "=", 
            RowBox[{
             RowBox[{
              RowBox[{"Solve", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SubscriptBox["\[PartialD]", "sr"], " ", 
                  RowBox[{"(", 
                   RowBox[{"cr", "/.", "d4"}], ")"}]}], "\[Equal]", "0"}], 
                ",", "sr"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}], "<>", 
        "\"\<. Adding that information to \>\""}], ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<d4\>\"", ",", "Bold"}], "]"}], ",", 
       "\"\<, inserting it into Equation 11.16 and solving for \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<cr\>\"", ",", "Italic"}], "]"}], ",", 
       RowBox[{"\"\< provides $\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"cr", "/.", 
             SubscriptBox["sr", "crmax"]}], "/.", "d4"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
        "\"\<, suggesting an unappetizing vacancy factor of \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"100", " ", "vf"}], "/.", "d4"}], "/.", 
            RowBox[{"sr", "\[Rule]", 
             RowBox[{
              SubscriptBox["sr", "crmax"], "[", 
              RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "3"}], "}"}]}], "]"}], "]"}], "<>", 
        "\"\<%. Figure 11.10 shows the expected rise in vacancy factor with \
the rise in rent.\>\""}]}], "}"}], "]"}], ",", "\"\<Text\>\""}], "]"}], 
  "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.533326281472204*^9, 3.5333264896031084`*^9}, {
   3.533326536188773*^9, 3.5333265429271584`*^9}, 3.5391770040976667`*^9, {
   3.541248518532056*^9, 
   3.5412486137365007`*^9}},ExpressionUUID->"e64b14b7-51f4-45db-8805-\
b0364df8826b"],

Cell[TextData[{
 "Using data ",
 StyleBox["d4",
  FontWeight->Bold],
 " to fix certain values in Equation 11.16 we set the partial derivative of ",
 StyleBox["cr",
  FontSlant->Italic],
 " with respect to scheduled rent to zero and find the optimum scheduled rent \
to be $402.94. Adding that information to ",
 StyleBox["d4",
  FontWeight->Bold],
 ", inserting it into Equation 11.16 and solving for ",
 StyleBox["cr",
  FontSlant->Italic],
 " provides $314.30, suggesting an unappetizing vacancy factor of 21.995%. \
Figure 11.10 shows the expected rise in vacancy factor with the rise in rent."
}], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.7314218591103573`*^9},ExpressionUUID->"ffbc8bf6-42e9-4b09-86e3-\
4ce4f4c8b77a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"vf", "/.", "d4"}], ",", 
   RowBox[{"{", 
    RowBox[{"sr", ",", "100", ",", "500"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Scheduled Rent\>\"", ",", "\"\<Vacancy Factor\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.4117756855*^9, 
  3.539177004098667*^9},ExpressionUUID->"90e5c9dc-c2c6-4f92-aab7-\
581093e80546"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVjHs01HkYxsesNJGNjVyyuRRWNa3KpTTjfdW2VJJstsZm3ZIRGrdBLr9h
p7VpMGxmJQdTQhcmDArZsHIiIVGMMt/SdmK3szaOyKW1fzznOc/5PM9j6s/z
CKTTaLSDS/rfXdhsMxqNg83a63liugR2dzqvVSznYHKwOn1cTQKsox46Nas4
6DvQcmuvhgS2RgSpcY2XeObQcZqOBAxLssd7HJeyiqOa0FwCf618U12UxEFa
fJWiyUUCmc8z98AcB6WHb9ZqZElgIIGcoKa9MLlDNGxg9htECw/SnfS8sblG
bOHEy4XHAdoTY6t9kIRWzLxvvAgKEbXHVeiLZKJvelTvEhzZz7l7P9sPcZP6
MuHNfGDyfby3ZfqjtPOOc4FjAYjPdm5qKQrA5rrs6YQviqAmqaPbo/wEkqvH
aY8FUtgxOpn3rDQQTRxneboxl2EvU/grVXcS8cg7NjvnClSNsuX6NUHo3rqi
uKq6GJTC9Gu15VzM4vDJwshVyGXgw+iGYGxe8dpxP6sUZLPr1ljWnUIym3fr
77wycOvxz5xrD8HwSXtmt/V1qMx0GO7rC8WsiTlR1cgNiGxguxd0hSEpiHCa
SC+Hps6S92nDpxHVV2it/UkGQc47m4IHeTij3fFdEKsSDvZfVNjyw5FY8dQ8
/KrgwewI3pkLR98tGTLf3GqIGnDYZXMmAvWbTJiHu+Xgv36fq5NKJGq1mFos
7KiFFMuwf52TI/Haz2Z6SSV1kGIyTOudj0SuD3MD3fwOtIvmLMaEUTjYtu5l
5et6cKjY+nJOJRqz0lu7E0sbYRINq4vOR+OEPJXRJG+CjA7Xd21afGR8Yn24
Te7BUYbk7mgGH6eMpAFajBYIrBdfuaAbg6wg4Tfv3Fqh2ERqxM6JQemQ8Mp4
7h/QmviRxtWKxUS5ZbLkfRtYHFg+vz43FqcKhhJnfmmH+h4r0ZBOHLIKvTm9
xg8gu33R2qQgDjfzNO3+nO+Ai1Fjp3yNzuC8qSKdvHgIKbrrVpnlnUGbFz7e
QUOPQGa1rDPaJB7dtr9OqtftBY0pFYOWwnhsO/ajWM3pMZRbV1GFlglY99Yz
gV/UB1v8b7gtVCTgIOv377/U6Qeyr77ac1Mi5mzMEoeJBuBZcTwT5InoYjzV
ZrDnGSzID7PMtiWhF12Z37c4CKr1kbWpsiQcV31VfO6JAtytv92baEvhiKxh
45uZ59Dl/XVwiJxCL0HZzIKZEvQDuI0FtRTaHeKoMphKCOBe1uy9TeGgbUi4
rr0SPkaurra5S2Go39HTDgeU8NW5Dx8X2ihUfUAzq4hSwtnqe+lZTyncvD2M
Z3dfCezl7pW1sxRe+DwtNtyWwLmVafS3cxQuei2WlTsQ6NduPWK4SOGrVdfz
x4FAqJHNLEUX4CRPsydkP4FLW/V3u2gIUN3KPFboQ2D6B/JEYSTA0pIXnozz
BHb7GVhoGgvwn426n/mJCWSc9IgDUwEaTHomNeYQ2BDRZnTVXIDe/bxhfhEB
j9RrgWFbBMjtjjtEqyVQKHp5u8hagBODoTFBDQTGsgzV+7YJ8NgbLq/3HoHk
/HSZnf3SXjI/VNZJoEt6nxa8c6mf9tR1TS8BvdJFj/xdS3+W7JzUAQL+N+1L
HrEF2LWhr3JGQUBWGf7hEwjwaYR9cSgh8B8fg0vs
       "]]},
     Annotation[#, "Charting`Private`Tag$3120#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Scheduled Rent\"", TraditionalForm], 
    FormBox["\"Vacancy Factor\"", TraditionalForm]},
  AxesOrigin->{100.0000081632653, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{100.0000081632653, 499.9999918367347}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.41194704878125*^9, 3.5320265367343955`*^9, 
  3.5321232832769814`*^9, 3.5322123332533484`*^9, 3.533320443526293*^9, 
  3.533685026515625*^9, 3.533744491787266*^9, 3.533756939453125*^9, 
  3.533756989984375*^9, 3.539176833013881*^9, 3.5391770041156673`*^9, 
  3.540053803800408*^9, 3.540055017518829*^9, 3.5401285709179473`*^9, 
  3.5412484470249653`*^9, 3.5412499186961403`*^9, 3.541604919967924*^9, 
  3.5433495095007734`*^9, 3.5868086174959*^9, 3.6983497485588384`*^9, 
  3.6983498606037965`*^9, 3.731421859177559*^9},
 TextAlignment->Center,ExpressionUUID->"ac96fc06-d81c-4ae9-affe-4dff358ec8c5"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.10.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Increased vacancy with rise in scheduled rent"
}], "FigureCaption",
 CellChangeTimes->{3.5391770041156673`*^9, 3.5412518520837235`*^9},
 TextAlignment->Center,ExpressionUUID->"9154248a-7e28-484f-a385-bf23fe75fd32"],

Cell[TextData[{
 "Returning to the property manager's problem, this time considering the \
vacancy factor by substituting ",
 StyleBox["mgt cr",
  FontSlant->"Italic"],
 " for ",
 StyleBox["gu",
  FontSlant->"Italic"],
 " in the original ",
 StyleBox["np",
  FontSlant->"Italic"],
 " function and substituting Equation 11.16 for ",
 StyleBox["cr",
  FontSlant->"Italic"],
 ", we construct a new net profit function ",
 StyleBox["np3",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.5320265700222993`*^9, 3.53202661356679*^9}, {
   3.5320267504316187`*^9, 3.532026753123772*^9}, {3.5333265944711065`*^9, 
   3.533326596374215*^9}, 3.5391770041156673`*^9, 
   3.540055496745239*^9},ExpressionUUID->"52a2846b-a63d-4e47-aacf-\
f34755caf916"],

Cell[BoxData[{
 RowBox[{"np3", ":=", 
  RowBox[{
   RowBox[{"mgt", " ", "cr"}], "-", "ac", "-", "tc"}]}], "\n", 
 RowBox[{"np3", ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5320266301767397`*^9, 3.532026653860095*^9}, 
   3.5391770041156673`*^9},ExpressionUUID->"2177c85e-35fd-4c65-b0b4-\
91de91c16cce"],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox["np3",
    FontSlant->"Italic"], 
   StyleBox["=",
    FontSlant->"Italic"], 
   RowBox[{
    StyleBox[
     RowBox[{
      RowBox[{"mgt", " ", "cr"}], " ", "-", " ", "ac", " ", "-", " ", "tc"}],
     FontSlant->"Italic"], 
    StyleBox["=",
     FontSlant->"Italic"], 
    RowBox[{
     RowBox[{
      StyleBox["mgt",
       FontSlant->"Italic"], 
      StyleBox[" ",
       FontSlant->"Italic"], 
      RowBox[{
       StyleBox["(",
        FontSlant->"Italic"], 
       RowBox[{
        StyleBox["1",
         FontSlant->"Italic"], 
        StyleBox["+",
         FontSlant->"Italic"], 
        StyleBox["sr",
         FontSlant->"Italic"], 
        StyleBox["-",
         FontSlant->"Italic"], 
        SuperscriptBox["\[Alpha]", 
         RowBox[{"sr", " ", "\[Beta]"}]]}], 
       StyleBox[")",
        FontSlant->"Italic"]}]}], 
     StyleBox["-",
      FontSlant->"Italic"], 
     StyleBox["ac",
      FontSlant->"Italic"], 
     StyleBox["-",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"d", " ", "loc"}]], " ", "h", " ", "u"}], "2"],
      FontSlant->"Italic"]}]}]}], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.532026646975701*^9, 3.5320266638516665`*^9}, {
   3.532026706209089*^9, 3.532026732996621*^9}, {3.532026767709606*^9, 
   3.532026802828615*^9}, 
   3.5391770041166677`*^9},ExpressionUUID->"b09f6e7b-48f5-4aee-ac30-\
c98f6f142626"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["sr", "np2m"], "=", 
   RowBox[{
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "sr"], 
         RowBox[{"(", " ", 
          RowBox[{"np3", "/.", "d5"}], ")"}]}], "\[Equal]", "0"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"sr", ",", "400"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"Cell", "[", 
    RowBox[{
     RowBox[{"TextData", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<This time using data \>\"", ",", 
        RowBox[{"StyleBox", "[", 
         RowBox[{"\"\<d5\>\"", ",", "Bold"}], "]"}], ",", 
        "\"\< in Table 11.1, we compute the optimum scheduled rent in the \
same fashion as before, taking the partial derivative of \>\"", ",", 
        RowBox[{"StyleBox", "[", 
         RowBox[{"\"\<np3\>\"", ",", "Italic"}], "]"}], ",", 
        RowBox[{
        "\"\< with respect to scheduled rent, setting it equal to zero and \
solving. Optimal rent is $\>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{
           SubscriptBox["sr", "np2m"], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], "<>", 
         "\"\<, making the manager's profit under those same conditions \
positive ($\>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"AccountingForm", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"np3", "/.", 
               SubscriptBox["sr", "np2m"]}], ")"}], "/.", "d5"}], ",", 
            RowBox[{"{", 
             RowBox[{"6", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
         "\"\<).\>\""}]}], "}"}], "]"}], ",", "\"\<Text\>\""}], "]"}], 
   "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.5333271256404877`*^9, 
   3.5333272488435345`*^9}, {3.533327296518261*^9, 3.533327370934518*^9}, {
   3.5333274366182747`*^9, 3.533327524551304*^9}, {3.53332759337224*^9, 
   3.5333276147724648`*^9}, 3.539177004117668*^9, {3.541248685196588*^9, 
   3.541248729584127*^9}},ExpressionUUID->"26fd0192-907a-4253-8a2f-\
b6ad59655e5f"],

Cell[TextData[{
 "This time using data ",
 StyleBox["d5",
  FontWeight->Bold],
 " in Table 11.1, we compute the optimum scheduled rent in the same fashion \
as before, taking the partial derivative of ",
 StyleBox["np3",
  FontSlant->Italic],
 " with respect to scheduled rent, setting it equal to zero and solving. \
Optimal rent is $402.94, making the manager's profit under those same \
conditions positive ($15.83)."
}], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731421859211628*^9},ExpressionUUID->"b23b7460-3994-469c-8db9-\
2179d45ecebe"]
}, Open  ]],

Cell[TextData[{
 "Figure 11.11 shows the new profit function for the manager; we see it peaks \
at the same optimal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"rent", 
    SuperscriptBox[".", 
     ButtonBox["3",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote3"]]}], TraditionalForm]],ExpressionUUID->
  "13968fd4-8757-4236-833f-f041630590e8"]
}], "Text",
 CellChangeTimes->{
  3.5320269129969163`*^9, {3.5320270514508357`*^9, 3.5320270554710655`*^9}, {
   3.53332752832452*^9, 3.533327537826063*^9}, {3.5391770041186676`*^9, 
   3.539177004119668*^9}, 
   3.6983497778346634`*^9},ExpressionUUID->"2743c2d1-0c8c-4ef1-bb84-\
876143e6a13d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotNP", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"np3", "/.", "d5"}], ",", 
    RowBox[{"{", 
     RowBox[{"sr", ",", "0", ",", "500"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"AbsoluteDashing", "[", 
        RowBox[{"{", 
         RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", 
       RowBox[{"Hue", "[", ".6", "]"}], ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Scheduled Rent\>\"", ",", "\"\<Manager Net Profit\>\""}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.41177571278125*^9, {3.531943149119619*^9, 3.5319431505497007`*^9}, 
   3.539177004120668*^9},ExpressionUUID->"468746ad-4151-4734-a007-\
80adbeeb2766"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {Hue[0.6, 1, 1], AbsoluteThickness[2], Opacity[1.], 
      AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwV13k4VdsbB3DEDSlDkVSmE5Fjb4kGwjdE5lKpXEWKEJnP2fsc89R4MzVq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       "]]},
     Annotation[#, "Charting`Private`Tag$3166#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Manager Net Profit\"", TraditionalForm], None}, {
     FormBox["\"Scheduled Rent\"", TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{-15., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {15., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-19., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-17., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-13., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-11., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-9., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {9., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {11., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {13., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {19., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {200., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {300., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {400., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {500., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {120., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {140., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {160., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {180., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {220., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {240., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {260., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {280., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {320., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {340., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {360., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {380., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {420., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {440., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {460., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {480., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {520., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {540., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {560., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {580., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {600., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{Automatic, Automatic},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 500}, {-15.602110328899292`, 15.829040608837985`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.41194704890625*^9, 3.5320269985308084`*^9, 
  3.5321232834119887`*^9, 3.5322123351984596`*^9, 3.533320444787365*^9, 
  3.533685026796875*^9, 3.5337444930453377`*^9, 3.53375693971875*^9, 
  3.533756990296875*^9, 3.539176855911191*^9, 3.5391770041506696`*^9, 
  3.5400538055195065`*^9, 3.5400550176518364`*^9, 3.540128572509038*^9, 
  3.54124844955011*^9, 3.541249920853264*^9, 3.5416049217940283`*^9, 
  3.5433495096927843`*^9, 3.586808617532902*^9, 3.698349748688182*^9, 
  3.69834986071908*^9, 3.731421859305879*^9},
 TextAlignment->Center,ExpressionUUID->"45e72b94-bf2e-4519-9783-49664a890682"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.11.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Plot of manager's net profit with change in scheduled rent"
}], "FigureCaption",
 CellMargins->{{101.33333333333333`, 10.}, {6., 2.}},
 CellChangeTimes->{3.5391770041506696`*^9, 3.5412526373826404`*^9},
 TextAlignment->Center,ExpressionUUID->"ff6fe751-47e3-485b-b6fd-50b6e6c85aa0"],

Cell[TextData[{
 "Finally, we look at how the owner's position is optimized.  This time \
vacancy is separated and dealt with in ",
 StyleBox["cr",
  FontSlant->"Italic"],
 " so variable costs, ",
 StyleBox["vc1", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 ", and the new net operating income, ",
 StyleBox["noi1", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 ", are a function of ",
 StyleBox["collected",
  FontSlant->"Italic"],
 " rent (",
 StyleBox["egi",
  FontSlant->"Italic"],
 "). "
}], "Text",
 CellChangeTimes->{
  3.532027225057765*^9, 3.5391770041506696`*^9, {3.540055543161894*^9, 
   3.5400555452720146`*^9}},ExpressionUUID->"69763583-7724-499e-bd95-\
a0f63ae11ef1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vc1", ":=", 
   RowBox[{
    RowBox[{"100", 
     RowBox[{"(", 
      RowBox[{"1", "-", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", ".025"}], " ", "cr"}]]}], ")"}]}], " ", "+", 
    RowBox[{"mgt", " ", "cr"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"noi1", ":=", 
  RowBox[{"cr", "-", "fc", "-", "vc1"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.5391770041516695`*^9},ExpressionUUID->"8fe133d9-38cd-4be8-9740-\
09cfb5e55ee5"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"vc1", "=", 
    RowBox[{
     RowBox[{"100", 
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", ".025"}], " ", "cr"}]]}], ")"}]}], " ", "+", 
     RowBox[{"mgt", " ", "cr"}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5320273739342804`*^9, 3.532027382246756*^9}, 
   3.532027516289423*^9, 
   3.5391770041516695`*^9},ExpressionUUID->"3bef5d15-a62e-4349-85ed-\
72a39b87ffd7"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"noi1", "=", 
    RowBox[{"1", "-", 
     RowBox[{"100", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "0.025`"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "sr", "-", 
            SuperscriptBox["\[Alpha]", 
             RowBox[{"sr", " ", "\[Beta]"}]]}], ")"}]}]]}], ")"}]}], "-", 
     "fc", "+", "sr", "-", 
     SuperscriptBox["\[Alpha]", 
      RowBox[{"sr", " ", "\[Beta]"}]], "-", 
     RowBox[{"mgt", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "sr", "-", 
        SuperscriptBox["\[Alpha]", 
         RowBox[{"sr", " ", "\[Beta]"}]]}], ")"}]}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.532027309571599*^9, {3.5320273861139774`*^9, 3.5320273872410417`*^9}, 
   3.532027523888858*^9, 
   3.5391770041516695`*^9},ExpressionUUID->"93f37ed3-3e15-4efb-9142-\
9c0e49515e08"],

Cell[TextData[{
 "Plotting, we see",
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 "that optimal net operating income is again achieved at the same scheduled \
rent. "
}], "Text",
 CellChangeTimes->{
  3.5391770041516695`*^9},ExpressionUUID->"d21bdd02-dc9e-4353-9305-\
4e6f28b9ecab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotNOI", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"noi1", "/.", "d6"}], ",", 
    RowBox[{"{", 
     RowBox[{"sr", ",", "0", ",", "450"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"AbsoluteDashing", "[", 
        RowBox[{"{", 
         RowBox[{"5", ",", "9"}], "}"}], "]"}], ",", 
       RowBox[{"Hue", "[", ".3", "]"}], ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Scheduled Rent\>\"", ",", "\"\<Net Operating Income\>\""}],
       "}"}]}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.411775830984375*^9, {3.531943176204168*^9, 3.5319431777072535`*^9}, 
   3.53917700415267*^9},ExpressionUUID->"9afc4faf-35d0-4cdf-827b-\
4ff9ae4bd096"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {Hue[0.3, 1, 1], AbsoluteThickness[2], Opacity[1.], 
      AbsoluteDashing[{5, 9}], LineBox[CompressedData["
1:eJwV1nk8VN8bB3BbUtlSCZVsWbOksUU89n2ZGco6cxPakWXMnaFEhUJaLMlW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       "]]},
     Annotation[#, "Charting`Private`Tag$3217#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Net Operating Income\"", TraditionalForm], None}, {
     FormBox["\"Scheduled Rent\"", TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{-50., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {50., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-90., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-70., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {70., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {90., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {110., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {120., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {130., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {140., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {150., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {200., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {300., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {400., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {120., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {140., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {160., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {180., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {220., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {240., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {260., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {280., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {320., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {340., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {360., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {380., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {420., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {440., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {460., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {480., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {500., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{Automatic, Automatic},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 450}, {-77.22055387512903, 132.91903582645836`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.41194704925*^9, 3.532027406996172*^9, 
  3.5321232835009937`*^9, 3.5322123358734984`*^9, 3.533320445540408*^9, 
  3.533685027015625*^9, 3.533744493948389*^9, 3.53375693990625*^9, 
  3.5337569905*^9, 3.5391768560832005`*^9, 3.539177004175671*^9, 
  3.540053806945588*^9, 3.540055017751842*^9, 3.54012857394512*^9, 
  3.541248450829183*^9, 3.541249922406352*^9, 3.5416049227220817`*^9, 
  3.54334950978679*^9, 3.5868086175739045`*^9, 3.6983497487754135`*^9, 
  3.698349860824383*^9, 3.731421859497387*^9},
 TextAlignment->Center,ExpressionUUID->"5fdcafad-bac4-4253-8cbe-b2fdb8a9792c"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.12.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Plot of new net operating income with change in scheduled rent"
}], "FigureCaption",
 CellMargins->{{85.33333333333333, 10.}, {6., 2.}},
 CellChangeTimes->{3.539177004175671*^9, 3.5412526444420443`*^9},
 TextAlignment->Center,ExpressionUUID->"78e47451-8b53-4dbf-ab75-ecb5d09c569f"],

Cell[CellGroupData[{

Cell[TextData[{
 "Optimal rent (the same $402.94) and the owner's net operating income at \
that rent is computed to show owner\[CloseCurlyQuote]s ",
 StyleBox["noi",
  FontSlant->"Italic"],
 " is also positive."
}], "Text",
 CellChangeTimes->{{3.5320275467091627`*^9, 3.532027584058299*^9}, {
   3.533327768361249*^9, 3.533327779717899*^9}, 
   3.539177004175671*^9},ExpressionUUID->"e475e5f1-3437-4af5-ae8a-\
74bca70f6260"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["sr", "noi1max"], "=", 
  RowBox[{
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "sr"], 
        RowBox[{"(", 
         RowBox[{"noi1", "/.", "\[InvisibleSpace]", "d6"}], ")"}]}], "==", 
       "0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"sr", ",", "400"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"noi1", "/.", 
    SubscriptBox["sr", "noi1max"]}], ")"}], "/.", "d6"}]}], "Input",
 CellChangeTimes->{
  3.539177004176671*^9},ExpressionUUID->"841adf44-b83e-483b-90ca-\
7f3485224099"],

Cell[BoxData[
 RowBox[{"sr", "\[Rule]", "402.93992220130286`"}]], "Output",
 CellChangeTimes->{3.41194704928125*^9, 3.532027537281624*^9, 
  3.5321232835609975`*^9, 3.5322123365995398`*^9, 3.5333204460624375`*^9, 
  3.533685027125*^9, 3.5337444945334225`*^9, 3.53375694003125*^9, 
  3.5337569906875*^9, 3.5391768561642056`*^9, 3.539177004176671*^9, 
  3.540053807780636*^9, 3.540055017820846*^9, 3.5401285748061695`*^9, 
  3.5412484522392635`*^9, 3.5412499233994093`*^9, 3.5416049235291276`*^9, 
  3.5433495098497934`*^9, 3.5868086175869055`*^9, 3.6983497487904263`*^9, 
  3.6983498608383927`*^9, 
  3.731421859569578*^9},ExpressionUUID->"3f0541ac-03ef-4fc7-a6a5-\
0be8049f672d"],

Cell[BoxData["132.91904069918894`"], "Output",
 CellChangeTimes->{3.41194704928125*^9, 3.532027537281624*^9, 
  3.5321232835609975`*^9, 3.5322123365995398`*^9, 3.5333204460624375`*^9, 
  3.533685027125*^9, 3.5337444945334225`*^9, 3.53375694003125*^9, 
  3.5337569906875*^9, 3.5391768561642056`*^9, 3.539177004176671*^9, 
  3.540053807780636*^9, 3.540055017820846*^9, 3.5401285748061695`*^9, 
  3.5412484522392635`*^9, 3.5412499233994093`*^9, 3.5416049235291276`*^9, 
  3.5433495098497934`*^9, 3.5868086175869055`*^9, 3.6983497487904263`*^9, 
  3.6983498608383927`*^9, 
  3.7314218595715847`*^9},ExpressionUUID->"24a7c6c2-aaaf-44e1-a5ad-\
2f73166eec2f"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "The importance of this exercise is to place both the owner and the manager \
problems at the same rent level set by tenants who demand space. Plotting \
Equations ",
 StyleBox["11.16",
  FontFamily->"Times New Roman"],
 ", ",
 StyleBox["11.18",
  FontFamily->"Times New Roman"],
 " and ",
 StyleBox["11.19",
  FontFamily->"Times New Roman"],
 " on the same graph in ",
 StyleBox["Figure 11.13",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 "combines the perspectives to show collected rent, the manager\
\[CloseCurlyQuote]s net profit and the owners net operating income all \
optimized when scheduled rent is $402.94."
}], "Text",
 CellChangeTimes->{{3.5320276777166557`*^9, 3.532027682975957*^9}, 
   3.5320277766763163`*^9, {3.5320278130993996`*^9, 3.532027857921963*^9}, {
   3.533327792200613*^9, 3.5333278031492386`*^9}, 
   3.539177004176671*^9},ExpressionUUID->"05d31169-dc4f-47fa-91b4-\
1decc40f76ee"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"s1", "=", 
   RowBox[{"Legended", "[", 
    RowBox[{
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"plotCR", ",", "plotNP", ",", "plotNOI"}], "}"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Scheduled Rent\>\"", ",", "\"\<CR/Mgr NP/NOI\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Placed", "[", 
      RowBox[{
       RowBox[{"LineLegend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Directive", "[", 
            RowBox[{"Red", ",", 
             RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
           RowBox[{"Directive", "[", 
            RowBox[{"Blue", ",", 
             RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
             RowBox[{"AbsoluteDashing", "[", 
              RowBox[{"{", 
               RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "]"}], ",", 
           RowBox[{"Directive", "[", 
            RowBox[{
             RowBox[{"Hue", "[", ".3", "]"}], ",", 
             RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
             RowBox[{"AbsoluteDashing", "[", 
              RowBox[{"{", 
               RowBox[{"5", ",", "9"}], "}"}], "]"}]}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<Collected Rent\>\"", ",", "\"\<Mgr's Net Profit\>\"", ",", 
           "\"\<Net Op Inc\>\""}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{".9", ",", ".7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"fig7", "=", "s1"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.411775957875*^9, 3.411775992078125*^9}, 
   3.411776069515625*^9, 3.411776099796875*^9, {3.411776135859375*^9, 
   3.411776154171875*^9}, {3.411776224296875*^9, 3.41177626365625*^9}, 
   3.539177004178671*^9, {3.5868104066962366`*^9, 3.5868104895699763`*^9}, {
   3.58681052721513*^9, 3.58681062967799*^9}, {3.586810661021783*^9, 
   3.5868107906601977`*^9}, 
   3.586810823129055*^9},ExpressionUUID->"7049d511-0f28-4766-be2e-\
dc166a624187"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       TagBox[
        {Hue[0.9, 1, 1], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV13k4lO0XB3DEG6kkKbSiZKtUlrJ+s2eNtFhClN2MmYeZeWYYEdJqKUqE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          "]]},
        Annotation[#, "Charting`Private`Tag$3047#1"]& ]}, {}, {}}, {{{}, {}, 
       TagBox[
        {Hue[0.6, 1, 1], AbsoluteThickness[2], Opacity[1.], 
         AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwV13k4VdsbB3DEDSlDkVSmE5Fjb4kGwjdE5lKpXEWKEJnP2fsc89R4MzVq
QtKkEpHkcpKkkqSSipJKfoWQonL1W/11ns+zn73Wu971rnfto+Ub6u4nISYm
Ji8uJvbn9/PQmLOd/wfLY4EqTfYmtCjiDLvANu+2lUbxZ7sULi1iJvX5z8h7
YkU1H74nmkOLhNWFYpJ576zy36T2LlGmRf8dTnb5kfvV6hljfJ77nRJVSw59
/Zo7AY03T4hPq6BE6ub69oO5U/G9Md/lkzklcm2tG/iSy0Gf4uSV5TaGImQm
T1oeZQLmwNbvuvMMRIpfPYozt1ji6umna6RN9UWWN5lVsQq2KDz48sJRx7mi
3MjqS+3rHfBFWXimaJGO6LVDR8svO1dsfTP83tWBI/JzEvT5PloFkwX1ff3G
WqJllSOSj3asQc6uvqxqN3XRpIq3YjPfemD//c+vlJLVRAaD9juW7tqAjA+X
BuYHqIjMbqiJLCS8YNmhHkIfVhJdcfDWqQ/dhHM7lKWX35ws+ldWYVxxtw/E
NkZ5XyqWEqlVFL4qvr0ZmomFgh/RYzXayb/CK1W3oHhKmcXW+z01m4xlsnZu
2wqRvpjfjEn3rRT1XQrqTvnB6LlNYl/loFWohVto8JA/Eua5pIsViMH26E5u
ChWAI0ne4z8eT0SdUlz+X6mB8JmTMlknUR78MMN852dBOHKx4dNmZirylKce
kJAPRmfukPqOLhXw28otOVtC4KMWtVgpVQ11XRmvSnN3wPa2oaZq22zYPuZI
SLeFwt0vKLklWRMVOyrD3h0Iw/j2N6oRxtrYrRr3QmAcjobx7ePfrnNg9Dj3
pH1HODrV/WgpNx0M/Dql9z0lAi16Z+bEP9RFsGPlRS+tSMglnnkwRUsP/55d
sHf0fiRK+nP5y2P0cV+vYYtzYBSGngUWOV2Yh8GZS8STJKOR1t61zOSmAfpm
y/zqLYrG0nK3C271XJyxGe6Td+TBet3BJvk8QzDB891uOPNQr1gZEldgCMeD
O4p93XjQM6vN+3TWEP3dPRFla3hoS+u6ffOyIRbu6Rjx9Oah01KuGVWGaGiu
Fy+M4kElPW7Cs1ZD9G48qrz0FA9MZdDB2bIUqtNaeR/yyPur7uxdOplCxpWp
bfsLeBjt0Bxcr0DBVHx/ztvzPHgFj07Yo0IhriBJY+c1HhpGns99qE1B/vN2
/ZZ7PIgpda1uNaNgzFhaBAzz0PPYU/A5gEL2ZJ+49995+Gsr91LadgrD+Yk1
Pj94iOiZm6Cxg0L5w7plG8Z5EBVulXCMpGDOcbJzlOaj5/4qz6RYCrZN69y4
s/gYUl4bGJ9JwWNO+OYBGz6UTj+IPn2dwvUbWfnBdnyMZpUdHbhBQdXt2rue
FXy0vNAwN6+i8JId8Xvrwsf6kt+DDSIK3o9ig1rW8VFcdkSh/h6FAMGeyGvb
+WgU9k+ze0VB2Hw6lcnmI0LjnMXaMQoFz9tceg7yEZxsOrJ8nELT68kq64/w
ceimxBwTMRraffzCRSf4UBB+bpGWpNEg43z3eyEf3I5a/+xJNKbZDEtHV/Kx
cvfa7Vw1GkVltvvC3xJvzhn2M6XRWsWuefuOD49QxW6JRTR+3748a1U3HwGD
rronFtNwb1G9ZPSZ+Gjw/nvmNEb7ex9+GeZD7BHaxa1p2OodlN8hzUDusbzf
FxcaHTkfsoJoBuWPZ9aXbaFhrb7PSN6YQZqe8zFlPxqFecZNpSYMnO9oqkb4
0wg7Fy/z3xKG7M9WCa1AGpLlMxLSbRns2/wp2GMHDYPHLiHXNjAImMcxUWdo
ZKwZlt3gxSDJdHOdPUtj+HnOuf82MViRlN8VIqBR/frjO7utDBIki2qvxJD4
exM9X+xgoLp75juZRBrsxHL78WQGxTL/M1HZTeP1Hq8P+WkMrHdu75y4h8Q7
ZUKy/W4G9d17f38jllNeWZ2xn8SzbzDz7j4audqfTDhHGfg/MW6zyqAhVZjR
cvcYWe/yfYPTMmkE6S8KCz7JIDhSKryb2MQo5WLZaQbStbuOxWXTuGuhrr3i
MsnHFonQ5EM0uLfqanqLGRQm7d9tfpisz3b7xsxSBpo9u8a+EHs6VRx5WcGA
69/53uUojf717vIhtxlkHcje33GMxur20SLFegbHfyksZY7TqPA+5VjewMBX
e7qJ/AkaSf69qb8fMmhzujk2/yQN5ai0scw2Bl39nBrHXBrSWxUFMq8Y2FUU
eNYQj60+PpLQweBI6+fLRnk03i8oGQrtIvMNSMbI5NNo41iEfXxP4rUZHAwj
bpza0LfpI4PRo21qz4ivfe3ocellUPH9Tnz2aRrn3gX43+knNn1b0Ud8/MnX
d0sHyfp7tE7ZFtBILpV5Y/Cd5E9qUUgPMe/0Aa/TowyqEma6m54h+czWeKn2
i8SXsfx1HLF7pOkzGTEW5cHJ3RMLadhtEbknSrBYPCPf257YbLVT86gki07V
WYJkYsqm1SVsIovWJdEmVcRaCzY/+CjDQpRv9M8g8TRO7wpvORa+Lc1JnLMk
H1P59a1TWKw/9XyqO/GYhIStqyIZb1G9ZSzxwNC+W3emsgjWmi1xhvh913Qr
CxUWYYu9vO4Rt7XkV11TZaFZLOH8ibix1tCMO5OFhFL6o4nnaIhKKq6fns2i
0SL+gxbxtXwb05ma5Hngyn2Lic9lNZVkabMoVI+vdSI+nrTBSFaHxV9WO9P+
Jk6PeH8pcS4L59/vWrcRJ/mGGvzQZ+H1P/mSMGKe+89zYVwW/q9SVHjEQdap
uj0Ui4qJVRIM8SZjhQLv+SxWDhtG/3nurn1M6/kCFsUC9+BwYjsl3VOuC1kw
d3O7A4jNJK7Oql9M8uuZ3uVFTA2Z51iYs5CWOrDJhVi7q356mQUL617OBjNi
lZZVB7kgTitt5hDL1rYrFViT+I+V35Yh/u/qtoyZy1mM2uQa9f7JZ97Q5Gx7
Fvs+dyk/+JPPzNi9so4sxFwGwgv/5DNRWibJmbwftcQm7k8+w7PTfriySKqi
dv3ZH9FmdcnwVSy4LVZWf/bv2qrziT2rWbgXv/IfIPt7bH5NzPP1ZL1WweIJ
xPu1HH+6/s2iOdw83Jo4SfEZv34jmT/U0UmcOGjwU0SZL4vj3GeLoki9bXob
PcD1YzHQoWOv96f+HovtKNjGosXCp7KN1KvZVZXA7GAWHktN6ilimXBr73Ae
2X/bPLsr5Dws7rAsmc2SfD73WGtBHOBgLnVfyKJr38Xpd8n5qtcyuaidSOaf
9OvyQ3L+klp0Rp7sJfU6lekvJOf1qqW2Y8J+Fg0OkT5KxJ0X1E9wM0k9bkmN
Zsn5tkqebpN6iNTj+sMJZuT8jy2QSV+YR8b//uLNTtIvDHKlurpOsyga+kk3
HyH9RE7CNL2Q1N94kNI04or3P19+vMgif8Wt1P2kH0Uf7NU9Ws6ie7Txkwvp
V/3fH1X/ekDmn7P00fBeGrO3NCqea2KhumqZ7Z/+6PyoYeuaxyx8XG30B0k/
vXD2luylVrJ/2qlmr3bS2La+1GPTWxZDWTeWMskk/huH+kXfWSzcbdXyhPRv
ed3sZSE/WPSm2FrtIf3dMiv9wIwxFvVTP42a80n9B+0yixAX4K9KNYfMKBob
ZgrSOHICKJwfmD0hlEZLzEb1NC0B7PSeHxcn9819z5BRnTkCFEY9MIncTOPW
4tiWO7oCMN51Wp3eNIqHj6dJcQU4clR86KIXqYfg9v6UhQIE31enJnnQcPL6
uybZSYDRA3o63fbkPjDbfpTjShzISsrZkf1WFUbeXknm73JWNrSlMe9pztwJ
HgLU5vNqfUD6h/PL9CQfAeRCeJP2k/uzznyDT2K0AL5FxRvG59KomhFopsWQ
+ZS90apDo3SEmXZLIECWnJjJeQ6N/NIjDWIJAlR9ebQYGjQSDNqMEvYI4J7s
zzdWobF05jrx+FMC5AY9rNSZQKPs55r8mHsC4NqS0oUvKCxd7uD15YEAnbIP
nx5rpVCbbqHi2ySA6E6039gT8v0wR3eP/RMBYnxkGq80UehxHQlX6hCgfEiZ
9+Y2hVmnjy47NyBARNld1ucShRSn151PpgvR6Dgy8DKGguyhlhw7NSG6dkZJ
XWApZHbWr7kxSwjdWX72UTwKJ6OvNJzUEqLeh3b6GUqh4lRCcaCBEG0L1ac3
+lLo/aqd8NtSCIVNE9+l2FNYfXybhoG/EEPiD6g/33/Ttjy83BIgRLdF0Wo1
GQqt+gssBduFQK+XcEiSguf1ca97YUIcCW26mzFmSPr2wZxtQiFEOlOlUj8b
Iky6TrkgQ4iKtdf/cWgwxD9RmnKzbwqh/aAvkoo1hKt52rG6f4UwtnNbZ88Y
QkGid16wSIjgUwNvNkQa4kD6dYebd4QomfPu6fZAQxy/4LpzQ7MQvs0No9Zr
DXGhM0bi0AchijQ+xt40MMRd5xejUxRi0Bkb+qrmCReqCZyA3UoxsDYy/xjQ
xEVAacjzCcoxEGk/UpK7x4WsmkT56IwYUh/d1ajmwvnjvMguTgyCBcVaW85x
0ZIY01e2KAa6j1vqdgu5eF2u0eXlHQOf89XtTrO5+K7p/+DCZTJeZZ+VrKsB
5Otv31K9GoPuvUtqVtgbQG+7VkVaaQxKrr74kgADeJa1F/hWkPjMtD1fGxug
xmF1nFptDPw9OqVcphtgVwTm73kWg9H2ZNeR1/OgVqd2OHAsBkhIkA4OnAer
bY989RxjkTDB09g0SB8Hdp2kHjjHAhudbZQ266PnfMjPELdYlHjnTv64Th8Z
vZOyStfEwn3+02r+cn10ha+4ZekdS/L/RMdUUx9pMbc01kbFQq/PP3vWUz00
ZZa2J54k4/tZDSea6mFT1WGPV0OxKH6TXCPq0IW1o5PEqm+xyGoPS6Ge6EKn
bfxS/UgsmrsPUwcadEk9+UmVjMViKHz1HPtSXbAGJtd2/RWHiptb5jvt0sWB
nGbFhWpxWJHz/GKDkS4eMDIPM5bFwau17US8UAeLTYU2dhlxcDSw+2/SCAet
Qut5UtlxyDFVGH3Zw0F0rYxi3cE4iDm8LTr5koMStyOvlx2LQxGXR0lWc8AN
KmMtCuNwUrHrm10KB5qnvlwxqYpDT3NiceEUDmRkts7i9MRhcfvOGWfVtHHO
zWBC16c4iPz/CZCYpA27Q0P/y+2Lg9EZ3Fz1SwspnMTr6l+J2+auaXylhXGL
k+5q43HoDD9+2ei4FoYi2nYpTotHo/3lx8VqWsi4cSq0WSUeFWIZ2Q6yWqDF
tnmkz4iHu0LRj2c/NBH8zzfOZI148Pzccu61aaL7rFKN9Lx47Pv7VtLMQ5pI
6X9x5i43HofGpKtWpmqCY5q3L42OR+2lsgA2ShM+tbSnpGk8FmfmTDjjrolx
6RHcXhRP/n+zH84u08QJt+q5SWbxUAiU1T5ppImlh1KnLLOIR33wjNKdGpp4
2e787bdVPJynhWZtnaKJ/wMUGYwL
          "]]},
        Annotation[#, "Charting`Private`Tag$3166#1"]& ]}, {}, {}}, {{{}, {}, 
       TagBox[
        {Hue[0.3, 1, 1], AbsoluteThickness[2], Opacity[1.], 
         AbsoluteDashing[{5, 9}], LineBox[CompressedData["
1:eJwV1nk8VN8bB3BbUtlSCZVsWbOksUU89n2ZGco6cxPakWXMnaFEhUJaLMlW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          "]]},
        Annotation[#, "Charting`Private`Tag$3217#1"]& ]}, {}, {}}}, InsetBox[
     TemplateBox[{
      "\"Collected Rent\"","\"Mgr's Net Profit\"","\"Net Op Inc\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[1, 0, 0], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[1, 0, 0], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0, 0, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{2, 5}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0, 0, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{2, 5}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.3, 1, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{5, 9}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.3, 1, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{5, 9}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.3], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.3, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.3`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.3, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.3], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "9"}], "}"}], "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}]}], "]"}]& )], 
     Scaled[{0.9, 0.7}], ImageScaled[{1, 1}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{True, True}, {True, True}},
   FrameLabel->{
     FormBox["\"Scheduled Rent\"", TraditionalForm], 
     FormBox["\"CR/Mgr NP/NOI\"", TraditionalForm]},
   FrameTicks->FrontEndValueCache[{{Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {100., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {200., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {300., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-100., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-80., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-60., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-40., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-20., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {20., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {40., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {60., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {80., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {120., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {140., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {160., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {180., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {220., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {240., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {260., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {280., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {320., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {340., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {360., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {380., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {400., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {100., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {200., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {300., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {400., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {500., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-100., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-80., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-60., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-40., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-20., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {20., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {40., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {60., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {80., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {120., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {140., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {160., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {180., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {220., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {240., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {260., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {280., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {320., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {340., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {360., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {380., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {420., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {440., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {460., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {480., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {520., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {540., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {560., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {580., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {600., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}}],
   GridLines->{Automatic, Automatic},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->500,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{0, 500}, {0., 314.31151946760565`}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{{}, {}, 
         Annotation[{
           Directive[
            Opacity[1.], 
            Hue[0.9, 1, 1], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJwV13k4lO0XB3DEG6kkKbSiZKtUlrJ+s2eNtFhClN2MmYeZeWYYEdJqKUqE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            "]]}, "Charting`Private`Tag$3047#1"]}}, {}, {}}, {{{{}, {}, 
         Annotation[{
           Directive[
            Opacity[1.], 
            AbsoluteDashing[{2, 5}], 
            Hue[0.6, 1, 1], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJwV13k4VdsbB3DEDSlDkVSmE5Fjb4kGwjdE5lKpXEWKEJnP2fsc89R4MzVq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            "]]}, "Charting`Private`Tag$3166#1"]}}, {}, {}}, {{{{}, {}, 
         Annotation[{
           Directive[
            Opacity[1.], 
            AbsoluteDashing[{5, 9}], 
            Hue[0.3, 1, 1], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJwV1nk8VN8bB3BbUtlSCZVsWbOksUU89n2ZGco6cxPakWXMnaFEhUJaLMlW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            "]]}, "Charting`Private`Tag$3217#1"]}}, {}, {}}}, {
     ImageSize -> 500, FrameLabel -> {"Scheduled Rent", "CR/Mgr NP/NOI"}, 
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {Automatic, Automatic}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
      DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
      DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
      FrameLabel -> {{"Collected Rent", None}, {"Scheduled Rent", None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, 
      PlotRange -> {{0, 500}, {0., 314.31151946760565`}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[
         RGBColor[1, 0, 0], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0, 0, 1], 
         AbsoluteThickness[2], 
         AbsoluteDashing[{2, 5}]], 
        Directive[
         Hue[0.3], 
         AbsoluteThickness[2], 
         AbsoluteDashing[{5, 9}]]}, {
       "Collected Rent", "Mgr's Net Profit", "Net Op Inc"}]], {{0.9, 0.7}, {1,
       1}}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.5868107918712673`*^9, 3.6983497488616257`*^9, 
  3.6983498609075766`*^9, 3.7314218596517982`*^9},
 TextAlignment->Center,ExpressionUUID->"b6704b92-c1e5-40d0-b4fb-e89a421e3080"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.13.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Combined plots of collected rent, manager's profit and owner's net income \
with change in scheduled rent"
}], "FigureCaption",
 CellMargins->{{85.33333333333333, 10.}, {6., 2.}},
 CellChangeTimes->{3.5391770042526755`*^9, 3.5412526484012704`*^9},
 TextAlignment->Center,ExpressionUUID->"61d6a2fd-eb84-445b-8df1-cb2e7a0807b6"],

Cell[TextData[{
 "But there is a problem. Recall that we solved Equation ",
 StyleBox["11.7",
  FontFamily->"Times New Roman"],
 " using data ",
 StyleBox["d3",
  FontWeight->"Bold"],
 " to conclude that the optimal number of locations is 15. But using data ",
 StyleBox["d5",
  FontWeight->"Bold"],
 " to produce the plot above from Equation ",
 StyleBox["11.17",
  FontFamily->"Times New Roman"],
 " we had to restrict the number of locations to 3 for profit to be positive. \
 In a plot of ",
 StyleBox["np3",
  FontSlant->"Italic"],
 " using data ",
 StyleBox["d7",
  FontWeight->"Bold"],
 " in which the location parameter is set at the optimal 15, ",
 StyleBox["Figure 11.14",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["shows",
  FontColor->GrayLevel[0]],
 " us that the manager does, indeed, maximize his net profit at the optimal \
rent but at no scheduled rent are profits positive. In fact, for this model, \
management is unprofitable at any number of locations above 3. Under these \
conditions the manager and the owner ",
 StyleBox["cannot simultaneously optimize their respective net incomes under \
the incentive framework currently in use by the industry",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{
  3.5320280593544846`*^9, {3.532028435685009*^9, 3.532028445730584*^9}, {
   3.5320284842637877`*^9, 3.532028486378909*^9}, {3.532028631498209*^9, 
   3.5320286324882655`*^9}, 3.532056061337106*^9, 3.5333278983636847`*^9, 
   3.5391770042526755`*^9},ExpressionUUID->"86241d3e-5de3-4012-aa50-\
8564821cfe4d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optlocf", "/.", 
  RowBox[{"d", "\[Rule]", ".5"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.5391770042526755`*^9},ExpressionUUID->"c83c8b67-9034-4563-a619-\
a6bb1a5ea7b9"],

Cell[BoxData["15.47206304983694`"], "Output",
 CellOpen->False,
 CellChangeTimes->{3.41194705034375*^9, 3.532027708546419*^9, 
  3.5320285214249134`*^9, 3.5320561349863186`*^9, 3.5321232846100574`*^9, 
  3.532212338401643*^9, 3.5333204481745586`*^9, 3.53368502965625*^9, 
  3.533744496668545*^9, 3.5337569415625*^9, 3.533756992296875*^9, 
  3.5391768571302605`*^9, 3.5391770042526755`*^9, 3.540053809703746*^9, 
  3.5400550186798954`*^9, 3.5401285767112784`*^9, 3.541248454574397*^9, 
  3.541249925967556*^9, 3.54160492566425*^9, 3.5433495106928415`*^9, 
  3.586808618454955*^9, 3.6983497488806667`*^9, 3.6983498609286323`*^9, 
  3.731421859714967*^9},ExpressionUUID->"85387180-b206-4f68-a286-\
fc57e3e1022d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig8", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"np3", "/.", "d7"}], ",", 
    RowBox[{"{", 
     RowBox[{"sr", ",", "0", ",", "500"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", ".6", "]"}], ",", 
       RowBox[{"AbsoluteDashing", "[", 
        RowBox[{"{", 
         RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Scheduled Rent\>\"", ",", "\"\<Manager Net Profit\>\""}], 
      "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.411776300921875*^9, {3.531943199748514*^9, 3.5319432010385885`*^9}, 
   3.5391770042536755`*^9},ExpressionUUID->"116e3ce9-f9c2-4141-bac3-\
8bb85228f2e0"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {Hue[0.6, 1, 1], AbsoluteThickness[2], Opacity[1.], 
      AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwd13k4VP0XAHBJZcneYolCSUyLimQ9ScpeUeEVRSK7MHPv7JamPTsl4SKp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       "]]},
     Annotation[#, "Charting`Private`Tag$3292#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, -2270.0530170610555`},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Manager Net Profit\"", TraditionalForm], None}, {
     FormBox["\"Scheduled Rent\"", TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
     Automatic, {{-2270., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-2260., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-2250., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-2240., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-2280., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2278., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2276., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2274., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2272., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2268., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2266., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2264., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2262., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2258., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2256., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2254., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2252., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2248., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2246., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2244., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2242., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2238., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2236., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2234., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2232., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2230., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {200., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {300., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {400., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {500., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {120., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {140., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {160., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {180., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {220., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {240., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {260., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {280., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {320., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {340., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {360., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {380., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {420., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {440., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {460., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {480., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {520., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {540., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {560., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {580., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {600., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{Automatic, Automatic},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 500}, {-2270.0530170610555`, -2238.6218661233183`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4119470505*^9, 3.5320285247021008`*^9, 
  3.532056137594468*^9, 3.5321232846600604`*^9, 3.5322123386456566`*^9, 
  3.5333204484185724`*^9, 3.533685029796875*^9, 3.533744497047567*^9, 
  3.533756941640625*^9, 3.533756992375*^9, 3.5391768571802635`*^9, 
  3.539177004282677*^9, 3.540053810033765*^9, 3.5400550187248974`*^9, 
  3.5401285770592985`*^9, 3.541248455044424*^9, 3.54124992638358*^9, 
  3.5416049259742675`*^9, 3.5433495107328444`*^9, 3.586808618475956*^9, 
  3.6983497489599047`*^9, 3.6983498609988227`*^9, 3.7314218597941885`*^9},
 TextAlignment->Center,ExpressionUUID->"ec970bc8-1b64-4a3d-93f0-a9ed64a3e5b8"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.14.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Manager's net profit when locations = 15"
}], "FigureCaption",
 CellMargins->{{85.33333333333333, 10.}, {6., 2.}},
 CellChangeTimes->{3.539177004282677*^9, 3.541252662613083*^9},
 TextAlignment->Center,ExpressionUUID->"2974a7da-d202-4044-bfe1-8c77fe2a6834"],

Cell[TextData[{
 "To justify management of small properties in many locations one must either \
combine it with the rewards of ownership or management efforts must \
complement and enhance income from other sources. Indeed, management is \
sometimes merely an ",
 StyleBox["accommodation ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 "brokers offer owners. Responsible real estate professionals who do both are \
careful to maintain a separation between the two activities to prevent the \
kinds of conflicts discussed above."
}], "Text",
 CellChangeTimes->{
  3.539177004282677*^9},ExpressionUUID->"7b6f13a9-3cf9-4cb3-8546-\
58cbb5d3f470"]
}, Open  ]],

Cell[CellGroupData[{

Cell["11.6. Data issues", "Section",
 CellChangeTimes->{3.532056165572068*^9, 3.5337447637038183`*^9, 
  3.539177004282677*^9},ExpressionUUID->"a9f57b21-73aa-446a-ac9b-\
bb580a65cbef"],

Cell["\<\
This chapter leads to a bleak conclusion, something we might loosely call the \
Impossibility Theorem of small investment property management. An earlier \
sage remarked \"If you want something done right, do it yourself\". One asks, \
Is there no middle ground? Perhaps there is and perhaps data can assist. The \
key is to manage the manager. The owner must institute supervision policies \
to keep the manager alert and aware of his duties and the owner's objectives. \
One method of supervision is monitor utility consumption.\
\>", "Text",
 CellChangeTimes->{
  3.539177004282677*^9},ExpressionUUID->"29b96d37-cf49-4f7f-98a0-\
c1a45e540c13"],

Cell["\<\
A building occupied by residential tenants is usually plumbed such that the \
owner pays for water consumption. Such a utility can be used as a canary in \
the mine shaft. Tracking water consumption and noticing when it changes is an \
early warning of the need for owner inquiry.  Most municipalities render a \
water bill showing the prior and current meter reading used to compute the \
charge for the time period. The meter measures gallons or hundreds of cubic \
feet (742 gallons - 1 HCF). Some owners have the water bill sent to them \
rather than to the manager, giving the owner the earliest opportunity to \
receive and use the information.\
\>", "Text",
 CellChangeTimes->{
  3.539177004282677*^9},ExpressionUUID->"55f0682c-49fb-4fc1-97f1-\
13c206ff5aa7"],

Cell["\<\
Water consumption should follow some sort of distribution. In this case the \
assumption that it is normal is reasonable. Thus the standard z table can be \
used as the red flag. High z-score readings mean an observation far from the \
mean and therefore unlikely. When a high z-score occurs the owner should look \
into the matter to see if additional non-permitted occupants have moved in, \
excess lawn irrigation is taking place, the tenants have started a car \
washing business or there is a leak in the building. While not a sure thing, \
the change in water consumption indicates that some sort of change has taken \
place at the site. Such changes should be of interest to the alert owner and \
may not (although one can argue that they should) come to the attention of \
the manager.\
\>", "Text",
 CellChangeTimes->{
  3.539177004282677*^9},ExpressionUUID->"a8add357-9f26-4539-8965-\
1ff7cf643ac6"],

Cell["\<\
We use a database of actual water consumption on a small residential property \
over approximately twelve years. In each record the first element is the \
meter reading for hundreds of cubic feet consumed and the second is the \
number of days between meter readings. It is sometimes easier to think in \
terms of gallons per day, a simple conversion.\
\>", "Text",
 CellChangeTimes->{{3.532119224226817*^9, 3.5321192248038497`*^9}, {
   3.533327967196622*^9, 3.5333279680996733`*^9}, 
   3.539177004282677*^9},ExpressionUUID->"66673e56-9cf3-4450-a600-\
fce0737725d5"],

Cell[CellGroupData[{

Cell[TextData[{
 "waterdata={{\"HCF\",\"Days\"},{56,57},{70,62},{70,60},{74,65},{81,58},{73,\
62},{57,57},{72,66},{85,65},{80,62},{66,54},{67,67},{24,57},{28,60},{34,62},{\
31,57},{27,58},{25,62},{27,58},{23,36},{40,66},{28,55},{29,63},{27,62},{33,56}\
,{37,64},{38,64},{32,56},{36,63},{34,60},{32,59},{37,64},{39,61},{30,62},{17,\
59},{25,60},{26,59},{41,67},{31,59},{23,61},{33,61},{21,58},{29,61},{31,67},{\
34,61},{25,61},{17,60},{22,60},{18,59},{31,60},{13,59},{12,63},{16,61},{24,59}\
,{94,69},{45,61},{46,59},{5,62},{10,57},{37,62},{25,62},{35,58},{26,64},{27,\
61},{42,62},{31,59},{26,61},{33,62},{25,59},{32,63}};\n\
hcf=Drop[waterdata[[All,1]],1];\ndays=Drop[waterdata[[All,2]],1];\n\
galperday=N[",
 Cell[BoxData[
  FractionBox[
   RowBox[{"hcf", " ", "748"}], "days"]],ExpressionUUID->
  "e23aae02-02ce-4c6c-9fbc-86a470914a25"],
 "];\nexcessive=Mean[galperday]+1.645 StandardDeviation[galperday];\n\
suspicious=Select[galperday,#>excessive&];\nCellPrint[TextCell[\"The mean (\" \
<> ToString[Mean[galperday]] <> \") and standard deviation (\" <> \
ToString[StandardDeviation[galperday]] <> \") of gallons consumed per day \
give us some idea of what to expect. If the data are distributed normally, \
95% of all observations should be within 1.645 standard deviations of the \
mean (we only care about one tail). Those above that should be considered \
'suspicious'. So, consumption in excess of \" <> \
ToString[NumberForm[excessive, {6, 2}]] <> \" gallons per day should be \
considered not normal. In \" <>ToString[Length[Drop[waterdata[[All,2]],1]]]<>\
\" meter readings, \"<>ToString[Length[suspicious]]<>\" exceed \
\"<>ToString[NumberForm[excessive, {6, 2}]]<>\" gallons per day and should be \
investigated.\", \"Text\"]]"
}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{66., 32.66666666666663}, {5., 10.}},
 CellOpen->False,
 CellChangeTimes->{
  3.533327982458495*^9, 3.533328160241664*^9, {3.533328197005766*^9, 
   3.5333282443464737`*^9}, {3.533328293559289*^9, 3.5333283249490843`*^9}, {
   3.5333283677365313`*^9, 3.533328395065095*^9}, {3.533328713328298*^9, 
   3.533328718388588*^9}, {3.5333288174972563`*^9, 3.533328826511772*^9}, {
   3.533328900573008*^9, 3.5333290968152323`*^9}, {3.539177004282677*^9, 
   3.5391770042846775`*^9}},ExpressionUUID->"5c68a581-cb08-4e6a-a476-\
da329233c2c9"],

Cell["\<\
The mean (451.805) and standard deviation (228.941) of gallons consumed per \
day give us some idea of what to expect. If the data are distributed \
normally, 95% of all observations should be within 1.645 standard deviations \
of the mean (we only care about one tail). Those above that should be \
considered 'suspicious'. So, consumption in excess of 828.41 gallons per day \
should be considered not normal. In 70 meter readings, 9 exceed 828.41 \
gallons per day and should be investigated.\
\>", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731421859862381*^9},ExpressionUUID->"47b2063a-1b4f-4a52-92f3-\
c72573e4c8e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"NumberForm", "[", 
      RowBox[{
       RowBox[{"TableForm", "[", 
        RowBox[{"suspicious", ",", 
         RowBox[{"TableAlignments", "\[Rule]", "Right"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "3"}], "}"}]}], "]"}], ",", 
     "\"\<Suspicious meter readings\>\"", ",", "Top"}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5321239503891377`*^9, 3.5321241007277365`*^9}, 
   3.533328227459508*^9, {3.5333287551066875`*^9, 3.533328776783928*^9}, {
   3.533329871926566*^9, 3.5333299294368553`*^9}, {3.53332996256575*^9, 
   3.5333299819188576`*^9}, {3.533330060584357*^9, 3.5333300731210737`*^9}, {
   3.533330116730568*^9, 3.533330120975811*^9}, {3.5333301845544477`*^9, 
   3.5333301854414988`*^9}, {3.5333302375494785`*^9, 3.5333303438845606`*^9}, 
   3.5391770042846775`*^9},ExpressionUUID->"909cebfa-9bb6-4b91-849f-\
e58b4f63da95"],

Cell[BoxData[
 StyleBox[
  TemplateBox[{TagBox[
     TagBox[
      TagBox[
       GridBox[{{
          InterpretationBox[
          "\"844.516\"", 844.516129032258, AutoDelete -> True]}, {
          InterpretationBox[
          "\"872.667\"", 872.6666666666666, AutoDelete -> True]}, {
          InterpretationBox[
          "\"851.569\"", 851.5692307692308, AutoDelete -> True]}, {
          InterpretationBox[
          "\"1044.620\"", 1044.6206896551723`, AutoDelete -> True]}, {
          InterpretationBox[
          "\"880.710\"", 880.7096774193549, AutoDelete -> True]}, {
          InterpretationBox[
          "\"978.154\"", 978.1538461538462, AutoDelete -> True]}, {
          InterpretationBox[
          "\"965.161\"", 965.1612903225806, AutoDelete -> True]}, {
          InterpretationBox[
          "\"914.222\"", 914.2222222222222, AutoDelete -> True]}, {
          InterpretationBox[
          "\"1019.010\"", 1019.0144927536232`, AutoDelete -> True]}}, 
        ColumnAlignments -> Right, RowSpacings -> 1, ColumnAlignments -> 
        Left], Column], 
      Function[BoxForm`e$, 
       TableForm[BoxForm`e$, TableAlignments -> Right]]], 
     NumberForm[#, {6, 3}]& ],"\"Suspicious meter readings\""},
   "Labeled",
   DisplayFunction->(GridBox[{{
       ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
       TagBox[
        ItemBox[
         PaneBox[
          TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
          BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
        "SkipImageSizeLevel"]}}, 
     GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
     AutoDelete -> False, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      BaselinePosition -> {2, 1}]& ),
   InterpretationFunction->(RowBox[{"Labeled", "[", 
      RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{
  3.411947050625*^9, 3.53205625303207*^9, 3.5321232848210697`*^9, {
   3.532124013484747*^9, 3.5321240310217495`*^9}, 3.532124101445778*^9, 
   3.532212340310752*^9, 3.533320449905658*^9, {3.533328760773012*^9, 
   3.5333287774399652`*^9}, 3.5333299308679376`*^9, 3.533330073979123*^9, 
   3.533330123161936*^9, 3.5333301861845407`*^9, {3.5333302442738633`*^9, 
   3.5333302870923123`*^9}, {3.5333303210492544`*^9, 3.533330345176635*^9}, 
   3.5336850303125*^9, 3.53374449781161*^9, 3.53375694184375*^9, 
   3.533756992609375*^9, 3.5391768574292774`*^9, 3.539177004287678*^9, 
   3.540053811489848*^9, 3.540055018887907*^9, 3.5401285781583614`*^9, 
   3.5412484609667625`*^9, 3.5412499278366632`*^9, 3.541604927050329*^9, 
   3.5433495108478503`*^9, 3.5868086185019574`*^9, 3.69834974903608*^9, 
   3.6983498610599833`*^9, 3.7314218598944445`*^9},
 TextAlignment->Center,ExpressionUUID->"80ed5702-30d1-4bdc-8f4b-28bc7018e69d"]
}, Open  ]],

Cell["\<\
Picking out the \"spikes\" in the series, we see the 9 occasions upon which \
the owner should have made a personal inspection to determine why the water \
consumption for that period was above the critical value.\
\>", "Text",
 CellChangeTimes->{{3.53333048601269*^9, 3.533330542402915*^9}, 
   3.539177004287678*^9},ExpressionUUID->"48ce1d3d-92d2-4582-bde4-\
375ec733b3e5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"lpwater", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"galperday", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", "828", "}"}]}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "\"\<Gal/Day\>\""}], "}"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"excess", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{"828", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1", ",", "70"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"fig9", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"lpwater", ",", "excess", ",", 
    RowBox[{"ImageSize", "->", "500"}]}], "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.411776414953125*^9, 3.53205632226103*^9, 
  3.5391770042886777`*^9},ExpressionUUID->"8351170e-f38d-4b7f-807e-\
1fab89c75f47"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdlGtIk2EUx0cJ7Us1aYTJVhnmpULTzHTe/l6mbk63iQZp0LxEkZe8NM3L
W2voIu/aDUqiiAgyK6kGWUkaaWa51JLKNMhQImSCgR+E6H15z/PBHRiH337P
nvec8zzvvHJPph9dI5FIEvmPkMVYjCnZ1s+5LdtAX6BOFif1ym8gliJTCHUj
sQzDzd/fNncyL8ezu+5XatLbiD1gn8wq6K5n6xViNp0n3i5mywXiHZBH9GyK
aG8h9ob/nUvpWn/GPlAMlSqG2puI/Vz224Ulz3cFfg/LiffAXYgxM3EA8pqC
Bj1uVxHvhSNX1fi7kHEQlkMGyvSv2fpgqOY7y0e/lhHvc/Eh+BXWMhs2wxHv
F+eTWUscig/vhagkPgCjXG2U17Pfh6HW+XJ5JvsUcTg0Hd6ajqYaYpWY1zGO
EPMA40gUT9mLpuzVxFEuHI2ZaT44xjFY72s+sjWb9YvV+1sAQ+mw7P4s6ycW
P2r4Am9UkI/FmapC9cfFE+Tj0HWPj2qatyUOzwNbu6XXWD/x8Blfe/nxdZqH
JR6fOX6DttPkEzDPNaTYbpaST4B0cmyO07L61JiekI5ELZSQVyNgi9X8JJzq
kSRCszFjtPgWzdOSiJg3O+MfbWD9JiHjcLDbHz9WXxLNg9WfjAQhvNnzk+Ec
ydtttRWS16BSCF+q16Kh/vLJa/E30rEU6cghr8X4nNDQcfIp0E5fHTroxp6f
gt4K0wPll1byOuhsJmVR9DnyOriHdH7iwq3kU+n+p5FPhXnzxCHdMRP5NAx6
8Dd6jp1fmst91cMzh38jQ9n89WL+x7wB/apvL/Q9dF4woKD76WRW11lab1h9
Xq8M4JszKRfY+2UE/+9QJ/tJHkZYbRd7Ax2sXyMWV/qcK32V+A/gaSKH
       "]]}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQrWrHUMXI8MGeAQQedDqsWJi25sjVX3D+tKa094ev
MjnA+CFfImuvT+GD82uE75UHHROB86vfK5ivV5OC82cEaals+S0P54t0b2Xs
3qYE52cbWHJMWKkK50tsPyp4oU8Dzv//NneKnZM2nF+a8VOX0UAPzp/sGaDw
s9QAzp/mr6HNf9YQzk/4Xujo72gM57uXe05ZNscEzv82Y9IndVEzOD9AO+HS
sTZzOP/41N3vau5bwPmsizrEYkOtEOa3Pa4K2WQN5zfzbHhVqmML5wcyM97Z
Mt8Ozre9dJ+T+5c9nF+hOGPh0R0OcP4D1/YYwQxHOH/uIosbr4Wd4Hy7C4si
o88h+G9fBleG1TjD+Q1X9s57ZuEC52d8f9nC+gnBj2eL5dwwzxXOt3rWMfl9
pBucr7zp9+5dHO5wftI2g6UiWxD8lm65Kcx5HnD+Vp9gxTppTzj/1D2HLb3X
Efy3MaVPNdq94Pw04ZzrQcbecP6hWdLnBd8h+Lp8Qqkxc3zg/Oqggww2kb5w
vvx5o9hVQn5w/iXz1+FL9iP4GYUxEcbV/nB+u3fXbzXRADi/tcp99e8sBP+L
4MO7UicQ/Gz5eff/ywXC+Zb8t9/U+yP47P/Ff/2vR/ABrhcKsA==
        "]]},
      Annotation[#, "Charting`Private`Tag$3409#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, 
    FormBox["\"Gal/Day\"", TraditionalForm]},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 70.}, {0, 1044.6206896551723`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{{}, {{828, 
      FormBox["828", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{3.41194705078125*^9, 3.532056327771345*^9, 
  3.5321232848730726`*^9, 3.5322123409057865`*^9, 3.5333204504996915`*^9, 
  3.53368503078125*^9, 3.5337444983586416`*^9, 3.533756941953125*^9, 
  3.53375699271875*^9, 3.539176857504282*^9, 3.5391770042916775`*^9, 
  3.540053812253892*^9, 3.5400550189499106`*^9, 3.540128578886403*^9, 
  3.5412484616067996`*^9, 3.5412499287657166`*^9, 3.5416049277233677`*^9, 
  3.5433495108918533`*^9, 3.5868086185209584`*^9, 3.698349749155431*^9, 
  3.6983498611632833`*^9, 3.731421860028823*^9},
 TextAlignment->Center,ExpressionUUID->"b915bf8e-ca1c-4738-a132-a9b87e3128f0"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.15.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Water consumption history"
}], "FigureCaption",
 CellMargins->{{85.33333333333333, 10.}, {6., 2.}},
 CellChangeTimes->{3.5391770042916775`*^9, 3.5412526699585037`*^9},
 TextAlignment->Center,ExpressionUUID->"06430960-1078-4851-b768-c2a4626457fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["11.7. Conclusion", "Section",
 CellChangeTimes->{3.532056392767063*^9, 
  3.5391770042916775`*^9},ExpressionUUID->"5a3dec89-e831-48e9-adc5-\
61cc43be9aa9"],

Cell["\<\
To place the subject in the positive, as building size increases the \
compensation available for managers increases and the possibility of \
retaining capable people rises because they are more highly compensated. \
Also, larger properties and portfolios of large properties often attract \
managers who understand complex compensation arrangements. An obvious \
solution to the conflict described in our model is to make the manager's \
compensation dependent on net rather than gross income. By industry \
convention, this procedure is uncommon for small properties. One reason for \
this might be that the owners of these properties have non-uniform \
maintenance procedures making managers unwilling to base their compensation \
on something that is out of their control. Or, it may be that small property \
management is simply not very lucrative so the added expense of \
administrating complex compensation arrangements is just not justified. \
Regardless, the smaller the property, the more likely the compensation will \
be a percentage of collected rent and incentive arrangements will be \
inefficient.\
\>", "Text",
 CellChangeTimes->{{3.533330579463035*^9, 3.533330616758168*^9}, 
   3.5391770042916775`*^9},ExpressionUUID->"c4fb6d61-fe25-45d3-b68f-\
5abbfdbf9671"],

Cell[TextData[{
 "The successful Tier II investor is a hands-on owner. If he is not there is \
reason to suspect his tenure will be short. In addition to the perverse \
incentives described in the model some brokers use their management (or lack \
of it) to obtain listings on properties. Real estate brokerage is often more \
profitable than management and brokers find that if they have control of the \
management of the property they can influence or participate in sales when \
the owner becomes frustrated with the process. Unscrupulous managers may \
manipulate the situation to steer the owner toward a sale in order to claim a \
brokerage commission. To eliminate this temptation, the astute Tier II \
investor who does use a management firm may wish to delete the standard \
clause in many management agreements that calls for the manager to be the \
broker or be paid a commission in the event the owner wishes to sell.  \
Separate from the incentive problem, one can make an argument that the skill \
sets required to be an excellent manager and those required to be an \
excellent broker are quite different. The two are different ",
 StyleBox["specialties",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 ", having very different compensation arrangements and attracting very \
different kind of people. One wonders if it is likely that someone who is a \
good property manager is also a good broker. Surely such people exist but it \
seems they might be in the minority."
}], "Text",
 CellChangeTimes->{
  3.5391770042916775`*^9, {3.5412526995571966`*^9, 
   3.5412527269167614`*^9}},ExpressionUUID->"648544d5-8a26-4ea4-9a00-\
98ce44f34b2e"],

Cell["\<\
Finally, one must consider who has the greatest incentive to see that all \
goes well. Returning to \"the building as the firm\" metaphor, the owner's \
compensation is the residual claim to whatever remains after all others have \
been satisfied. It is the owner who has the global view of his objectives, \
the market and his property. Ultimately, he is the manager regardless of who \
he hires to execute specific tasks.\
\>", "Text",
 CellChangeTimes->{{3.532056444094999*^9, 3.5320564732156644`*^9}, 
   3.5391770042916775`*^9},ExpressionUUID->"2eb7c207-9210-47c9-9b0c-\
ad963a4bd1fd"],

Cell["\<\
In real property ownership the buck stops at the owner. Denying this is folly.\
\>", "Text",
 CellChangeTimes->{{3.532056444094999*^9, 3.532056445400073*^9}, 
   3.5391770042916775`*^9},ExpressionUUID->"d8576da9-71d6-4149-8d67-\
b6614369918a"]
}, Open  ]],

Cell["Endnotes", "EndnoteSection",
 CellChangeTimes->{{3.5319668334752865`*^9, 3.5319668353513937`*^9}, 
   3.5391770042916775`*^9},
 LineSpacing->{1., 1., 2.},
 ParagraphSpacing->{
  0, 0.},ExpressionUUID->"627631ac-7460-4b28-9780-85f173b331b9"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "1"], TraditionalForm]],ExpressionUUID->
  "285aeffc-e22f-44ec-ab81-281b6cb73ebd"],
 "This is not to say that larger buildings do not produce more net profit, \
something clearly evident from the plot in Figure 11-4. The plot shows that \
for all sized buildings, given that they are all the same as they are in our \
stylized example, the optimum number of locations is 15. The effect is more \
pronounced in larger buildings."
}], "Endnote",
 CellChangeTimes->{{3.531966862490946*^9, 3.5319668930766954`*^9}, {
  3.5319669262615933`*^9, 3.531966930537838*^9}, {3.5319984644057503`*^9, 
  3.5319984644117503`*^9}, {3.539177004292678*^9, 3.539177004293678*^9}},
 CellTags->"endnote1",ExpressionUUID->"b3009463-b40e-4460-8fa3-3f0af7ed7d3d"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]],ExpressionUUID->
  "92f72aa9-358d-4b3f-a15d-b1a9d2f4bea8"],
 " There is an even more perverse incentive in some management contracts that \
pay the manager a fixed fee when tenants turnover. The problems this \
engenders are too obvious to address at any length here."
}], "Endnote",
 CellChangeTimes->{{3.5319984665518727`*^9, 3.531998480230655*^9}, {
  3.5320269310429487`*^9, 3.5320269310489492`*^9}, {3.539177004293678*^9, 
  3.5391770042946777`*^9}},
 CellTags->"endnote2",ExpressionUUID->"512df4dc-4f4f-4a0e-87ea-f8d6b3b2f162"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "3"], TraditionalForm]],ExpressionUUID->
  "d303e6db-a542-440a-8cb0-1c60b3da2b7d"],
 " To keep the profit positive in the rent range for our example it is \
necessary to constrain locations to 3, and accounting costs to 10. More about \
this later."
}], "Endnote",
 CellChangeTimes->{{3.532026932797049*^9, 3.532026953342224*^9}, {
  3.5320279138591623`*^9, 3.532027915824275*^9}, {3.5391770042946777`*^9, 
  3.539177004295678*^9}},
 CellTags->"endnote3",ExpressionUUID->"ca39658a-6f89-4471-b226-bba1b245bf56"],

Cell["References", "ReferenceSection",
 CellChangeTimes->{{3.5320565092577257`*^9, 3.5320565114648523`*^9}, 
   3.539177004295678*^9},ExpressionUUID->"6873e46f-3a9d-43af-b980-\
9565d5d79881"],

Cell[TextData[{
 "Institute of Real Estate Management. (1991). ",
 StyleBox["Principles of Real Estate Management",
  FontVariations->{"Underline"->True}],
 ". Chicago, IL: Institute of Real Estate Management."
}], "Reference",
 CellChangeTimes->{{3.5320565201143465`*^9, 3.5320565539632826`*^9}, 
   3.539177004295678*^9, {3.539179727646445*^9, 3.539179745644474*^9}, 
   3.5400556598265667`*^9},ExpressionUUID->"24fad992-02cf-40c9-a254-\
be810d57dddb"],

Cell[TextData[{
 "Jensen, M. C. , & Meckling, W. H. (1976). Theory of the Firm: Managerial \
Behavior, Agency Costs and Ownership Structure. ",
 StyleBox["Journal of Financial Economics, ",
  FontVariations->{"Underline"->True}],
 "3, 305-360."
}], "Reference",
 CellChangeTimes->{{3.5320565201143465`*^9, 3.5320565584505396`*^9}, 
   3.539177004295678*^9, 
   3.5400556618716836`*^9},ExpressionUUID->"9a8033a0-15c5-4273-b776-\
153dffb256ed"],

Cell[TextData[{
 "Wei, J. (1975). Least Square Fitting of an Elephant. ",
 StyleBox["CHEMTECH, 5",
  FontVariations->{"Underline"->True}],
 "(2), 128-129."
}], "Reference",
 CellChangeTimes->{{3.5320565201143465`*^9, 3.5320565595656033`*^9}, 
   3.539177004295678*^9, 3.540055663280764*^9, 
   3.5412548172173195`*^9},ExpressionUUID->"5d036c94-f01c-4dbd-b22d-\
78637657ad92"],

Cell["Problems", "ExerciseSection",
 CellChangeTimes->{{3.532056589617322*^9, 3.5320565913714223`*^9}, 
   3.539177004295678*^9},ExpressionUUID->"f1697f94-15e7-41af-a688-\
b037c1067749"],

Cell["\<\
Using Equation 11.8 compute the optimal locations when d = 1.4\
\>", "Item1Exercise",
 CellChangeTimes->{{3.5320565974907722`*^9, 3.5320565974987726`*^9}, {
   3.533331304449502*^9, 3.533331317810266*^9}, 
   3.539177004296678*^9},ExpressionUUID->"1a65c771-d7fe-4508-b831-\
88e76c506689"],

Cell["\<\
Using the format of Table 11.1 create a dataset with different variables and \
compute the owner and the manager\[CloseCurlyQuote]s separate optimal \
scheduled rent. How does your result differ from those shown in this chapter? \
To what do you attribute the difference?\
\>", "Item1Exercise",
 CellChangeTimes->{
  3.541255451021571*^9},ExpressionUUID->"98381d37-48e4-4529-ab3f-\
9c292eb498ed"],

Cell[CellGroupData[{

Cell["Appendix A: Caution on the use of data to construct theories", \
"AppendixSection",
 CellChangeTimes->{
  3.539177004297678*^9, {3.698596976327793*^9, 
   3.6985969982232256`*^9}},ExpressionUUID->"bfe46b9d-e74c-49c5-ae42-\
40835e0fbfe0"],

Cell["\<\
The model in this chapter has some deficiencies. This Appendix is designed to \
propose a correction but at the same time make a point about how far one may \
go to mathematically model a process.\
\>", "Text",
 CellChangeTimes->{
  3.539177004297678*^9},ExpressionUUID->"3b10b7cb-1ac6-4f3d-bc5d-\
cab7f23bc27c"],

Cell["Making vacancy and rental rates reasonable", "Subsection",
 CellChangeTimes->{
  3.539177004297678*^9},ExpressionUUID->"4a3f87e1-27b9-46bd-89de-\
623a6a1d771d"],

Cell["\<\
Recall that we complained of the requirement to have either unrealistic \
vacancy rates or unrealistic scheduled rent, at least on a per unit basis. \
Let's see what it takes to repair this problem.\
\>", "Text",
 CellChangeTimes->{
  3.539177004297678*^9},ExpressionUUID->"324459a7-23f6-476e-9ec2-\
316e30561f7d"],

Cell[TextData[{
 "Defining a new function for collected rent, ",
 StyleBox["crOpt",
  FontSlant->"Italic"],
 ", one can use Equation 11.20 and its derivative Equation 11.21 to \
demonstrate optimum rent at a so-called \"market vacancy rate\".  This \
involves fixing a value for \[Alpha] and finding roots for the remaining \
variables, \[Beta] and scheduled rent.  Below is an example of the sort of \
thing one can do, however ill-advised, with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.532117929696774*^9, 3.532117955908273*^9}, 
   3.539177004297678*^9},ExpressionUUID->"fbcdb526-4b9a-4fb4-9339-\
e6af5f1d9cc9"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"crOpt", "=", 
    RowBox[{
     StyleBox[
      RowBox[{"sr", "+", "1", "-"}],
      FontSlant->"Italic"], " ", 
     SuperscriptBox["\[Alpha]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Beta]", " ", "sr"}], ")"}], "6"]]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5320566899320593`*^9, 
  3.539177004297678*^9},ExpressionUUID->"966dcd7e-08f8-4294-99fe-\
57845e88c4e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"crOpt", "=", 
   RowBox[{"sr", "+", "1", "-", " ", 
    SuperscriptBox["\[Alpha]", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Beta]", " ", "sr"}], ")"}], "6"]]}]}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.539177004297678*^9},ExpressionUUID->"b68d1134-58cc-4bc3-bc55-\
454bdc5dbc05"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", "crOpt"}], 
     RowBox[{"\[PartialD]", "sr"}]], "=", 
    RowBox[{"1", "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["sr", "5"], " ", 
      SuperscriptBox["\[Alpha]", 
       RowBox[{
        SuperscriptBox["sr", "6"], " ", 
        SuperscriptBox["\[Beta]", "6"]}]], " ", 
      SuperscriptBox["\[Beta]", "6"], " ", 
      RowBox[{
       StyleBox["Log",
        FontSlant->"Italic"], "[", "\[Alpha]", "]"}]}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.532056732683505*^9, {3.5320572839320345`*^9, 3.5320573167309103`*^9}, 
   3.539177004298678*^9},ExpressionUUID->"f68a920e-a559-45e3-b135-\
b7d244cf8aa2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "sr"], " ", "crOpt"}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.5321179933894167`*^9, {3.5333307018310337`*^9, 3.5333307067703166`*^9}, 
   3.539177004298678*^9},ExpressionUUID->"7e22e402-1df1-41b5-a4e0-\
a116dbca6bc1"],

Cell["\<\
Fixing \[Alpha] = 1.3, at 5% vacancy we have optimal scheduled rent at just \
under $500 per month.\
\>", "Text",
 CellChangeTimes->{{3.5320568109379807`*^9, 3.5320568258108315`*^9}, 
   3.539177004298678*^9},ExpressionUUID->"bf2a2686-beb1-4bf4-bc32-\
c24428ebe89c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pr", "=", 
   RowBox[{"Quiet", "[", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{".95", "sr"}], "\[Equal]", "crOpt"}], ",", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[PartialD]", "sr"], " ", "crOpt"}], "\[Equal]", 
            "0"}]}], "}"}], ")"}], "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", "1.3"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"sr", ",", "600"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", ".003"}], "}"}], ",", 
      RowBox[{"MaxIterations", "\[Rule]", "50"}]}], "]"}], "]"}]}], ";", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"TextCell", "[", 
    RowBox[{
     RowBox[{"\"\<Optimal scheduled rent at 5% vacancy is $\>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"AccountingForm", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"pr", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "2"}], "}"}]}], "]"}], "]"}]}], ",", 
     "\"\<Text\>\""}], "]"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.5333308577119503`*^9, 
   3.5333308761390038`*^9}, {3.5333309073947916`*^9, 3.5333309257848434`*^9}, 
   3.539177004299678*^9},ExpressionUUID->"4deb2561-0f82-4ed4-b4da-\
d2fe6c99d010"],

Cell["Optimal scheduled rent at 5% vacancy is $469.21", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731421860066929*^9},ExpressionUUID->"f3428b5b-85be-4239-bc09-\
4206b5c4cb8a"]
}, Open  ]],

Cell["\<\
Figure 11.16 shows how the 95% occupancy line intersects the crOpt function \
at its apex under these conditions.\
\>", "Text",
 CellChangeTimes->{{3.532118180642127*^9, 3.532118184646356*^9}, 
   3.5391770043006783`*^9},ExpressionUUID->"448a04ad-80d4-463c-9972-\
757738e51560"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Legended", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{".95", "sr"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"crOpt", "/.", 
          RowBox[{"\[Alpha]", "\[Rule]", "1.3"}]}], ")"}], "/.", "pr"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sr", ",", "400", ",", "500"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"400", ",", "500"}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "469.21", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{".95", " ", "469.21"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"400", ",", "469.21", ",", "500"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"400", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{".95", " ", "469.21"}], ",", "\"\<445.75\>\""}], "}"}], 
          ",", "500"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Scheduled Rent\>\"", ",", "\"\<Collected Rent\>\""}], 
       "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", "Blue", ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", "Red", ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], "}"}]}], 
     RowBox[{"(*", 
      RowBox[{",", 
       RowBox[{"PlotLegend", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<95% of Scheduled Rent\>\"", ",", "\"\<Collected Rent\>\""}], 
         "}"}]}], ",", 
       RowBox[{"LegendSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1.15", ",", ".15"}], "}"}]}], ",", 
       RowBox[{"LegendPosition", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", ".6"}], ",", ".4"}], "}"}]}]}], "*)"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], ",", 
   RowBox[{"Placed", "[", 
    RowBox[{
     RowBox[{"LineLegend", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", "Blue", ",", 
           RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", "Red", ",", 
           RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<95% of Scheduled Rent\>\"", ",", "\"\<Collected Rent\>\""}], 
        "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{".5", ",", ".9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.411776570328125*^9, {3.532057198520149*^9, 3.532057204265478*^9}, {
   3.5321182782407093`*^9, 3.532118367310804*^9}, {3.5321187676567025`*^9, 
   3.5321188702015676`*^9}, {3.5321189026084213`*^9, 3.5321189591696568`*^9}, 
   3.5391770043016787`*^9, {3.586810939064686*^9, 3.5868110162200994`*^9}, {
   3.58681108005875*^9, 3.586811122523179*^9}, {3.586811178146361*^9, 
   3.5868112403489184`*^9}},ExpressionUUID->"b27b521f-9753-4603-bb28-\
d631245e8139"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
        AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwdznlMU3cAB/DCyJiGo5jCnMC2ghexk6uCcn6jiEABuWYol0uDAsrV4Qx9
7/36xiEQokgYoCCmIkoRFIRxhA3KhgsDNpihDiIqOByHWMEl4BqBsbd9k2++
+fz3FcoyIk4Z8ng8b67/rdnsgfKJMAq8/6NAVk+SVd5pCto+S7tKgQKKUouO
ygsU6lse6q1dFOAbJFeFqinUVC/77YxQwHX6wcxPAxS8j6VNGGcqMC/9VT69
QMFwOXQ6rVQBbXhSbMxWGss/eHp73VdA0mXc+I0DjcKowj9mRxSI6o7ykUto
HHnhtmaxpMDLvWp307M0Gl2Pxn5kQsH8QP35kEs0xGyXU52IQrrGnb/UTGNh
RRxXEUwhumPULGSUhr/IYlR2hsKjgG2RYW9oDCWEd7QVU3gSGLtuwWfwNuLN
zLMGCtaDbjyxI4NgefVpOfdbN6MJfBfGYKC44WThHIXAs8F6ZSaDV6csVdlG
NNxLC3TqMgZir7lI3U4a8S6Rns7tDG579ScM+tEwP7xrOVvL4Md/1ltYGY2I
pbqFxFUGBj3Xznfn0hB+sPeYuSWBzqMqb/QGDQeVD2+HmID3Z+2cREOjf8xg
c/BzgoNFZn2SKRrzWcMyt68IrJceP9u9TuN6q69JwBUCu+Nbvsy3YTAd992O
7V0EWvmV4F4PBtILP+cFjBM0a5xIQjSDxKAcF1s9QdP7++1zsxmsMfC//6ES
Ufxi85xKBvbBd1Xzh5QQWgbJDbsY5F1tjGRjlbDys3TQjTPIiGhO/Z1SolPs
u6d1hYGuIeGX32qUUHw6Uq0XEKymCi4X9SixMNIdZe1K4N4cd6/2iRI5t1sT
68MItl4Mtzi5oYRXtunit5kEKROSyUkbFnUmgx01JQQ92yfTk2xZtA0vHLa7
TMCPSX5vhXN/0ZaHas6dT/NFpp+weG4kWWwrJTCc6VX6CllYb4x8PFRGUK1z
tL+1i0XZa23haiXBsIEgNW0/i69Hp6WhKgLbIzd57ziXXOTNazln5jtVFDiy
uB4kPCe9QWBlHKJRObH4fkBWklhLIDMp4I+5sHirme2n6gjWrPTtbu4s0lte
7VOrCUKjCwIfcCZpJt2iBoKbVYKp4wdZXNr3mX8b5wAbZ+OUQywa1elf9N4h
KBeekV7zZDGn+qtc20QwL9O/3uPFYjV+m530LoHHrYLcds5GNq4tU5yf765r
GvFmIbx6bujlPQLXZGfE+LBwOlFxIqOZoOBO36M5zr6CzhcrnB8vhqRk+bII
HRvPpFoIRKKnG5uc40v/3tjk/C/Pu72y
         "]]},
       Annotation[#, "Charting`Private`Tag$3457#1"]& ], 
      TagBox[
       {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
        AbsoluteDashing[{0, 0}], LineBox[CompressedData["
1:eJw92Hk4Vd33AHBDNMiQRElFEUUoylSsFBUypxIZMiVTpNx7zj6iyCsKlSih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         "]]},
       Annotation[#, "Charting`Private`Tag$3457#2"]& ]}, {}, {}}, InsetBox[
     TemplateBox[{"\"95% of Scheduled Rent\"","\"Collected Rent\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteDashing[{2, 5}], 
                    RGBColor[0, 0, 1], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteDashing[{2, 5}], 
                    RGBColor[0, 0, 1], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteDashing[{0, 0}], 
                    RGBColor[1, 0, 0], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteDashing[{0, 0}], 
                    RGBColor[1, 0, 0], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& )], Scaled[{0.5, 0.9}], 
     ImageScaled[{1, 1}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{400.0000020408163, 400},
   DisplayFunction->Identity,
   Frame->{{True, False}, {True, False}},
   FrameLabel->{{
      FormBox["\"Collected Rent\"", TraditionalForm], None}, {
      FormBox["\"Scheduled Rent\"", TraditionalForm], None}},
   FrameTicks->{{{{400, 
        FormBox["400", TraditionalForm]}, {445.74949999999995`, 
        FormBox["\"445.75\"", TraditionalForm]}, {500, 
        FormBox["500", TraditionalForm]}}, {{400, 
        FormBox["400", TraditionalForm]}, {445.74949999999995`, 
        FormBox["\"445.75\"", TraditionalForm]}, {500, 
        FormBox["500", TraditionalForm]}}}, {{{400, 
        FormBox["400", TraditionalForm]}, {469.21, 
        FormBox["469.21`", TraditionalForm]}, {500, 
        FormBox["500", TraditionalForm]}}, {{400, 
        FormBox["400", TraditionalForm]}, {469.21, 
        FormBox["469.21`", TraditionalForm]}, {500, 
        FormBox["500", TraditionalForm]}}}},
   GridLines->{{469.21}, {445.74949999999995`}},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->500,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{400.0000020408163, 499.9999979591837}, {400, 500}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteDashing[{2, 5}], 
           RGBColor[0, 0, 1], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwdznlMU3cAB/DCyJiGo5jCnMC2ghexk6uCcn6jiEABuWYol0uDAsrV4Qx9
7/36xiEQokgYoCCmIkoRFIRxhA3KhgsDNpihDiIqOByHWMEl4BqBsbd9k2++
+fz3FcoyIk4Z8ng8b67/rdnsgfKJMAq8/6NAVk+SVd5pCto+S7tKgQKKUouO
ygsU6lse6q1dFOAbJFeFqinUVC/77YxQwHX6wcxPAxS8j6VNGGcqMC/9VT69
QMFwOXQ6rVQBbXhSbMxWGss/eHp73VdA0mXc+I0DjcKowj9mRxSI6o7ykUto
HHnhtmaxpMDLvWp307M0Gl2Pxn5kQsH8QP35kEs0xGyXU52IQrrGnb/UTGNh
RRxXEUwhumPULGSUhr/IYlR2hsKjgG2RYW9oDCWEd7QVU3gSGLtuwWfwNuLN
zLMGCtaDbjyxI4NgefVpOfdbN6MJfBfGYKC44WThHIXAs8F6ZSaDV6csVdlG
NNxLC3TqMgZir7lI3U4a8S6Rns7tDG579ScM+tEwP7xrOVvL4Md/1ltYGY2I
pbqFxFUGBj3Xznfn0hB+sPeYuSWBzqMqb/QGDQeVD2+HmID3Z+2cREOjf8xg
c/BzgoNFZn2SKRrzWcMyt68IrJceP9u9TuN6q69JwBUCu+Nbvsy3YTAd992O
7V0EWvmV4F4PBtILP+cFjBM0a5xIQjSDxKAcF1s9QdP7++1zsxmsMfC//6ES
Ufxi85xKBvbBd1Xzh5QQWgbJDbsY5F1tjGRjlbDys3TQjTPIiGhO/Z1SolPs
u6d1hYGuIeGX32qUUHw6Uq0XEKymCi4X9SixMNIdZe1K4N4cd6/2iRI5t1sT
68MItl4Mtzi5oYRXtunit5kEKROSyUkbFnUmgx01JQQ92yfTk2xZtA0vHLa7
TMCPSX5vhXN/0ZaHas6dT/NFpp+weG4kWWwrJTCc6VX6CllYb4x8PFRGUK1z
tL+1i0XZa23haiXBsIEgNW0/i69Hp6WhKgLbIzd57ziXXOTNazln5jtVFDiy
uB4kPCe9QWBlHKJRObH4fkBWklhLIDMp4I+5sHirme2n6gjWrPTtbu4s0lte
7VOrCUKjCwIfcCZpJt2iBoKbVYKp4wdZXNr3mX8b5wAbZ+OUQywa1elf9N4h
KBeekV7zZDGn+qtc20QwL9O/3uPFYjV+m530LoHHrYLcds5GNq4tU5yf765r
GvFmIbx6bujlPQLXZGfE+LBwOlFxIqOZoOBO36M5zr6CzhcrnB8vhqRk+bII
HRvPpFoIRKKnG5uc40v/3tjk/C/Pu72y
           "]]}, "Charting`Private`Tag$3457#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteDashing[{0, 0}], 
           RGBColor[1, 0, 0], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJw92Hk4Vd33AHBDNMiQRElFEUUoylSsFBUypxIZMiVTpNx7zj6iyCsKlSih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           "]]}, "Charting`Private`Tag$3457#2"]}}, {}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {400.0000020408163, 400}, 
      FrameTicks -> {{{400, {445.74949999999995`, "445.75"}, 500}, {
         400, {445.74949999999995`, "445.75"}, 500}}, {{400, 469.21, 500}, {
         400, 469.21, 500}}}, GridLines -> {{469.21}, {445.74949999999995`}}, 
      DisplayFunction -> Identity, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}}, PlotRangeClipping -> True, ImagePadding -> 
      All, DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, AxesLabel -> {None, None}, 
      AxesOrigin -> {400.0000020408163, 400.}, DisplayFunction :> Identity, 
      Frame -> {{True, False}, {True, False}}, 
      FrameLabel -> {{"Collected Rent", None}, {"Scheduled Rent", None}}, 
      FrameTicks -> {{{400, {445.74949999999995`, "445.75"}, 500}, {
         400, {445.74949999999995`, "445.75"}, 500}}, {{400, 469.21, 500}, {
         400, 469.21, 500}}}, GridLines -> {{469.21}, {445.74949999999995`}}, 
      GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImageSize -> 500, 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, 
      PlotRange -> {{400.0000020408163, 499.9999979591837}, {400, 500}}, 
      PlotRangeClipping -> True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {Automatic, Automatic}}, 
      Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[
         AbsoluteDashing[{2, 5}], 
         RGBColor[0, 0, 1], 
         AbsoluteThickness[2]], 
        Directive[
         AbsoluteDashing[{0, 0}], 
         RGBColor[1, 0, 0], 
         AbsoluteThickness[2]]}, {
       "95% of Scheduled Rent", "Collected Rent"}]], {{0.5, 0.9}, {1, 1}}, 
     Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.411947051890625*^9, 3.5320572060565805`*^9, 3.532118170623554*^9, 
   3.5321183146047897`*^9, 3.5321183682518578`*^9, {3.532118774067069*^9, 
   3.5321188399348364`*^9}, 3.5321188710176144`*^9, {3.5321189034014664`*^9, 
   3.532118960348724*^9}, 3.5321232859731355`*^9, 3.5322123450550237`*^9, 
   3.533320455629985*^9, 3.5336850336875*^9, 3.5337445017058334`*^9, 
   3.53375694375*^9, 3.5337569944375*^9, 3.539176859707408*^9, 
   3.53917700433068*^9, 3.540053816525136*^9, 3.5400550199029655`*^9, 
   3.540128584220708*^9, 3.5412484670571113`*^9, 3.5412499340430183`*^9, 
   3.541604930083503*^9, 3.5433495114258833`*^9, 3.586808619019987*^9, 
   3.5868111237492495`*^9, {3.5868112226029034`*^9, 3.586811240776943*^9}, 
   3.6983497493178616`*^9, 3.698349861355796*^9, 3.7314218602112856`*^9},
 TextAlignment->Center,ExpressionUUID->"3f89c632-b343-47e4-ae1f-d2631da8f406"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.16.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Optimized collected rent with a 6th order function for vacancy"
}], "FigureCaption",
 CellMargins->{{85.33333333333333, 10.}, {6., 2.}},
 CellChangeTimes->{{3.532118144087036*^9, 3.5321181596979294`*^9}, 
   3.5391770043316803`*^9, 3.5412530084908667`*^9},
 TextAlignment->Center,ExpressionUUID->"0523f7c0-b6a2-4a42-a4e4-50a58ae957ae"],

Cell["\<\
The procedure above requires a sixth order function, something unlikely to \
exist in nature.  The interaction of market forces that produce market \
vacancy is a complex process.  Our purpose was not to solve a general \
equilibrium problem for the housing market here.  Thus, hearing Sir Occam \
sharpening his razor in the background, we assert without proof that \
empirical results elsewhere indicate that scheduled rent is optimized in the \
area where vacancy is around 5% and return to the model in the chapter.\
\>", "Text",
 CellChangeTimes->{{3.53205724800698*^9, 3.5320572495130663`*^9}, 
   3.5391770043316803`*^9},ExpressionUUID->"462a4d4a-4e72-44ff-a6b3-\
cf48c39f6fb3"],

Cell["The model to end all models", "Subsection",
 CellChangeTimes->{
  3.5391770043316803`*^9},ExpressionUUID->"0c2dec00-09a7-45f0-a267-\
ddbf6ed90821"],

Cell[TextData[{
 "We have made the point on several occasions that one can get in trouble \
with simplifying assumptions. Examples include: assuming that there is a \
linear relationship between variables or that data are distributed normally. \
At the other extreme, one must be careful not to over-complicate. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is often the perfect tool to explain a complex process but one may, while \
not taxing ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " in the least, still strain credulity. One must exercise care in \
\"back-fitting\" a pet theory to data. In the hands of one who is inclined to \
\"prove anything with numbers\" ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is a powerful and perhaps dangerous tool. "
}], "Text",
 CellChangeTimes->{{3.532118998546909*^9, 3.5321190072314053`*^9}, {
   3.532119051051912*^9, 3.5321190541590896`*^9}, {3.539176934607692*^9, 
   3.539176935187725*^9}, 3.5391770043316803`*^9, 
   3.6986008630892534`*^9},ExpressionUUID->"0909a0e0-a21f-4dda-8de1-\
aa1fe5dc0248"],

Cell["\<\
Suppose we are presented with the 27 observations of paired data in Table \
11.2 representing as the first element in each pair the predictions of market \
returns made by economists; and as the second element the actual outcomes.\
\>", "Text",
 CellChangeTimes->{{3.532119096946537*^9, 3.532119097124547*^9}, {
   3.5333309712434435`*^9, 3.5333309738195906`*^9}, 
   3.5391770043316803`*^9},ExpressionUUID->"683d47b2-f207-448e-b998-\
89d6b212f8be"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"el1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.0509461", ",", "0.282387"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0727802", ",", "0.449782"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.131004", ",", "0.503639"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.343523", ",", "0.521106"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.537118", ",", "0.508006"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.710335", ",", "0.475983"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.826783", ",", "0.490539"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.921397", ",", "0.474527"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.967977", ",", "0.393013"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.959243", ",", "0.152838"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.935953", ",", "0.151383"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.922853", ",", "0.305677"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.921397", ",", "0.224163"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.908297", ",", "0.259098"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.845706", ",", "0.279476"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.815138", ",", "0.317322"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.809316", ",", "0.0320233"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.714702", ",", "0.0320233"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.694323", ",", "0.213974"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.57933", ",", "0.212518"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.286754", ",", "0.253275"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.215429", ",", "0.200873"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.174672", ",", "0.0349345"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0873362", ",", "0.0393013"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0917031", ",", "0.270742"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0800582", ",", "0.379913"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0509461", ",", "0.283843"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{"el1", ",", 
     RowBox[{"TableHeadings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Predicted\>\"", ",", "\"\<Actual\>\""}], "}"}]}], 
       "}"}]}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.411777709171875*^9, 3.41177772621875*^9}, {
   3.4119453621875*^9, 3.411945371265625*^9}, {3.5321193910783606`*^9, 
   3.532119431017645*^9}, {3.5333309879924016`*^9, 3.5333309988820243`*^9}, 
   3.5391770043316803`*^9},ExpressionUUID->"7b4179df-5abf-4342-970a-\
fa0f1f5263ec"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Predicted\"\>",
        HoldForm], 
       TagBox["\<\"Actual\"\>",
        HoldForm]},
      {"0.0509461`", "0.282387`"},
      {"0.0727802`", "0.449782`"},
      {"0.131004`", "0.503639`"},
      {"0.343523`", "0.521106`"},
      {"0.537118`", "0.508006`"},
      {"0.710335`", "0.475983`"},
      {"0.826783`", "0.490539`"},
      {"0.921397`", "0.474527`"},
      {"0.967977`", "0.393013`"},
      {"0.959243`", "0.152838`"},
      {"0.935953`", "0.151383`"},
      {"0.922853`", "0.305677`"},
      {"0.921397`", "0.224163`"},
      {"0.908297`", "0.259098`"},
      {"0.845706`", "0.279476`"},
      {"0.815138`", "0.317322`"},
      {"0.809316`", "0.0320233`"},
      {"0.714702`", "0.0320233`"},
      {"0.694323`", "0.213974`"},
      {"0.57933`", "0.212518`"},
      {"0.286754`", "0.253275`"},
      {"0.215429`", "0.200873`"},
      {"0.174672`", "0.0349345`"},
      {"0.0873362`", "0.0393013`"},
      {"0.0917031`", "0.270742`"},
      {"0.0800582`", "0.379913`"},
      {"0.0509461`", "0.283843`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$, TableHeadings -> {None, {"Predicted", "Actual"}}]]],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.532119432248715*^9, 3.5321232860961423`*^9, 
  3.5322123452120323`*^9, 3.533320455843997*^9, 3.5333309996000657`*^9, 
  3.53368503396875*^9, 3.5337445022918663`*^9, 3.533756943875*^9, 
  3.533756994578125*^9, 3.539176859842416*^9, 3.5391770043326797`*^9, 
  3.540053817175173*^9, 3.540055020050974*^9, 3.540128584831743*^9, 
  3.541248467979164*^9, 3.541249934848064*^9, 3.5416049307975435`*^9, 
  3.543349511491887*^9, 3.586808619033988*^9, 3.6983497493349113`*^9, 
  3.6983498613708086`*^9, 3.731421860235351*^9},
 TextAlignment->Center,ExpressionUUID->"a12696df-d0dd-4dfa-a979-a82198b33fa1"],

Cell[TextData[{
 StyleBox["Table 11.2.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "TableTitleLabel"],
 "Economists' prediction and actual realizations"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{62, 10}, {1, 7}},
 CellChangeTimes->{3.5391770043326797`*^9},
 TextAlignment->Center,ExpressionUUID->"8e51c144-2182-4627-b9e3-5713ee6902d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CellPrint", "[", 
  RowBox[{"TextCell", "[", 
   RowBox[{
    RowBox[{
    "\"\<We wonder if there is a correlation and calculate the Person \
correlation to get \>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"Correlation", "[", 
       RowBox[{
        RowBox[{"el1", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"el1", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], "<>", 
     "\"\<. The correlation appears non-existent. How can this be? There must \
be SOME relationship between what economists say and what happens.  \
Undaunted, we plot the data.  LO AND BEHOLD!! What do we see in Figure 11.17? \
A PATTERN!! \>\""}], ",", "\"\<Text\>\""}], "]"}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.532530398299035*^9, 3.5325304023550425`*^9}, {
   3.5325304330134964`*^9, 3.5325306903396473`*^9}, {3.532530725324909*^9, 
   3.5325307493826513`*^9}, {3.5333310306688423`*^9, 3.533331064057752*^9}, {
   3.533331099842799*^9, 3.533331110189391*^9}, {3.533331149028612*^9, 
   3.53333115650804*^9}, 3.53917700433368*^9, {3.541253036207452*^9, 
   3.541253036406463*^9}},ExpressionUUID->"1a085106-bb19-4078-8213-\
714a4d56374c"],

Cell["\<\
We wonder if there is a correlation and calculate the Person correlation to \
get -0.0368665. The correlation appears non-existent. How can this be? There \
must be SOME relationship between what economists say and what happens.  \
Undaunted, we plot the data.  LO AND BEHOLD!! What do we see in Figure 11.17? \
A PATTERN!! \
\>", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.7314218602544236`*^9},ExpressionUUID->"9d80d3b0-ff14-4f3b-902b-\
f8496231f54e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig11a", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"el1", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "0.02", "]"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.41194531996875*^9, 
  3.53917700433368*^9},ExpressionUUID->"2ba636e5-7a5f-4d9e-85c0-c139e1c76f38"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQ3bh2e9Fs0VX2jEYlbxYIXbJ/fOe00s6Fm+yFxEQL
rU7esU+Zesl475ED9k7r7TvPyz6wXyM/+4n7n6v2j3+V1z5b88De5WeTmJDB
Q3uD+tYzUx0f2Fd3uJUL7H5mz/12Tlpj2T37UwU28xlLX9nLp8/a8Dflvn2X
7ZZ+0Zq39rFZLXXL4u7Zh34/8WzVz3f2zicq/8ur37SvDLdNkNv0zn4+82lB
owmH7af82rQl+PNb+3nnRJe2JBy2f1h3gJm54639mdcdzmYTLsPNS5n8pyN+
4xn76wcP3jsi8NY+OUH2OP/UC/YH/zawswm8tr8swuj3/tFF+3Cncs85oq/s
N3kIv2fwv2Kvqcqy+tXTl/abW7KXRKcusM+I6Nl17d4zOF+qy/reE/Nn9l/u
STA1JJ+2535fJHi/85H9zJvPDU8Zn7a/e/F/kW7UJfubtpURK0wv2H8VPpen
O/m0/Vn5y7dMtp20v1V4+P2y6GNQ+xfaGx096LUqeps9U27iGR/5JfZfpQq3
36rcbi999aXDteCL9lwXj23bWLfF/u6FKXPrAm7Yw+Jn/ZaeK9Val+wB92rf
YA==
      "]]}, {}}, {}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.967977}, {0, 0.521106}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4119470526875*^9, 3.5321232861981487`*^9, 
  3.532212346060081*^9, 3.533320456626042*^9, 3.533685034296875*^9, 
  3.5337445031299143`*^9, 3.53375694415625*^9, 3.53375699484375*^9, 
  3.539176860025426*^9, 3.539177004349681*^9, 3.540053818230233*^9, 
  3.5400550201859813`*^9, 3.540128585705793*^9, 3.5412484691202292`*^9, 
  3.541249935941127*^9, 3.5416049320046124`*^9, 3.5433495115778923`*^9, 
  3.58680861906999*^9, 3.6983497494341383`*^9, 3.6983498614701*^9, 
  3.7314218603265924`*^9},
 TextAlignment->Center,ExpressionUUID->"3cb3dcb9-e91c-4ae3-a4fc-83b3d79f2048"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.17.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Plot of economists' prediction and actual outcomes."
}], "FigureCaption",
 CellMargins->{{85.33333333333333, 10.}, {6., 2.}},
 CellChangeTimes->{{3.532118144087036*^9, 3.5321181596979294`*^9}, 
   3.539177004349681*^9},
 TextAlignment->Center,ExpressionUUID->"b542a433-a548-4476-84ee-437de38b5bd5"],

Cell["\<\
We wish heartily that our data support a \"theory\" that there is some \
functional relationship between what economists say and what actually happens.\
\>", "Text",
 CellChangeTimes->{3.5321196010083675`*^9, 3.539177004349681*^9, 
  3.5400549480858574`*^9},ExpressionUUID->"ee258d64-baf8-4a04-b543-\
939fbd251de3"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is equal to the task. The Interpolation function fits polynomial curves \
between successive data points. A table is then created that increases the \
number of points, all equally spaced. The choice of InterpolationOrder = 1 \
avoids filtering by the Interpolation process and ensures that all the new \
points fall on the lines created by connecting the original points."
}], "Text",
 CellChangeTimes->{{3.5321196010083675`*^9, 3.5321196022154365`*^9}, 
   3.539177004349681*^9},ExpressionUUID->"02259672-99cc-41ef-af18-\
b51224306ffa"]
}, Open  ]],

Cell["\<\
In Figure 11.18 we can plot these new points (the left) and connect them (the \
right) to better see the pattern in the data.\
\>", "Text",
 CellChangeTimes->{{3.5321198588211136`*^9, 3.532119883328515*^9}, 
   3.539177004349681*^9},ExpressionUUID->"39cd9c9f-9364-4a88-9318-\
fb5297f14980"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ix1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"el1", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "27"}], "}"}]}], "]"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iy1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"el1", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "27"}], "}"}]}], "]"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"po", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ix1", "[", "n", "]"}], ",", 
       RowBox[{"iy1", "[", "n", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "27"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ex2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ix1", "[", "n", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "27", ",", ".25"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ey2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"iy1", "[", "n", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "27", ",", ".25"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"ln", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"ex2", ",", "ey2"}], "}"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ln", ",", 
     RowBox[{"Show", "[", 
      RowBox[{"po", ",", "ln"}], "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "550"}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5321196377604694`*^9, 3.532119666629121*^9}, {
   3.5321197711180973`*^9, 3.5321198400690413`*^9}, 
   3.539177004351681*^9},ExpressionUUID->"731063cd-8627-4bc1-8456-\
8edeacf5d91c"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxFVX08FPYfP6wHsoW6fsVQm826/aK0tIh3MqrJaj1ML1dol5Vn2vIQZUx+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          "]]}, {}}, {}, {}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 0.967977}, {0, 0.521106}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {192., -109.27378126856352}, 
     ImageScaled[{0.5, 0.5}], {360., 208.14053574964478}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxFm3c81f/7/5GKEspsoD2USCiFh8oIpZDRoLLJCu1kNSRKhQbK3rKJyMw6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           "]]},
         Annotation[#, "Charting`Private`Tag$3587#1"]& ]}, {{}, {{}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.009166666666666668], AbsoluteThickness[1.6], 
          PointBox[CompressedData["
1:eJxFVX08FPYfP6wHsoW6fsVQm826/aK0tIh3MqrJaj1ML1dol5Vn2vIQZUx+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           "]]}, {}}, {}, {}, {}, {}}},
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{"ScalingFunctions" -> None},
      PlotRange->{{0., 0.9679447832938628}, {0., 0.521046923418233}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {576., -109.27378126856352}, 
     ImageScaled[{0.5, 0.5}], {360., 208.14053574964478}]}, {}},
  ContentSelectable->True,
  ImageSize->550,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.411947052796875*^9, 3.532119642623748*^9, 3.5321196730604887`*^9, {
   3.5321198099203167`*^9, 3.5321198404520626`*^9}, 3.5321232862541513`*^9, 
   3.532212346544109*^9, 3.5333204571630726`*^9, 3.533685034421875*^9, 
   3.533744503613942*^9, 3.53375694428125*^9, 3.533756995*^9, 
   3.5391768601354322`*^9, 3.5391770044126844`*^9, 3.54005381922129*^9, 
   3.540055020264986*^9, 3.5401285864938383`*^9, 3.541248470284296*^9, 
   3.5412499370211887`*^9, 3.5416049326756506`*^9, 3.5433495116828985`*^9, 
   3.586808619117993*^9, 3.6983497495935626`*^9, 3.6983498615964355`*^9, 
   3.7314218604509244`*^9},
 TextAlignment->Center,ExpressionUUID->"68676b85-9eaa-4654-bff0-674e863681d6"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.18.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "A more fine-grained look at economists' prediction and actual outcomes"
}], "FigureCaption",
 CellMargins->{{85.33333333333333, 10.}, {6., 2.}},
 CellChangeTimes->{{3.532118144087036*^9, 3.5321181596979294`*^9}, 
   3.5391770044126844`*^9, 3.54125329038799*^9},
 TextAlignment->Center,ExpressionUUID->"bb1b7d11-c01e-42ed-939f-fdb6d47fc915"],

Cell[CellGroupData[{

Cell[TextData[{
 "Using Intersection to find elements common to both lists we confirm that 25 \
of our original 27 ",
 StyleBox["x",
  FontSlant->"Italic"],
 " variables and 26 of the original 27 ",
 StyleBox["y",
  FontSlant->"Italic"],
 " variables are represented. "
}], "Text",
 CellOpen->False,
 CellChangeTimes->{
  3.5391770044126844`*^9},ExpressionUUID->"850ce2ac-4ac9-48c1-af2f-\
4c9affeb563b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Intersection", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"el1", "[", 
       RowBox[{"[", 
        RowBox[{"n", ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "27"}], "}"}]}], "]"}], ",", "ex2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Length", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Intersection", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"el1", "[", 
       RowBox[{"[", 
        RowBox[{"n", ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "27"}], "}"}]}], "]"}], ",", "ey2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Length", "[", "%", "]"}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.532119914273285*^9, 3.5321199152983437`*^9}, 
   3.539177004413685*^9},ExpressionUUID->"17b196e2-4695-4aed-ab82-\
70535b247d4f"]
}, Closed]],

Cell["\<\
James Wei (1975) observed that there is a least square Fourier sine series \
that will fit these coordinates, the equations for which are\
\>", "Text",
 CellChangeTimes->{{3.5321199899306126`*^9, 3.532119999236145*^9}, 
   3.539177004413685*^9},ExpressionUUID->"ac011a65-6bb1-4be4-8997-\
bc30752d49fc"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "t", ")"}], "=", 
   FormBox[
    RowBox[{
     FormBox[
      SubscriptBox["a", "o"],
      TraditionalForm], "+", 
     RowBox[{
      SubscriptBox["\[Sum]", "i"], 
      RowBox[{
       SubscriptBox["a", "i"], " ", 
       StyleBox["sin",
        FontSlant->"Italic"], " ", 
       FractionBox["it\[Pi]", "36"]}]}]}],
    TraditionalForm]}], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5321199469261527`*^9, 
  3.539177004414685*^9},ExpressionUUID->"e4b34c7e-1937-4e96-a8ae-\
369baecc7c39"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "(", "t", ")"}], "=", 
   FormBox[
    RowBox[{
     FormBox[
      SubscriptBox["b", "o"],
      TraditionalForm], "+", 
     RowBox[{
      SubscriptBox["\[Sum]", "i"], 
      RowBox[{
       SubscriptBox["b", "i"], " ", 
       StyleBox["sin",
        FontSlant->"Italic"], " ", 
       FractionBox["it\[Pi]", "36"]}]}]}],
    TraditionalForm]}], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5321199612909746`*^9, 
  3.5391770044156847`*^9},ExpressionUUID->"3fe12ab8-2ecd-4c8b-a07f-\
768a3a3dbfec"],

Cell[TextData[{
 "Professor Wei claimed that the minimum number of terms in the Fourier \
expansion was 30. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " makes this quite easy."
}], "Text",
 CellChangeTimes->{{3.5333312458251486`*^9, 3.5333312521315093`*^9}, 
   3.5391770044156847`*^9},ExpressionUUID->"d4b7b872-cd94-4241-b3e0-\
0ebaac0a5322"],

Cell[TextData[{
 "The question becomes one of finding a sufficient number of terms, beginning \
with an offset term, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "o"], TraditionalForm]],ExpressionUUID->
  "3cd7b360-0c8f-45f3-8f45-71b5e0d19b97"],
 ", the remainder each with a constant coefficient, to create a shape that \
fits the data. In the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " statement below we test with five and find that the fit of the data to our \
model is not too impressive..."
}], "Text",
 CellChangeTimes->{{3.5391770044156847`*^9, 
  3.539177004416685*^9}},ExpressionUUID->"ab558e32-b7cb-412e-a5f2-\
8582ea84810c"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmXc81d8fx21JJUrqq0LKyExFEa+GCmmJKG2UQqWkzCgaQlKSQjIyQta1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     "]]}},
  Axes->True,
  AxesOrigin->{0, 0.1},
  PlotRange->{{0., 0.9575206221806173}, {0.07317555719728001, 
   0.5252198160355187}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 Editable->False,
 CellChangeTimes->{3.411947053359375*^9, 3.532122703291808*^9, 
  3.5391770044306855`*^9},ExpressionUUID->"3c3799ed-8299-4851-9b25-\
8275e03a9516"],

Cell["...but 9 terms is an improvement...", "Text",
 CellChangeTimes->{
  3.5391770044306855`*^9},ExpressionUUID->"ed9533f4-136c-4bf8-963b-\
62343bbc9f29"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwU13k8VF8fB/BSiBCVlESUJS0ISdun0GaJKJSlkqVSyhJFlL2SlKxR2SpL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     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 0.9600185265084339}, {0., 0.5170299482464341}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 Editable->False,
 CellChangeTimes->{3.4119470535*^9, 3.532122721187832*^9, 
  3.5391770044466867`*^9},ExpressionUUID->"7c4ebe7f-d3ee-469c-8c1e-\
4b1d96e25758"],

Cell["...and fifteen makes the fit a very close one.", "Text",
 CellChangeTimes->{
  3.5391770044466867`*^9},ExpressionUUID->"edfef7ad-aae4-4bff-92f2-\
a77de6293e3d"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81H8cxzMymkqDijQks4FC45WRpFBKpEKZlRFFRZPsECqlqYisbEr2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     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  ImageSize->500,
  PlotRange->{{0., 0.96716897604452}, {0., 0.5207593086016181}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 Editable->False,
 CellChangeTimes->{3.4119470536875*^9, 
  3.5391770044626875`*^9},ExpressionUUID->"10627555-1733-473a-8bc9-\
392136817a40"],

Cell["\<\
The conclusion is that there is a 15 term Fourier sine series relationship \
between what economists say and what actually happens!  Or, more likely, the \
correlation value generated at the outset tells a simpler, more accurate (if \
less flattering to economists) story - there is no relationship between the \
two variables.\
\>", "Text",
 CellChangeTimes->{3.5321229579993763`*^9, 
  3.5391770044626875`*^9},ExpressionUUID->"2555106c-82cf-4a12-89fb-\
708fbb7707f5"],

Cell[TextData[{
 "As Professor Wei's elephant had an eye, it is only fair to add the five \
more points to improve our elephant's vision if not appearance. Figure 11.19 \
lets you \[OpenCurlyDoubleQuote]elephant walk\[CloseCurlyDoubleQuote] through \
the number of points required. The message becomes: If you want this elephant \
to have feathers, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can include them in the fit. Have you have found a theory in your data? \
No. Is your client impressed? Perhaps, if your client is Disney Studios."
}], "Text",
 CellChangeTimes->{{3.5321229579993763`*^9, 3.53212295963647*^9}, {
   3.5321231925317907`*^9, 3.5321232174882183`*^9}, 
   3.5391770044626875`*^9},ExpressionUUID->"f61c95f4-e191-4763-a0bb-\
1c0c857cc1f9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"TrigFit", "[", 
    RowBox[{"data_List", ",", " ", "n_Integer", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x_", ",", " ", 
       RowBox[{"x0_:", "0"}], ",", " ", "x1_"}], "}"}]}], "]"}], " ", ":=", 
   "\n", "    ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"issueObsoleteFunMessage", "[", 
      RowBox[{"TrigFit", ",", "\"\<NumericalMath`TrigFit`\>\""}], "]"}], ";", 
     "\n", "\t", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"answer", " ", "=", " ", 
         RowBox[{"SinAndCos", "[", 
          RowBox[{"data", ",", " ", 
           RowBox[{"Min", "[", 
            RowBox[{"n", ",", " ", 
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Length", "[", "data", "]"}], "-", "1"}], ")"}], "/",
                "2"}], "]"}]}], "]"}], ",", "\n", "\t\t\t\t\t\t\t", 
           RowBox[{"2", "Pi", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"x", "-", "x0"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"x1", "-", "x0"}], ")"}]}]}]}], "]"}]}], "}"}], ",", 
       "\n", "\t", 
       RowBox[{"answer", " ", "/;", " ", 
        RowBox[{"answer", " ", "=!=", " ", "$Failed"}]}]}], "\n", "\t", 
      "]"}]}], ")"}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TrigFit", "[", 
    RowBox[{"data_List", ",", " ", "n_Integer", ",", " ", "x_"}], "]"}], " ", 
   ":=", "\n", "    ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"issueObsoleteFunMessage", "[", 
      RowBox[{"TrigFit", ",", "\"\<NumericalMath`TrigFit`\>\""}], "]"}], ";", 
     "\n", "\t", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"answer", " ", "=", " ", 
         RowBox[{"SinAndCos", "[", 
          RowBox[{"data", ",", " ", 
           RowBox[{"Min", "[", 
            RowBox[{"n", ",", " ", 
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Length", "[", "data", "]"}], "-", "1"}], ")"}], "/",
                "2"}], "]"}]}], "]"}], ",", " ", "x"}], "]"}]}], "}"}], ",", 
       "\n", "\t", 
       RowBox[{"answer", " ", "/;", " ", 
        RowBox[{"answer", " ", "=!=", " ", "$Failed"}]}]}], "\n", "\t", 
      "]"}]}], ")"}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"SinAndCos", "[", 
    RowBox[{"data_", ",", " ", "n_", ",", " ", "x_"}], "]"}], " ", ":=", "\n",
    "    ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "fcslist", ",", " ", "clist", ",", " ", "slist", ",", " ", "c0", ",", 
       " ", "len", ",", " ", "k", ",", " ", "rflag"}], "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"len", " ", "=", " ", 
       RowBox[{"Length", "[", "data", "]"}]}], ";", "\n", "\t", 
      RowBox[{"fcslist", " ", "=", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Precision", "[", "data", "]"}], " ", "===", " ", 
          "Infinity"}], ",", " ", 
         RowBox[{"N", "[", "data", "]"}], ",", " ", "data"}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{"rflag", " ", "=", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Union", "[", 
          RowBox[{
           RowBox[{"Im", "[", "fcslist", "]"}], ",", " ", 
           RowBox[{"SameTest", " ", "->", " ", "SameQ"}]}], "]"}], " ", "===",
          " ", 
         RowBox[{"{", "0", "}"}]}], ")"}]}], ";", "\n", "\t", 
      RowBox[{"clist", " ", "=", " ", 
       RowBox[{"Drop", "[", 
        RowBox[{"fcslist", ",", " ", "1"}], "]"}]}], ";", "\n", "\t", 
      RowBox[{"slist", " ", "=", " ", 
       RowBox[{"Reverse", "[", "clist", "]"}]}], ";", "\n", "\t", 
      RowBox[{"fcslist", " ", "=", " ", 
       RowBox[{"Prepend", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"clist", "+", "slist"}], ")"}], "/", "2"}], " ", "+", " ", 
          RowBox[{"I", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"clist", "-", "slist"}], ")"}], "/", "2"}]}]}], ",", " ", 
         RowBox[{"fcslist", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", "\n", "\t", 
      RowBox[{"fcslist", " ", "=", " ", 
       RowBox[{"Fourier", "[", 
        RowBox[{"fcslist", ",", " ", 
         RowBox[{"FourierParameters", " ", "->", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", " ", "1"}], "}"}]}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"VectorQ", "[", 
          RowBox[{"fcslist", ",", " ", "NumberQ"}], "]"}]}], ",", " ", 
        RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", "\n", "\t", 
      RowBox[{"c0", " ", "=", " ", 
       RowBox[{"First", "[", "fcslist", "]"}]}], ";", "\n", "\t", 
      RowBox[{"clist", " ", "=", " ", 
       RowBox[{"Drop", "[", 
        RowBox[{"fcslist", ",", " ", "1"}], "]"}]}], ";", "\n", "\t", 
      RowBox[{"slist", " ", "=", " ", 
       RowBox[{"Reverse", "[", "clist", "]"}]}], ";", "\n", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"clist", ",", " ", "slist"}], "}"}], " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"clist", " ", "+", " ", "slist"}], ",", " ", "n"}], "]"}], 
         ",", " ", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"clist", " ", "-", " ", "slist"}], ",", " ", "n"}], 
          "]"}]}], "}"}]}], ";", "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{"rflag", ",", " ", 
        RowBox[{
         RowBox[{"c0", " ", "=", " ", 
          RowBox[{"Re", "[", "c0", "]"}]}], ";", " ", 
         RowBox[{"clist", " ", "=", " ", 
          RowBox[{"Re", "[", "clist", "]"}]}], ";", " ", 
         RowBox[{"slist", " ", "=", " ", 
          RowBox[{"Re", "[", "slist", "]"}]}]}]}], "]"}], ";", "\n", "\t", 
      RowBox[{"c0", " ", "+", " ", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"k", " ", "x"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"k", ",", " ", "n"}], "}"}]}], "]"}], " ", ".", " ", 
        "clist"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"k", " ", "x"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"k", ",", " ", "n"}], "}"}]}], "]"}], " ", ".", " ", 
        "slist"}]}]}]}], "\n", "\t", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"el1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.0509461", ",", "0.282387"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0727802", ",", "0.449782"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.131004", ",", "0.503639"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.343523", ",", "0.521106"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.537118", ",", "0.508006"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.710335", ",", "0.475983"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.826783", ",", "0.490539"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.921397", ",", "0.474527"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.967977", ",", "0.393013"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.959243", ",", "0.152838"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.935953", ",", "0.151383"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.922853", ",", "0.305677"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.921397", ",", "0.224163"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.908297", ",", "0.259098"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.845706", ",", "0.279476"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.815138", ",", "0.317322"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.809316", ",", "0.0320233"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.714702", ",", "0.0320233"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.694323", ",", "0.213974"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.57933", ",", "0.212518"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.286754", ",", "0.253275"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.215429", ",", "0.200873"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.174672", ",", "0.0349345"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0873362", ",", "0.0393013"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0917031", ",", "0.270742"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0800582", ",", "0.379913"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0509461", ",", "0.283843"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eye", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.864865", ",", "0.372613"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.884084", ",", "0.391832"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.905225", ",", "0.376456"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.886006", ",", "0.357237"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.862943", ",", "0.374535"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ix1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"el1", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "27"}], "}"}]}], "]"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iy1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"el1", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "27"}], "}"}]}], "]"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"po", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ix1", "[", "n", "]"}], ",", 
       RowBox[{"iy1", "[", "n", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "27"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ex2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ix1", "[", "n", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "27", ",", ".25"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ey2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"iy1", "[", "n", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "27", ",", ".25"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"listplot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"el1", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"PointSize", "[", "0.02", "]"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"StringJoin", "[", 
       RowBox[{"\"\<correlation = \>\"", ",", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Correlation", "[", "el1", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"listplot", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"el1", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"PointSize", "[", "0.02", "]"}]}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"StringJoin", "[", 
         RowBox[{"\"\<correlation = \>\"", ",", 
          RowBox[{"ToString", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Correlation", "[", "el1", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"tx", "=", 
     RowBox[{"TrigFit", "[", 
      RowBox[{"ex2", ",", "terms", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"j", "/", "27"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"ty", "=", 
     RowBox[{"TrigFit", "[", 
      RowBox[{"ey2", ",", "terms", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"j", "/", "27"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"eyex", "=", 
     RowBox[{"TrigFit", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"eye", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "5"}], "}"}]}], "]"}], ",", "1", ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["j", "27"], ",", "1"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"eyey", "=", 
     RowBox[{"TrigFit", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"eye", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "5"}], "}"}]}], "]"}], ",", "1", ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["j", "27"], ",", "1"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"pp1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tx", ",", "ty"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "0", ",", "32"}], "}"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"pp2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"tx", ",", "ty"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"eyex", ",", "eyey"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "0", ",", "32"}], "}"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"fitdata", "===", "True"}], "&&", 
       RowBox[{"showeye", "===", "False"}]}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"listplot", ",", "pp1"}], "}"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"500", ",", "350"}], "}"}]}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fitdata", "===", "True"}], "&&", 
       RowBox[{"showeye", "===", "True"}]}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"listplot", ",", "pp2"}], "}"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"500", ",", "350"}], "}"}]}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fitdata", "===", "False"}], "&&", 
       RowBox[{"showeye", "===", "False"}]}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{"listplot", ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"500", ",", "350"}], "}"}]}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fitdata", "===", "False"}], "&&", 
       RowBox[{"showeye", "===", "True"}]}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{"pp2", ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"500", ",", "350"}], "}"}]}]}], "]"}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"terms", ",", "5", ",", "\"\<constants\>\""}], "}"}], ",", "5", 
     ",", "15", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fitdata", ",", "True", ",", "\"\<fit data\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"showeye", ",", "False", ",", "\"\<include eye\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"terms", ",", "fitdata", ",", "showeye"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input",
 CellOpen->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.35696210375764*^9, {3.438199236*^9, 3.43819928*^9}, {3.438200555828125*^9,
    3.438200561890625*^9}, {3.43820122878125*^9, 3.4382012313125*^9}, {
   3.43820190615625*^9, 3.438201914140625*^9}, {3.43820197765625*^9, 
   3.43820197884375*^9}, 3.5321228523813353`*^9, 3.539177004475688*^9},
 CellID->146366557,ExpressionUUID->"d0264414-fbbd-4836-b4ea-b9d8cb981170"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`fitdata$$ = True, $CellContext`showeye$$ = 
    False, $CellContext`terms$$ = 5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`terms$$], 5, "constants"}, 5, 15, 1}, {{
       Hold[$CellContext`fitdata$$], True, "fit data"}, {True, False}}, {{
       Hold[$CellContext`showeye$$], False, "include eye"}, {True, False}}}, 
    Typeset`size$$ = {500., {172., 178.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`terms$3722$$ = 0, $CellContext`fitdata$3727$$ = 
    False, $CellContext`showeye$3728$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`fitdata$$ = True, $CellContext`showeye$$ = 
        False, $CellContext`terms$$ = 5}, "ControllerVariables" :> {
        Hold[$CellContext`terms$$, $CellContext`terms$3722$$, 0], 
        Hold[$CellContext`fitdata$$, $CellContext`fitdata$3727$$, False], 
        Hold[$CellContext`showeye$$, $CellContext`showeye$3728$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`listplot = 
        ListPlot[$CellContext`el1, PlotStyle -> PointSize[0.02], PlotLabel -> 
          StringJoin["correlation = ", 
            ToString[
             Part[
              Part[
               Correlation[$CellContext`el1], 1], 
              2]]]]; $CellContext`tx = $CellContext`TrigFit[$CellContext`ex2, \
$CellContext`terms$$, {$CellContext`j/27, 
           1}]; $CellContext`ty = $CellContext`TrigFit[$CellContext`ey2, \
$CellContext`terms$$, {$CellContext`j/27, 
           1}]; $CellContext`eyex = $CellContext`TrigFit[
          Table[
           Part[$CellContext`eye, $CellContext`i, 1], {$CellContext`i, 5}], 
          1, {$CellContext`j/27, 1}]; $CellContext`eyey = $CellContext`TrigFit[
          Table[
           Part[$CellContext`eye, $CellContext`i, 2], {$CellContext`i, 5}], 
          1, {$CellContext`j/27, 1}]; $CellContext`pp1 = 
        ParametricPlot[{$CellContext`tx, $CellContext`ty}, {$CellContext`j, 0,
            32}, Axes -> False]; $CellContext`pp2 = 
        ParametricPlot[{{$CellContext`tx, $CellContext`ty}, \
{$CellContext`eyex, $CellContext`eyey}}, {$CellContext`j, 0, 32}, Axes -> 
          False]; Which[
         And[$CellContext`fitdata$$ === True, $CellContext`showeye$$ === 
          False], 
         Show[{$CellContext`listplot, $CellContext`pp1}, 
          ImageSize -> {500, 350}], 
         And[$CellContext`fitdata$$ === True, $CellContext`showeye$$ === 
          True], 
         Show[{$CellContext`listplot, $CellContext`pp2}, 
          ImageSize -> {500, 350}], 
         And[$CellContext`fitdata$$ === False, $CellContext`showeye$$ === 
          False], 
         Show[$CellContext`listplot, ImageSize -> {500, 350}], 
         And[$CellContext`fitdata$$ === False, $CellContext`showeye$$ === 
          True], 
         Show[$CellContext`pp2, ImageSize -> {500, 350}]]), 
      "Specifications" :> {{{$CellContext`terms$$, 5, "constants"}, 5, 15, 1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`fitdata$$, True, "fit data"}, {
         True, False}}, {{$CellContext`showeye$$, False, "include eye"}, {
         True, False}}}, 
      "Options" :> {
       TrackedSymbols :> {$CellContext`terms$$, $CellContext`fitdata$$, \
$CellContext`showeye$$}}, "DefaultOptions" :> {}],
     ImageSizeCache->{549., {236., 242.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`listplot = Graphics[{{}, {{{}, {
             Hue[0.67, 0.6, 0.6], 
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6], 
              PointSize[0.02]], 
             Point[CompressedData["
1:eJxTTMoPSmViYGCQBmIQ3bh2e9Fs0VX2jEYlbxYIXbJ/fOe00s6Fm+yFxEQL
rU7esU+Zesl475ED9k7r7TvPyz6wXyM/+4n7n6v2j3+V1z5b88De5WeTmJDB
Q3uD+tYzUx0f2Fd3uJUL7H5mz/12Tlpj2T37UwU28xlLX9nLp8/a8Dflvn2X
7ZZ+0Zq39rFZLXXL4u7Zh34/8WzVz3f2zicq/8ur37SvDLdNkNv0zn4+82lB
owmH7af82rQl+PNb+3nnRJe2JBy2f1h3gJm54639mdcdzmYTLsPNS5n8pyN+
4xn76wcP3jsi8NY+OUH2OP/UC/YH/zawswm8tr8swuj3/tFF+3Cncs85oq/s
N3kIv2fwv2Kvqcqy+tXTl/abW7KXRKcusM+I6Nl17d4zOF+qy/reE/Nn9l/u
STA1JJ+2535fJHi/85H9zJvPDU8Zn7a/e/F/kW7UJfubtpURK0wv2H8VPpen
O/m0/Vn5y7dMtp20v1V4+P2y6GNQ+xfaGx096LUqeps9U27iGR/5JfZfpQq3
36rcbi999aXDteCL9lwXj23bWLfF/u6FKXPrAm7Yw+Jn/ZaeK9Val+wB92rf
YA==
              "]]}, {}}}, {}, {}, {}, {}}, {
         DisplayFunction -> Identity, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
          PlotRange -> {{0, 0.967977}, {0, 0.521106}}, PlotRangeClipping -> 
          True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          GoldenRatio^(-1), Axes -> {True, True}, AxesLabel -> {None, None}, 
          AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
          Frame -> {{False, False}, {False, False}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (Identity[#]& )[
                 Part[#, 1]], 
                (Identity[#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (Identity[#]& )[
                 Part[#, 1]], 
                (Identity[#]& )[
                 Part[#, 2]]}& )}}, PlotLabel -> "correlation = -0.0368665", 
          PlotRange -> {{0, 0.967977}, {0, 0.521106}}, PlotRangeClipping -> 
          True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, 
          Ticks -> {
           Automatic, Automatic}}], $CellContext`el1 = CompressedData["
1:eJxTTMoPSmViYGCQBmIQ3bh2e9Fs0VX2jEYlbxYIXbJ/fOe00s6Fm+yFxEQL
rU7esU+Zesl475ED9k7r7TvPyz6wXyM/+4n7n6v2j3+V1z5b88De5WeTmJDB
Q3uD+tYzUx0f2Fd3uJUL7H5mz/12Tlpj2T37UwU28xlLX9nLp8/a8Dflvn2X
7ZZ+0Zq39rFZLXXL4u7Zh34/8WzVz3f2zicq/8ur37SvDLdNkNv0zn4+82lB
owmH7af82rQl+PNb+3nnRJe2JBy2f1h3gJm54639mdcdzmYTLsPNS5n8pyN+
4xn76wcP3jsi8NY+OUH2OP/UC/YH/zawswm8tr8swuj3/tFF+3Cncs85oq/s
N3kIv2fwv2Kvqcqy+tXTl/abW7KXRKcusM+I6Nl17d4zOF+qy/reE/Nn9l/u
STA1JJ+2535fJHi/85H9zJvPDU8Zn7a/e/F/kW7UJfubtpURK0wv2H8VPpen
O/m0/Vn5y7dMtp20v1V4+P2y6GNQ+xfaGx096LUqeps9U27iGR/5JfZfpQq3
36rcbi999aXDteCL9lwXj23bWLfF/u6FKXPrAm7Yw+Jn/ZaeK9Val+wB92rf
YA==
        "], $CellContext`TrigFit[
         Pattern[$CellContext`data, 
          Blank[List]], 
         Pattern[$CellContext`n, 
          Blank[Integer]], {
          Pattern[$CellContext`x, 
           Blank[]], 
          Optional[
           Pattern[$CellContext`x0, 
            Blank[]], 0], 
          Pattern[$CellContext`x1, 
           
           Blank[]]}] := \
($CellContext`issueObsoleteFunMessage[$CellContext`TrigFit, 
          "NumericalMath`TrigFit`"]; 
        Module[{$CellContext`answer = \
$CellContext`SinAndCos[$CellContext`data, 
             Min[$CellContext`n, 
              Floor[(Length[$CellContext`data] - 1)/2]], (2 
              Pi) (($CellContext`x - $CellContext`x0)/($CellContext`x1 - \
$CellContext`x0))]}, 
          
          Condition[$CellContext`answer, $CellContext`answer =!= $Failed]]), \
$CellContext`TrigFit[
         Pattern[$CellContext`data, 
          Blank[List]], 
         Pattern[$CellContext`n, 
          Blank[Integer]], 
         Pattern[$CellContext`x, 
          
          Blank[]]] := \
($CellContext`issueObsoleteFunMessage[$CellContext`TrigFit, 
          "NumericalMath`TrigFit`"]; 
        Module[{$CellContext`answer = \
$CellContext`SinAndCos[$CellContext`data, 
             Min[$CellContext`n, 
              Floor[(Length[$CellContext`data] - 1)/2]], $CellContext`x]}, 
          
          Condition[$CellContext`answer, $CellContext`answer =!= $Failed]]), \
$CellContext`SinAndCos[
         Pattern[$CellContext`data, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]]] := 
       Module[{$CellContext`fcslist, $CellContext`clist, $CellContext`slist, \
$CellContext`c0, $CellContext`len, $CellContext`k, $CellContext`rflag}, \
$CellContext`len = Length[$CellContext`data]; $CellContext`fcslist = 
          If[Precision[$CellContext`data] === Infinity, 
            N[$CellContext`data], $CellContext`data]; $CellContext`rflag = 
          Union[
             Im[$CellContext`fcslist], SameTest -> SameQ] === {
            0}; $CellContext`clist = 
          Drop[$CellContext`fcslist, 1]; $CellContext`slist = 
          Reverse[$CellContext`clist]; $CellContext`fcslist = 
          Prepend[($CellContext`clist + $CellContext`slist)/2 + 
            I (($CellContext`clist - $CellContext`slist)/2), 
            Part[$CellContext`fcslist, 1]]; $CellContext`fcslist = 
          Fourier[$CellContext`fcslist, FourierParameters -> {-1, 1}]; If[
           Not[
            VectorQ[$CellContext`fcslist, NumberQ]], 
           Return[$Failed]]; $CellContext`c0 = 
          First[$CellContext`fcslist]; $CellContext`clist = 
          Drop[$CellContext`fcslist, 1]; $CellContext`slist = 
          Reverse[$CellContext`clist]; {$CellContext`clist, \
$CellContext`slist} = {
            Take[$CellContext`clist + $CellContext`slist, $CellContext`n], 
            Take[$CellContext`clist - $CellContext`slist, $CellContext`n]}; 
         If[$CellContext`rflag, $CellContext`c0 = 
            Re[$CellContext`c0]; $CellContext`clist = 
            Re[$CellContext`clist]; $CellContext`slist = 
            Re[$CellContext`slist]]; $CellContext`c0 + Dot[
            Table[
             
             Cos[$CellContext`k $CellContext`x], {$CellContext`k, \
$CellContext`n}], $CellContext`clist] - Dot[
           Table[
            
            Sin[$CellContext`k $CellContext`x], {$CellContext`k, \
$CellContext`n}], $CellContext`slist]], $CellContext`ex2 = CompressedData["
1:eJwBVQOq/CFib1JlAQAAAGkAAACBrbdymxWqP5KwbycR4aw/pLMn3Iasrz9a
229I/juxP+PcyyK5obI/XDACdKlbtj/WgzjFmRW6P0/XbhaKz70/ZJXSM73E
wD/hfyvZsZHHP15qhH6mXs4/bqrukc2V0j+sH5vkR/zVP2PUtfY+Fdk/GonQ
CDYu3D/RPesaLUffP0T5ghYSMOE/Et2zrtGS4j/gwORGkfXjP62kFd9QWOU/
e4hGdxC75j+PAkTBjKnnP6J8QQsJmOg/tvY+VYWG6T/KcDyfAXXqP/pjWpvG
Nus/Kld4l4v46z9aSpaTULrsP4o9tI8VfO0//Wt55Xrb7T9wmj474DruP+LI
A5FFmu4/VffI5qr57j9eDybFx+fuP2cng6Pk1e4/cD/ggQHE7j95Vz1gHrLu
P0DAWrVrgu4/Bil4CrlS7j/NkZVfBiPuP5T6srRT8+0/p1t2iH/Y7T+6vDlc
q73tP84d/S/Xou0/4X7AAwOI7T+Lbr2mB4XtPzZeukkMgu0/4E237BB/7T+K
PbSPFXztP52ed2NBYe0/sP86N21G7T/EYP4KmSvtP9fBwd7EEO0/0pDxKJWQ
7D/MXyFzZRDsP8YuUb01kOs/wf2ABwYQ6z/mjv6Xa9HqPwwgfCjRkuo/MrH5
uDZU6j9XQndJnBXqPwx72uGvCeo/wLM9esP96T907KAS1/HpPyklBKvq5ek/
+THmriUk6T/IPsiyYGLoP5hLqraboOc/aFiMutbe5j/UJHhDGrXmP0HxY8xd
i+Y/rr1PVaFh5j8aijve5DfmP1ZjCWtjTOU/kjzX9+Fg5D/PFaWEYHXjPwvv
chHfieI/hC12+6wy4D/61/LK9bbbP+tU+Z6RCNc/3dH/ci1a0j/knxnEBzbR
P+xtMxXiEdA/5neazHjbzT/1E85uLZPLP25rC89LRco/6MJIL2r3yD9hGoaP
iKnHP9pxw++mW8Y/Cs4qfTKQwz86KpIKvsTAP9IM8y+T8rs/MsXBSqpbtj+j
mu1lNqO2PxRwGYHC6rY/hEVFnE4ytz/1GnG32nm3P3qIRncQu7Y/APYbN0b8
tT+FY/H2ez21PwrRxraxfrQ/eBJst7ihsj/lUxG4v8SwP6YqbXGNz60/ga23
cpsVqj+HF7eL
        "], $CellContext`ey2 = CompressedData["
1:eJyFkWlQjAEYx98tGTk7idVuaDR2TO4r9I9GmMoRg7E6SNjUVOiaSmpWCLWI
0Sqitsl9xCZLx25Wtbvt8W5vNnr3JSNUmCm5IssYX3145vn0/Of/+z0TtsUE
RbAIghBYhjVzX1eRgwE2uwsCl9cYMbSk7kZ3dAtGtnWNymO3wmG0c5xXw3N4
lsXkk5I2+Hs11kZl0tildn9nE2rG0ps4onVlwJMH+p1ewsChmW/Nj2DwvUNQ
43aEQfu3xLTX1xj08ReudTjJYOijn+7eiQxcOfIvgi0MpqcfVP++s3k0L4sg
GEg/kelUqhlhcfN7rn6lMay7YEdGAg2R//hktzs0nK+cO1rdTUM8hH0+ZIoZ
3J3iWz+2m/G+w+nVzklmVO3KHWN4QSPnra3/oiIawZHC/aUhNKjaWrrOrg1r
xg54t8ufoTF20QVWfCt865MHuB4mlEqNS0JWN8NWMk1YkKiHabLz8XtQ4YK1
yn6mSIFQaaHUT6gARxDL5ycpQLN9idgoBc43OUuEYQo81+UV7l9TDzbpeCbJ
R4PrkSuXL3DRQ9152HeuiISfr7J4/VIDqsXWg/b26hD3KqN+YqAW20/1Hw69
rcZDTkB2rlbzl68JFeJ45WcbHcLDXJ+MOq1DeiBVduiNDue8crMHFupR4bEi
KjFXD9KJterDSz1UF5dJe9IMkHtmc764kHgga8rqLydxZ4XjB2K1ERsl7W4t
qVqsrCwKv8ZXIkEsC7COf4By4e4SfkTRf7d37d0QeUs5JtTM6qRSq5EZapJ9
Ej1GL+1idSBchcLC4TknN6rgt4UYJ/FX4eO4XkmFxV++qWNG4ywVuJlX9Fcz
1CjlRccdt3BOJafZx7hqYVqcvKlsjg6VJZEy26om1GhePpbbaaDs26xLseRq
uGTrbGkDPAQ/z1I76mAVse7GR88qSD9f5s0Wlf/lvwgzL//64D2X8M5nxggO
qxh9Gxqi5oiKYRW9VR3ALUF/cM6IU+b7kFkltFa3KJBEuXtKLf3YzW99qHV6
DM9z2kQ4kugPQgzPYESXfWTW+hMU2v789SkMDUGdP5QUlHK7BWmLm//5vXn3
mDGFZ8AvOpCoyw==
        "], $CellContext`eye = {{0.864865, 0.372613}, {0.884084, 0.391832}, {
        0.905225, 0.376456}, {0.886006, 0.357237}, {0.862943, 0.374535}}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.5321228545444593`*^9, 3.5321228828880806`*^9}, 
   3.532123286390159*^9, 3.532212348347212*^9, 3.533320458216133*^9, 
   3.5333316251218433`*^9, 3.5336850348125*^9, 3.533744504391987*^9, 
   3.533756944546875*^9, 3.5337569953125*^9, 3.5391768604134483`*^9, 
   3.5391770047957067`*^9, 3.5400538204843626`*^9, 3.5400550204559965`*^9, 
   3.5401285877939124`*^9, 3.5412484710463395`*^9, 3.5412499388222914`*^9, 
   3.5416049336517067`*^9, 3.5433495118629084`*^9, 3.586808619228999*^9, 
   3.698349749743989*^9, 3.698349861740796*^9, 3.731421860720641*^9},
 TextAlignment->Center,ExpressionUUID->"918f8f9e-cd2d-461f-bea0-ac3630d432f0"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.19.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "How many constants do you ",
 StyleBox["really",
  FontSlant->"Italic"],
 " need to fit an elephant?"
}], "FigureCaption",
 CellMargins->{{85.33333333333333, 10.}, {6., 2.}},
 CellChangeTimes->{{3.532118144087036*^9, 3.5321181596979294`*^9}, 
   3.5391770047957067`*^9},
 TextAlignment->Center,ExpressionUUID->"f93f0697-10c0-406d-90f2-db8526ad8e31"]
}, Open  ]],

Cell["Appendix B: Using decision trees to resolve disputes", "AppendixSection",
 CellChangeTimes->{{3.698597036082632*^9, 
  3.6985970593061447`*^9}},ExpressionUUID->"852e6115-6dda-4d87-968c-\
dbe7b3497045"],

Cell["A time tested approach", "Subsection",
 CellChangeTimes->{{3.6986009198411827`*^9, 
  3.698600926776922*^9}},ExpressionUUID->"d8b1cac3-ab9d-44ef-84ba-\
102d8b18f695"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986009198411827`*^9, 
  3.6986009258657103`*^9}},ExpressionUUID->"e00b743a-4774-4d5e-a40a-\
0307d8d18be7"],

Cell[TextData[{
 "Why is it that machines learn and people don\[CloseCurlyQuote]t? This \
provocative, if argumentative, question is at the heart of this appendix.\n\n\
A problem arises in privately held real estate investment when parties cannot \
agree on management or disposition of a property owned in common. Differences \
of opinion on the future path for the property can arise due to the passage \
of time or of some event, such as the illness or death of a ",
 Cell[BoxData[
  FormBox[
   RowBox[{"partner", "."}], TraditionalForm]],ExpressionUUID->
  "3b1888e3-8113-4e51-875a-f45ef080e097"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    ButtonBox["B1",
     BaseStyle->"Hyperlink",
     ButtonData->"endnoteB1"]], TraditionalForm]],ExpressionUUID->
  "bec1a748-8a5f-4260-b8cd-8b07a2fbe316"],
 "\n\nHere we propose a decision tree to analyze this difficulty and present \
an automated tool to implement it. A fixture of operations research, the \
decision tree has been in use for many ",
 Cell[BoxData[
  FormBox[
   RowBox[{"years", 
    SuperscriptBox[".", 
     ButtonBox["B2",
      BaseStyle->"Hyperlink",
      ButtonData->"endnoteB2"]]}], TraditionalForm]],ExpressionUUID->
  "7117e827-a546-456b-b12f-978389538f17"],
 " Today it forms the basis of widely used algorithms employed by machine \
learning. The reason each person on an airplane has paid a different price \
for their ticket is because of a decision tree. If you are unfortunate enough \
to develop a brain tumor the shape you see on the film attached to the light \
box hanging in the doctor\[CloseCurlyQuote]s office was made using a decision \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"tree", 
    SuperscriptBox[".", 
     ButtonBox["B3",
      BaseStyle->"Hyperlink",
      ButtonData->"endnoteB3"]]}], TraditionalForm]],ExpressionUUID->
  "24e2ebd4-9318-4dc8-bf12-294bd3a11ca5"],
 " Yet, people are often unwilling to use structured analysis to reach \
efficient solutions, bringing us back to the question asked at the beginning. "
}], "Text",
 CellChangeTimes->{{3.679959647306422*^9, 3.6799597044984484`*^9}, {
   3.680011394865362*^9, 3.68001211057769*^9}, {3.680012144747508*^9, 
   3.680012339767858*^9}, {3.6804394879892254`*^9, 3.6804395294796963`*^9}, {
   3.680439597133507*^9, 3.6804396290379868`*^9}, {3.6806352118403583`*^9, 
   3.680635258535519*^9}, {3.680635291023856*^9, 3.680635335576294*^9}, {
   3.6806353919361424`*^9, 3.6806358094674673`*^9}, {3.680635965478203*^9, 
   3.6806359681081944`*^9}, {3.680987794929143*^9, 3.680987921398834*^9}, {
   3.6809879685402203`*^9, 3.680988046558841*^9}, {3.680988319958499*^9, 
   3.6809884727600822`*^9}, {3.682238006336905*^9, 3.6822380695280094`*^9}, {
   3.6822381128528132`*^9, 3.6822381317908354`*^9}, {3.682238208687971*^9, 
   3.682238245237171*^9}, {3.6822384819631567`*^9, 3.6822387135552597`*^9}, {
   3.68224820381954*^9, 3.6822483617448063`*^9}, {3.682248426602559*^9, 
   3.6822484485859056`*^9}, {3.682262871079429*^9, 3.682263116673386*^9}, {
   3.6986009384094467`*^9, 3.698601000947131*^9}, 3.6986010327175007`*^9, {
   3.698602086517908*^9, 3.698602111194962*^9}, {3.6986021726454115`*^9, 
   3.698602174162834*^9}, {3.698602206826004*^9, 3.698602252156104*^9}, {
   3.6986024707539196`*^9, 3.6986024912566195`*^9}, {3.698602551992815*^9, 
   3.6986025534404397`*^9}, {3.698602764117364*^9, 
   3.698602764117364*^9}},ExpressionUUID->"92027fc9-83b8-436d-a97b-\
935048bc4e48"],

Cell["All decisions are binary", "Subsection",
 CellChangeTimes->{{3.698601055993702*^9, 
  3.698601061730976*^9}},ExpressionUUID->"1382be44-0009-4063-bb8d-\
a5bb7b617c02"],

Cell[TextData[{
 "\nFor our sandbox exercise we will assume two owners, one is our client and \
the other is the co-owner/partner. Their respective percentage shares are \
unimportant. Generally, absent an agreement, the idea of \"partnership \
democracy\" does not govern decisions for this ",
 Cell[BoxData[
  FormBox[
   RowBox[{"venture", 
    SuperscriptBox[".", 
     ButtonBox["B4",
      BaseStyle->"Hyperlink",
      ButtonData->"endnoteB4"]]}], TraditionalForm]],ExpressionUUID->
  "29c17e69-4c37-4ec0-bc74-170b64e48e0b"],
 " Either the client or the partner could own 50% or 5% but in every case all \
must agree completely for anything to be done. This is a difficult standard \
to meet, especially over time as facts on the ground change.\n\nWhen parties \
do not agree and resort to the court for a solution, the result is that the \
court listens patiently, encourages the parties to reach agreement but if \
none is found the court takes the rather dramatic and extreme path of \
supervising a sale and dividing the sale proceeds between the partners \
according to their ownership shares. The essence of this is a divorce in \
which the parties need not be married (although they might be). The court has \
no way to divide property in kind (suppose it is a 5 unit apartment building, \
the court cannot give each partner 2.5 units) but once the property is \
liquidated to a third party the court holds cash which can then be divided. \
The court is not particularly good at this. The court's interest is the \
proper administration of the law. Economics are secondary.\n\nEventually the \
inefficiency of the court supervised sale becomes apparent to the parties. In \
most cases warring parties are educated about this by their respective \
attorneys, usually at great expense and often at different points in time. \
Eventually, recognizing they will both lose money if they do not agree, a \
solution is found.\n\nEverything about this is replicated and compounded in \
the case where one of the owners dies and this wife and five grown children \
replace him as owners, each with different spouses, goals, objectives, \
management abilities, understanding and talent.\n\nBelow we assume one party \
(\"Client\") wants to enter into a buy-sell agreement to ",
 StyleBox["pre",
  IgnoreSpellCheck->True],
 "-resolve all the issues attendant with the demise of either ",
 Cell[BoxData[
  FormBox[
   RowBox[{"party", 
    SuperscriptBox[".", 
     ButtonBox["B5",
      BaseStyle->"Hyperlink",
      ButtonData->"endnoteB5"]]}], TraditionalForm]],ExpressionUUID->
  "d40b4060-e9bf-459b-8071-73a377022c82"],
 " We assume the other party (\"Partner\") is unwilling. The narrative \
proceeds as if a mediator is retained to intervene. The decision tree takes \
the parties down various paths, each with a set of probabilities and \
end-of-game payoffs. Before describing a set of fully elaborated examples, it \
is useful to describe the basic workings of a decision tree.\n\nAlthough they \
can be more complex, the simplest involve a series of binary choices, \
occurring in order. Each pair of choices are mutually exclusive (taking one \
means you cannot take the other) and collectively exhaustive (only two \
choices exist and one must be taken). Below is the simplest, the starting \
point is today and the two choices are not very controversial."
}], "Text",
 CellChangeTimes->{{3.679959647306422*^9, 3.6799597044984484`*^9}, {
   3.680011394865362*^9, 3.68001211057769*^9}, {3.680012144747508*^9, 
   3.680012339767858*^9}, {3.6804394879892254`*^9, 3.6804395294796963`*^9}, {
   3.680439597133507*^9, 3.6804396290379868`*^9}, {3.6806352118403583`*^9, 
   3.680635258535519*^9}, {3.680635291023856*^9, 3.680635335576294*^9}, {
   3.6806353919361424`*^9, 3.6806358094674673`*^9}, {3.680635965478203*^9, 
   3.6806359681081944`*^9}, {3.680987794929143*^9, 3.680987921398834*^9}, {
   3.6809879685402203`*^9, 3.680988046558841*^9}, {3.680988319958499*^9, 
   3.6809884727600822`*^9}, {3.682238006336905*^9, 3.6822380695280094`*^9}, {
   3.6822381128528132`*^9, 3.6822381317908354`*^9}, {3.682238208687971*^9, 
   3.682238245237171*^9}, {3.6822384819631567`*^9, 3.6822387135552597`*^9}, {
   3.68224820381954*^9, 3.6822483617448063`*^9}, {3.682248426602559*^9, 
   3.6822484485859056`*^9}, {3.682262871079429*^9, 3.682263116673386*^9}, {
   3.6986009384094467`*^9, 3.698601000947131*^9}, 3.6986010668389697`*^9, {
   3.6986028086433573`*^9, 3.698602809973781*^9}, {3.6986034091773014`*^9, 
   3.6986034091773014`*^9}, {3.6986038586410275`*^9, 3.698603859879458*^9}, {
   3.6986039401274967`*^9, 
   3.6986039401279984`*^9}},ExpressionUUID->"8d1ccffb-f807-4200-b697-\
21c396144295"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g0", "=", 
  RowBox[{"Style", "[", 
   RowBox[{
    RowBox[{"Framed", "[", 
     RowBox[{"TreePlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Do Nothing\>\""}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Take Action\>\""}]}], 
        "\[IndentingNewLine]", "}"}], ",", "Left", ",", 
       RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
       RowBox[{"VertexRenderingFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "Yellow", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"#1", ",", "0.25"}], "]"}], ",", "Black", ",", 
            RowBox[{"Text", "[", 
             RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}]}], "]"}], "]"}], ",", "Red"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6033006525463047`*^9, 3.603300655515475*^9}, {
   3.6033007573182974`*^9, 3.603300796469537*^9}, {3.6033170350553308`*^9, 
   3.6033170676581955`*^9}, {3.6033959113510036`*^9, 3.603395923381692*^9}, {
   3.603395978671854*^9, 3.6033960071424828`*^9}, {3.6034107565130987`*^9, 
   3.603410757502155*^9}, {3.6034107876048765`*^9, 3.6034108097751446`*^9}, {
   3.6034108493504086`*^9, 3.603410957343585*^9}, {3.603411045870649*^9, 
   3.6034111065731206`*^9}, {3.6034111568509965`*^9, 
   3.6034111846345854`*^9}, {3.603411828355404*^9, 3.603412267549525*^9}, {
   3.603468562273399*^9, 3.6034687685231953`*^9}, {3.603468808924506*^9, 
   3.6034688225812874`*^9}, {3.6034688656687517`*^9, 
   3.6034689585040617`*^9}, {3.6034689918589697`*^9, 3.603469054929577*^9}, 
   3.603469165952927*^9, {3.6034692044341283`*^9, 3.6034692588842425`*^9}, {
   3.6034699966274395`*^9, 3.603470003038806*^9}, {3.6034703370569105`*^9, 
   3.6034704295932035`*^9}, {3.603470463907166*^9, 3.6034704699135094`*^9}, {
   3.603470513035976*^9, 3.6034706855498433`*^9}, {3.6034709334900246`*^9, 
   3.6034710086403227`*^9}, {3.6034710720949526`*^9, 3.603471404888987*^9}, {
   3.6034714391749477`*^9, 3.603471536542517*^9}, {3.60347157539874*^9, 
   3.603471584010232*^9}, {3.603471875794921*^9, 3.603471983108059*^9}, {
   3.603472036589118*^9, 3.6034720557352133`*^9}, {3.6034721565149775`*^9, 
   3.603472162295308*^9}, {3.6034735593542156`*^9, 3.603473598334445*^9}, {
   3.6034739904108706`*^9, 3.603474066434219*^9}, {3.603474120005283*^9, 
   3.603474120704323*^9}, {3.680988276856824*^9, 
   3.6809882774383945`*^9}},ExpressionUUID->"d3d61809-d88a-4f7d-99b9-\
50c9388ec5e1"],

Cell[BoxData[
 StyleBox[
  FrameBox[
   GraphicsBox[
    TagBox[
     GraphicsGroupBox[{
       GraphicsComplexBox[{{0., 0.447213595499957}, {0.8944271909999163, 
        0.}, {0.8944271909999153, 0.8944271909999159}}, 
        {RGBColor[0.5, 0., 0.], LineBox[{{1, 2}, {1, 3}}]}], {
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0., 0.447213595499957}, 0.25], 
         {GrayLevel[0], InsetBox["\<\"Today\"\>", {0., 0.447213595499957}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8944271909999163, 0.}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Do Nothing\"\>", {0.8944271909999163, 0.}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8944271909999153, 0.8944271909999159}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Take Action\"\>", \
{0.8944271909999153, 0.8944271909999159}]}}}},
      ContentSelectable->True],
     Annotation[#, 
      VertexCoordinateRules -> {{0., 0.447213595499957}, {0.8944271909999163, 
       0.}, {0.8944271909999153, 0.8944271909999159}}]& ],
    AspectRatio->0.9999999999999997,
    BaseStyle->{FontSize -> 15, FontFamily -> "Times", Italic},
    FrameTicks->None,
    ImageSize->600,
    PlotRange->All,
    PlotRangePadding->Scaled[0.1]],
   StripOnInput->False],
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontColor->RGBColor[1, 0, 0]]], "Output",
 CellChangeTimes->{3.680988283618162*^9, 3.6809888832077436`*^9, 
  3.6822704436312914`*^9, 3.6823658314624314`*^9, 3.694890346489962*^9, 
  3.7314218609572697`*^9},
 TextAlignment->Center,ExpressionUUID->"9155f976-1c38-428f-aff2-755d608e6d77"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.20",
  FontWeight->"Bold"],
 ". The simplest decision"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}},
 TextAlignment->Center,ExpressionUUID->"dc4e4512-c6ad-44f7-a7cd-8e8d33d5c9d0"],

Cell["Adding Probabilities", "Subsection",
 CellChangeTimes->{{3.6986035590976906`*^9, 
  3.6986035645580683`*^9}},ExpressionUUID->"88488f33-4c09-4713-abf4-\
e345e1ad3798"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986035590976906`*^9, 
  3.698603564378829*^9}},ExpressionUUID->"a8d3cf0e-5975-488e-bd0d-\
625c0719242f"],

Cell[TextData[{
 "Developing a stylistic example which at times will seem unrealistic, we beg \
the reader\[CloseCurlyQuote]s indulgence. Particular assumptions may not \
initially make sense. But the heuristics demand we proceed in small steps. \
With this admonition in mind, let us assume that each step involves some \
probability that step will be taken. That probability appears adjacent to the \
line connecting the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"steps", 
    SuperscriptBox[".", "B6"]}], TraditionalForm]],ExpressionUUID->
  "4de5cf3a-2a6f-4750-bf5f-bf7114b0187c"],
 " For now we will just assume that today there is an equal probability that \
you will do something or nothing so the probability for each is .5 = 50%, \
below.\n\nNote that, because of the properties mutually exclusive and \
collectively exhaustive, at each node one need only know a single \
probability, p. Since the other choice must be taken if the first is not, its \
probability must be 1-p. So, for example, if we are told the person involved \
is ambitious, known to strive actively with a history of achievement, it is \
reasonable to assume that there is a high probability, say .7 = 70% that he \
will take action. This automatically leaves the remaining choice, to do \
nothing, at a .3 = 30% probability because both probabilities must sum to 1."
}], "Text",
 CellChangeTimes->{{3.6809885080084667`*^9, 3.680988778876857*^9}, {
  3.680988951367456*^9, 3.6809890486574335`*^9}, {3.6809890921063733`*^9, 
  3.6809891863173895`*^9}, {3.6809893188172407`*^9, 3.680989347933031*^9}, {
  3.6822485306647797`*^9, 3.682248596129789*^9}, {3.682263133079976*^9, 
  3.6822631870464897`*^9}, {3.6986040427554674`*^9, 
  3.698604044093543*^9}},ExpressionUUID->"170fd733-e3ce-421a-a81e-\
1640236baf11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1", "=", 
  RowBox[{"Style", "[", 
   RowBox[{
    RowBox[{"Framed", "[", 
     RowBox[{"TreePlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Do Nothing\>\""}], ",", 
           "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Take Action\>\""}], ",", 
           "\"\<\\n\\n.5\>\""}], "}"}]}], "}"}], ",", "Left", ",", 
       RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
       RowBox[{"VertexRenderingFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "Yellow", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"#1", ",", "0.25"}], "]"}], ",", "Black", ",", 
            RowBox[{"Text", "[", 
             RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}]}], "]"}], "]"}], ",", "Red"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6033006525463047`*^9, 3.603300655515475*^9}, {
   3.6033007573182974`*^9, 3.603300796469537*^9}, {3.6033170350553308`*^9, 
   3.6033170676581955`*^9}, {3.6033959113510036`*^9, 3.603395923381692*^9}, {
   3.603395978671854*^9, 3.6033960071424828`*^9}, {3.6034107565130987`*^9, 
   3.603410757502155*^9}, {3.6034107876048765`*^9, 3.6034108097751446`*^9}, {
   3.6034108493504086`*^9, 3.603410957343585*^9}, {3.603411045870649*^9, 
   3.6034111065731206`*^9}, {3.6034111568509965`*^9, 
   3.6034111846345854`*^9}, {3.603411828355404*^9, 3.603412267549525*^9}, {
   3.603468562273399*^9, 3.6034687685231953`*^9}, {3.603468808924506*^9, 
   3.6034688225812874`*^9}, {3.6034688656687517`*^9, 
   3.6034689585040617`*^9}, {3.6034689918589697`*^9, 3.603469054929577*^9}, 
   3.603469165952927*^9, {3.6034692044341283`*^9, 3.6034692588842425`*^9}, {
   3.6034699966274395`*^9, 3.603470003038806*^9}, {3.6034703370569105`*^9, 
   3.6034704295932035`*^9}, {3.603470463907166*^9, 3.6034704699135094`*^9}, {
   3.603470513035976*^9, 3.6034706855498433`*^9}, {3.6034709334900246`*^9, 
   3.6034710086403227`*^9}, {3.6034710720949526`*^9, 3.603471404888987*^9}, {
   3.6034714391749477`*^9, 3.603471536542517*^9}, {3.60347157539874*^9, 
   3.603471584010232*^9}, {3.603471875794921*^9, 3.603471983108059*^9}, {
   3.603472036589118*^9, 3.6034720557352133`*^9}, {3.6034721565149775`*^9, 
   3.603472162295308*^9}, {3.6034735593542156`*^9, 3.603473598334445*^9}, {
   3.6034739904108706`*^9, 3.603474066434219*^9}, {3.603474120005283*^9, 
   3.603474120704323*^9}, 3.6809885281779537`*^9, {3.680988821267803*^9, 
   3.680988878197612*^9}},ExpressionUUID->"69015a34-45b4-4a5b-8481-\
bda424864528"],

Cell[BoxData[
 StyleBox[
  FrameBox[
   GraphicsBox[
    TagBox[
     GraphicsGroupBox[{
       GraphicsComplexBox[{{0., 0.447213595499957}, {0.8944271909999163, 
        0.}, {0.8944271909999153, 0.8944271909999159}}, 
        {RGBColor[0.5, 0., 0.], 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 2}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 3}]}}], {
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0., 0.447213595499957}, 0.25], 
         {GrayLevel[0], InsetBox["\<\"Today\"\>", {0., 0.447213595499957}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8944271909999163, 0.}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Do Nothing\"\>", {0.8944271909999163, 0.}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8944271909999153, 0.8944271909999159}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Take Action\"\>", \
{0.8944271909999153, 0.8944271909999159}]}}}},
      ContentSelectable->True],
     Annotation[#, 
      VertexCoordinateRules -> {{0., 0.447213595499957}, {0.8944271909999163, 
       0.}, {0.8944271909999153, 0.8944271909999159}}]& ],
    AspectRatio->0.9999999999999997,
    BaseStyle->{FontSize -> 15, FontFamily -> "Times", Italic},
    FrameTicks->None,
    ImageSize->600,
    PlotRange->All,
    PlotRangePadding->Scaled[0.1]],
   StripOnInput->False],
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontColor->RGBColor[1, 0, 0]]], "Output",
 CellChangeTimes->{
  3.680988531108249*^9, {3.680988864969925*^9, 3.680988878977639*^9}, 
   3.682270632749207*^9, 3.6823658316342998`*^9, 3.6948903466588697`*^9, 
   3.7314218610194354`*^9},
 TextAlignment->Center,ExpressionUUID->"47fd5c9f-b0f0-4536-8831-ad913d69f12b"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.21",
  FontWeight->"Bold"],
 ". Adding probabilities to the simplest decision"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597375982063*^9}},
 TextAlignment->Center,ExpressionUUID->"bdb85538-3c38-424f-b893-a3257a7f2ecf"],

Cell["Introducing payoff values", "Subsection",
 CellChangeTimes->{{3.6986036255814495`*^9, 
  3.698603636821076*^9}},ExpressionUUID->"851d9aed-8b1a-49dc-8998-\
21ae20971b40"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986036255814495`*^9, 
  3.6986036361324697`*^9}},ExpressionUUID->"264950f8-3a69-45c5-b69d-\
5a6b32021120"],

Cell[TextData[{
 "A second crucial assumption is that choices have consequences which we \
refer to as \[OpenCurlyDoubleQuote]Payoffs\[CloseCurlyDoubleQuote] and denote \
with a number to the right on the graph below. While it is intuitively \
reasonable that choices have consequences, the Devil is in the details when \
placing a value on a particular choice. This task is so difficult that we do \
not address it for the moment. Rather, all we do is observe that the \
numerical methodology is ordinal, not cardinal. The process requires only \
ranking.Thus, whatever value we place on a particular choice, the number \
tells us only how that choice compares to others. The values have no units at \
this stage. We only say that a payoff of 10 is more than a payoff of 9. \
Below, we ",
 StyleBox["arbitrarily",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 " add a zero to each of the foregoing and say that Taking Action has a \
payoff of 100 and doing nothing has a payoff of 90. The reader is reminded of \
the important economic notion of utility covered in previous chapters."
}], "Text",
 CellChangeTimes->{{3.6809889135378594`*^9, 3.6809889426315055`*^9}, {
  3.680989722574294*^9, 3.6809900061146975`*^9}, {3.68099007370627*^9, 
  3.6809900977946177`*^9}, {3.6822486669462023`*^9, 3.682248676917363*^9}, {
  3.682248707868861*^9, 3.6822487083533015`*^9}, {3.68226321935538*^9, 
  3.682263264255762*^9}, {3.6986036865630903`*^9, 
  3.6986037485334873`*^9}},ExpressionUUID->"1270bca9-c72a-4072-bf2a-\
931423e69ed2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g2", "=", 
  RowBox[{"Style", "[", 
   RowBox[{
    RowBox[{"Framed", "[", 
     RowBox[{"TreePlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Do Nothing\>\""}], ",", 
           "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Take Action\>\""}], ",", 
           "\"\<\\n\\n.5\>\""}], "}"}]}], "}"}], ",", "Left", ",", 
       RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
       RowBox[{"VertexRenderingFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "Yellow", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"#1", ",", "0.25"}], "]"}], ",", "Black", ",", 
            RowBox[{"Text", "[", 
             RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{"\"\<100\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"1.2", ",", ".9"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<90\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"1.2", ",", "0"}], "}"}]}], "]"}]}], "}"}]}]}], "]"}], 
     "]"}], ",", "Red"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6033006525463047`*^9, 3.603300655515475*^9}, {
   3.6033007573182974`*^9, 3.603300796469537*^9}, {3.6033170350553308`*^9, 
   3.6033170676581955`*^9}, {3.6033959113510036`*^9, 3.603395923381692*^9}, {
   3.603395978671854*^9, 3.6033960071424828`*^9}, {3.6034107565130987`*^9, 
   3.603410757502155*^9}, {3.6034107876048765`*^9, 3.6034108097751446`*^9}, {
   3.6034108493504086`*^9, 3.603410957343585*^9}, {3.603411045870649*^9, 
   3.6034111065731206`*^9}, {3.6034111568509965`*^9, 
   3.6034111846345854`*^9}, {3.603411828355404*^9, 3.603412267549525*^9}, {
   3.603468562273399*^9, 3.6034687685231953`*^9}, {3.603468808924506*^9, 
   3.6034688225812874`*^9}, {3.6034688656687517`*^9, 
   3.6034689585040617`*^9}, {3.6034689918589697`*^9, 3.603469054929577*^9}, 
   3.603469165952927*^9, {3.6034692044341283`*^9, 3.6034692588842425`*^9}, {
   3.6034699966274395`*^9, 3.603470003038806*^9}, {3.6034703370569105`*^9, 
   3.6034704295932035`*^9}, {3.603470463907166*^9, 3.6034704699135094`*^9}, {
   3.603470513035976*^9, 3.6034706855498433`*^9}, {3.6034709334900246`*^9, 
   3.6034710086403227`*^9}, {3.6034710720949526`*^9, 3.603471404888987*^9}, {
   3.6034714391749477`*^9, 3.603471536542517*^9}, {3.60347157539874*^9, 
   3.603471584010232*^9}, {3.603471875794921*^9, 3.603471983108059*^9}, {
   3.603472036589118*^9, 3.6034720557352133`*^9}, {3.6034721565149775`*^9, 
   3.603472162295308*^9}, {3.6034735593542156`*^9, 3.603473598334445*^9}, {
   3.6034739904108706`*^9, 3.603474066434219*^9}, {3.603474120005283*^9, 
   3.603474120704323*^9}, 3.6809885281779537`*^9, {3.680988821267803*^9, 
   3.680988878197612*^9}, 3.6809893933129063`*^9, {3.6809894632449503`*^9, 
   3.680989464319627*^9}, {3.6809894964450417`*^9, 
   3.680989670550537*^9}},ExpressionUUID->"203d85b8-2ffc-424c-881f-\
2ad372f95cb3"],

Cell[BoxData[
 StyleBox[
  FrameBox[
   GraphicsBox[
    TagBox[
     GraphicsGroupBox[{
       GraphicsComplexBox[{{0., 0.447213595499957}, {0.8944271909999163, 
        0.}, {0.8944271909999153, 0.8944271909999159}}, 
        {RGBColor[0.5, 0., 0.], 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 2}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 3}]}}], {
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0., 0.447213595499957}, 0.25], 
         {GrayLevel[0], InsetBox["\<\"Today\"\>", {0., 0.447213595499957}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8944271909999163, 0.}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Do Nothing\"\>", {0.8944271909999163, 0.}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8944271909999153, 0.8944271909999159}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Take Action\"\>", \
{0.8944271909999153, 0.8944271909999159}]}}}},
      ContentSelectable->True],
     Annotation[#, 
      VertexCoordinateRules -> {{0., 0.447213595499957}, {0.8944271909999163, 
       0.}, {0.8944271909999153, 0.8944271909999159}}]& ],
    AspectRatio->0.9999999999999997,
    BaseStyle->{FontSize -> 15, FontFamily -> "Times", Italic},
    Epilog->{
      InsetBox[
       FormBox["\"100\"", TraditionalForm], {1.2, 0.9}], 
      InsetBox[
       FormBox["\"90\"", TraditionalForm], {1.2, 0}]},
    FrameTicks->None,
    ImageSize->600,
    PlotRange->All,
    PlotRangePadding->Scaled[0.1]],
   StripOnInput->False],
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontColor->RGBColor[1, 0, 0]]], "Output",
 CellChangeTimes->{
  3.6809893938796406`*^9, {3.680989561976396*^9, 3.680989670786771*^9}, 
   3.6822707181969204`*^9, 3.682365831712433*^9, 3.6948903467240486`*^9, 
   3.731421861049549*^9},
 TextAlignment->Center,ExpressionUUID->"2f3b3755-99ed-4680-b741-4631bb81633d"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.22",
  FontWeight->"Bold"],
 ". Adding payoffs to the end result for the simplest decision"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}, {
  3.6985974019449472`*^9, 3.698597442241228*^9}},
 TextAlignment->Center,ExpressionUUID->"277ce481-133d-4412-8b01-6bab6321f119"],

Cell["Computing the Expected result", "Subsection",
 CellChangeTimes->{{3.6986042960140915`*^9, 
  3.698604304526616*^9}},ExpressionUUID->"42908803-72f2-4cfd-b8c0-\
1d2544f93850"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986042960140915`*^9, 
  3.698604303403489*^9}},ExpressionUUID->"11355ac4-501d-4e75-a8a9-\
67b9674ed6ef"],

Cell[TextData[{
 "In order to be able to accomplish something out of this academic exercise \
it is fair to ask \[OpenCurlyDoubleQuote]To what end?\[CloseCurlyDoubleQuote] \
The reader is forgiven for thinking \[OpenCurlyDoubleQuote]What is the \
purpose of all this?\[CloseCurlyDoubleQuote] Again, patience is requested. \
One more maneuver is necessary to round out the story. That maneuver is the \
computation of \[OpenCurlyDoubleQuote]Expected ",
 Cell[BoxData[
  FormBox[
   RowBox[{"result", "\"\<\!\(\*
SuperscriptBox[\".\", 
ButtonBox[\"B7\",BaseStyle->\"Hyperlink\",ButtonData->\"endnoteB7\"]]\)\>"}], 
   TraditionalForm]],ExpressionUUID->"9ab0bb90-a5f8-4fa8-adff-057d0cd093e5"],
 "\n\nThe mechanics of computing Expected result, working from right to left, \
is to merely multiply the payoffs times their respective probabilities and \
then add those products together. Thus, for our example so far:"
}], "Text",
 CellChangeTimes->{{3.680990365495884*^9, 3.680990633845635*^9}, {
  3.6809906756453357`*^9, 3.6809907202655134`*^9}, {3.682248737523494*^9, 
  3.682248753129121*^9}, {3.682263295588046*^9, 3.682263311986662*^9}, {
  3.698604232315017*^9, 3.6986042340818048`*^9}, {3.6986043162598066`*^9, 
  3.698604319616047*^9}, {3.6986044063975105`*^9, 
  3.6986044063980103`*^9}},ExpressionUUID->"3b8a7719-fe4a-4e1a-944b-\
abd3c38f08d7"],

Cell["Expected result = (.5 x 100) + (.5 x 90) = 95", "Text",
 CellChangeTimes->{{3.6809906448115425`*^9, 3.6809906716054983`*^9}, {
  3.6809907250053005`*^9, 3.6809907305255985`*^9}},
 TextAlignment->Center,ExpressionUUID->"d19864e5-144b-43a9-883d-4277dba4d796"],

Cell["which now appears on the graphic below.", "Text",
 CellChangeTimes->{{3.6809906901049013`*^9, 
  3.6809906976332455`*^9}},ExpressionUUID->"83da4465-d946-463a-bb6d-\
82dcfc43c7f0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g3result", "=", 
   RowBox[{
    RowBox[{".5", " ", "90"}], "+", 
    RowBox[{".5", " ", "100"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"g3", "=", 
  RowBox[{"Style", "[", 
   RowBox[{"Framed", "[", 
    RowBox[{"TreePlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Do Nothing\>\""}], ",", 
          "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Take Action\>\""}], ",", 
          "\"\<\\n\\n.5\>\""}], "}"}]}], "}"}], ",", "Left", ",", 
      RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
      RowBox[{"VertexRenderingFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "Yellow", ",", 
           RowBox[{"Disk", "[", 
            RowBox[{"#1", ",", "0.25"}], "]"}], ",", "Black", ",", 
           RowBox[{"Text", "[", 
            RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
        "}"}]}], ",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"\"\<100\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"1.2", ",", ".9"}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<90\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"1.2", ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"StringJoin", "[", 
             RowBox[{"\"\<Expected result = \>\"", ",", 
              RowBox[{"ToString", "[", "g3result", "]"}]}], "]"}], ",", 
            "Red"}], "]"}], "]"}]}], "}"}]}]}], "]"}], "]"}], 
   "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6033006525463047`*^9, 3.603300655515475*^9}, {
   3.6033007573182974`*^9, 3.603300796469537*^9}, {3.6033170350553308`*^9, 
   3.6033170676581955`*^9}, {3.6033959113510036`*^9, 3.603395923381692*^9}, {
   3.603395978671854*^9, 3.6033960071424828`*^9}, {3.6034107565130987`*^9, 
   3.603410757502155*^9}, {3.6034107876048765`*^9, 3.6034108097751446`*^9}, {
   3.6034108493504086`*^9, 3.603410957343585*^9}, {3.603411045870649*^9, 
   3.6034111065731206`*^9}, {3.6034111568509965`*^9, 
   3.6034111846345854`*^9}, {3.603411828355404*^9, 3.603412267549525*^9}, {
   3.603468562273399*^9, 3.6034687685231953`*^9}, {3.603468808924506*^9, 
   3.6034688225812874`*^9}, {3.6034688656687517`*^9, 
   3.6034689585040617`*^9}, {3.6034689918589697`*^9, 3.603469054929577*^9}, 
   3.603469165952927*^9, {3.6034692044341283`*^9, 3.6034692588842425`*^9}, {
   3.6034699966274395`*^9, 3.603470003038806*^9}, {3.6034703370569105`*^9, 
   3.6034704295932035`*^9}, {3.603470463907166*^9, 3.6034704699135094`*^9}, {
   3.603470513035976*^9, 3.6034706855498433`*^9}, {3.6034709334900246`*^9, 
   3.6034710086403227`*^9}, {3.6034710720949526`*^9, 3.603471404888987*^9}, {
   3.6034714391749477`*^9, 3.603471536542517*^9}, {3.60347157539874*^9, 
   3.603471584010232*^9}, {3.603471875794921*^9, 3.603471983108059*^9}, {
   3.603472036589118*^9, 3.6034720557352133`*^9}, {3.6034721565149775`*^9, 
   3.603472162295308*^9}, {3.6034735593542156`*^9, 3.603473598334445*^9}, {
   3.6034739904108706`*^9, 3.603474066434219*^9}, {3.603474120005283*^9, 
   3.603474120704323*^9}, 3.6809885281779537`*^9, {3.680988821267803*^9, 
   3.680988878197612*^9}, 3.6809893933129063`*^9, {3.6809894632449503`*^9, 
   3.680989464319627*^9}, {3.6809894964450417`*^9, 3.680989670550537*^9}, 
   3.680990134049247*^9, {3.680990169386113*^9, 3.6809902762960386`*^9}, {
   3.6822487865948343`*^9, 3.682248786750885*^9}, {3.6822488650609274`*^9, 
   3.6822489173583555`*^9}, 
   3.6822490720038056`*^9},ExpressionUUID->"96bd59e1-b9d9-4b11-852e-\
139d011f2594"],

Cell[BoxData[
 FrameBox[
  GraphicsBox[
   TagBox[
    GraphicsGroupBox[{
      GraphicsComplexBox[{{0., 0.447213595499957}, {0.8944271909999163, 0.}, {
       0.8944271909999153, 0.8944271909999159}}, 
       {RGBColor[0.5, 0., 0.], 
        {Arrowheads[{{0.5, 0.5, 
            GraphicsBox[{
              GrayLevel[0], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\\n.5\"", StripOnInput -> False], 
                 TraditionalForm]], {0, 0}, 
               ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
               GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 2}]}, 
        {Arrowheads[{{0.5, 0.5, 
            GraphicsBox[{
              GrayLevel[0], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\\n\\n.5\"", StripOnInput -> False], 
                 TraditionalForm]], {0, 0}, 
               ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
               GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 3}]}}], {
       {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
        DiskBox[{0., 0.447213595499957}, 0.25], 
        {GrayLevel[0], InsetBox["\<\"Today\"\>", {0., 0.447213595499957}]}}, 
       {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
        DiskBox[{0.8944271909999163, 0.}, 0.25], 
        {GrayLevel[0], 
         InsetBox["\<\"Do Nothing\"\>", {0.8944271909999163, 0.}]}}, 
       {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
        DiskBox[{0.8944271909999153, 0.8944271909999159}, 0.25], 
        {GrayLevel[0], 
         InsetBox["\<\"Take Action\"\>", \
{0.8944271909999153, 0.8944271909999159}]}}}},
     ContentSelectable->True],
    Annotation[#, 
     VertexCoordinateRules -> {{0., 0.447213595499957}, {0.8944271909999163, 
      0.}, {0.8944271909999153, 0.8944271909999159}}]& ],
   AspectRatio->0.9999999999999997,
   BaseStyle->{FontSize -> 15, FontFamily -> "Times", Italic},
   Epilog->{
     InsetBox[
      FormBox["\"100\"", TraditionalForm], {1.2, 0.9}], 
     InsetBox[
      FormBox["\"90\"", TraditionalForm], {1.2, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"Expected result = 95.\"", 
        RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {0, 0}]},
   FrameTicks->None,
   ImageSize->600,
   PlotRange->All,
   PlotRangePadding->Scaled[0.1]],
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.68236583177494*^9, 3.694890346795744*^9, 
  3.731421861084611*^9},
 TextAlignment->Center,ExpressionUUID->"3d96f78e-44c8-4b63-81db-5047a97e5425"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.23",
  FontWeight->"Bold"],
 ". Computing Expected result for the simplest decision"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}, {
  3.6985974745657053`*^9, 3.698597486806926*^9}},
 TextAlignment->Center,ExpressionUUID->"1cfc5704-36ef-45d3-be1a-e2d97d9a2047"],

Cell["The reality of mortality", "Subsection",
 CellChangeTimes->{{3.698604739227498*^9, 
  3.698604746644658*^9}},ExpressionUUID->"249cb447-2b2e-4f1d-9618-\
b86a05ca129d"],

Cell["", "Subsection",
 CellChangeTimes->{{3.698604739227498*^9, 
  3.6986047460461655`*^9}},ExpressionUUID->"71cf07aa-d524-45ca-a1ac-\
bfab50d42a56"],

Cell[TextData[{
 "One may surmise that not only do different choices lead to different \
payoffs, they also lead to additional choices. Thus, below we complicate \
matters by introducing some realism. While doing nothing is always an option, \
it may be that such a choice leaves Nature to force particular outcomes. \n\n\
In the context of our opening discussion, imagine two partners with differing \
age and health (nearly always true even if only by a small degree). We should \
be able to agree that, eventually, they will both die but that one of them is \
likely to die ",
 Cell[BoxData[
  FormBox[
   RowBox[{"first", 
    SuperscriptBox[".", 
     ButtonBox["B8",
      BaseStyle->"Hyperlink",
      ButtonData->"endnoteB8"]]}], TraditionalForm]],ExpressionUUID->
  "fd8680ed-509b-476d-9403-506fa3093b5e"],
 " This results in the survivor continuing on without the other, perhaps \
dealing with heirs who do not understand the business the partners have \
jointly built and operated. Finally, if the age difference is great we can \
agree that the probabilities are not equal. Mortality tables and Nature tell \
us that the older partner may be expected to die ",
 Cell[BoxData[
  FormBox[
   RowBox[{"first", 
    SuperscriptBox[".", 
     StyleBox[
      ButtonBox[
       StyleBox["B9",
        FontSlant->"Plain"],
       BaseStyle->"Hyperlink",
       ButtonData->"endnoteB9"],
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "6e16b23a-597e-41e4-a7fc-eb237f487c81"]
}], "Text",
 CellChangeTimes->{{3.6809907914119563`*^9, 3.6809909386038065`*^9}, {
   3.6809913091848836`*^9, 3.680991653672242*^9}, {3.682248951100605*^9, 
   3.682248957680271*^9}, 3.6822633321001143`*^9, {3.68227228637473*^9, 
   3.682272290053508*^9}, {3.6986044891783123`*^9, 3.698604501668581*^9}, {
   3.6986045734918127`*^9, 3.6986046056535482`*^9}, {3.698604691962867*^9, 
   3.6986046919633675`*^9}},ExpressionUUID->"c3f6672c-a43f-4a10-99ab-\
f1c573567119"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g4result", "=", 
   RowBox[{
    RowBox[{".5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"60", " ", ".5"}], "+", 
       RowBox[{"50", " ", ".5"}]}], ")"}]}], "+", 
    RowBox[{".5", " ", "100"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"g4", "=", 
  RowBox[{"Style", "[", 
   RowBox[{
    RowBox[{"Framed", "[", 
     RowBox[{"TreePlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Do Nothing\>\""}], ",", 
           "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Take Action\>\""}], ",", 
           "\"\<\\n\\n.5\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Do Nothing\>\"", "\[Rule]", "\"\<Client dies\>\""}], 
           ",", "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Do Nothing\>\"", "\[Rule]", "\"\<Partner dies\>\""}], 
           ",", "\"\<.5\\n\>\""}], "}"}]}], "}"}], ",", "Left", ",", 
       RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
       RowBox[{"VertexRenderingFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "Yellow", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"#1", ",", "0.25"}], "]"}], ",", "Black", ",", 
            RowBox[{"Text", "[", 
             RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{"\"\<100\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"1.3", ",", "1.35"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<50\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.2", ",", "0"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<60\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.2", ",", ".9"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"StringJoin", "[", 
              RowBox[{"\"\<Expected result = \>\"", ",", 
               RowBox[{"ToString", "[", "g4result", "]"}]}], "]"}], ",", 
             "Red"}], "]"}], "]"}]}], "}"}]}]}], "]"}], "]"}], ",", "Red"}], 
   "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6033006525463047`*^9, 3.603300655515475*^9}, {
   3.6033007573182974`*^9, 3.603300796469537*^9}, {3.6033170350553308`*^9, 
   3.6033170676581955`*^9}, {3.6033959113510036`*^9, 3.603395923381692*^9}, {
   3.603395978671854*^9, 3.6033960071424828`*^9}, {3.6034107565130987`*^9, 
   3.603410757502155*^9}, {3.6034107876048765`*^9, 3.6034108097751446`*^9}, {
   3.6034108493504086`*^9, 3.603410957343585*^9}, {3.603411045870649*^9, 
   3.6034111065731206`*^9}, {3.6034111568509965`*^9, 
   3.6034111846345854`*^9}, {3.603411828355404*^9, 3.603412267549525*^9}, {
   3.603468562273399*^9, 3.6034687685231953`*^9}, {3.603468808924506*^9, 
   3.6034688225812874`*^9}, {3.6034688656687517`*^9, 
   3.6034689585040617`*^9}, {3.6034689918589697`*^9, 3.603469054929577*^9}, 
   3.603469165952927*^9, {3.6034692044341283`*^9, 3.6034692588842425`*^9}, {
   3.6034699966274395`*^9, 3.603470003038806*^9}, {3.6034703370569105`*^9, 
   3.6034704295932035`*^9}, {3.603470463907166*^9, 3.6034704699135094`*^9}, {
   3.603470513035976*^9, 3.6034706855498433`*^9}, {3.6034709334900246`*^9, 
   3.6034710086403227`*^9}, {3.6034710720949526`*^9, 3.603471404888987*^9}, {
   3.6034714391749477`*^9, 3.603471536542517*^9}, {3.60347157539874*^9, 
   3.603471584010232*^9}, {3.603471875794921*^9, 3.603471983108059*^9}, {
   3.603472036589118*^9, 3.6034720557352133`*^9}, {3.6034721565149775`*^9, 
   3.603472162295308*^9}, {3.6034735593542156`*^9, 3.603473598334445*^9}, {
   3.6034739904108706`*^9, 3.603474066434219*^9}, {3.603474120005283*^9, 
   3.603474120704323*^9}, 3.6809885281779537`*^9, {3.680988821267803*^9, 
   3.680988878197612*^9}, 3.6809893933129063`*^9, {3.6809894632449503`*^9, 
   3.680989464319627*^9}, {3.6809894964450417`*^9, 3.680989670550537*^9}, 
   3.680990134049247*^9, {3.680990169386113*^9, 3.6809902762960386`*^9}, {
   3.680990772382846*^9, 3.68099077488398*^9}, {3.680990966312471*^9, 
   3.6809911499848404`*^9}, {3.6809912249118524`*^9, 3.680991241925047*^9}, {
   3.6809917598742237`*^9, 3.6809917662886257`*^9}, {3.682248996185254*^9, 
   3.682249020566741*^9}, 
   3.6822490660490046`*^9},ExpressionUUID->"e0ab0ffe-638c-49df-878a-\
7d9bf3b89a78"],

Cell[BoxData[
 StyleBox[
  FrameBox[
   GraphicsBox[
    TagBox[
     GraphicsGroupBox[{
       GraphicsComplexBox[{{0., 0.8944271909999141}, {0.8944271909999165, 
        0.44721359549995704`}, {0.8944271909999156, 1.341640786499873}, {
        1.7888543819998328`, 0.}, {1.788854381999832, 0.8944271909999161}}, 
        {RGBColor[0.5, 0., 0.], 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 2}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 3}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 4}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\".5\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 5}]}}], {
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0., 0.8944271909999141}, 0.25], 
         {GrayLevel[0], InsetBox["\<\"Today\"\>", {0., 0.8944271909999141}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8944271909999165, 0.44721359549995704}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Do Nothing\"\>", \
{0.8944271909999165, 0.44721359549995704}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8944271909999156, 1.341640786499873}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Take Action\"\>", \
{0.8944271909999156, 1.341640786499873}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.7888543819998328, 0.}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Client dies\"\>", {1.7888543819998328, 0.}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.788854381999832, 0.8944271909999161}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Partner dies\"\>", \
{1.788854381999832, 0.8944271909999161}]}}}},
      ContentSelectable->True],
     Annotation[#, 
      VertexCoordinateRules -> {{0., 0.8944271909999141}, {0.8944271909999165,
        0.44721359549995704`}, {0.8944271909999156, 1.341640786499873}, {
       1.7888543819998328`, 0.}, {1.788854381999832, 0.8944271909999161}}]& ],
    AspectRatio->0.8660254037844382,
    BaseStyle->{FontSize -> 15, FontFamily -> "Times", Italic},
    Epilog->{
      InsetBox[
       FormBox["\"100\"", TraditionalForm], {1.3, 1.35}], 
      InsetBox[
       FormBox["\"50\"", TraditionalForm], {2.2, 0}], 
      InsetBox[
       FormBox["\"60\"", TraditionalForm], {2.2, 0.9}], 
      InsetBox[
       FormBox[
        StyleBox["\"Expected result = 77.5\"", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {0, 0}]},
    FrameTicks->None,
    ImageSize->600,
    PlotRange->All,
    PlotRangePadding->Scaled[0.1]],
   StripOnInput->False],
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontColor->RGBColor[1, 0, 0]]], "Output",
 CellChangeTimes->{{3.6809910045649805`*^9, 3.6809910750948462`*^9}, {
   3.680991142194722*^9, 3.680991150285948*^9}, 3.680991244823576*^9, 
   3.6809917674341683`*^9, 3.682249021457416*^9, 3.6822490815219126`*^9, 
   3.682270917169103*^9, 3.6823658318687296`*^9, 3.6948903469035482`*^9, 
   3.7314218611257176`*^9},
 TextAlignment->Center,ExpressionUUID->"d17a7ab3-6b1d-4201-83cb-5428c855c750"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.24",
  FontWeight->"Bold"],
 ". Adding a layer of alternatives to the simplest decision"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}, {
  3.698597520372753*^9, 3.6985975486660337`*^9}},
 TextAlignment->Center,ExpressionUUID->"9abba2fe-6883-4e1d-84bd-6b3e7dfe86a5"],

Cell["\<\
Naturally, one wonders where the Expected result comes from. Let\
\[CloseCurlyQuote]s take the easiest number first. Beginning at the far right \
with the payoffs times the probabilities we compute each step separately. \
First, the \[OpenCurlyDoubleQuote]Do Nothing\[CloseCurlyDoubleQuote] node is\
\>", "Text",
 CellChangeTimes->{{3.680991278064816*^9, 3.680991298574686*^9}, {
   3.680991674134095*^9, 3.6809917404040966`*^9}, {3.6809917882222424`*^9, 
   3.680991836334282*^9}, 3.682249058218917*^9, {3.6822633567175713`*^9, 
   3.682263372396244*^9}},ExpressionUUID->"b21fe22a-d67d-4b2b-9e07-\
3698cb0dc877"],

Cell["60 x .5 + 50 x .5 = 55", "Text",
 CellChangeTimes->{{3.6809918453741736`*^9, 3.680991882999797*^9}},
 TextAlignment->Center,ExpressionUUID->"379fa787-1c7c-4e8f-8555-51594cae12da"],

Cell["\<\
In turn, that value is multiplied by its probability and added to the same \
computation for \[OpenCurlyDoubleQuote]Take Action\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.6809919016221275`*^9, 
  3.6809919303940973`*^9}},ExpressionUUID->"ebed1824-7c99-4a5b-a2e8-\
1d85986c93a1"],

Cell[".5 x 55 +.5 x 100 = 77.5", "Text",
 CellChangeTimes->{{3.680991941144163*^9, 3.6809919798139567`*^9}, {
  3.680992033587719*^9, 3.68099203751405*^9}, {3.680992122409091*^9, 
  3.680992135973947*^9}},
 TextAlignment->Center,ExpressionUUID->"c115f6e5-faf0-4211-aae8-4aa95fa1055d"],

Cell["which is the same as", "Text",
 CellChangeTimes->{{3.680992048554208*^9, 
  3.6809920516940775`*^9}},ExpressionUUID->"124323fd-2775-4b96-89ae-\
8e41fcbece89"],

Cell[".5 x (60 x .5 + 50 x .5) + .5 x 100 = 77.5", "Text",
 CellChangeTimes->{{3.6809920564812326`*^9, 3.6809920905434675`*^9}},
 TextAlignment->Center,ExpressionUUID->"2281defe-b7a8-4d6b-a56d-d5d01c706050"],

Cell[TextData[{
 "As for the choice of payoff values, for the moment be satisfied with a hint \
that subjectivity is involved. So, if this is being viewed from your client\
\[CloseCurlyQuote]s standpoint it is reasonable to believe that he would put \
the \[OpenCurlyDoubleQuote]Payoff\[CloseCurlyDoubleQuote] of his own death \
below that of the partner\[CloseCurlyQuote]s ",
 Cell[BoxData[
  FormBox[
   RowBox[{"death", 
    SuperscriptBox[".", 
     ButtonBox["B10",
      BaseStyle->"Hyperlink",
      ButtonData->"endnoteB10"]]}], TraditionalForm]],ExpressionUUID->
  "97b76b94-2ef6-402c-9d66-853520698d8f"]
}], "Text",
 CellChangeTimes->{{3.6809922015536036`*^9, 3.6809924433463917`*^9}, 
   3.6822491119681687`*^9, {3.6822633999134307`*^9, 3.682263457541647*^9}, {
   3.682271040599556*^9, 3.682271043235541*^9}, 3.698604789544407*^9, {
   3.6986049993068137`*^9, 3.6986050008457947`*^9}, {3.6986051519199514`*^9, 
   3.6986051706396413`*^9}},ExpressionUUID->"f38c7c94-4620-4988-ac7c-\
1bc2925e6ca5"],

Cell["Bring on the lawyers", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 
  3.6986065777641625`*^9}},ExpressionUUID->"a2fc4833-8fcf-4d98-8418-\
12c65007a177"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 
  3.698604813983841*^9}},ExpressionUUID->"8541187a-7fad-4604-9e13-\
e8baae1eb3ef"],

Cell["\<\
Continuing our example, let's provide two outcomes for the \"Take Action\" \
node, to negotiate or litigate. Each of these are given, again somewhat \
arbitrary, values to permit the illustration to move forward.\
\>", "Text",
 CellChangeTimes->{{3.6809922015536036`*^9, 3.6809924433463917`*^9}, 
   3.6822491119681687`*^9, {3.6822633999134307`*^9, 3.682263457541647*^9}, {
   3.682271040599556*^9, 3.682271043235541*^9}, {3.6986047932290487`*^9, 
   3.698604798039459*^9}},ExpressionUUID->"a0517f1e-8042-49aa-b36b-\
0b91f2ca795e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g5result", "=", 
   RowBox[{
    RowBox[{".5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"60", " ", ".5"}], "+", 
       RowBox[{"50", " ", ".5"}]}], ")"}]}], "+", 
    RowBox[{".5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"100", " ", ".5"}], "+", 
       RowBox[{"90", " ", ".5"}]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"g5", "=", 
  RowBox[{"Style", "[", 
   RowBox[{
    RowBox[{"Framed", "[", 
     RowBox[{"TreePlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Do Nothing\>\""}], ",", 
           "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Take Action\>\""}], ",", 
           "\"\<\\n\\n.5\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Take Action\>\"", "\[Rule]", "\"\<Litigation\>\""}], 
           ",", "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Take Action\>\"", "\[Rule]", "\"\<Negotiation\>\""}], 
           ",", "\"\<.5\\n\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Do Nothing\>\"", "\[Rule]", "\"\<Client dies\>\""}], 
           ",", "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Do Nothing\>\"", "\[Rule]", "\"\<Partner dies\>\""}], 
           ",", "\"\<.5\\n\>\""}], "}"}]}], "}"}], ",", "Left", ",", 
       RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
       RowBox[{"VertexRenderingFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "Yellow", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"#1", ",", "0.25"}], "]"}], ",", "Black", ",", 
            RowBox[{"Text", "[", 
             RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{"\"\<100\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", "2.45"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<90\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", "1.6"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<60\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", ".85"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<50\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", ".02"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"StringJoin", "[", 
              RowBox[{"\"\<Expected result = \>\"", ",", 
               RowBox[{"ToString", "[", "g5result", "]"}]}], "]"}], ",", 
             "Red"}], "]"}], "]"}]}], "}"}]}]}], "]"}], "]"}], ",", "Red"}], 
   "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6033006525463047`*^9, 3.603300655515475*^9}, {
   3.6033007573182974`*^9, 3.603300796469537*^9}, {3.6033170350553308`*^9, 
   3.6033170676581955`*^9}, {3.6033959113510036`*^9, 3.603395923381692*^9}, {
   3.603395978671854*^9, 3.6033960071424828`*^9}, {3.6034107565130987`*^9, 
   3.603410757502155*^9}, {3.6034107876048765`*^9, 3.6034108097751446`*^9}, {
   3.6034108493504086`*^9, 3.603410957343585*^9}, {3.603411045870649*^9, 
   3.6034111065731206`*^9}, {3.6034111568509965`*^9, 
   3.6034111846345854`*^9}, {3.603411828355404*^9, 3.603412267549525*^9}, {
   3.603468562273399*^9, 3.6034687685231953`*^9}, {3.603468808924506*^9, 
   3.6034688225812874`*^9}, {3.6034688656687517`*^9, 
   3.6034689585040617`*^9}, {3.6034689918589697`*^9, 3.603469054929577*^9}, 
   3.603469165952927*^9, {3.6034692044341283`*^9, 3.6034692588842425`*^9}, {
   3.6034699966274395`*^9, 3.603470003038806*^9}, {3.6034703370569105`*^9, 
   3.6034704295932035`*^9}, {3.603470463907166*^9, 3.6034704699135094`*^9}, {
   3.603470513035976*^9, 3.6034706855498433`*^9}, {3.6034709334900246`*^9, 
   3.6034710086403227`*^9}, {3.6034710720949526`*^9, 3.603471404888987*^9}, {
   3.6034714391749477`*^9, 3.603471536542517*^9}, {3.60347157539874*^9, 
   3.603471584010232*^9}, {3.603471875794921*^9, 3.603471983108059*^9}, {
   3.603472036589118*^9, 3.6034720557352133`*^9}, {3.6034721565149775`*^9, 
   3.603472162295308*^9}, {3.6034735593542156`*^9, 3.603473598334445*^9}, {
   3.6034739904108706`*^9, 3.603474066434219*^9}, {3.603474120005283*^9, 
   3.603474120704323*^9}, 3.6809885281779537`*^9, {3.680988821267803*^9, 
   3.680988878197612*^9}, 3.6809893933129063`*^9, {3.6809894632449503`*^9, 
   3.680989464319627*^9}, {3.6809894964450417`*^9, 3.680989670550537*^9}, 
   3.680990134049247*^9, {3.680990169386113*^9, 3.6809902762960386`*^9}, {
   3.680990772382846*^9, 3.68099077488398*^9}, {3.680990966312471*^9, 
   3.6809911499848404`*^9}, {3.6809912249118524`*^9, 3.680991241925047*^9}, {
   3.6809917598742237`*^9, 3.6809917662886257`*^9}, {3.6809921850665383`*^9, 
   3.6809921880937405`*^9}, 3.6809924704632025`*^9, {3.6809925266051593`*^9, 
   3.680992589813464*^9}, {3.6809926277332106`*^9, 3.6809928699530168`*^9}, {
   3.68224912571986*^9, 3.682249143880681*^9}, 3.682249409927187*^9, {
   3.682249495828002*^9, 
   3.682249511207129*^9}},ExpressionUUID->"1ec1fa1b-0d27-440c-860d-\
f631b0af1b6b"],

Cell[BoxData[
 StyleBox[
  FrameBox[
   GraphicsBox[
    TagBox[
     GraphicsGroupBox[{
       GraphicsComplexBox[{{0., 1.2247448713915874`}, {0.816496580927727, 
        0.4082482904638622}, {0.8164965809277253, 2.0412414523193143`}, {
        1.6329931618554516`, 1.6329931618554523`}, {1.632993161855451, 
        2.4494897427831783`}, {1.6329931618554536`, 0.}, {1.6329931618554527`,
         0.8164965809277261}}, 
        {RGBColor[0.5, 0., 0.], 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 2}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 3}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 6}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\".5\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 7}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{3, 4}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\".5\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{3, 5}]}}], {
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0., 1.2247448713915874}, 0.25], 
         {GrayLevel[0], InsetBox["\<\"Today\"\>", {0., 1.2247448713915874}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.816496580927727, 0.4082482904638622}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Do Nothing\"\>", \
{0.816496580927727, 0.4082482904638622}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.8164965809277253, 2.0412414523193143}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Take Action\"\>", \
{0.8164965809277253, 2.0412414523193143}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.6329931618554516, 1.6329931618554523}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Litigation\"\>", \
{1.6329931618554516, 1.6329931618554523}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.632993161855451, 2.4494897427831783}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Negotiation\"\>", \
{1.632993161855451, 2.4494897427831783}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.6329931618554536, 0.}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Client dies\"\>", {1.6329931618554536, 0.}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.6329931618554527, 0.8164965809277261}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Partner dies\"\>", \
{1.6329931618554527, 0.8164965809277261}]}}}},
      ContentSelectable->True],
     Annotation[#, 
      VertexCoordinateRules -> {{0., 1.2247448713915874`}, {0.816496580927727,
        0.4082482904638622}, {0.8164965809277253, 2.0412414523193143`}, {
       1.6329931618554516`, 1.6329931618554523`}, {1.632993161855451, 
       2.4494897427831783`}, {1.6329931618554536`, 0.}, {1.6329931618554527`, 
       0.8164965809277261}}]& ],
    AspectRatio->1.2247448713915885`,
    BaseStyle->{FontSize -> 15, FontFamily -> "Times", Italic},
    Epilog->{
      InsetBox[
       FormBox["\"100\"", TraditionalForm], {2, 2.45}], 
      InsetBox[
       FormBox["\"90\"", TraditionalForm], {2, 1.6}], 
      InsetBox[
       FormBox["\"60\"", TraditionalForm], {2, 0.85}], 
      InsetBox[
       FormBox["\"50\"", TraditionalForm], {2, 0.02}], 
      InsetBox[
       FormBox[
        StyleBox["\"Expected result = 75.\"", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {0, 0}]},
    FrameTicks->None,
    ImageSize->600,
    PlotRange->All,
    PlotRangePadding->Scaled[0.1]],
   StripOnInput->False],
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontColor->RGBColor[1, 0, 0]]], "Output",
 CellChangeTimes->{
  3.6809924812707224`*^9, {3.680992527479582*^9, 3.680992590109748*^9}, {
   3.6809926324729238`*^9, 3.680992660661662*^9}, {3.68099270903299*^9, 
   3.680992796132825*^9}, {3.680992852367958*^9, 3.6809928701953106`*^9}, 
   3.682249144083629*^9, 3.6822494103022203`*^9, 3.682249537829988*^9, 
   3.6822710878969593`*^9, 3.6823658319468336`*^9, 3.6948903469627066`*^9, 
   3.731421861170838*^9},
 TextAlignment->Center,ExpressionUUID->"444b945b-1eec-4454-836d-e5fec8dc1b86"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.25",
  FontWeight->"Bold"],
 ". Further complicating the set of alternatives"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}, {
  3.6985975956760397`*^9, 3.6985976142685385`*^9}},
 TextAlignment->Center,ExpressionUUID->"7869a79f-3603-4d55-ba57-7089a51e87fc"],

Cell["\<\
Rounding out our stylized example, we add choices arising from the  \
\[OpenCurlyDoubleQuote]Negotiation\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]Litigation\[CloseCurlyDoubleQuote] alternatives, \
keeping probabilities even and adding, still arbitrary, payoff values. The \
Expected result is calculated as before.\
\>", "Text",
 CellChangeTimes->{{3.6822505301441803`*^9, 3.682250633057803*^9}, {
  3.682263527923737*^9, 
  3.6822635535017433`*^9}},ExpressionUUID->"90547a4c-a152-4448-a8c6-\
dc5c577ac9ed"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g6result", "=", 
   RowBox[{
    RowBox[{".5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{".5", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"80", " ", ".5"}], "+", 
          RowBox[{"70", " ", ".5"}]}], ")"}]}], "+", 
       RowBox[{".5", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{".5", " ", "90"}], "+", 
          RowBox[{".5", " ", "100"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{".5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{".5", " ", "60"}], "+", 
       RowBox[{".5", " ", "50"}]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"g6", "=", 
  RowBox[{"Style", "[", 
   RowBox[{
    RowBox[{"Framed", "[", 
     RowBox[{"TreePlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Do Nothing\>\""}], ",", 
           "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Take Action\>\""}], ",", 
           "\"\<\\n\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Take Action\>\"", "\[Rule]", "\"\<Litigation\>\""}], 
           ",", "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Take Action\>\"", "\[Rule]", "\"\<Negotiation\>\""}], 
           ",", "\"\<.5\\n\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Do Nothing\>\"", "\[Rule]", "\"\<Client dies\>\""}], 
           ",", "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Do Nothing\>\"", "\[Rule]", "\"\<Partner dies\>\""}], 
           ",", "\"\<.5\\n\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "\"\<Negotiation\>\"", "\[Rule]", "\"\<Negotiated\\nBuyout\>\""}], 
           ",", "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "\"\<Negotiation\>\"", "\[Rule]", 
            "\"\<\\nSale or\\n    Exchange\\n\>\""}], ",", "\"\<.5\\n\>\""}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Litigation\>\"", "\[Rule]", "\"\<Forced\\nSale\>\""}],
            ",", "\"\<\\n.5\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Litigation\>\"", "\[Rule]", "\"\<Buyout\>\""}], ",", 
           "\"\<.5\\n\>\""}], "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
       "Left", ",", 
       RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
       RowBox[{"VertexRenderingFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "Yellow", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"#1", ",", "0.25"}], "]"}], ",", "Black", ",", 
            RowBox[{"Text", "[", 
             RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{"\"\<100\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", "3.5"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<90\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", "2.7"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<80\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", "1.95"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<70\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", "1.15"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<Client Owns with\\nPartner Heirs\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.2", ",", ".75"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<60\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", ".75"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<Client Heirs\\nOwn with Partner\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.2", ",", ".02"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<50\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", ".02"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"StringJoin", "[", 
              RowBox[{"\"\<Expected result = \>\"", ",", 
               RowBox[{"ToString", "[", "g6result", "]"}]}], "]"}], ",", 
             "Red"}], "]"}], "]"}]}], "}"}]}]}], "]"}], "]"}], ",", "Red"}], 
   "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6033006525463047`*^9, 3.603300655515475*^9}, {
   3.6033007573182974`*^9, 3.603300796469537*^9}, {3.6033170350553308`*^9, 
   3.6033170676581955`*^9}, {3.6033959113510036`*^9, 3.603395923381692*^9}, {
   3.603395978671854*^9, 3.6033960071424828`*^9}, {3.6034107565130987`*^9, 
   3.603410757502155*^9}, {3.6034107876048765`*^9, 3.6034108097751446`*^9}, {
   3.6034108493504086`*^9, 3.603410957343585*^9}, {3.603411045870649*^9, 
   3.6034111065731206`*^9}, {3.6034111568509965`*^9, 
   3.6034111846345854`*^9}, {3.603411828355404*^9, 3.603412267549525*^9}, {
   3.603468562273399*^9, 3.6034687685231953`*^9}, {3.603468808924506*^9, 
   3.6034688225812874`*^9}, {3.6034688656687517`*^9, 
   3.6034689585040617`*^9}, {3.6034689918589697`*^9, 3.603469054929577*^9}, 
   3.603469165952927*^9, {3.6034692044341283`*^9, 3.6034692588842425`*^9}, {
   3.6034699966274395`*^9, 3.603470003038806*^9}, {3.6034703370569105`*^9, 
   3.6034704295932035`*^9}, {3.603470463907166*^9, 3.6034704699135094`*^9}, {
   3.603470513035976*^9, 3.6034706855498433`*^9}, {3.6034709334900246`*^9, 
   3.6034710086403227`*^9}, {3.6034710720949526`*^9, 3.603471404888987*^9}, {
   3.6034714391749477`*^9, 3.603471536542517*^9}, {3.60347157539874*^9, 
   3.603471584010232*^9}, {3.603471875794921*^9, 3.603471983108059*^9}, {
   3.603472036589118*^9, 3.6034720557352133`*^9}, {3.6034721565149775`*^9, 
   3.603472162295308*^9}, {3.6034735593542156`*^9, 3.603473598334445*^9}, {
   3.6034739904108706`*^9, 3.603474066434219*^9}, {3.603474120005283*^9, 
   3.603474120704323*^9}, 3.6809885281779537`*^9, {3.680988821267803*^9, 
   3.680988878197612*^9}, 3.6809893933129063`*^9, {3.6809894632449503`*^9, 
   3.680989464319627*^9}, {3.6809894964450417`*^9, 3.680989670550537*^9}, 
   3.680990134049247*^9, {3.680990169386113*^9, 3.6809902762960386`*^9}, {
   3.680990772382846*^9, 3.68099077488398*^9}, {3.680990966312471*^9, 
   3.6809911499848404`*^9}, {3.6809912249118524`*^9, 3.680991241925047*^9}, {
   3.6809917598742237`*^9, 3.6809917662886257`*^9}, {3.6809921850665383`*^9, 
   3.6809921880937405`*^9}, 3.6809924704632025`*^9, {3.6809925266051593`*^9, 
   3.680992589813464*^9}, {3.6809926277332106`*^9, 3.6809928699530168`*^9}, {
   3.68224912571986*^9, 3.682249143880681*^9}, {3.682249384060742*^9, 
   3.682249394256723*^9}, {3.682249757482933*^9, 3.682249769443985*^9}, {
   3.682249803760685*^9, 3.682249866966345*^9}, {3.6822499273701553`*^9, 
   3.682249954879283*^9}, {3.682249989247903*^9, 3.682249990060463*^9}, {
   3.6822500247077985`*^9, 3.6822500459393225`*^9}, {3.682250108468666*^9, 
   3.682250183565791*^9}, 3.682250276974346*^9, {3.6822503079919324`*^9, 
   3.682250481329376*^9}, {3.682250856255248*^9, 
   3.68225091619357*^9}},ExpressionUUID->"d0938010-84f5-4add-9dfd-\
ddd89c489b35"],

Cell[BoxData[
 StyleBox[
  FrameBox[
   GraphicsBox[
    TagBox[
     GraphicsGroupBox[{
       GraphicsComplexBox[{{0., 1.3572417850765908`}, {0.7755667343294824, 
        0.3877833671647399}, {0.7755667343294803, 2.326700202988443}, {
        1.5511334686589626`, 1.5511334686589628`}, {1.551133468658961, 
        3.1022669373179252`}, {1.5511334686589644`, 0.}, {1.5511334686589635`,
         0.7755667343294814}, {2.3267002029884427`, 2.7144835701531855`}, {
        2.326700202988442, 3.490050304482667}, {2.326700202988444, 
        1.163350101494223}, {2.326700202988443, 1.9389168358237043`}}, 
        {RGBColor[0.5, 0., 0.], 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 2}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 3}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 6}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\".5\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 7}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{3, 4}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\".5\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{3, 5}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{4, 10}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\".5\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{4, 11}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n.5\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{5, 8}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\".5\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{5, 9}]}}], {
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0., 1.3572417850765908}, 0.25], 
         {GrayLevel[0], InsetBox["\<\"Today\"\>", {0., 1.3572417850765908}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.7755667343294824, 0.3877833671647399}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Do Nothing\"\>", \
{0.7755667343294824, 0.3877833671647399}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.7755667343294803, 2.326700202988443}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Take Action\"\>", \
{0.7755667343294803, 2.326700202988443}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.5511334686589626, 1.5511334686589628}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Litigation\"\>", \
{1.5511334686589626, 1.5511334686589628}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.551133468658961, 3.1022669373179252}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Negotiation\"\>", \
{1.551133468658961, 3.1022669373179252}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.5511334686589644, 0.}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Client dies\"\>", {1.5511334686589644, 0.}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.5511334686589635, 0.7755667343294814}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Partner dies\"\>", \
{1.5511334686589635, 0.7755667343294814}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{2.3267002029884427, 2.7144835701531855}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Negotiated\\nBuyout\"\>", \
{2.3267002029884427, 2.7144835701531855}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{2.326700202988442, 3.490050304482667}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"\\nSale or\\n    Exchange\\n\"\>", \
{2.326700202988442, 3.490050304482667}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{2.326700202988444, 1.163350101494223}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Forced\\nSale\"\>", \
{2.326700202988444, 1.163350101494223}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{2.326700202988443, 1.9389168358237043}, 0.25], 
         {GrayLevel[0], 
          InsetBox["\<\"Buyout\"\>", \
{2.326700202988443, 1.9389168358237043}]}}}},
      ContentSelectable->True],
     Annotation[#, 
      VertexCoordinateRules -> {{0., 1.3572417850765908`}, {
       0.7755667343294824, 0.3877833671647399}, {0.7755667343294803, 
       2.326700202988443}, {1.5511334686589626`, 1.5511334686589628`}, {
       1.551133468658961, 3.1022669373179252`}, {1.5511334686589644`, 0.}, {
       1.5511334686589635`, 0.7755667343294814}, {2.3267002029884427`, 
       2.7144835701531855`}, {2.326700202988442, 3.490050304482667}, {
       2.326700202988444, 1.163350101494223}, {2.326700202988443, 
       1.9389168358237043`}}]& ],
    AspectRatio->1.2247448713915894`,
    BaseStyle->{FontSize -> 15, FontFamily -> "Times", Italic},
    Epilog->{
      InsetBox[
       FormBox["\"100\"", TraditionalForm], {2.7, 3.5}], 
      InsetBox[
       FormBox["\"90\"", TraditionalForm], {2.7, 2.7}], 
      InsetBox[
       FormBox["\"80\"", TraditionalForm], {2.7, 1.95}], 
      InsetBox[
       FormBox["\"70\"", TraditionalForm], {2.7, 1.15}], 
      InsetBox[
       FormBox["\"Client Owns with\\nPartner Heirs\"", TraditionalForm], {2.2,
        0.75}], 
      InsetBox[
       FormBox["\"60\"", TraditionalForm], {2.7, 0.75}], 
      InsetBox[
       FormBox["\"Client Heirs\\nOwn with Partner\"", TraditionalForm], {2.2, 
       0.02}], 
      InsetBox[
       FormBox["\"50\"", TraditionalForm], {2.7, 0.02}], 
      InsetBox[
       FormBox[
        StyleBox["\"Expected result = 70.\"", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {0, 0}]},
    FrameTicks->None,
    ImageSize->600,
    PlotRange->All,
    PlotRangePadding->Scaled[0.1]],
   StripOnInput->False],
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontColor->RGBColor[1, 0, 0]]], "Output",
 CellChangeTimes->{
  3.6822497720698156`*^9, {3.6822500040349817`*^9, 3.682250049804537*^9}, 
   3.682250189598302*^9, 3.682250278208832*^9, 3.6822503101952667`*^9, {
   3.682250369237688*^9, 3.682250422136256*^9}, 3.6822504866899137`*^9, {
   3.682250857130742*^9, 3.682250916474651*^9}, 3.682271167697733*^9, 
   3.682365832040613*^9, 3.694890347034593*^9, 3.731421861223005*^9},
 TextAlignment->Center,ExpressionUUID->"7e9d83fd-9902-4935-b04f-65879763820f"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.26",
  FontWeight->"Bold"],
 ". A minimum set of realistic alternatives"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}, {
  3.698597651684987*^9, 3.6985976801729326`*^9}},
 TextAlignment->Center,ExpressionUUID->"9d5718e5-7c2a-4b1e-b254-8049fdf98c14"],

Cell["Nearly infinite variations", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 3.6986065777641625`*^9}, {3.6986066152627025`*^9, 
  3.698606633634901*^9}},ExpressionUUID->"af250846-1662-422a-ac73-\
8f7df9dc3a68"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 
  3.6986065777641625`*^9}},ExpressionUUID->"e4aa3ed4-2663-4d74-8a62-\
093c596a261a"],

Cell[TextData[{
 "By now, in this relatively simple example, we have six payoffs and ten \
probabilities. We can make our example more realistic by adding more nodes. \
For instance, we may assume that each of the conclusions in the top four \
outcomes may be \[OpenCurlyDoubleQuote]At Market\[CloseCurlyDoubleQuote] or \
\[OpenCurlyDoubleQuote]Below Market\[CloseCurlyDoubleQuote] as buyers and \
brokers swarm properties that are the subject of ownership controversy.\n\n\
Rather than expand the structure of this example, let us explore how the \
Expected result changes under different assumptions. At the same time, let us \
automate the calculations to relieve the tedium. Below is an interactive \
graphic which provides the user with several alternatives and automatically \
calculations Expected result under the chosen conditions.\n\nIn the example \
above, we assumed probabilities and payoffs were all fixed at the values \
given. That is the default for the \[OpenCurlyDoubleQuote]Fixed\
\[CloseCurlyDoubleQuote] button below, an outcome identical to Figure 11.26 \
above. At the other extreme we might assume that all of those values are \
random. Selecting the \[OpenCurlyDoubleQuote]Random\[CloseCurlyDoubleQuote] \
button in Figure 11.27 (and repeatedly using the \
\[OpenCurlyDoubleQuote]Re-randomize\[CloseCurlyDoubleQuote] button that \
appears when \[OpenCurlyDoubleQuote]Random\[CloseCurlyDoubleQuote] is \
selected) one may view values and probabilities chosen Monte Carlo style and \
the related, somewhat chaotic, Expected result.\n\nFramed by the two \
extremes, Fixed and Random, is the usual middle ground that culminates in \
partner dissolution. Earlier we made the distinction between two deaths, \
making it easy to agree that yours is less desirable than someone ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"else", "'"}], 
    RowBox[{
     StyleBox["s",
      FontSlant->"Plain"], 
     SuperscriptBox[".", 
      ButtonBox["B11",
       BaseStyle->"Hyperlink",
       ButtonData->"endnoteB11"]]}]}], TraditionalForm]],ExpressionUUID->
  "0adbe3d0-0426-4bc1-a6fe-2494dbd8f9fc"],
 " Now let us simplistically assume that there are three broad classes of \
personality types that characterize ",
 Cell[BoxData[
  FormBox[
   RowBox[{"partners", 
    SuperscriptBox[".", 
     ButtonBox["B12",
      BaseStyle->"Hyperlink",
      ButtonData->"endnoteB12"]]}], TraditionalForm]],ExpressionUUID->
  "384b6ccb-5133-4339-b753-033f1ded7a15"],
 " One is \[OpenCurlyDoubleQuote]Engaged\[CloseCurlyDoubleQuote] where the \
partners share authority and responsibilities well and equally. The other two \
are \[OpenCurlyDoubleQuote]Aggressive\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]Passive\[CloseCurlyDoubleQuote] each having their \
common meaning and presumed to apply to individual partners to different \
degrees. These three types are shown under the \
\[OpenCurlyDoubleQuote]Approach\[CloseCurlyDoubleQuote] button. Each type \
comes with a different set of payoffs and probabilities that, while still \
arbitrary, are less arbitrary than the \[OpenCurlyDoubleQuote]Fixed\
\[CloseCurlyDoubleQuote] case and less mechanistic than the \
\[OpenCurlyDoubleQuote]Random\[CloseCurlyDoubleQuote] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"case", 
    SuperscriptBox[".", 
     ButtonBox["B13",
      BaseStyle->"Hyperlink",
      ButtonData->"endnoteB13"]]}], TraditionalForm]],ExpressionUUID->
  "b01eb3a1-fce7-4b50-8942-f2f9a10ee440"],
 " Without dwelling too much on the specifics, note the Expected result for \
each of these three cases. Deliberately, this value declines as each \
individual custom choice is made. This suggests that \
\[OpenCurlyDoubleQuote]Engaged\[CloseCurlyDoubleQuote] provides the best \
outcome, \[OpenCurlyDoubleQuote]Passive\[CloseCurlyDoubleQuote] the worst and \
\[OpenCurlyDoubleQuote]Aggressive\[CloseCurlyDoubleQuote] falls in the \
middle.\n\nOne can argue endlessly about whether the three classifications \
are useful or realistic. Indeed, one can make a persuasive case that there \
should be 30 or 300 rather than three classes. Actually, one could take the \
position that a World of 7 billion souls produces the same number of unique \
classes. As Facebook approaches 100% of the World\[CloseCurlyQuote]s \
population as subscribers, their algorithms have the opportunity to sort them \
all out. But we are concerned with a specific piece of real property and a \
small number of owners so we won\[CloseCurlyQuote]t explore the limits of Big \
Data here."
}], "Text",
 CellChangeTimes->{{3.682250764110051*^9, 3.6822507770030975`*^9}, {
  3.6822509385734057`*^9, 3.6822511441417093`*^9}, {3.6822511903085833`*^9, 
  3.682251211199051*^9}, {3.6822512709751577`*^9, 3.68225156169522*^9}, {
  3.682252183207941*^9, 3.6822526472437925`*^9}, {3.6822526906623397`*^9, 
  3.682253076891938*^9}, {3.6822635863541107`*^9, 3.682263779417378*^9}, {
  3.69860552173656*^9, 3.6986055228055844`*^9}, {3.6986056022259245`*^9, 
  3.6986056022259245`*^9}, {3.6986056950848436`*^9, 3.6986057547002745`*^9}, {
  3.6986058134157085`*^9, 3.6986058317524376`*^9}, {3.698605960729741*^9, 
  3.6986059632459583`*^9}, {3.698606059291963*^9, 
  3.698606101749558*^9}},ExpressionUUID->"2bbdf89f-0fda-4c52-b856-\
8f073b4185bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g7", "=", 
  RowBox[{"TabView", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<Fixed/Random/Approach\>\"", "\[Rule]", 
      RowBox[{"Manipulate", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Dynamic", "@", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"regime", "\[NotEqual]", "1"}], ",", "\[IndentingNewLine]",
            "\[IndentingNewLine]", 
           RowBox[{"fct1", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{"i", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "100", ",", "50", ",", 
                 RowBox[{"-", "10"}]}], "}"}]}], "]"}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{"Riffle", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"ConstantArray", "[", 
                    RowBox[{"1", ",", "5"}], "]"}], "-", "#"}], ")"}], ",", 
                 "#"}], "]"}], "&"}], "[", 
              RowBox[{"custprobs", "[", 
               RowBox[{"[", "regime", "]"}], "]"}], "]"}]}], "]"}], ",", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"Dynamic", "@", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"variable", "===", "fixed"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Column", "[", 
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Invisible", "[", 
                  RowBox[{"Button", "[", 
                   RowBox[{"\"\<Re-randomize\>\"", ",", 
                    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}], "]"}],
                  ",", "\[IndentingNewLine]", 
                 RowBox[{"fct1", "[", 
                  RowBox[{
                   RowBox[{"Table", "[", 
                    RowBox[{"i", ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "100", ",", "50", ",", 
                    RowBox[{"-", "10"}]}], "}"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    ".5", ",", ".5", ",", ".5", ",", ".5", ",", ".5", ",", 
                    ".5", ",", ".5", ",", ".5", ",", ".5", ",", ".5"}], 
                    "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], "]"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{"Column", "[", 
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Button", "[", 
                  RowBox[{"\"\<Re-randomize\>\"", ",", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"payoff", "=", 
                    RowBox[{"RandomInteger", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"10", ",", "100"}], "}"}], ",", "6"}], "]"}]}], 
                    ";", "\[IndentingNewLine]", 
                    RowBox[{"probs", "=", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Riffle", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ConstantArray", "[", 
                    RowBox[{"1", ",", "5"}], "]"}], "-", "#"}], ")"}], ",", 
                    "#"}], "]"}], "&"}], "[", 
                    RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"RandomInteger", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "9"}], "}"}], ",", "5"}], "]"}], "/", 
                    "10"}], "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], 
                  "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"fct1", "[", 
                  RowBox[{"payoff", ",", "probs"}], "]"}]}], 
                "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", 
             "]"}]}]}], 
          RowBox[{"(*", 
           RowBox[{"end", " ", "first", " ", "IF"}], "*)"}], 
          "\[IndentingNewLine]", "]"}]}], 
        RowBox[{"(*", 
         RowBox[{"end", " ", "second", " ", "If"}], "*)"}], ",", "\n", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"variable", ",", "fixed", ",", "\"\<Choose\>\""}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"fixed", "\[Rule]", "\"\<Fixed\>\""}], ",", 
                RowBox[{"random", "\[Rule]", "\"\<Random\>\""}]}], "}"}]}], 
             "}"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"Control", "@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"regime", ",", "1", ",", "\"\<  or  \>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "\[Rule]", "\"\<Approach\>\""}], ",", 
                RowBox[{"2", "\[Rule]", "\"\<Engaged\>\""}], ",", 
                RowBox[{"3", "\[Rule]", "\"\<Aggressive\>\""}], ",", 
                RowBox[{"4", "\[Rule]", "\"\<Passive\>\""}]}], "}"}], ",", 
              RowBox[{"ControlType", "\[Rule]", "PopupMenu"}], ",", 
              RowBox[{"FieldSize", "\[Rule]", "Small"}]}], "}"}]}]}], 
          "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Initialization", "\[RuleDelayed]", 
         RowBox[{"(", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"fct1", "[", 
             RowBox[{
              RowBox[{"payoff_List", "/;", 
               RowBox[{
                RowBox[{"Length", "[", "payoff", "]"}], "\[Equal]", "6"}]}], 
              ",", 
              RowBox[{"probs_List", "/;", 
               RowBox[{
                RowBox[{"Length", "[", "probs", "]"}], "\[Equal]", "10"}]}]}],
              "]"}], ":=", 
            RowBox[{"Module", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "vertices", ",", "edges", ",", "outcomes", ",", "labels", ",", 
                "eLabels", ",", "vlabels", ",", "vsh"}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"vsh", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"xc_", ",", "yc_"}], "}"}], ",", "name_", ",", 
                  RowBox[{"{", 
                   RowBox[{"w_", ",", "h_"}], "}"}]}], "]"}], ":=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "LightYellow",
                   ",", 
                  RowBox[{"Disk", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"xc", ",", "yc"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.25", ",", "0.25"}], "}"}]}], "]"}], ",", 
                  RowBox[{"Inset", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{"labels", "[", 
                    RowBox[{"[", "name", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"FontSize", "\[Rule]", "10"}], ",", "Black"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"xc", ",", "yc"}], "}"}]}], "]"}]}], "}"}]}], ";",
                "\[IndentingNewLine]", 
               RowBox[{"vertices", "=", 
                RowBox[{"Range", "[", "11", "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"edges", "=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"1", "\[DirectedEdge]", "2"}], ",", 
                  RowBox[{"1", "\[DirectedEdge]", "3"}], ",", 
                  RowBox[{"2", "\[DirectedEdge]", "4"}], ",", 
                  RowBox[{"2", "\[DirectedEdge]", "5"}], ",", 
                  RowBox[{"3", "\[DirectedEdge]", "6"}], ",", 
                  RowBox[{"3", "\[DirectedEdge]", "9"}], ",", 
                  RowBox[{"6", "\[DirectedEdge]", "7"}], ",", 
                  RowBox[{"6", "\[DirectedEdge]", "8"}], ",", 
                  RowBox[{"9", "\[DirectedEdge]", "10"}], ",", 
                  RowBox[{"9", "\[DirectedEdge]", "11"}]}], "}"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"outcomes", "=", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Today\>\"", ",", "\"\<Do Nothing\>\"", ",", 
                  "\"\<Take Action\>\"", ",", "\"\<Client\\nDies\>\"", ",", 
                  "\"\<Partner\\nDies\>\"", ",", "\"\<Litigation\>\"", ",", 
                  "\"\<Forced\\nSale\>\"", ",", "\"\<Negotiated\\nBuyout\>\"",
                   ",", "\"\<Negotiation\>\"", ",", 
                  "\"\<Negotiated\\nBuyout\>\"", ",", 
                  "\"\<\\nSale or\\nExchange\\n\>\""}], "}"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"labels", "=", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "10"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
                    "Italic"}], "}"}]}], "]"}], "&"}], "/@", "outcomes"}]}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"eLabels", "=", "probs"}], ";", "\[IndentingNewLine]", 
               RowBox[{"eLabels", "=", 
                RowBox[{"MapThread", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Rule", "[", 
                    RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"edges", ",", "eLabels"}], "}"}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"vlabels", "=", 
                RowBox[{"MapThread", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Rule", "[", 
                    RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Range", "[", "11", "]"}], ",", "labels"}], 
                   "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
               "\[IndentingNewLine]", 
               RowBox[{"Show", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Graph", "[", 
                  RowBox[{
                  "vertices", ",", "edges", ",", "\[IndentingNewLine]", 
                   RowBox[{"EdgeLabels", "\[Rule]", "eLabels"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"GraphLayout", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"\"\<LayeredEmbedding\>\"", ",", 
                    RowBox[{"\"\<Orientation\>\"", "\[Rule]", "Left"}]}], 
                    "}"}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{"VertexShapeFunction", "\[Rule]", "vsh"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"ImageSize", "\[Rule]", "442"}]}], 
                  "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"Epilog", "\[Rule]", 
                  RowBox[{"{", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"\"\<Expected Result =\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "payoff", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "10", 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    "payoff", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "9", 
                    "\[RightDoubleBracket]"}]}]}], ")"}], " ", 
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "6", 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "5", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "8", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{
                    "payoff", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "7", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{
                    "payoff", "\[LeftDoubleBracket]", "4", 
                    "\[RightDoubleBracket]"}]}]}], ")"}]}]}], ")"}], " ", 
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "payoff", "\[LeftDoubleBracket]", "5", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "4", 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    "payoff", "\[LeftDoubleBracket]", "6", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{
                    "probs", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}]}]}], ")"}]}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "3.45"}], "}"}]}], "]"}], ",", "Red"}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"payoff", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", "3.45"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"payoff", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", "2.7"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"payoff", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", "1.9"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"payoff", "[", 
                    RowBox[{"[", "4", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", "1.15"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"payoff", "[", 
                    RowBox[{"[", "5", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", ".75"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{"\"\<\\nClient Owns\\nw/Partner\\nHeirs\>\"", ",", 
                    RowBox[{"{", 
                    RowBox[{"2.0", ",", ".75"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"payoff", "[", 
                    RowBox[{"[", "6", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", ".02"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    "\"\<Client\\n   Heirs Own\\nwith Partner\>\"", ",", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", ".02"}], "}"}]}], "]"}]}], "}"}]}], ",",
                  "\[IndentingNewLine]", 
                 RowBox[{"PlotRangePadding", "\[Rule]", "0.25"}], ",", 
                 RowBox[{"BaseStyle", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "10"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
                    "Italic"}], "}"}]}]}], "]"}]}]}], "\[IndentingNewLine]", 
             "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"payoff", "=", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"10", ",", "100"}], "}"}], ",", "6"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"probs", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"Riffle", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"ConstantArray", "[", 
                   RowBox[{"1", ",", "5"}], "]"}], "-", "#"}], ")"}], ",", 
                "#"}], "]"}], "&"}], "[", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"RandomInteger", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "9"}], "}"}], ",", "5"}], "]"}], "/", 
               "10"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"custprobs", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{".5", ",", ".5", ",", ".5", ",", ".5", ",", ".5"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{".9", ",", ".8", ",", ".7", ",", ".6", ",", ".2"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{".9", ",", ".5", ",", ".2", ",", ".5", ",", ".5"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{".1", ",", ".5", ",", ".8", ",", ".5", ",", ".5"}], 
               "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", ")"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{"fixed", ",", "random"}], "}"}]}]}], "\[IndentingNewLine]", 
       "]"}]}], "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "===", "===", "===", "===", "===", "===", "===", "===", "===", "===", 
        "==="}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Second", " ", "Tab"}], "===", "===", "===", "===", "===", "===",
          "===", "==="}], "="}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"\"\<Custom\>\"", "\[Rule]", 
      RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"pr", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Riffle", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"ConstantArray", "[", 
                 RowBox[{"1", ",", "5"}], "]"}], "-", "#"}], ")"}], ",", 
              "#"}], "]"}], "&"}], "[", 
           RowBox[{"{", 
            RowBox[{"pr1", ",", "pr2", ",", "pr3", ",", "pr4", ",", "pr5"}], 
            "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"value", "=", 
          RowBox[{"{", 
           RowBox[{
           "v1", ",", "v2", ",", "v3", ",", "v4", ",", "v5", ",", "v6"}], 
           "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Dynamic", "@", 
          RowBox[{"fct2", "[", 
           RowBox[{"value", ",", "pr"}], "]"}]}]}], ",", "\n", "\t ", 
        "\[IndentingNewLine]", 
        RowBox[{"Grid", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Values\>\"", ",", "Bold"}], "]"}], ",", 
               RowBox[{"Control", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                   "v1", ",", "100", ",", "\"\<Sale or Exchange\>\""}], "}"}],
                   ",", "0", ",", "100", ",", "10", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Control", "@", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                   "v2", ",", "90", ",", "\"\<Negotiated Buyout\>\""}], "}"}],
                   ",", "0", ",", "100", ",", "10", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Control", "@", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                   "v3", ",", "80", ",", "\"\<Negotiated Buyout\>\""}], "}"}],
                   ",", "0", ",", "100", ",", "10", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Control", "@", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"v4", ",", "70", ",", "\"\<Forced Sale\>\""}], 
                   "}"}], ",", "0", ",", "100", ",", "10", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", " ", 
               RowBox[{"Control", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"v5", ",", "60", ",", "\"\<Partner Dies\>\""}], 
                   "}"}], ",", "0", ",", "100", ",", "10", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Control", "@", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"v6", ",", "50", ",", "\"\<Client Dies\>\""}], 
                   "}"}], ",", "0", ",", "100", ",", "10", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Probabilities\>\"", ",", "Bold"}], "]"}], ",", 
               RowBox[{"Control", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                   "pr1", ",", ".9", ",", "\"\<Today - Take Action\>\""}], 
                   "}"}], ",", "0", ",", "1", ",", ".05", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Control", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                   "pr2", ",", ".8", ",", 
                    "\"\<Do nothing - Partner Dies\>\""}], "}"}], ",", "0", 
                  ",", "1", ",", ".05", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Control", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                   "pr3", ",", ".7", ",", 
                    "\"\<Take Action - Negotiation\>\""}], "}"}], ",", "0", 
                  ",", "1", ",", ".05", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Control", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                   "pr4", ",", ".6", ",", 
                    "\"\<Litigation - Negotiated Buyout\>\""}], "}"}], ",", 
                  "0", ",", "1", ",", ".05", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Control", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                   "pr5", ",", ".2", ",", 
                    "\"\<Negotiation - Sale or Exchange\>\""}], "}"}], ",", 
                  "0", ",", "1", ",", ".05", ",", 
                  RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", "\"\<\>\""}], "}"}]}], 
            "}"}], "]"}], ",", 
          RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Initialization", "\[RuleDelayed]", 
         RowBox[{"(", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"fct2", "[", 
             RowBox[{
              RowBox[{"value_List", "/;", 
               RowBox[{
                RowBox[{"Length", "[", "value", "]"}], "\[Equal]", "6"}]}], 
              ",", 
              RowBox[{"pr_List", "/;", 
               RowBox[{
                RowBox[{"Length", "[", "pr", "]"}], "\[Equal]", "10"}]}]}], 
             "]"}], ":=", 
            RowBox[{"Module", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "vertices", ",", "edges", ",", "outcomes", ",", "labels", ",", 
                "eLabels", ",", "vlabels", ",", "vsh"}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"vsh", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"xc_", ",", "yc_"}], "}"}], ",", "name_", ",", 
                  RowBox[{"{", 
                   RowBox[{"w_", ",", "h_"}], "}"}]}], "]"}], ":=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "LightYellow",
                   ",", 
                  RowBox[{"Disk", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"xc", ",", "yc"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.25", ",", "0.25"}], "}"}]}], "]"}], ",", 
                  RowBox[{"Inset", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{"labels", "[", 
                    RowBox[{"[", "name", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"FontSize", "\[Rule]", "10"}], ",", "Black"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"xc", ",", "yc"}], "}"}]}], "]"}]}], "}"}]}], ";",
                "\[IndentingNewLine]", 
               RowBox[{"vertices", "=", 
                RowBox[{"Range", "[", "11", "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"edges", "=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"1", "\[DirectedEdge]", "2"}], ",", 
                  RowBox[{"1", "\[DirectedEdge]", "3"}], ",", 
                  RowBox[{"2", "\[DirectedEdge]", "4"}], ",", 
                  RowBox[{"2", "\[DirectedEdge]", "5"}], ",", 
                  RowBox[{"3", "\[DirectedEdge]", "6"}], ",", 
                  RowBox[{"3", "\[DirectedEdge]", "9"}], ",", 
                  RowBox[{"6", "\[DirectedEdge]", "7"}], ",", 
                  RowBox[{"6", "\[DirectedEdge]", "8"}], ",", 
                  RowBox[{"9", "\[DirectedEdge]", "10"}], ",", 
                  RowBox[{"9", "\[DirectedEdge]", "11"}]}], "}"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"outcomes", "=", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Today\>\"", ",", "\"\<Do Nothing\>\"", ",", 
                  "\"\<Take Action\>\"", ",", "\"\<Client\\nDies\>\"", ",", 
                  "\"\< Partner\\nDies\>\"", ",", "\"\<Litigation\>\"", ",", 
                  "\"\<Forced\\nSale\>\"", ",", "\"\<Negotiated\\nBuyout\>\"",
                   ",", "\"\<Negotiation\>\"", ",", 
                  "\"\<Negotiated\\nBuyout\>\"", ",", 
                  "\"\<\\nSale or\\n  Exchange\\n\>\""}], "}"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"labels", "=", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "10"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
                    "Italic"}], "}"}]}], "]"}], "&"}], "/@", "outcomes"}]}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"eLabels", "=", "pr"}], ";", "\[IndentingNewLine]", 
               RowBox[{"eLabels", "=", 
                RowBox[{"MapThread", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Rule", "[", 
                    RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"edges", ",", "eLabels"}], "}"}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"vlabels", "=", 
                RowBox[{"MapThread", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Rule", "[", 
                    RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Range", "[", "11", "]"}], ",", "labels"}], 
                   "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
               "\[IndentingNewLine]", 
               RowBox[{"Show", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Graph", "[", 
                  RowBox[{
                  "vertices", ",", "edges", ",", "\[IndentingNewLine]", 
                   RowBox[{"EdgeLabels", "\[Rule]", "eLabels"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"GraphLayout", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"\"\<LayeredEmbedding\>\"", ",", 
                    RowBox[{"\"\<Orientation\>\"", "\[Rule]", "Left"}]}], 
                    "}"}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{"VertexShapeFunction", "\[Rule]", "vsh"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"ImageSize", "\[Rule]", "432"}]}], 
                  "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"Epilog", "\[Rule]", 
                  RowBox[{"{", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"\"\<Expected Result =\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"v1", " ", "pr5"}], "+", 
                    RowBox[{"v2", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", "pr5"}], ")"}]}]}], ")"}], " ", "pr3"}],
                     "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "pr3"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"pr4", " ", "v3"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "pr4"}], ")"}], " ", "v4"}]}], 
                    ")"}]}]}], ")"}], " ", "pr1"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "pr1"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"v5", " ", "pr2"}], "+", 
                    RowBox[{"v6", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", "pr2"}], ")"}]}]}], ")"}]}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "3.45"}], "}"}]}], "]"}], ",", "Red"}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{"v1", ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", "3.45"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{"v2", ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", "2.7"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{"v3", ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", "1.9"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{"v4", ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", "1.15"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{"v5", ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", ".75"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{"\"\<\\nClient Owns\\nw/Partner\\nHeirs\>\"", ",", 
                    RowBox[{"{", 
                    RowBox[{"2.0", ",", ".75"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{"v6", ",", 
                    RowBox[{"{", 
                    RowBox[{"2.7", ",", ".02"}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    "\"\<Client\\n   Heirs Own\\nwith Partner\>\"", ",", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", ".02"}], "}"}]}], "]"}]}], "}"}]}], ",",
                  "\[IndentingNewLine]", 
                 RowBox[{"PlotRangePadding", "\[Rule]", "0.25"}], ",", 
                 RowBox[{"BaseStyle", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "10"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
                    "Italic"}], "}"}]}]}], "]"}]}]}], "\[IndentingNewLine]", 
             "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          ")"}]}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{
          "v1", ",", "v2", ",", "v3", ",", "v4", ",", "v5", ",", "v6", ",", 
           "pr1", ",", "pr2", ",", "pr3", ",", "pr4", ",", "pr5"}], "}"}]}]}],
        "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6802737483066874`*^9, 3.680273780783266*^9}, {
   3.680273819968315*^9, 3.680273904631494*^9}, {3.6802740003374605`*^9, 
   3.6802740318668556`*^9}, {3.6802740933360786`*^9, 
   3.6802741344450903`*^9}, {3.6802742296366663`*^9, 
   3.6802742302460546`*^9}, {3.6802744435914636`*^9, 
   3.6802744775008125`*^9}, {3.680274545957698*^9, 3.6802745461000953`*^9}, {
   3.680274598158095*^9, 3.680274609185483*^9}, {3.68027469034553*^9, 
   3.6802747090407906`*^9}, {3.6802873120801163`*^9, 
   3.6802873132171383`*^9}, {3.680288386522744*^9, 3.680288417033836*^9}, {
   3.6802885215486135`*^9, 3.6802885365364475`*^9}, {3.6802885945586576`*^9, 
   3.680288606467308*^9}, {3.6802886603886194`*^9, 3.6802887594388723`*^9}, {
   3.680288816389233*^9, 3.6802888412613373`*^9}, {3.6802888722316504`*^9, 
   3.6802888784170895`*^9}, {3.6802893610134463`*^9, 3.680289391991779*^9}, {
   3.680289434397485*^9, 3.680289452209857*^9}, {3.6802895180648537`*^9, 
   3.680289554692201*^9}, {3.680289609148934*^9, 3.6802896105867553`*^9}, {
   3.680289759972791*^9, 3.6802898033009477`*^9}, {3.6802898840565777`*^9, 
   3.6802899446466117`*^9}, {3.680289976354885*^9, 3.680290008224589*^9}, {
   3.6802901572837553`*^9, 3.6802902044842033`*^9}, {3.680290592988762*^9, 
   3.680290649557107*^9}, 3.6802907030372458`*^9, {3.680290754951252*^9, 
   3.6802909664734*^9}, {3.6802910205751905`*^9, 3.6802910349363594`*^9}, {
   3.6802910710022144`*^9, 3.680291161432558*^9}, {3.6802912537148237`*^9, 
   3.680291288083195*^9}, {3.680292401538669*^9, 3.6802925006540956`*^9}, {
   3.680292567935917*^9, 3.6802926413500338`*^9}, {3.6802927184098415`*^9, 
   3.680292749156561*^9}, {3.680292781549654*^9, 3.680292859887859*^9}, {
   3.6802929174257827`*^9, 3.6802929471137176`*^9}, {3.6802929944364595`*^9, 
   3.6802930574649754`*^9}, {3.680293091531517*^9, 3.6802931165249424`*^9}, {
   3.6802931591943493`*^9, 3.6802931653597345`*^9}, {3.6802933346887746`*^9, 
   3.680293387103079*^9}, {3.6802975089452686`*^9, 3.680297539967688*^9}, {
   3.6802977199319935`*^9, 3.6802977400725207`*^9}, {3.6802979528941865`*^9, 
   3.6802979726466513`*^9}, {3.680298037526113*^9, 3.6802980662043076`*^9}, {
   3.680298659692667*^9, 3.680298701893798*^9}, {3.680298815048566*^9, 
   3.680298884837019*^9}, {3.6802992765184984`*^9, 3.680299340977845*^9}, {
   3.6802994969162655`*^9, 3.680299638463467*^9}, {3.680299669703496*^9, 
   3.6802996712465963`*^9}, {3.6802997046654177`*^9, 
   3.6802998570233507`*^9}, {3.68029989056954*^9, 3.680299958822911*^9}, 
   3.6803651377852263`*^9, {3.680365323645853*^9, 3.680365364767536*^9}, {
   3.6803697728523655`*^9, 3.680369798144661*^9}, {3.6803698408462286`*^9, 
   3.680369878805959*^9}, 3.680369927754055*^9, {3.680369967397769*^9, 
   3.680370002494133*^9}, {3.680370035298579*^9, 3.6803700925677075`*^9}, {
   3.6803701736277156`*^9, 3.680370219150052*^9}, {3.6803705420969296`*^9, 
   3.6803705642470946`*^9}, {3.680370604721717*^9, 3.680370646167429*^9}, {
   3.680370958901067*^9, 3.6803710472265725`*^9}, {3.6803711489947605`*^9, 
   3.6803711607064266`*^9}, 3.6803714821858892`*^9, {3.6803791718203287`*^9, 
   3.680379242161621*^9}, {3.6803793657013855`*^9, 3.6803794408713665`*^9}, {
   3.680379483061412*^9, 3.680379483650312*^9}, {3.6803795406714015`*^9, 
   3.6803795426637278`*^9}, {3.6803796571848965`*^9, 
   3.6803797303908997`*^9}, {3.6803797930876665`*^9, 3.680379844069093*^9}, 
   3.680379889274456*^9, 3.6803799354407935`*^9, {3.680380016350673*^9, 
   3.680380067107807*^9}, {3.680380104790722*^9, 3.680380148430372*^9}, {
   3.6803801813472385`*^9, 3.6803802140004272`*^9}, {3.6803802621188707`*^9, 
   3.6803802642105265`*^9}, {3.680380330380146*^9, 3.680380444430359*^9}, {
   3.680380874089486*^9, 3.680380875351739*^9}, {3.6803810786339693`*^9, 
   3.6803810805491347`*^9}, {3.6803811979220343`*^9, 3.680381200059266*^9}, 
   3.6803816085925245`*^9, 3.6803816596085777`*^9, {3.680381744904811*^9, 
   3.680381755738618*^9}, {3.680381868193688*^9, 3.6803818792195387`*^9}, 
   3.6803822175433173`*^9, {3.680382355459588*^9, 3.6803823666656017`*^9}, {
   3.6804403577190137`*^9, 3.6804404444716077`*^9}, {3.680440488219904*^9, 
   3.680440517384718*^9}, {3.680440550033128*^9, 3.6804405511740704`*^9}, {
   3.680440689761246*^9, 3.6804407084293785`*^9}, {3.680440744617527*^9, 
   3.680440779256984*^9}, {3.680440857055871*^9, 3.680440865714426*^9}, {
   3.6804432953795547`*^9, 3.6804433042213774`*^9}, {3.6804437209261274`*^9, 
   3.6804437362879677`*^9}, {3.680443786144599*^9, 3.680443799506757*^9}, {
   3.680443840477668*^9, 3.680443847056714*^9}, {3.6804438860842586`*^9, 
   3.680443908181858*^9}, {3.680443994074888*^9, 3.6804440970454063`*^9}, {
   3.680444290550125*^9, 3.6804443202698183`*^9}, 3.6804502363516273`*^9, {
   3.6804502931688795`*^9, 3.680450310219516*^9}, {3.68045040260186*^9, 
   3.6804504053368454`*^9}, {3.680450452961153*^9, 3.68045054009915*^9}, 
   3.6805467253758945`*^9, {3.6805468010326757`*^9, 3.680546814565857*^9}, {
   3.6805469704590735`*^9, 3.680546982005247*^9}, {3.6805487965763216`*^9, 
   3.6805488113023367`*^9}, {3.6805500054300756`*^9, 3.680550039688525*^9}, 
   3.6805529196170545`*^9, {3.6805529682963266`*^9, 3.680552989556572*^9}, {
   3.680553023006873*^9, 3.680553043563877*^9}, {3.6805530876935477`*^9, 
   3.6805532448220935`*^9}, {3.6805532774612885`*^9, 3.680553308626788*^9}, {
   3.680553360077577*^9, 3.680553418085668*^9}, {3.680553490728046*^9, 
   3.6805534993334494`*^9}, {3.680553542272244*^9, 3.680553629108422*^9}, {
   3.6805537010518465`*^9, 3.680553798610881*^9}, {3.6805538574568243`*^9, 
   3.6805538691707563`*^9}, {3.6805539004129667`*^9, 
   3.6805539468422585`*^9}, {3.680554012829484*^9, 3.680554042144509*^9}, {
   3.6805540933183727`*^9, 3.6805541070561743`*^9}, {3.6805541586694775`*^9, 
   3.6805541930050144`*^9}, {3.6805543056840963`*^9, 3.680554418917229*^9}, {
   3.680554456619794*^9, 3.680554469227345*^9}, {3.680554501617812*^9, 
   3.6805546578880496`*^9}, {3.6805547624545746`*^9, 
   3.6805547740422783`*^9}, {3.680554997493306*^9, 3.680554998581463*^9}, {
   3.680555111747424*^9, 3.6805551151079326`*^9}, 3.680606225520898*^9, {
   3.6806063162364483`*^9, 3.680606336449054*^9}, {3.68060653230685*^9, 
   3.6806065339653378`*^9}, {3.680606640278417*^9, 3.6806066502227983`*^9}, {
   3.6806079038933997`*^9, 3.68060792721612*^9}, 3.680608179197067*^9, {
   3.680608279286213*^9, 3.680608300534049*^9}, {3.680608705156001*^9, 
   3.6806087317869186`*^9}, {3.680608783815057*^9, 3.680609018910228*^9}, {
   3.680609135393193*^9, 3.6806091760292315`*^9}, {3.6806092629670706`*^9, 
   3.6806092800742826`*^9}, {3.6806093647452307`*^9, 
   3.6806094417919283`*^9}, {3.6806094751816454`*^9, 3.680609488588195*^9}, {
   3.6806096116118355`*^9, 3.6806096205197287`*^9}, {3.6806096897894163`*^9, 
   3.6806097298025675`*^9}, {3.680609918448802*^9, 3.6806099195905943`*^9}, {
   3.6806100297871113`*^9, 3.6806100940516715`*^9}, {3.680610163413589*^9, 
   3.680610172077397*^9}, {3.680610220584776*^9, 3.6806102463440523`*^9}, {
   3.6806103016448145`*^9, 3.680610311481276*^9}, {3.680610396362032*^9, 
   3.680610451299285*^9}, {3.6806104901042137`*^9, 3.680610508323859*^9}, {
   3.680610553560462*^9, 3.680610607663024*^9}, {3.6806108633067155`*^9, 
   3.680610926359166*^9}, {3.68061101167725*^9, 3.680611038086608*^9}, {
   3.680611082553032*^9, 3.6806111277421055`*^9}, {3.6806111777321477`*^9, 
   3.6806111821423225`*^9}, {3.680611219568489*^9, 3.6806112367617416`*^9}, {
   3.6806112769752283`*^9, 3.680611326616909*^9}, {3.6806113661380825`*^9, 
   3.680611373551446*^9}, {3.6806114220335445`*^9, 3.6806115083368826`*^9}, {
   3.6806115478542614`*^9, 3.6806116490307503`*^9}, {3.680611686966715*^9, 
   3.680611785864561*^9}, {3.680611909356168*^9, 3.680611925526566*^9}, 
   3.680612073252208*^9, 3.680612160747672*^9, {3.6806123252345743`*^9, 
   3.680612383287507*^9}, {3.6806124307010827`*^9, 3.6806124538740644`*^9}, {
   3.680612534183073*^9, 3.6806125388354053`*^9}, {3.6806126043804207`*^9, 
   3.680612642760007*^9}, {3.680612681855123*^9, 3.680612731930774*^9}, {
   3.6806290681526346`*^9, 3.6806290928382583`*^9}, {3.680632660485718*^9, 
   3.6806327037747664`*^9}, {3.680632790501318*^9, 3.6806327918549166`*^9}, {
   3.6806328352312274`*^9, 3.680632835936101*^9}, {3.6806328820777626`*^9, 
   3.6806328831847057`*^9}, {3.6806330144596834`*^9, 
   3.6806330600739737`*^9}, {3.6806331560149913`*^9, 
   3.6806331945394325`*^9}, {3.68063330170128*^9, 3.6806333083148613`*^9}, 
   3.6806333393904715`*^9, {3.68063340278302*^9, 3.6806334349505053`*^9}, {
   3.6806336330009985`*^9, 3.680633648274601*^9}, {3.680633762359883*^9, 
   3.680633780347701*^9}, {3.6806338117812634`*^9, 3.680633838146352*^9}, {
   3.680633890625862*^9, 3.6806339846227417`*^9}, {3.6806341384948206`*^9, 
   3.680634147619075*^9}, {3.6806342135112133`*^9, 3.680634213764887*^9}, {
   3.6806342544390144`*^9, 3.6806342594373016`*^9}, 3.680634311713271*^9, {
   3.680634441204507*^9, 3.680634460358426*^9}, {3.6806350675277224`*^9, 
   3.6806351099094143`*^9}, {3.680635890004593*^9, 3.6806358919136696`*^9}, 
   3.682251890197281*^9, {3.6822712850600777`*^9, 3.6822712858241343`*^9}, {
   3.694892411237364*^9, 3.6948924124144635`*^9}, {3.69489245308169*^9, 
   3.6948924608162622`*^9}},ExpressionUUID->"1eca4d13-ca65-4c1b-902d-\
b1d26dd97d76"],

Cell[BoxData[
 TabViewBox[{{1,"\<\"Fixed/Random/Approach\"\>"->
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`regime$$ = 
     1, $CellContext`variable$$ = $CellContext`fixed, Typeset`show$$ = True, 
     Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`variable$$], $CellContext`fixed, 
        "Choose"}, {$CellContext`fixed -> "Fixed", $CellContext`random -> 
        "Random"}}, {{
        Hold[$CellContext`regime$$], 1, "  or  "}, {
       1 -> "Approach", 2 -> "Engaged", 3 -> "Aggressive", 4 -> "Passive"}}, {
       Hold[
        Row[{
          Manipulate`Place[1], 
          Manipulate`Place[2]}]], Manipulate`Dump`ThisIsNotAControl}}, 
     Typeset`size$$ = {442., {309., 315.}}, Typeset`update$$ = 0, 
     Typeset`initDone$$, Typeset`skipInitDone$$ = 
     False, $CellContext`variable$4359$$ = False, $CellContext`regime$4360$$ =
      False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      2, StandardForm, 
       "Variables" :> {$CellContext`regime$$ = 
         1, $CellContext`variable$$ = $CellContext`fixed}, 
       "ControllerVariables" :> {
         Hold[$CellContext`variable$$, $CellContext`variable$4359$$, False], 
         Hold[$CellContext`regime$$, $CellContext`regime$4360$$, False]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> Dynamic[
         If[$CellContext`regime$$ != 1, 
          $CellContext`fct1[
           Table[$CellContext`i, {$CellContext`i, 100, 50, -10}], 
           (Riffle[ConstantArray[1, 5] - #, #]& )[
            Part[$CellContext`custprobs, $CellContext`regime$$]]], 
          Dynamic[
           If[$CellContext`variable$$ === $CellContext`fixed, 
            Column[{
              Invisible[
               Button["Re-randomize", ImageSize -> Large]], 
              $CellContext`fct1[
               Table[$CellContext`i, {$CellContext`i, 100, 50, -10}], {0.5, 
               0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5}]}], 
            Column[{
              Button[
              "Re-randomize", $CellContext`payoff = 
                RandomInteger[{10, 100}, 6]; $CellContext`probs = (Riffle[
                 ConstantArray[1, 5] - #, #]& )[
                  N[RandomInteger[{0, 9}, 5]/10]], ImageSize -> Large], 
              $CellContext`fct1[$CellContext`payoff, \
$CellContext`probs]}]]]]], 
       "Specifications" :> {{{$CellContext`variable$$, $CellContext`fixed, 
           "Choose"}, {$CellContext`fixed -> "Fixed", $CellContext`random -> 
           "Random"}, ControlPlacement -> 
          1}, {{$CellContext`regime$$, 1, "  or  "}, {
          1 -> "Approach", 2 -> "Engaged", 3 -> "Aggressive", 4 -> "Passive"},
           ControlType -> PopupMenu, FieldSize -> Small, ControlPlacement -> 
          2}, 
         Row[{
           Manipulate`Place[1], 
           Manipulate`Place[2]}]}, 
       "Options" :> {
        TrackedSymbols :> {$CellContext`fixed, $CellContext`random}}, 
       "DefaultOptions" :> {}],
      ImageSizeCache->{491., {356., 362.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>({{$CellContext`fct1[
            Condition[
             Pattern[$CellContext`payoff, 
              Blank[List]], Length[$CellContext`payoff] == 6], 
            Condition[
             Pattern[$CellContext`probs, 
              Blank[List]], Length[$CellContext`probs] == 10]] := 
          Module[{$CellContext`vertices, $CellContext`edges, \
$CellContext`outcomes, $CellContext`labels, $CellContext`eLabels, \
$CellContext`vlabels, $CellContext`vsh}, $CellContext`vsh[{
                Pattern[$CellContext`xc, 
                 Blank[]], 
                Pattern[$CellContext`yc, 
                 Blank[]]}, 
               Pattern[$CellContext`name, 
                Blank[]], {
                Pattern[$CellContext`w, 
                 Blank[]], 
                Pattern[$CellContext`h, 
                 Blank[]]}] := {
               EdgeForm[Black], LightYellow, 
               Disk[{$CellContext`xc, $CellContext`yc}, {0.25, 0.25}], 
               Inset[
                Style[
                 Text[
                  Part[$CellContext`labels, $CellContext`name]], FontSize -> 
                 10, Black], {$CellContext`xc, $CellContext`yc}]}; \
$CellContext`vertices = Range[11]; $CellContext`edges = {
               DirectedEdge[1, 2], 
               DirectedEdge[1, 3], 
               DirectedEdge[2, 4], 
               DirectedEdge[2, 5], 
               DirectedEdge[3, 6], 
               DirectedEdge[3, 9], 
               DirectedEdge[6, 7], 
               DirectedEdge[6, 8], 
               DirectedEdge[9, 10], 
               DirectedEdge[9, 11]}; $CellContext`outcomes = {
              "Today", "Do Nothing", "Take Action", "Client\nDies", 
               "Partner\nDies", "Litigation", "Forced\nSale", 
               "Negotiated\nBuyout", "Negotiation", "Negotiated\nBuyout", 
               "\nSale or\nExchange\n"}; $CellContext`labels = 
             Map[Style[#, {
                FontSize -> 10, FontFamily -> "Times", 
                 Italic}]& , $CellContext`outcomes]; $CellContext`eLabels = \
$CellContext`probs; $CellContext`eLabels = 
             MapThread[# -> #2& , {$CellContext`edges, $CellContext`eLabels}]; \
$CellContext`vlabels = MapThread[# -> #2& , {
                Range[11], $CellContext`labels}]; Show[
              
              Graph[$CellContext`vertices, $CellContext`edges, 
               EdgeLabels -> $CellContext`eLabels, 
               GraphLayout -> {"LayeredEmbedding", "Orientation" -> Left}, 
               VertexShapeFunction -> $CellContext`vsh, ImageSize -> 442], 
              Epilog -> {
                Style[
                 Text[
                  StringJoin["Expected Result =", 
                   ToString[
                    
                    NumberForm[((
                    Part[$CellContext`payoff, 1] Part[$CellContext`probs, 10] + 
                    Part[$CellContext`payoff, 2] Part[$CellContext`probs, 9]) 
                    Part[$CellContext`probs, 6] + 
                    Part[$CellContext`probs, 5] (
                    Part[$CellContext`probs, 8] Part[$CellContext`payoff, 3] + 
                    Part[$CellContext`probs, 7] Part[$CellContext`payoff, 4]))
                     Part[$CellContext`probs, 2] + 
                    Part[$CellContext`probs, 1] (
                    Part[$CellContext`payoff, 5] Part[$CellContext`probs, 4] + 
                    Part[$CellContext`payoff, 6] 
                    Part[$CellContext`probs, 3]), {4, 2}]]], {0, 3.45}], Red], 
                Text[
                 Part[$CellContext`payoff, 1], {2.7, 3.45}], 
                Text[
                 Part[$CellContext`payoff, 2], {2.7, 2.7}], 
                Text[
                 Part[$CellContext`payoff, 3], {2.7, 1.9}], 
                Text[
                 Part[$CellContext`payoff, 4], {2.7, 1.15}], 
                Text[
                 Part[$CellContext`payoff, 5], {2.7, 0.75}], 
                Text["\nClient Owns\nw/Partner\nHeirs", {2., 0.75}], 
                Text[
                 Part[$CellContext`payoff, 6], {2.7, 0.02}], 
                Text["Client\n   Heirs Own\nwith Partner", {2, 0.02}]}, 
              PlotRangePadding -> 0.25, 
              BaseStyle -> {
               FontSize -> 10, FontFamily -> "Times", 
                Italic}]], $CellContext`payoff = {73, 15, 100, 80, 21, 
           34}, $CellContext`probs = {0.8, 0.2, 0.4, 0.6, 0.9, 0.1, 0.7, 0.3, 
           0.9, 0.1}, $CellContext`custprobs = {{0.5, 0.5, 0.5, 0.5, 0.5}, {
           0.9, 0.8, 0.7, 0.6, 0.2}, {0.9, 0.5, 0.2, 0.5, 0.5}, {0.1, 0.5, 
           0.8, 0.5, 0.5}}}; ($CellContext`fct1[
            Condition[
             Pattern[$CellContext`payoff, 
              Blank[List]], Length[$CellContext`payoff] == 6], 
            Condition[
             Pattern[$CellContext`probs, 
              Blank[List]], Length[$CellContext`probs] == 10]] := 
          
          Module[{$CellContext`vertices, $CellContext`edges, \
$CellContext`outcomes, $CellContext`labels, $CellContext`eLabels, \
$CellContext`vlabels, $CellContext`vsh}, $CellContext`vsh[{
                Pattern[$CellContext`xc, 
                 Blank[]], 
                Pattern[$CellContext`yc, 
                 Blank[]]}, 
               Pattern[$CellContext`name, 
                Blank[]], {
                Pattern[$CellContext`w, 
                 Blank[]], 
                Pattern[$CellContext`h, 
                 Blank[]]}] := {
               EdgeForm[Black], LightYellow, 
               Disk[{$CellContext`xc, $CellContext`yc}, {0.25, 0.25}], 
               Inset[
                Style[
                 Text[
                  Part[$CellContext`labels, $CellContext`name]], FontSize -> 
                 10, Black], {$CellContext`xc, $CellContext`yc}]}; \
$CellContext`vertices = Range[11]; $CellContext`edges = {
               DirectedEdge[1, 2], 
               DirectedEdge[1, 3], 
               DirectedEdge[2, 4], 
               DirectedEdge[2, 5], 
               DirectedEdge[3, 6], 
               DirectedEdge[3, 9], 
               DirectedEdge[6, 7], 
               DirectedEdge[6, 8], 
               DirectedEdge[9, 10], 
               DirectedEdge[9, 11]}; $CellContext`outcomes = {
              "Today", "Do Nothing", "Take Action", "Client\nDies", 
               "Partner\nDies", "Litigation", "Forced\nSale", 
               "Negotiated\nBuyout", "Negotiation", "Negotiated\nBuyout", 
               "\nSale or\nExchange\n"}; $CellContext`labels = 
             Map[Style[#, {
                FontSize -> 10, FontFamily -> "Times", 
                 Italic}]& , $CellContext`outcomes]; $CellContext`eLabels = \
$CellContext`probs; $CellContext`eLabels = 
             MapThread[# -> #2& , {$CellContext`edges, $CellContext`eLabels}]; \
$CellContext`vlabels = MapThread[# -> #2& , {
                Range[11], $CellContext`labels}]; Show[
              Graph[$CellContext`vertices, $CellContext`edges, 
               EdgeLabels -> $CellContext`eLabels, 
               GraphLayout -> {"LayeredEmbedding", "Orientation" -> Left}, 
               VertexShapeFunction -> $CellContext`vsh, ImageSize -> 442], 
              Epilog -> {
                Style[
                 Text[
                  StringJoin["Expected Result =", 
                   ToString[
                    
                    NumberForm[((
                    Part[$CellContext`payoff, 1] Part[$CellContext`probs, 10] + 
                    Part[$CellContext`payoff, 2] Part[$CellContext`probs, 9]) 
                    Part[$CellContext`probs, 6] + 
                    Part[$CellContext`probs, 5] (
                    Part[$CellContext`probs, 8] Part[$CellContext`payoff, 3] + 
                    Part[$CellContext`probs, 7] Part[$CellContext`payoff, 4]))
                     Part[$CellContext`probs, 2] + 
                    Part[$CellContext`probs, 1] (
                    Part[$CellContext`payoff, 5] Part[$CellContext`probs, 4] + 
                    Part[$CellContext`payoff, 6] 
                    Part[$CellContext`probs, 3]), {4, 2}]]], {0, 3.45}], Red], 
                Text[
                 Part[$CellContext`payoff, 1], {2.7, 3.45}], 
                Text[
                 Part[$CellContext`payoff, 2], {2.7, 2.7}], 
                Text[
                 Part[$CellContext`payoff, 3], {2.7, 1.9}], 
                Text[
                 Part[$CellContext`payoff, 4], {2.7, 1.15}], 
                Text[
                 Part[$CellContext`payoff, 5], {2.7, 0.75}], 
                Text["\nClient Owns\nw/Partner\nHeirs", {2., 0.75}], 
                Text[
                 Part[$CellContext`payoff, 6], {2.7, 0.02}], 
                Text["Client\n   Heirs Own\nwith Partner", {2, 0.02}]}, 
              PlotRangePadding -> 0.25, 
              BaseStyle -> {
               FontSize -> 10, FontFamily -> "Times", 
                Italic}]]; $CellContext`payoff = 
          RandomInteger[{10, 100}, 6]; $CellContext`probs = (Riffle[
           ConstantArray[1, 5] - #, #]& )[
            N[RandomInteger[{0, 9}, 5]/10]]; $CellContext`custprobs = {{0.5, 
           0.5, 0.5, 0.5, 0.5}, {0.9, 0.8, 0.7, 0.6, 0.2}, {0.9, 0.5, 0.2, 
           0.5, 0.5}, {0.1, 0.5, 0.8, 0.5, 0.5}}; Null)}; 
      Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]]}, {2,"\<\"Custom\"\>"->
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`pr1$$ = 0.9, $CellContext`pr2$$ = 
     0.8, $CellContext`pr3$$ = 0.7, $CellContext`pr4$$ = 
     0.6, $CellContext`pr5$$ = 0.2, $CellContext`v1$$ = 
     100, $CellContext`v2$$ = 90, $CellContext`v3$$ = 80, $CellContext`v4$$ = 
     70, $CellContext`v5$$ = 60, $CellContext`v6$$ = 50, Typeset`show$$ = 
     True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`v1$$], 100, "Sale or Exchange"}, 0, 100, 10}, {{
        Hold[$CellContext`v2$$], 90, "Negotiated Buyout"}, 0, 100, 10}, {{
        Hold[$CellContext`v3$$], 80, "Negotiated Buyout"}, 0, 100, 10}, {{
        Hold[$CellContext`v4$$], 70, "Forced Sale"}, 0, 100, 10}, {{
        Hold[$CellContext`v5$$], 60, "Partner Dies"}, 0, 100, 10}, {{
        Hold[$CellContext`v6$$], 50, "Client Dies"}, 0, 100, 10}, {{
        Hold[$CellContext`pr1$$], 0.9, "Today - Take Action"}, 0, 1, 0.05}, {{
        Hold[$CellContext`pr2$$], 0.8, "Do nothing - Partner Dies"}, 0, 1, 
       0.05}, {{
        Hold[$CellContext`pr3$$], 0.7, "Take Action - Negotiation"}, 0, 1, 
       0.05}, {{
        Hold[$CellContext`pr4$$], 0.6, "Litigation - Negotiated Buyout"}, 0, 
       1, 0.05}, {{
        Hold[$CellContext`pr5$$], 0.2, "Negotiation - Sale or Exchange"}, 0, 
       1, 0.05}, {
       Hold[
        Grid[{{
           Style["Values", Bold], 
           Style["Probabilities", Bold]}, {
           Manipulate`Place[1], 
           Manipulate`Place[7]}, {
           Manipulate`Place[2], 
           Manipulate`Place[8]}, {
           Manipulate`Place[3], 
           Manipulate`Place[9]}, {
           Manipulate`Place[4], 
           Manipulate`Place[10]}, {
           Manipulate`Place[5], 
           Manipulate`Place[11]}, {
           Manipulate`Place[6], ""}}, Alignment -> Left]], 
       Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
     432., {289., 294.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
     Typeset`skipInitDone$$ = False, $CellContext`v1$4379$$ = 
     0, $CellContext`v2$4380$$ = 0, $CellContext`v3$4381$$ = 
     0, $CellContext`v4$4382$$ = 0, $CellContext`v5$4383$$ = 
     0, $CellContext`v6$4384$$ = 0, $CellContext`pr1$4385$$ = 
     0, $CellContext`pr2$4386$$ = 0, $CellContext`pr3$4387$$ = 
     0, $CellContext`pr4$4388$$ = 0}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      2, StandardForm, 
       "Variables" :> {$CellContext`pr1$$ = 0.9, $CellContext`pr2$$ = 
         0.8, $CellContext`pr3$$ = 0.7, $CellContext`pr4$$ = 
         0.6, $CellContext`pr5$$ = 0.2, $CellContext`v1$$ = 
         100, $CellContext`v2$$ = 90, $CellContext`v3$$ = 
         80, $CellContext`v4$$ = 70, $CellContext`v5$$ = 
         60, $CellContext`v6$$ = 50}, "ControllerVariables" :> {
         Hold[$CellContext`v1$$, $CellContext`v1$4379$$, 0], 
         Hold[$CellContext`v2$$, $CellContext`v2$4380$$, 0], 
         Hold[$CellContext`v3$$, $CellContext`v3$4381$$, 0], 
         Hold[$CellContext`v4$$, $CellContext`v4$4382$$, 0], 
         Hold[$CellContext`v5$$, $CellContext`v5$4383$$, 0], 
         Hold[$CellContext`v6$$, $CellContext`v6$4384$$, 0], 
         Hold[$CellContext`pr1$$, $CellContext`pr1$4385$$, 0], 
         Hold[$CellContext`pr2$$, $CellContext`pr2$4386$$, 0], 
         Hold[$CellContext`pr3$$, $CellContext`pr3$4387$$, 0], 
         Hold[$CellContext`pr4$$, $CellContext`pr4$4388$$, 0]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, 
       "Body" :> ($CellContext`pr = (Riffle[
          ConstantArray[
            1, 5] - #, #]& )[{$CellContext`pr1$$, $CellContext`pr2$$, \
$CellContext`pr3$$, $CellContext`pr4$$, $CellContext`pr5$$}]; \
$CellContext`value = {$CellContext`v1$$, $CellContext`v2$$, \
$CellContext`v3$$, $CellContext`v4$$, $CellContext`v5$$, $CellContext`v6$$}; 
        Dynamic[
          $CellContext`fct2[$CellContext`value, $CellContext`pr]]), 
       "Specifications" :> {{{$CellContext`v1$$, 100, "Sale or Exchange"}, 0, 
          100, 10, Appearance -> "Labeled", ControlPlacement -> 
          1}, {{$CellContext`v2$$, 90, "Negotiated Buyout"}, 0, 100, 10, 
          Appearance -> "Labeled", ControlPlacement -> 
          2}, {{$CellContext`v3$$, 80, "Negotiated Buyout"}, 0, 100, 10, 
          Appearance -> "Labeled", ControlPlacement -> 
          3}, {{$CellContext`v4$$, 70, "Forced Sale"}, 0, 100, 10, Appearance -> 
          "Labeled", ControlPlacement -> 
          4}, {{$CellContext`v5$$, 60, "Partner Dies"}, 0, 100, 10, 
          Appearance -> "Labeled", ControlPlacement -> 
          5}, {{$CellContext`v6$$, 50, "Client Dies"}, 0, 100, 10, Appearance -> 
          "Labeled", ControlPlacement -> 
          6}, {{$CellContext`pr1$$, 0.9, "Today - Take Action"}, 0, 1, 0.05, 
          Appearance -> "Labeled", ControlPlacement -> 
          7}, {{$CellContext`pr2$$, 0.8, "Do nothing - Partner Dies"}, 0, 1, 
          0.05, Appearance -> "Labeled", ControlPlacement -> 
          8}, {{$CellContext`pr3$$, 0.7, "Take Action - Negotiation"}, 0, 1, 
          0.05, Appearance -> "Labeled", ControlPlacement -> 
          9}, {{$CellContext`pr4$$, 0.6, "Litigation - Negotiated Buyout"}, 0,
           1, 0.05, Appearance -> "Labeled", ControlPlacement -> 
          10}, {{$CellContext`pr5$$, 0.2, "Negotiation - Sale or Exchange"}, 
          0, 1, 0.05, Appearance -> "Labeled", ControlPlacement -> 11}, 
         Grid[{{
            Style["Values", Bold], 
            Style["Probabilities", Bold]}, {
            Manipulate`Place[1], 
            Manipulate`Place[7]}, {
            Manipulate`Place[2], 
            Manipulate`Place[8]}, {
            Manipulate`Place[3], 
            Manipulate`Place[9]}, {
            Manipulate`Place[4], 
            Manipulate`Place[10]}, {
            Manipulate`Place[5], 
            Manipulate`Place[11]}, {
            Manipulate`Place[6], ""}}, Alignment -> Left]}, 
       "Options" :> {
        TrackedSymbols :> {$CellContext`v1$$, $CellContext`v2$$, \
$CellContext`v3$$, $CellContext`v4$$, $CellContext`v5$$, $CellContext`v6$$, \
$CellContext`pr1$$, $CellContext`pr2$$, $CellContext`pr3$$, \
$CellContext`pr4$$, $CellContext`pr5$$}}, "DefaultOptions" :> {}],
      ImageSizeCache->{830., {411., 417.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>(($CellContext`fct2[
          Condition[
           Pattern[$CellContext`value$, 
            Blank[List]], Length[$CellContext`value$] == 6], 
          Condition[
           Pattern[$CellContext`pr$, 
            Blank[List]], Length[$CellContext`pr$] == 10]] := 
        Module[{$CellContext`vertices$, $CellContext`edges$, \
$CellContext`outcomes$, $CellContext`labels$, $CellContext`eLabels$, \
$CellContext`vlabels$, $CellContext`vsh$}, $CellContext`vsh$[{
              Pattern[$CellContext`xc$, 
               Blank[]], 
              Pattern[$CellContext`yc$, 
               Blank[]]}, 
             Pattern[$CellContext`name$, 
              Blank[]], {
              Pattern[$CellContext`w$, 
               Blank[]], 
              Pattern[$CellContext`h$, 
               Blank[]]}] := {
             EdgeForm[Black], LightYellow, 
             Disk[{$CellContext`xc$, $CellContext`yc$}, {0.25, 0.25}], 
             Inset[
              Style[
               Text[
                Part[$CellContext`labels$, $CellContext`name$]], FontSize -> 
               10, Black], {$CellContext`xc$, $CellContext`yc$}]}; \
$CellContext`vertices$ = Range[11]; $CellContext`edges$ = {
             DirectedEdge[1, 2], 
             DirectedEdge[1, 3], 
             DirectedEdge[2, 4], 
             DirectedEdge[2, 5], 
             DirectedEdge[3, 6], 
             DirectedEdge[3, 9], 
             DirectedEdge[6, 7], 
             DirectedEdge[6, 8], 
             DirectedEdge[9, 10], 
             DirectedEdge[9, 11]}; $CellContext`outcomes$ = {
            "Today", "Do Nothing", "Take Action", "Client\nDies", 
             " Partner\nDies", "Litigation", "Forced\nSale", 
             "Negotiated\nBuyout", "Negotiation", "Negotiated\nBuyout", 
             "\nSale or\n  Exchange\n"}; $CellContext`labels$ = 
           Map[Style[#, {
              FontSize -> 10, FontFamily -> "Times", 
               Italic}]& , $CellContext`outcomes$]; $CellContext`eLabels$ = \
$CellContext`pr$; $CellContext`eLabels$ = 
           MapThread[# -> #2& , {$CellContext`edges$, $CellContext`eLabels$}]; \
$CellContext`vlabels$ = MapThread[# -> #2& , {
              Range[11], $CellContext`labels$}]; Show[
            
            Graph[$CellContext`vertices$, $CellContext`edges$, 
             EdgeLabels -> $CellContext`eLabels$, 
             GraphLayout -> {"LayeredEmbedding", "Orientation" -> Left}, 
             VertexShapeFunction -> $CellContext`vsh$, ImageSize -> 432], 
            Epilog -> {
              Style[
               Text[
                StringJoin["Expected Result =", 
                 ToString[
                  
                  NumberForm[(($CellContext`v1$$ $CellContext`pr5$$ + \
$CellContext`v2$$ (1 - $CellContext`pr5$$)) $CellContext`pr3$$ + (
                    1 - $CellContext`pr3$$) ($CellContext`pr4$$ \
$CellContext`v3$$ + (
                    1 - $CellContext`pr4$$) $CellContext`v4$$)) \
$CellContext`pr1$$ + (
                    1 - $CellContext`pr1$$) ($CellContext`v5$$ \
$CellContext`pr2$$ + $CellContext`v6$$ (1 - $CellContext`pr2$$)), {4, 2}]]], {
                0, 3.45}], Red], 
              Text[$CellContext`v1$$, {2.7, 3.45}], 
              Text[$CellContext`v2$$, {2.7, 2.7}], 
              Text[$CellContext`v3$$, {2.7, 1.9}], 
              Text[$CellContext`v4$$, {2.7, 1.15}], 
              Text[$CellContext`v5$$, {2.7, 0.75}], 
              Text["\nClient Owns\nw/Partner\nHeirs", {2., 0.75}], 
              Text[$CellContext`v6$$, {2.7, 0.02}], 
              Text["Client\n   Heirs Own\nwith Partner", {2, 0.02}]}, 
            PlotRangePadding -> 0.25, 
            BaseStyle -> {FontSize -> 10, FontFamily -> "Times", Italic}]]; 
       Null); Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]]}}, 1]], "Output",
 CellChangeTimes->{{3.6805535716159286`*^9, 3.6805535767466097`*^9}, 
   3.6805536385877166`*^9, {3.6805538007700977`*^9, 3.6805538041798153`*^9}, {
   3.680553871657936*^9, 3.680553873925905*^9}, {3.6805539491030345`*^9, 
   3.6805539537445726`*^9}, {3.6805540464422293`*^9, 3.680554048724416*^9}, {
   3.680554110572482*^9, 3.680554112946476*^9}, {3.6805541615821095`*^9, 
   3.6805541640379963`*^9}, {3.68055419477138*^9, 3.680554197696627*^9}, {
   3.6805545095424433`*^9, 3.6805545118867702`*^9}, {3.6805546635485477`*^9, 
   3.6805546661131663`*^9}, {3.680554881643214*^9, 3.680554884537652*^9}, {
   3.680555015097005*^9, 3.680555017474558*^9}, {3.6805551180773444`*^9, 
   3.680555120527362*^9}, {3.680606339043795*^9, 3.6806063424039345`*^9}, {
   3.6806065391906595`*^9, 3.680606542319951*^9}, {3.6806065755812225`*^9, 
   3.680606577800478*^9}, {3.680607929280923*^9, 3.680607933672725*^9}, {
   3.680608183185963*^9, 3.680608185250147*^9}, 3.680608288846203*^9, {
   3.6806086058764796`*^9, 3.680608608191448*^9}, {3.6806090221297193`*^9, 
   3.680609024739369*^9}, {3.6806091106523495`*^9, 3.680609117253636*^9}, {
   3.6806091809706993`*^9, 3.6806091835358763`*^9}, {3.680609265413786*^9, 
   3.680609286784358*^9}, {3.680609456161042*^9, 3.680609458755436*^9}, {
   3.6806096269346*^9, 3.6806096303396487`*^9}, {3.6806097332550583`*^9, 
   3.6806097422498837`*^9}, {3.6806099215305586`*^9, 
   3.6806099241269765`*^9}, {3.6806101077182617`*^9, 
   3.6806101099696255`*^9}, {3.680610174532679*^9, 3.6806101776599846`*^9}, {
   3.680610249159613*^9, 3.6806102517652607`*^9}, {3.680610453099188*^9, 
   3.680610455130683*^9}, {3.680610511857706*^9, 3.680610514078956*^9}, {
   3.6806105724063854`*^9, 3.680610579806167*^9}, {3.6806106100854297`*^9, 
   3.680610612882954*^9}, {3.6806109293929415`*^9, 3.680610932332198*^9}, {
   3.680611040305587*^9, 3.68061104261627*^9}, {3.680611103479787*^9, 
   3.6806111086338773`*^9}, {3.6806111844111342`*^9, 
   3.6806111873515177`*^9}, {3.6806112407977576`*^9, 3.68061124306592*^9}, {
   3.680611292585913*^9, 3.680611295135537*^9}, {3.6806113285237503`*^9, 
   3.6806113305712447`*^9}, {3.680611375708337*^9, 3.68061137817772*^9}, {
   3.680611424943124*^9, 3.6806114552114305`*^9}, {3.6806114909968476`*^9, 
   3.6806115141976748`*^9}, {3.680611569613121*^9, 3.680611574660945*^9}, 
   3.680611612618482*^9, {3.6806116516319785`*^9, 3.680611654778829*^9}, {
   3.6806117409063973`*^9, 3.6806117447295685`*^9}, {3.6806117883339725`*^9, 
   3.680611791553362*^9}, {3.680611928780114*^9, 3.680611930891945*^9}, {
   3.680611967427839*^9, 3.680612020800953*^9}, {3.680612078320363*^9, 
   3.680612081212084*^9}, {3.6806121752137284`*^9, 3.680612178464446*^9}, 
   3.68061238547821*^9, {3.6806124564864483`*^9, 3.680612467030819*^9}, 
   3.6806125409767747`*^9, 3.680612606877514*^9, {3.680612646749117*^9, 
   3.6806126576653557`*^9}, 3.680612738800712*^9, 3.68062892302987*^9, 
   3.680629128287524*^9, {3.680632911586234*^9, 3.680632915732229*^9}, 
   3.6806329643645115`*^9, 3.6806330777198815`*^9, 3.680633158895648*^9, 
   3.6806333101918497`*^9, {3.6806336394742064`*^9, 3.680633654844065*^9}, 
   3.680633691925642*^9, 3.6806339886073337`*^9, 3.6806340371724377`*^9, 
   3.6806341498610067`*^9, 3.6806342155195513`*^9, 3.6806342622959023`*^9, {
   3.6806343173743196`*^9, 3.680634333695709*^9}, 3.680634373396247*^9, {
   3.6806344631428547`*^9, 3.6806344791182976`*^9}, {3.680634961748521*^9, 
   3.6806349857473316`*^9}, {3.680635135258774*^9, 3.680635162790969*^9}, 
   3.680635858537944*^9, 3.6806359032086687`*^9, 3.680637117491646*^9, {
   3.6806379146028576`*^9, 3.6806379287474623`*^9}, {3.682251242323388*^9, 
   3.6822512504510317`*^9}, 3.6822514733404465`*^9, 3.682251890697361*^9, 
   3.682253088921568*^9, 3.6822637905219*^9, {3.682263951205106*^9, 
   3.6822639582849283`*^9}, 3.6822712563106375`*^9, 3.6822712874955745`*^9, 
   3.6822719619120007`*^9, 3.6823658324781537`*^9, 3.6823668034128947`*^9, 
   3.694890348206399*^9, 3.6948912570246067`*^9, 3.69489228585977*^9, {
   3.694892353018469*^9, 3.6948923550658894`*^9}, 3.694892415074568*^9, 
   3.6948924619131546`*^9, 3.6948926427001457`*^9, {3.6948927014905443`*^9, 
   3.694892702816081*^9}, 3.694894343685731*^9, 3.6948947103522987`*^9, 
   3.698605401993102*^9, {3.698605475320919*^9, 3.698605482103382*^9}, 
   3.6986056530730753`*^9, 3.7314218613412914`*^9, 3.731421962216604*^9},
 TextAlignment->Center,ExpressionUUID->"d1c2d2c6-1b97-4a83-a1cb-44d445a91c23"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.27",
  FontWeight->"Bold"],
 ". Toward a more robust tool for these conditions"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}, {
  3.6985977251561365`*^9, 3.6985977511283717`*^9}},
 TextAlignment->Center,ExpressionUUID->"662c6a94-f488-405a-994b-1ea5319f0ebb"],

Cell["Client participation", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 3.6986065777641625`*^9}, {3.698606676409209*^9, 
  3.6986066807771935`*^9}, {3.6986067130799007`*^9, 
  3.6986067130799007`*^9}},ExpressionUUID->"d87e75f4-9306-4be2-bb5e-\
42235d450be3"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 3.6986065777641625`*^9}, {3.698606676409209*^9, 
  3.6986066807771935`*^9}},ExpressionUUID->"ff4fa5c6-5266-4b0d-b5dd-\
cb45b9d8f29b"],

Cell["\<\
Allow me to make the case for the three approaches as a useful refinement. In \
so doing, the reader is asked to imagine himself as arbitrator seeking \
resolution between disagreeing partners. For this thought experiment, assume \
the arbitrator arrives with our story to tell, decision trees as the proposed \
methodology, and two copies the graphic shown in Figure 11.28 with all the \
payoffs and probabilities blank. The arbitrator explains the theory, method \
of calculation, and how the blanks are to be completed to each party, asking \
each party to assign their own probabilities and outcome values, leaving the \
calculation of the Expected result to later.

In our Fixed example, notice that the upper outcomes have higher values, \
reflecting the notion that dispassionate market solutions negotiated \
rationally produce better results than outcomes imposed by third parties \
which are still better than a surviving partner left with the uninvolved \
heirs of the decedent partner. Remembering the ordinal nature of these \
values, retaining that hierarchy while changing the values within specific \
bands is one way the parties can separately value their differing perspectives.

Returning to our three approaches and their respective sets of payoff values \
and probabilities, it is easy to believe that over time the change in age, \
health and circumstances of the founding members will create a natural \
division of their separate, personal goals and objectives. So, where at \
inception they might both have been \[OpenCurlyDoubleQuote]Engaged\
\[CloseCurlyDoubleQuote], the ravages of time might well have left one of \
them \[OpenCurlyDoubleQuote]Passive\[CloseCurlyDoubleQuote]. If that is \
reasonable, might we agree that the passing of one partner\[CloseCurlyQuote]s \
interest to heirs would widen the gap between owners even more, especially if \
one partner becomes a number of heirs and spouses of heirs, each in varying \
conditions of age, health and circumstances? All of this is to (a) justify \
the value of early negotiation among founding members and (b) recognize that \
\[OpenCurlyDoubleQuote]approaches\[CloseCurlyDoubleQuote], be there three or \
thirty-thee of them, exist and come with their own particular sets of payoffs \
and probabilities to be inserted into the blanks on the decision tree.\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQbXbupff3rNeOXp/5g0E0z8boCQLZrx0Lai69BNHT
Xou/A9HekyrYBIH0nuX/pz8E0msi9eeC6A2uS5aCaAPzhStBtPmTKk3HnNeO
P5UC9UF03uEEYxDNUPjJAkQ//PLXHkTXfdUrAdEFvuvbQXRIGXMHiO7aHRv0
Fkg7HNZJAtE1noIZIHqZeWAWiJ6X+/NXaP5rR6Zovt8gWlJc9GA4kH6n7vAI
RFs53P0LohdF72GIANLcRXfZQfTGnVNDQPSOqLcRIPr7wwmpIDq2/GQjiI55
W9QOoqddlk+KAdIWk/wyQbTMfQfZjr7XjsxCFoogGgCJrZhZ
  "],ExpressionUUID->"09ac5e58-e5e7-4d4a-88ba-0ce17e6eea10"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g8result", "=", 
   RowBox[{
    RowBox[{".5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{".5", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"80", " ", ".5"}], "+", 
          RowBox[{"70", " ", ".5"}]}], ")"}]}], "+", 
       RowBox[{".5", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{".5", " ", "90"}], "+", 
          RowBox[{".5", " ", "100"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{".5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{".5", " ", "60"}], "+", 
       RowBox[{".5", " ", "50"}]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"g8", "=", 
  RowBox[{"Style", "[", 
   RowBox[{
    RowBox[{"Framed", "[", 
     RowBox[{"TreePlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Do Nothing\>\""}], ",", 
           "\"\<\\n___\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Today\>\"", "\[Rule]", "\"\<Take Action\>\""}], ",", 
           "\"\<\\n\\n___\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Take Action\>\"", "\[Rule]", "\"\<Litigation\>\""}], 
           ",", "\"\<\\n___\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Take Action\>\"", "\[Rule]", "\"\<Negotiation\>\""}], 
           ",", "\"\<___\\n\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Do Nothing\>\"", "\[Rule]", "\"\<Client dies\>\""}], 
           ",", "\"\<\\n___\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Do Nothing\>\"", "\[Rule]", "\"\<Partner dies\>\""}], 
           ",", "\"\<___\\n\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "\"\<Negotiation\>\"", "\[Rule]", "\"\<Negotiated\\nBuyout\>\""}], 
           ",", "\"\<\\n___\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "\"\<Negotiation\>\"", "\[Rule]", 
            "\"\<\\nSale or\\n    Exchange\\n\>\""}], ",", "\"\<___\\n\>\""}],
           "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Litigation\>\"", "\[Rule]", "\"\<Forced\\nSale\>\""}],
            ",", "\"\<\\n___\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Litigation\>\"", "\[Rule]", "\"\<Buyout\>\""}], ",", 
           "\"\<___\\n\>\""}], "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
       "Left", ",", 
       RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
       RowBox[{"VertexRenderingFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "Black", "]"}], ",", "Yellow", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"#1", ",", "0.20"}], "]"}], ",", "Black", ",", 
            RowBox[{"Text", "[", 
             RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "650"}], ",", 
       RowBox[{"ImagePadding", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"20", ",", "20"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"20", ",", "20"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{"\"\<___\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", "3.5"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<___\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", "2.7"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<___\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", "1.95"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<___\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", "1.15"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<Client Owns with\\nPartner Heirs\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.2", ",", ".75"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<___\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", ".75"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<Client Heirs\\nOwn with Partner\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.2", ",", ".02"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<___\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"2.7", ",", ".02"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{
             "StringJoin", "[", "\"\<Expected result =___ \>\"", "]"}], ",", 
             "Red"}], "]"}], "]"}]}], "}"}]}]}], "]"}], "]"}], ",", "Red"}], 
   "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.6033006525463047`*^9, 3.603300655515475*^9}, {
   3.6033007573182974`*^9, 3.603300796469537*^9}, {3.6033170350553308`*^9, 
   3.6033170676581955`*^9}, {3.6033959113510036`*^9, 3.603395923381692*^9}, {
   3.603395978671854*^9, 3.6033960071424828`*^9}, {3.6034107565130987`*^9, 
   3.603410757502155*^9}, {3.6034107876048765`*^9, 3.6034108097751446`*^9}, {
   3.6034108493504086`*^9, 3.603410957343585*^9}, {3.603411045870649*^9, 
   3.6034111065731206`*^9}, {3.6034111568509965`*^9, 
   3.6034111846345854`*^9}, {3.603411828355404*^9, 3.603412267549525*^9}, {
   3.603468562273399*^9, 3.6034687685231953`*^9}, {3.603468808924506*^9, 
   3.6034688225812874`*^9}, {3.6034688656687517`*^9, 
   3.6034689585040617`*^9}, {3.6034689918589697`*^9, 3.603469054929577*^9}, 
   3.603469165952927*^9, {3.6034692044341283`*^9, 3.6034692588842425`*^9}, {
   3.6034699966274395`*^9, 3.603470003038806*^9}, {3.6034703370569105`*^9, 
   3.6034704295932035`*^9}, {3.603470463907166*^9, 3.6034704699135094`*^9}, {
   3.603470513035976*^9, 3.6034706855498433`*^9}, {3.6034709334900246`*^9, 
   3.6034710086403227`*^9}, {3.6034710720949526`*^9, 3.603471404888987*^9}, {
   3.6034714391749477`*^9, 3.603471536542517*^9}, {3.60347157539874*^9, 
   3.603471584010232*^9}, {3.603471875794921*^9, 3.603471983108059*^9}, {
   3.603472036589118*^9, 3.6034720557352133`*^9}, {3.6034721565149775`*^9, 
   3.603472162295308*^9}, {3.6034735593542156`*^9, 3.603473598334445*^9}, {
   3.6034739904108706`*^9, 3.603474066434219*^9}, {3.603474120005283*^9, 
   3.603474120704323*^9}, 3.6809885281779537`*^9, {3.680988821267803*^9, 
   3.680988878197612*^9}, 3.6809893933129063`*^9, {3.6809894632449503`*^9, 
   3.680989464319627*^9}, {3.6809894964450417`*^9, 3.680989670550537*^9}, 
   3.680990134049247*^9, {3.680990169386113*^9, 3.6809902762960386`*^9}, {
   3.680990772382846*^9, 3.68099077488398*^9}, {3.680990966312471*^9, 
   3.6809911499848404`*^9}, {3.6809912249118524`*^9, 3.680991241925047*^9}, {
   3.6809917598742237`*^9, 3.6809917662886257`*^9}, {3.6809921850665383`*^9, 
   3.6809921880937405`*^9}, 3.6809924704632025`*^9, {3.6809925266051593`*^9, 
   3.680992589813464*^9}, {3.6809926277332106`*^9, 3.6809928699530168`*^9}, {
   3.68224912571986*^9, 3.682249143880681*^9}, {3.682249384060742*^9, 
   3.682249394256723*^9}, {3.682249757482933*^9, 3.682249769443985*^9}, {
   3.682249803760685*^9, 3.682249866966345*^9}, {3.6822499273701553`*^9, 
   3.682249954879283*^9}, {3.682249989247903*^9, 3.682249990060463*^9}, {
   3.6822500247077985`*^9, 3.6822500459393225`*^9}, {3.682250108468666*^9, 
   3.682250183565791*^9}, 3.682250276974346*^9, {3.6822503079919324`*^9, 
   3.682250481329376*^9}, {3.682250856255248*^9, 3.68225091619357*^9}, {
   3.682254653413253*^9, 3.682254788083007*^9}, {3.682254865867404*^9, 
   3.6822548870448933`*^9}, {3.682258015171109*^9, 3.6822580964825683`*^9}, {
   3.68225830285408*^9, 3.6822583507699037`*^9}, {3.682258401752679*^9, 
   3.682258427696864*^9}, {3.6822714888006773`*^9, 3.6822714925205708`*^9}, {
   3.6822716195021772`*^9, 3.682271652707464*^9}, {3.682271683073167*^9, 
   3.6822716970734167`*^9}, {3.6822717276045604`*^9, 3.682271741108463*^9}, 
   3.682271796709669*^9},ExpressionUUID->"12332cca-b807-4671-9b95-\
aab12eff81a2"],

Cell[BoxData[
 StyleBox[
  FrameBox[
   GraphicsBox[
    TagBox[
     GraphicsGroupBox[{
       GraphicsComplexBox[{{0., 1.3572417850765908`}, {0.7755667343294824, 
        0.3877833671647399}, {0.7755667343294803, 2.326700202988443}, {
        1.5511334686589626`, 1.5511334686589628`}, {1.551133468658961, 
        3.1022669373179252`}, {1.5511334686589644`, 0.}, {1.5511334686589635`,
         0.7755667343294814}, {2.3267002029884427`, 2.7144835701531855`}, {
        2.326700202988442, 3.490050304482667}, {2.326700202988444, 
        1.163350101494223}, {2.326700202988443, 1.9389168358237043`}}, 
        {RGBColor[0.5, 0., 0.], 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n___\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 2}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n\\n___\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{1, 3}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n___\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 6}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"___\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 7}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n___\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{3, 4}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"___\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{3, 5}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n___\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{4, 10}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"___\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{4, 11}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"\\n___\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{5, 8}]}, 
         {Arrowheads[{{0.5, 0.5, 
             GraphicsBox[{
               GrayLevel[0], 
               InsetBox[
                BoxData[
                 FormBox[
                  StyleBox["\"___\\n\"", StripOnInput -> False], 
                  TraditionalForm]], {0, 0}, 
                ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
                GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{5, 9}]}}], {
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0., 1.3572417850765908}, 0.2], 
         {GrayLevel[0], InsetBox["\<\"Today\"\>", {0., 1.3572417850765908}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.7755667343294824, 0.3877833671647399}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Do Nothing\"\>", \
{0.7755667343294824, 0.3877833671647399}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{0.7755667343294803, 2.326700202988443}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Take Action\"\>", \
{0.7755667343294803, 2.326700202988443}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.5511334686589626, 1.5511334686589628}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Litigation\"\>", \
{1.5511334686589626, 1.5511334686589628}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.551133468658961, 3.1022669373179252}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Negotiation\"\>", \
{1.551133468658961, 3.1022669373179252}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.5511334686589644, 0.}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Client dies\"\>", {1.5511334686589644, 0.}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{1.5511334686589635, 0.7755667343294814}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Partner dies\"\>", \
{1.5511334686589635, 0.7755667343294814}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{2.3267002029884427, 2.7144835701531855}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Negotiated\\nBuyout\"\>", \
{2.3267002029884427, 2.7144835701531855}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{2.326700202988442, 3.490050304482667}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"\\nSale or\\n    Exchange\\n\"\>", \
{2.326700202988442, 3.490050304482667}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{2.326700202988444, 1.163350101494223}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Forced\\nSale\"\>", \
{2.326700202988444, 1.163350101494223}]}}, 
        {RGBColor[1, 1, 0], EdgeForm[GrayLevel[0]], 
         DiskBox[{2.326700202988443, 1.9389168358237043}, 0.2], 
         {GrayLevel[0], 
          InsetBox["\<\"Buyout\"\>", \
{2.326700202988443, 1.9389168358237043}]}}}},
      ContentSelectable->True],
     Annotation[#, 
      VertexCoordinateRules -> {{0., 1.3572417850765908`}, {
       0.7755667343294824, 0.3877833671647399}, {0.7755667343294803, 
       2.326700202988443}, {1.5511334686589626`, 1.5511334686589628`}, {
       1.551133468658961, 3.1022669373179252`}, {1.5511334686589644`, 0.}, {
       1.5511334686589635`, 0.7755667343294814}, {2.3267002029884427`, 
       2.7144835701531855`}, {2.326700202988442, 3.490050304482667}, {
       2.326700202988444, 1.163350101494223}, {2.326700202988443, 
       1.9389168358237043`}}]& ],
    AspectRatio->1.2247448713915894`,
    BaseStyle->{FontSize -> 15, FontFamily -> "Times", Italic},
    Epilog->{
      InsetBox[
       FormBox["\"___\"", TraditionalForm], {2.7, 3.5}], 
      InsetBox[
       FormBox["\"___\"", TraditionalForm], {2.7, 2.7}], 
      InsetBox[
       FormBox["\"___\"", TraditionalForm], {2.7, 1.95}], 
      InsetBox[
       FormBox["\"___\"", TraditionalForm], {2.7, 1.15}], 
      InsetBox[
       FormBox["\"Client Owns with\\nPartner Heirs\"", TraditionalForm], {2.2,
        0.75}], 
      InsetBox[
       FormBox["\"___\"", TraditionalForm], {2.7, 0.75}], 
      InsetBox[
       FormBox["\"Client Heirs\\nOwn with Partner\"", TraditionalForm], {2.2, 
       0.02}], 
      InsetBox[
       FormBox["\"___\"", TraditionalForm], {2.7, 0.02}], 
      InsetBox[
       FormBox[
        StyleBox["\"Expected result =___ \"", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {0, 0}]},
    FrameTicks->None,
    ImagePadding->{{20, 20}, {20, 20}},
    ImageSize->650,
    PlotRange->All,
    PlotRangePadding->Scaled[0.1]],
   StripOnInput->False],
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontColor->RGBColor[1, 0, 0]]], "Output",
 CellChangeTimes->{
  3.682254792380788*^9, 3.6822548882010417`*^9, {3.6822580265952215`*^9, 
   3.682258098014137*^9}, {3.682258310934046*^9, 3.682258351377942*^9}, {
   3.6822584045185843`*^9, 3.682258428761379*^9}, 3.682271507864365*^9, {
   3.682271620585059*^9, 3.6822716343887277`*^9}, {3.6822716849592056`*^9, 
   3.682271697374216*^9}, 3.682271742066033*^9, 3.682271797131817*^9, 
   3.682365832931312*^9, 3.6948903485393677`*^9, 3.7314218620571966`*^9},
 TextAlignment->Center,ExpressionUUID->"d9c75405-588d-47be-8a31-e51bdef7dda0"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11.28",
  FontWeight->"Bold"],
 ". A template for use in practice"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}, {
  3.6985977829024878`*^9, 3.6985977955172777`*^9}},
 TextAlignment->Center,ExpressionUUID->"686e5ef4-e73d-4ab6-a0fd-41a119d1b5c6"],

Cell["Automating the process", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 3.6986065777641625`*^9}, {3.698606676409209*^9, 
  3.6986066807771935`*^9}, {3.6986067606007195`*^9, 
  3.698606769513935*^9}},ExpressionUUID->"34ca9be2-cf7e-4848-bd04-\
1d5d4a218c52"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 3.6986065777641625`*^9}, {3.698606676409209*^9, 
  3.6986066807771935`*^9}, {3.6986067606007195`*^9, 
  3.6986067693918557`*^9}},ExpressionUUID->"c9e132ef-2300-4182-a47e-\
9a473a2366d3"],

Cell["\<\
We are now left with the final feature of the decision tree calculator which \
is located under the tab \
\[OpenCurlyDoubleQuote]Custom\[CloseCurlyDoubleQuote] and illustrated in \
Figure 11.29 below. The default values are from the \
\[OpenCurlyDoubleQuote]Engaged\[CloseCurlyDoubleQuote] approach but the user \
is allowed to set values and probabilities with the Expected result \
automatically calculated. \
\>", "Text",
 CellChangeTimes->{{3.6822560154255023`*^9, 3.6822560619718876`*^9}, {
  3.682256093169795*^9, 3.6822563380775127`*^9}, {3.682256376082119*^9, 
  3.682256463939165*^9}, {3.6822639345719094`*^9, 3.682263941008026*^9}, {
  3.698606499388967*^9, 3.698606503860531*^9}, {3.698606774239644*^9, 
  3.698606774240144*^9}},ExpressionUUID->"b6774d9f-8e63-4f0f-9a6e-\
ce0320a92b77"],

Cell["", "Text",
 CellChangeTimes->{{3.6822560154255023`*^9, 3.6822560619718876`*^9}, {
  3.682256093169795*^9, 3.6822563380775127`*^9}, {3.682256376082119*^9, 
  3.682256463939165*^9}, {3.6822639345719094`*^9, 3.682263941008026*^9}, {
  3.698606499388967*^9, 
  3.698606503860531*^9}},ExpressionUUID->"278d9c1f-2a38-4d7b-9a7f-\
15181e4efb68"],

Cell[BoxData[
 TabViewBox[{{1,"\<\"Fixed/Random/Approach\"\>"->
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`regime$$ = 
     4, $CellContext`variable$$ = $CellContext`random, Typeset`show$$ = True, 
     Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`variable$$], $CellContext`fixed, 
        "Choose"}, {$CellContext`fixed -> "Fixed", $CellContext`random -> 
        "Random"}}, {{
        Hold[$CellContext`regime$$], 1, "  or  "}, {
       1 -> "Approach", 2 -> "Engaged", 3 -> "Aggressive", 4 -> "Passive"}}, {
       Hold[
        Row[{
          Manipulate`Place[1], 
          Manipulate`Place[2]}]], Manipulate`Dump`ThisIsNotAControl}}, 
     Typeset`size$$ = {332., {222., 225.}}, Typeset`update$$ = 0, 
     Typeset`initDone$$, Typeset`skipInitDone$$ = 
     False, $CellContext`variable$7433$$ = False, $CellContext`regime$7434$$ =
      False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      2, StandardForm, 
       "Variables" :> {$CellContext`regime$$ = 
         1, $CellContext`variable$$ = $CellContext`fixed}, 
       "ControllerVariables" :> {
         Hold[$CellContext`variable$$, $CellContext`variable$7433$$, False], 
         Hold[$CellContext`regime$$, $CellContext`regime$7434$$, False]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> Dynamic[
         If[$CellContext`regime$$ != 1, 
          $CellContext`fct1[
           Table[$CellContext`i, {$CellContext`i, 100, 50, -10}], 
           (Riffle[ConstantArray[1, 5] - #, #]& )[
            Part[$CellContext`custprobs, $CellContext`regime$$]]], 
          Dynamic[
           If[$CellContext`variable$$ === $CellContext`fixed, 
            Column[{
              Invisible[
               Button["Re-randomize", ImageSize -> Large]], 
              $CellContext`fct1[
               Table[$CellContext`i, {$CellContext`i, 100, 50, -10}], {0.5, 
               0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5}]}], 
            Column[{
              Button[
              "Re-randomize", $CellContext`payoff = 
                RandomInteger[{10, 100}, 6]; $CellContext`probs = (Riffle[
                 ConstantArray[1, 5] - #, #]& )[
                  N[RandomInteger[{0, 9}, 5]/10]], ImageSize -> Large], 
              $CellContext`fct1[$CellContext`payoff, \
$CellContext`probs]}]]]]], 
       "Specifications" :> {{{$CellContext`variable$$, $CellContext`fixed, 
           "Choose"}, {$CellContext`fixed -> "Fixed", $CellContext`random -> 
           "Random"}, ControlPlacement -> 
          1}, {{$CellContext`regime$$, 1, "  or  "}, {
          1 -> "Approach", 2 -> "Engaged", 3 -> "Aggressive", 4 -> "Passive"},
           ControlType -> PopupMenu, FieldSize -> Small, ControlPlacement -> 
          2}, 
         Row[{
           Manipulate`Place[1], 
           Manipulate`Place[2]}]}, 
       "Options" :> {
        TrackedSymbols :> {$CellContext`fixed, $CellContext`random}}, 
       "DefaultOptions" :> {}],
      ImageSizeCache->{381., {267., 273.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>({{$CellContext`fct1[
            Condition[
             Pattern[$CellContext`payoff, 
              Blank[List]], Length[$CellContext`payoff] == 6], 
            Condition[
             Pattern[$CellContext`probs, 
              Blank[List]], Length[$CellContext`probs] == 10]] := 
          Module[{$CellContext`vertices, $CellContext`edges, \
$CellContext`outcomes, $CellContext`labels, $CellContext`eLabels, \
$CellContext`vlabels, $CellContext`vsh}, $CellContext`vsh[{
                Pattern[$CellContext`xc, 
                 Blank[]], 
                Pattern[$CellContext`yc, 
                 Blank[]]}, 
               Pattern[$CellContext`name, 
                Blank[]], {
                Pattern[$CellContext`w, 
                 Blank[]], 
                Pattern[$CellContext`h, 
                 Blank[]]}] := {
               EdgeForm[Black], LightYellow, 
               Disk[{$CellContext`xc, $CellContext`yc}, {0.25, 0.25}], 
               Inset[
                Style[
                 Text[
                  Part[$CellContext`labels, $CellContext`name]], FontSize -> 
                 10, Black], {$CellContext`xc, $CellContext`yc}]}; \
$CellContext`vertices = Range[11]; $CellContext`edges = {
               DirectedEdge[1, 2], 
               DirectedEdge[1, 3], 
               DirectedEdge[2, 4], 
               DirectedEdge[2, 5], 
               DirectedEdge[3, 6], 
               DirectedEdge[3, 9], 
               DirectedEdge[6, 7], 
               DirectedEdge[6, 8], 
               DirectedEdge[9, 10], 
               DirectedEdge[9, 11]}; $CellContext`outcomes = {
              "Today", "Do Nothing", "Take Action", "Client\nDies", 
               "Partner\nDies", "Litigation", "Forced\nSale", 
               "Negotiated\nBuyout", "Negotiation", "Negotiated\nBuyout", 
               "\nSale or\nExchange\n"}; $CellContext`labels = 
             Map[Style[#, {
                FontSize -> 10, FontFamily -> "Times", 
                 Italic}]& , $CellContext`outcomes]; $CellContext`eLabels = \
$CellContext`probs; $CellContext`eLabels = 
             MapThread[# -> #2& , {$CellContext`edges, $CellContext`eLabels}]; \
$CellContext`vlabels = MapThread[# -> #2& , {
                Range[11], $CellContext`labels}]; Show[
              
              Graph[$CellContext`vertices, $CellContext`edges, 
               EdgeLabels -> $CellContext`eLabels, 
               GraphLayout -> {"LayeredEmbedding", "Orientation" -> Left}, 
               VertexShapeFunction -> $CellContext`vsh, ImageSize -> 442], 
              Epilog -> {
                Style[
                 Text[
                  StringJoin["Expected Result =", 
                   ToString[
                    
                    NumberForm[((
                    Part[$CellContext`payoff, 1] Part[$CellContext`probs, 10] + 
                    Part[$CellContext`payoff, 2] Part[$CellContext`probs, 9]) 
                    Part[$CellContext`probs, 6] + 
                    Part[$CellContext`probs, 5] (
                    Part[$CellContext`probs, 8] Part[$CellContext`payoff, 3] + 
                    Part[$CellContext`probs, 7] Part[$CellContext`payoff, 4]))
                     Part[$CellContext`probs, 2] + 
                    Part[$CellContext`probs, 1] (
                    Part[$CellContext`payoff, 5] Part[$CellContext`probs, 4] + 
                    Part[$CellContext`payoff, 6] 
                    Part[$CellContext`probs, 3]), {4, 2}]]], {0, 3.45}], Red], 
                Text[
                 Part[$CellContext`payoff, 1], {2.7, 3.45}], 
                Text[
                 Part[$CellContext`payoff, 2], {2.7, 2.7}], 
                Text[
                 Part[$CellContext`payoff, 3], {2.7, 1.9}], 
                Text[
                 Part[$CellContext`payoff, 4], {2.7, 1.15}], 
                Text[
                 Part[$CellContext`payoff, 5], {2.7, 0.75}], 
                Text["\nClient Owns\nw/Partner\nHeirs", {2., 0.75}], 
                Text[
                 Part[$CellContext`payoff, 6], {2.7, 0.02}], 
                Text["Client\n   Heirs Own\nwith Partner", {2, 0.02}]}, 
              PlotRangePadding -> 0.25, 
              BaseStyle -> {
               FontSize -> 10, FontFamily -> "Times", 
                Italic}]], $CellContext`payoff = {21, 72, 53, 74, 73, 
           23}, $CellContext`probs = {0.6, 0.4, 0.09999999999999998, 0.9, 0.9,
            0.1, 0.7, 0.3, 0.6, 0.4}, $CellContext`custprobs = {{0.5, 0.5, 
           0.5, 0.5, 0.5}, {0.9, 0.8, 0.7, 0.6, 0.2}, {0.9, 0.5, 0.2, 0.5, 
           0.5}, {0.1, 0.5, 0.8, 0.5, 0.5}}}; ($CellContext`fct1[
            Condition[
             Pattern[$CellContext`payoff, 
              Blank[List]], Length[$CellContext`payoff] == 6], 
            Condition[
             Pattern[$CellContext`probs, 
              Blank[List]], Length[$CellContext`probs] == 10]] := 
          
          Module[{$CellContext`vertices, $CellContext`edges, \
$CellContext`outcomes, $CellContext`labels, $CellContext`eLabels, \
$CellContext`vlabels, $CellContext`vsh}, $CellContext`vsh[{
                Pattern[$CellContext`xc, 
                 Blank[]], 
                Pattern[$CellContext`yc, 
                 Blank[]]}, 
               Pattern[$CellContext`name, 
                Blank[]], {
                Pattern[$CellContext`w, 
                 Blank[]], 
                Pattern[$CellContext`h, 
                 Blank[]]}] := {
               EdgeForm[Black], LightYellow, 
               Disk[{$CellContext`xc, $CellContext`yc}, {0.25, 0.25}], 
               Inset[
                Style[
                 Text[
                  Part[$CellContext`labels, $CellContext`name]], FontSize -> 
                 10, Black], {$CellContext`xc, $CellContext`yc}]}; \
$CellContext`vertices = Range[11]; $CellContext`edges = {
               DirectedEdge[1, 2], 
               DirectedEdge[1, 3], 
               DirectedEdge[2, 4], 
               DirectedEdge[2, 5], 
               DirectedEdge[3, 6], 
               DirectedEdge[3, 9], 
               DirectedEdge[6, 7], 
               DirectedEdge[6, 8], 
               DirectedEdge[9, 10], 
               DirectedEdge[9, 11]}; $CellContext`outcomes = {
              "Today", "Do Nothing", "Take Action", "Client\nDies", 
               "Partner\nDies", "Litigation", "Forced\nSale", 
               "Negotiated\nBuyout", "Negotiation", "Negotiated\nBuyout", 
               "\nSale or\nExchange\n"}; $CellContext`labels = 
             Map[Style[#, {
                FontSize -> 10, FontFamily -> "Times", 
                 Italic}]& , $CellContext`outcomes]; $CellContext`eLabels = \
$CellContext`probs; $CellContext`eLabels = 
             MapThread[# -> #2& , {$CellContext`edges, $CellContext`eLabels}]; \
$CellContext`vlabels = MapThread[# -> #2& , {
                Range[11], $CellContext`labels}]; Show[
              Graph[$CellContext`vertices, $CellContext`edges, 
               EdgeLabels -> $CellContext`eLabels, 
               GraphLayout -> {"LayeredEmbedding", "Orientation" -> Left}, 
               VertexShapeFunction -> $CellContext`vsh, ImageSize -> 442], 
              Epilog -> {
                Style[
                 Text[
                  StringJoin["Expected Result =", 
                   ToString[
                    
                    NumberForm[((
                    Part[$CellContext`payoff, 1] Part[$CellContext`probs, 10] + 
                    Part[$CellContext`payoff, 2] Part[$CellContext`probs, 9]) 
                    Part[$CellContext`probs, 6] + 
                    Part[$CellContext`probs, 5] (
                    Part[$CellContext`probs, 8] Part[$CellContext`payoff, 3] + 
                    Part[$CellContext`probs, 7] Part[$CellContext`payoff, 4]))
                     Part[$CellContext`probs, 2] + 
                    Part[$CellContext`probs, 1] (
                    Part[$CellContext`payoff, 5] Part[$CellContext`probs, 4] + 
                    Part[$CellContext`payoff, 6] 
                    Part[$CellContext`probs, 3]), {4, 2}]]], {0, 3.45}], Red], 
                Text[
                 Part[$CellContext`payoff, 1], {2.7, 3.45}], 
                Text[
                 Part[$CellContext`payoff, 2], {2.7, 2.7}], 
                Text[
                 Part[$CellContext`payoff, 3], {2.7, 1.9}], 
                Text[
                 Part[$CellContext`payoff, 4], {2.7, 1.15}], 
                Text[
                 Part[$CellContext`payoff, 5], {2.7, 0.75}], 
                Text["\nClient Owns\nw/Partner\nHeirs", {2., 0.75}], 
                Text[
                 Part[$CellContext`payoff, 6], {2.7, 0.02}], 
                Text["Client\n   Heirs Own\nwith Partner", {2, 0.02}]}, 
              PlotRangePadding -> 0.25, 
              BaseStyle -> {
               FontSize -> 10, FontFamily -> "Times", 
                Italic}]]; $CellContext`payoff = 
          RandomInteger[{10, 100}, 6]; $CellContext`probs = (Riffle[
           ConstantArray[1, 5] - #, #]& )[
            N[RandomInteger[{0, 9}, 5]/10]]; $CellContext`custprobs = {{0.5, 
           0.5, 0.5, 0.5, 0.5}, {0.9, 0.8, 0.7, 0.6, 0.2}, {0.9, 0.5, 0.2, 
           0.5, 0.5}, {0.1, 0.5, 0.8, 0.5, 0.5}}; Null)}; 
      Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]]}, {2,"\<\"Custom\"\>"->
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`pr1$$ = 0.9, $CellContext`pr2$$ = 
     0.8, $CellContext`pr3$$ = 0.7, $CellContext`pr4$$ = 
     0.6, $CellContext`pr5$$ = 0.2, $CellContext`v1$$ = 
     100, $CellContext`v2$$ = 90, $CellContext`v3$$ = 80, $CellContext`v4$$ = 
     70, $CellContext`v5$$ = 60, $CellContext`v6$$ = 50, Typeset`show$$ = 
     True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`v1$$], 100, "Sale or Exchange"}, 0, 100, 10}, {{
        Hold[$CellContext`v2$$], 90, "Negotiated Buyout"}, 0, 100, 10}, {{
        Hold[$CellContext`v3$$], 80, "Negotiated Buyout"}, 0, 100, 10}, {{
        Hold[$CellContext`v4$$], 70, "Forced Sale"}, 0, 100, 10}, {{
        Hold[$CellContext`v5$$], 60, "Partner Dies"}, 0, 100, 10}, {{
        Hold[$CellContext`v6$$], 50, "Client Dies"}, 0, 100, 10}, {{
        Hold[$CellContext`pr1$$], 0.9, "Today - Take Action"}, 0, 1, 0.05}, {{
        Hold[$CellContext`pr2$$], 0.8, "Do nothing - Partner Dies"}, 0, 1, 
       0.05}, {{
        Hold[$CellContext`pr3$$], 0.7, "Take Action - Negotiation"}, 0, 1, 
       0.05}, {{
        Hold[$CellContext`pr4$$], 0.6, "Litigation - Negotiated Buyout"}, 0, 
       1, 0.05}, {{
        Hold[$CellContext`pr5$$], 0.2, "Negotiation - Sale or Exchange"}, 0, 
       1, 0.05}, {
       Hold[
        Grid[{{
           Style["Values", Bold], 
           Style["Probabilities", Bold]}, {
           Manipulate`Place[1], 
           Manipulate`Place[7]}, {
           Manipulate`Place[2], 
           Manipulate`Place[8]}, {
           Manipulate`Place[3], 
           Manipulate`Place[9]}, {
           Manipulate`Place[4], 
           Manipulate`Place[10]}, {
           Manipulate`Place[5], 
           Manipulate`Place[11]}, {
           Manipulate`Place[6], ""}}, Alignment -> Left]], 
       Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
     432., {289., 294.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
     Typeset`skipInitDone$$ = False, $CellContext`v1$7453$$ = 
     0, $CellContext`v2$7454$$ = 0, $CellContext`v3$7455$$ = 
     0, $CellContext`v4$7456$$ = 0, $CellContext`v5$7457$$ = 
     0, $CellContext`v6$7458$$ = 0, $CellContext`pr1$7459$$ = 
     0, $CellContext`pr2$7460$$ = 0, $CellContext`pr3$7461$$ = 
     0, $CellContext`pr4$7462$$ = 0}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      2, StandardForm, 
       "Variables" :> {$CellContext`pr1$$ = 0.9, $CellContext`pr2$$ = 
         0.8, $CellContext`pr3$$ = 0.7, $CellContext`pr4$$ = 
         0.6, $CellContext`pr5$$ = 0.2, $CellContext`v1$$ = 
         100, $CellContext`v2$$ = 90, $CellContext`v3$$ = 
         80, $CellContext`v4$$ = 70, $CellContext`v5$$ = 
         60, $CellContext`v6$$ = 50}, "ControllerVariables" :> {
         Hold[$CellContext`v1$$, $CellContext`v1$7453$$, 0], 
         Hold[$CellContext`v2$$, $CellContext`v2$7454$$, 0], 
         Hold[$CellContext`v3$$, $CellContext`v3$7455$$, 0], 
         Hold[$CellContext`v4$$, $CellContext`v4$7456$$, 0], 
         Hold[$CellContext`v5$$, $CellContext`v5$7457$$, 0], 
         Hold[$CellContext`v6$$, $CellContext`v6$7458$$, 0], 
         Hold[$CellContext`pr1$$, $CellContext`pr1$7459$$, 0], 
         Hold[$CellContext`pr2$$, $CellContext`pr2$7460$$, 0], 
         Hold[$CellContext`pr3$$, $CellContext`pr3$7461$$, 0], 
         Hold[$CellContext`pr4$$, $CellContext`pr4$7462$$, 0]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, 
       "Body" :> ($CellContext`pr = (Riffle[
          ConstantArray[
            1, 5] - #, #]& )[{$CellContext`pr1$$, $CellContext`pr2$$, \
$CellContext`pr3$$, $CellContext`pr4$$, $CellContext`pr5$$}]; \
$CellContext`value = {$CellContext`v1$$, $CellContext`v2$$, \
$CellContext`v3$$, $CellContext`v4$$, $CellContext`v5$$, $CellContext`v6$$}; 
        Dynamic[
          $CellContext`fct2[$CellContext`value, $CellContext`pr]]), 
       "Specifications" :> {{{$CellContext`v1$$, 100, "Sale or Exchange"}, 0, 
          100, 10, Appearance -> "Labeled", ControlPlacement -> 
          1}, {{$CellContext`v2$$, 90, "Negotiated Buyout"}, 0, 100, 10, 
          Appearance -> "Labeled", ControlPlacement -> 
          2}, {{$CellContext`v3$$, 80, "Negotiated Buyout"}, 0, 100, 10, 
          Appearance -> "Labeled", ControlPlacement -> 
          3}, {{$CellContext`v4$$, 70, "Forced Sale"}, 0, 100, 10, Appearance -> 
          "Labeled", ControlPlacement -> 
          4}, {{$CellContext`v5$$, 60, "Partner Dies"}, 0, 100, 10, 
          Appearance -> "Labeled", ControlPlacement -> 
          5}, {{$CellContext`v6$$, 50, "Client Dies"}, 0, 100, 10, Appearance -> 
          "Labeled", ControlPlacement -> 
          6}, {{$CellContext`pr1$$, 0.9, "Today - Take Action"}, 0, 1, 0.05, 
          Appearance -> "Labeled", ControlPlacement -> 
          7}, {{$CellContext`pr2$$, 0.8, "Do nothing - Partner Dies"}, 0, 1, 
          0.05, Appearance -> "Labeled", ControlPlacement -> 
          8}, {{$CellContext`pr3$$, 0.7, "Take Action - Negotiation"}, 0, 1, 
          0.05, Appearance -> "Labeled", ControlPlacement -> 
          9}, {{$CellContext`pr4$$, 0.6, "Litigation - Negotiated Buyout"}, 0,
           1, 0.05, Appearance -> "Labeled", ControlPlacement -> 
          10}, {{$CellContext`pr5$$, 0.2, "Negotiation - Sale or Exchange"}, 
          0, 1, 0.05, Appearance -> "Labeled", ControlPlacement -> 11}, 
         Grid[{{
            Style["Values", Bold], 
            Style["Probabilities", Bold]}, {
            Manipulate`Place[1], 
            Manipulate`Place[7]}, {
            Manipulate`Place[2], 
            Manipulate`Place[8]}, {
            Manipulate`Place[3], 
            Manipulate`Place[9]}, {
            Manipulate`Place[4], 
            Manipulate`Place[10]}, {
            Manipulate`Place[5], 
            Manipulate`Place[11]}, {
            Manipulate`Place[6], ""}}, Alignment -> Left]}, 
       "Options" :> {
        TrackedSymbols :> {$CellContext`v1$$, $CellContext`v2$$, \
$CellContext`v3$$, $CellContext`v4$$, $CellContext`v5$$, $CellContext`v6$$, \
$CellContext`pr1$$, $CellContext`pr2$$, $CellContext`pr3$$, \
$CellContext`pr4$$, $CellContext`pr5$$}}, "DefaultOptions" :> {}],
      ImageSizeCache->{830., {411., 417.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>(($CellContext`fct2[
          Condition[
           Pattern[$CellContext`value$, 
            Blank[List]], Length[$CellContext`value$] == 6], 
          Condition[
           Pattern[$CellContext`pr$, 
            Blank[List]], Length[$CellContext`pr$] == 10]] := 
        Module[{$CellContext`vertices$, $CellContext`edges$, \
$CellContext`outcomes$, $CellContext`labels$, $CellContext`eLabels$, \
$CellContext`vlabels$, $CellContext`vsh$}, $CellContext`vsh$[{
              Pattern[$CellContext`xc$, 
               Blank[]], 
              Pattern[$CellContext`yc$, 
               Blank[]]}, 
             Pattern[$CellContext`name$, 
              Blank[]], {
              Pattern[$CellContext`w$, 
               Blank[]], 
              Pattern[$CellContext`h$, 
               Blank[]]}] := {
             EdgeForm[Black], LightYellow, 
             Disk[{$CellContext`xc$, $CellContext`yc$}, {0.25, 0.25}], 
             Inset[
              Style[
               Text[
                Part[$CellContext`labels$, $CellContext`name$]], FontSize -> 
               10, Black], {$CellContext`xc$, $CellContext`yc$}]}; \
$CellContext`vertices$ = Range[11]; $CellContext`edges$ = {
             DirectedEdge[1, 2], 
             DirectedEdge[1, 3], 
             DirectedEdge[2, 4], 
             DirectedEdge[2, 5], 
             DirectedEdge[3, 6], 
             DirectedEdge[3, 9], 
             DirectedEdge[6, 7], 
             DirectedEdge[6, 8], 
             DirectedEdge[9, 10], 
             DirectedEdge[9, 11]}; $CellContext`outcomes$ = {
            "Today", "Do Nothing", "Take Action", "Client\nDies", 
             " Partner\nDies", "Litigation", "Forced\nSale", 
             "Negotiated\nBuyout", "Negotiation", "Negotiated\nBuyout", 
             "\nSale or\n  Exchange\n"}; $CellContext`labels$ = 
           Map[Style[#, {
              FontSize -> 10, FontFamily -> "Times", 
               Italic}]& , $CellContext`outcomes$]; $CellContext`eLabels$ = \
$CellContext`pr$; $CellContext`eLabels$ = 
           MapThread[# -> #2& , {$CellContext`edges$, $CellContext`eLabels$}]; \
$CellContext`vlabels$ = MapThread[# -> #2& , {
              Range[11], $CellContext`labels$}]; Show[
            
            Graph[$CellContext`vertices$, $CellContext`edges$, 
             EdgeLabels -> $CellContext`eLabels$, 
             GraphLayout -> {"LayeredEmbedding", "Orientation" -> Left}, 
             VertexShapeFunction -> $CellContext`vsh$, ImageSize -> 432], 
            Epilog -> {
              Style[
               Text[
                StringJoin["Expected Result =", 
                 ToString[
                  
                  NumberForm[(($CellContext`v1$$ $CellContext`pr5$$ + \
$CellContext`v2$$ (1 - $CellContext`pr5$$)) $CellContext`pr3$$ + (
                    1 - $CellContext`pr3$$) ($CellContext`pr4$$ \
$CellContext`v3$$ + (
                    1 - $CellContext`pr4$$) $CellContext`v4$$)) \
$CellContext`pr1$$ + (
                    1 - $CellContext`pr1$$) ($CellContext`v5$$ \
$CellContext`pr2$$ + $CellContext`v6$$ (1 - $CellContext`pr2$$)), {4, 2}]]], {
                0, 3.45}], Red], 
              Text[$CellContext`v1$$, {2.7, 3.45}], 
              Text[$CellContext`v2$$, {2.7, 2.7}], 
              Text[$CellContext`v3$$, {2.7, 1.9}], 
              Text[$CellContext`v4$$, {2.7, 1.15}], 
              Text[$CellContext`v5$$, {2.7, 0.75}], 
              Text["\nClient Owns\nw/Partner\nHeirs", {2., 0.75}], 
              Text[$CellContext`v6$$, {2.7, 0.02}], 
              Text["Client\n   Heirs Own\nwith Partner", {2, 0.02}]}, 
            PlotRangePadding -> 0.25, 
            BaseStyle -> {FontSize -> 10, FontFamily -> "Times", Italic}]]; 
       Null); Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]]}}, 2]], "Output",
 Editable->False,
 CellChangeTimes->{{3.6805535716159286`*^9, 3.6805535767466097`*^9}, 
   3.6805536385877166`*^9, {3.6805538007700977`*^9, 3.6805538041798153`*^9}, {
   3.680553871657936*^9, 3.680553873925905*^9}, {3.6805539491030345`*^9, 
   3.6805539537445726`*^9}, {3.6805540464422293`*^9, 3.680554048724416*^9}, {
   3.680554110572482*^9, 3.680554112946476*^9}, {3.6805541615821095`*^9, 
   3.6805541640379963`*^9}, {3.68055419477138*^9, 3.680554197696627*^9}, {
   3.6805545095424433`*^9, 3.6805545118867702`*^9}, {3.6805546635485477`*^9, 
   3.6805546661131663`*^9}, {3.680554881643214*^9, 3.680554884537652*^9}, {
   3.680555015097005*^9, 3.680555017474558*^9}, {3.6805551180773444`*^9, 
   3.680555120527362*^9}, {3.680606339043795*^9, 3.6806063424039345`*^9}, {
   3.6806065391906595`*^9, 3.680606542319951*^9}, {3.6806065755812225`*^9, 
   3.680606577800478*^9}, {3.680607929280923*^9, 3.680607933672725*^9}, {
   3.680608183185963*^9, 3.680608185250147*^9}, 3.680608288846203*^9, {
   3.6806086058764796`*^9, 3.680608608191448*^9}, {3.6806090221297193`*^9, 
   3.680609024739369*^9}, {3.6806091106523495`*^9, 3.680609117253636*^9}, {
   3.6806091809706993`*^9, 3.6806091835358763`*^9}, {3.680609265413786*^9, 
   3.680609286784358*^9}, {3.680609456161042*^9, 3.680609458755436*^9}, {
   3.6806096269346*^9, 3.6806096303396487`*^9}, {3.6806097332550583`*^9, 
   3.6806097422498837`*^9}, {3.6806099215305586`*^9, 
   3.6806099241269765`*^9}, {3.6806101077182617`*^9, 
   3.6806101099696255`*^9}, {3.680610174532679*^9, 3.6806101776599846`*^9}, {
   3.680610249159613*^9, 3.6806102517652607`*^9}, {3.680610453099188*^9, 
   3.680610455130683*^9}, {3.680610511857706*^9, 3.680610514078956*^9}, {
   3.6806105724063854`*^9, 3.680610579806167*^9}, {3.6806106100854297`*^9, 
   3.680610612882954*^9}, {3.6806109293929415`*^9, 3.680610932332198*^9}, {
   3.680611040305587*^9, 3.68061104261627*^9}, {3.680611103479787*^9, 
   3.6806111086338773`*^9}, {3.6806111844111342`*^9, 
   3.6806111873515177`*^9}, {3.6806112407977576`*^9, 3.68061124306592*^9}, {
   3.680611292585913*^9, 3.680611295135537*^9}, {3.6806113285237503`*^9, 
   3.6806113305712447`*^9}, {3.680611375708337*^9, 3.68061137817772*^9}, {
   3.680611424943124*^9, 3.6806114552114305`*^9}, {3.6806114909968476`*^9, 
   3.6806115141976748`*^9}, {3.680611569613121*^9, 3.680611574660945*^9}, 
   3.680611612618482*^9, {3.6806116516319785`*^9, 3.680611654778829*^9}, {
   3.6806117409063973`*^9, 3.6806117447295685`*^9}, {3.6806117883339725`*^9, 
   3.680611791553362*^9}, {3.680611928780114*^9, 3.680611930891945*^9}, {
   3.680611967427839*^9, 3.680612020800953*^9}, {3.680612078320363*^9, 
   3.680612081212084*^9}, {3.6806121752137284`*^9, 3.680612178464446*^9}, 
   3.68061238547821*^9, {3.6806124564864483`*^9, 3.680612467030819*^9}, 
   3.6806125409767747`*^9, 3.680612606877514*^9, {3.680612646749117*^9, 
   3.6806126576653557`*^9}, 3.680612738800712*^9, 3.68062892302987*^9, 
   3.680629128287524*^9, {3.680632911586234*^9, 3.680632915732229*^9}, 
   3.6806329643645115`*^9, 3.6806330777198815`*^9, 3.680633158895648*^9, 
   3.6806333101918497`*^9, {3.6806336394742064`*^9, 3.680633654844065*^9}, 
   3.680633691925642*^9, 3.6806339886073337`*^9, 3.6806340371724377`*^9, 
   3.6806341498610067`*^9, 3.6806342155195513`*^9, 3.6806342622959023`*^9, {
   3.6806343173743196`*^9, 3.680634333695709*^9}, 3.680634373396247*^9, {
   3.6806344631428547`*^9, 3.6806344791182976`*^9}, {3.680634961748521*^9, 
   3.6806349857473316`*^9}, {3.680635135258774*^9, 3.680635162790969*^9}, 
   3.680635858537944*^9, 3.6806359032086687`*^9, 3.680637117491646*^9, {
   3.6806379146028576`*^9, 3.6806379287474623`*^9}, {3.682251242323388*^9, 
   3.6822512504510317`*^9}, 3.6822514733404465`*^9, 3.682251890697361*^9, 
   3.682253088921568*^9, 3.6822637905219*^9, 3.682263951205106*^9, {
   3.6948922780560226`*^9, 3.6948922795840735`*^9}},
 TextAlignment->Center,ExpressionUUID->"1193b183-9bfd-4ea1-9738-8bb4eccf0df7"],

Cell[TextData[{
 StyleBox["Figure 11.29",
  FontWeight->"Bold"],
 ". A calculator"
}], "FigureCaption",
 CellChangeTimes->{{3.6985973024826536`*^9, 3.698597334228609*^9}, {
  3.698597839200164*^9, 3.6985978691437993`*^9}, {3.6986065260003557`*^9, 
  3.698606552012314*^9}},
 TextAlignment->Center,ExpressionUUID->"fc22523e-7590-45e8-9c42-61c83f08682f"],

Cell["The rules", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 3.6986065777641625`*^9}, {3.698606676409209*^9, 
  3.6986066807771935`*^9}, {3.698606826729864*^9, 
  3.6986068286366396`*^9}},ExpressionUUID->"15574c31-b6be-4955-8f4d-\
2cc300040024"],

Cell["", "Subsection",
 CellChangeTimes->{{3.6986048101046124`*^9, 3.698604813983841*^9}, {
  3.6986065777636623`*^9, 3.6986065777641625`*^9}, {3.698606676409209*^9, 
  3.6986066807771935`*^9}, {3.698606826729864*^9, 
  3.6986068281618147`*^9}},ExpressionUUID->"1644fd9c-b500-411e-80c1-\
674f3fb0b631"],

Cell[TextData[{
 "Assuming the arbitrator is skilled in guiding the parties, only two rules \
must be followed. They are:\n\n1.\tEach payoff value must be between 0 and \
100 in increments of 10 and must descend from top to bottom along the right \
hand side;\n2.\tProbabilities must be between 0 and 1 in increments of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["0.05", 
    ButtonBox["B14",
     BaseStyle->"Hyperlink",
     ButtonData->"endnote14"]], TraditionalForm]],ExpressionUUID->
  "3b23af0c-54ff-41bc-8ce1-ed19ee489ae7"],
 " and each pair extending out from each node must add to 1;"
}], "Text",
 CellChangeTimes->{{3.6822560154255023`*^9, 3.6822560619718876`*^9}, {
  3.682256093169795*^9, 3.6822563380775127`*^9}, {3.682256376082119*^9, 
  3.682256463939165*^9}, {3.6822639345719094`*^9, 3.6822639453094473`*^9}, {
  3.682263995751548*^9, 3.682264002266863*^9}, {3.6986068788049498`*^9, 
  3.698606882362328*^9}, {3.6986069546083107`*^9, 
  3.6986069546083107`*^9}},ExpressionUUID->"24eaa7f5-faeb-4b88-965f-\
e01be51af090"],

Cell[TextData[{
 "The alert reader will at once recognize that it is a near certainty that \
the parties will not reach the same number for Expected result if, naturally, \
one assumes one\[CloseCurlyQuote]s own death is less preferred than another\
\[CloseCurlyQuote]s. The purpose is not to have the parties reach the same \
Expected result so much as it is to have them evaluate increments of the \
decision making process in the context of a global outcome. This sort of \
reductionism has a long and distinguished history in human thought and \
analysis. \n\nOne may ask, with respect to the Expected result: For ",
 StyleBox["whom",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 " is this result expected? This is a fair question. I leave it to the \
behavioral scientists to sort out when partnerships with joint and common \
goals and objectives devolve into sets of individual differing goals and \
objectives. It is at this flashpoint that the parties begin to count their \
separate winnings and come into conflict. Thus, the decision tree is expected \
to be applied individually to each decision maker. If used properly as a way \
to educate the parties, deflect them from emotional uproar and place them on \
a path to objective values, the exercise can bear fruit."
}], "Text",
 CellChangeTimes->{{3.6822565151388235`*^9, 3.6822568451966066`*^9}, {
  3.6822574750110517`*^9, 3.682257704500619*^9}, {3.682257758632428*^9, 
  3.6822578149306664`*^9}, {3.682264047620442*^9, 3.6822640900763445`*^9}, {
  3.6986070798027487`*^9, 3.698607079810253*^9}, {3.698607236401389*^9, 
  3.69860724022214*^9}},ExpressionUUID->"49635779-a5ad-40a9-8bfe-\
dc95ff2cc82a"],

Cell["\<\
The foregoing hints at a more global answer to the question posed at the \
outset. The reason machines learn is that they quantify things, follow rules \
and seek an optimal solution. Certainly the programmer influences, even sets, \
the goal the computer works toward. Whether humans are willing or even able \
to set aside emotions and become coldly analytical when their health, \
fortunes and family is involved remains an open question.\
\>", "Text",
 CellChangeTimes->{{3.6822565151388235`*^9, 3.6822568451966066`*^9}, {
   3.6822574750110517`*^9, 3.682257704500619*^9}, {3.682257758632428*^9, 
   3.6822578149306664`*^9}, {3.682264047620442*^9, 3.6822640900763445`*^9}, {
   3.6986070798027487`*^9, 3.698607079810253*^9}, 
   3.698607236401389*^9},ExpressionUUID->"e503f42e-1c39-4fba-aaeb-\
af660d084191"],

Cell["\<\
Before the humble decision tree was elevated to Rock Star status by the \
Digital Age, it labored well and faithfully in operations management systems \
to build a robust industrialized society. Underlying this story is a \
cautionary tale of how laws of men pale when compared to Laws of Nature. The \
logic of probability and economics of natural self-interest are powerful \
constructs which bow to no mortal. Perhaps the best advisor, attorney or \
otherwise, is one who appeals to universal laws at an early stage. While this \
article has used mediation as its template and partnership dispute as its \
example, the cautious investor may profitably use the decision tree to \
encourage a carefully stated exit strategy in formation documents. The \
decision tree is just a more elaborate form of the old Ben Franklin Balance \
Sheet. Artfully used early in the planning process, common sense and sound \
mathematics can help client avert heartache and disaster in later years.\
\>", "Text",
 CellChangeTimes->{{3.6822565151388235`*^9, 3.6822568451966066`*^9}, {
  3.6822574750110517`*^9, 3.682257704500619*^9}, {3.682257758632428*^9, 
  3.6822578149306664`*^9}, {3.682264047620442*^9, 3.6822640900763445`*^9}, {
  3.6986070815529633`*^9, 3.6986070962581425`*^9}, {3.698607131327009*^9, 
  3.698607141177519*^9}},ExpressionUUID->"0d85a131-b881-4dbe-9503-\
b692bdc63e90"],

Cell["Appendix B Endnotes", "EndnoteSection",
 CellChangeTimes->{{3.6986013542663517`*^9, 
  3.6986013627830915`*^9}},ExpressionUUID->"ea369955-4e1b-46b8-bcf5-\
dd29b586f48b"],

Cell["\<\
B1.\tThis problem is most often found in simple co-tenancies where no \
partnership agreement exists, matters governed by Uniform General Partnership \
Law.\
\>", "Endnote",
 CellChangeTimes->{{3.698601378480667*^9, 3.698601391864306*^9}, 
   3.698602351041978*^9},
 CellTags->"endnoteB1",ExpressionUUID->"8a8dbbca-ea7f-470f-a418-427fe592f403"],

Cell["\<\
B2.\tWhile the first use may date earlier it appears the idea first appeared \
in the literature in the late 1950s.\
\>", "Endnote",
 CellChangeTimes->{{3.6986023549734364`*^9, 3.6986023609902563`*^9}},
 CellTags->"endnoteB2",ExpressionUUID->"7b78bedb-204f-48e0-9d50-1c3490c362a1"],

Cell[TextData[StyleBox["B3.\tThe actual routine is random forests, for which \
decision trees are the progenitor. On September 7, 2016 a Google search on \
the terms \"digital imagining random forests\" yielded 293,000 hits.",
 FontFamily->"Times New Roman"]], "Endnote",
 CellChangeTimes->{{3.6986025699841943`*^9, 3.6986025747900524`*^9}, {
  3.698602708642056*^9, 3.698602712254153*^9}},
 CellTags->"endnoteB3",ExpressionUUID->"581dd8be-9c0d-420a-a967-939666dd9014"],

Cell[TextData[{
 "B4.\tIn a partnership agreement, in California, partition rights are",
 StyleBox[" waivabl",
  IgnoreSpellCheck->True],
 "e. This does not prevent conflict from ancillary derivative actions \
designed to destabilize the venture and promote dissolution."
}], "Endnote",
 CellChangeTimes->{{3.698602845019867*^9, 3.698602864594879*^9}},
 FontFamily->"Times New Roman",
 CellTags->"endnoteB4",ExpressionUUID->"352b27bb-1e08-4e2b-84cf-01ecce45ab6a"],

Cell["\<\
B5.\tFunds for the performance of this agreement may be provided by life \
insurance policies.\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.6986029970920534`*^9, {3.698603079584857*^9, 
   3.6986030860742097`*^9}},
 FontFamily->"Times New Roman",
 CellTags->"endnoteB5",ExpressionUUID->"b5ae3fb2-efc5-464c-9049-59d226f356f9"],

Cell["B6.\tReferred to as \"nodes\" in decision science.", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.6986030108827004`*^9, {3.6986031182723093`*^9, 
   3.6986031229794235`*^9}, 3.698604253698292*^9},
 FontFamily->"Times New Roman",
 CellTags->"endnoteB6",ExpressionUUID->"b8ebd3ca-8764-45ac-8355-429073b4d5fe"],

Cell["\<\
B7.\tLet us not quibble at this point over the semantic difference between \
that term and \"Expected value\" lest we become embroiled in an involved side \
trip through probability theory.\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.698603018160592*^9, {3.698603151213214*^9, 
   3.6986031585544786`*^9}, {3.698604087441762*^9, 3.6986040876108723`*^9}},
 FontFamily->"Times New Roman",
 CellTags->"endnoteB7",ExpressionUUID->"bf34c120-c0ae-41fb-9f37-0b7c1e4c6924"],

Cell["\<\
B8.\tFor simplicity we ignore a simultaneous death in a common disaster\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.698603022270254*^9, {3.69860316865316*^9, 
   3.6986031736837654`*^9}, {3.6986040910520706`*^9, 3.6986040911756525`*^9}, 
   3.698604128150796*^9},
 FontFamily->"Times New Roman",
 CellTags->"endnoteB8",ExpressionUUID->"8238c18c-b4c9-49a2-957b-b430ddd34b01"],

Cell["\<\
B9.\tOne must always be careful applying mortality tables to a single life as \
those tables assume large numbers are involved.\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.6986030253379383`*^9, {3.6986031794092474`*^9, 
   3.698603185138443*^9}, {3.6986040941748595`*^9, 3.698604094723223*^9}},
 FontFamily->"Times New Roman",
 CellTags->"endnoteB9",ExpressionUUID->"e8993717-7018-470c-9df8-cd469c109af7"],

Cell["\<\
B10.\tThe reader with substantial experience in estate planning or homicide \
could pose strong objections. Anecdotal evidence may always be found to \
contradict any general rule. Rather than become impaled on this, maintain \
patience just a bit longer to \tallow the process to be fully developed.\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.6986030319938087`*^9, {3.6986031892847614`*^9, 
   3.698603217847513*^9}, {3.6986040972098136`*^9, 3.698604097564657*^9}},
 FontFamily->"Times New Roman",
 CellTags->
  "endnoteB10",ExpressionUUID->"7db8e622-eaf2-4483-8555-d2579bb40034"],

Cell["\<\
B11.\tRecall the great philosopher Woody Allen who said \"I am not afraid of \
death, I just don't want to be there when it happens.\"\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.6986032331089993`*^9, {3.6986032838327484`*^9, 
   3.698603288607298*^9}, {3.6986041011154013`*^9, 3.698604101916931*^9}},
 FontFamily->"Times New Roman",
 CellTags->
  "endnoteB11",ExpressionUUID->"c80fbf61-c897-4c30-8fcc-63c89c611ef2"],

Cell["\<\
B12.\tIf this sounds like profiling it is because it is. Profiling is just a \
special case of conditional probability.\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.6986032371971216`*^9, {3.698603291586917*^9, 
   3.6986032972651606`*^9}, {3.6986041050018587`*^9, 3.6986041051347303`*^9}},
 FontFamily->"Times New Roman",
 CellTags->
  "endnoteB12",ExpressionUUID->"f885dc5a-2725-43f0-a2dc-763048bea186"],

Cell["\<\
B13.\tIn fact, they are influenced by the author's nearly half century of \
experience dealing with such matters involving real people and real assets.\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, 3.6986032408824344`*^9, {3.698603299908774*^9, 
   3.6986033086285667`*^9}, {3.6986041095424957`*^9, 3.698604116681718*^9}},
 FontFamily->"Times New Roman",
 CellTags->
  "endnoteB13",ExpressionUUID->"6a496287-8ce0-4b81-87cf-c44046bea38c"],

Cell["\<\
B14.\tThe fineness of the gradation may be set to allow for more variation in \
either payoff or probability input.\
\>", "Endnote",
 CellChangeTimes->{
  3.698602845019867*^9, {3.698603340362322*^9, 3.698603346467392*^9}, {
   3.6986041242487335`*^9, 3.6986041244064436`*^9}, {3.6986062341711864`*^9, 
   3.698606234313303*^9}, 3.698606894172925*^9},
 FontFamily->"Times New Roman",
 CellTags->"endnote14",ExpressionUUID->"824f6084-a21d-4bea-a39f-37cd3aa926da"]
},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{1280, 637},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{32000, 32000},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{576, 720},
"PrintingMargins"->{{54, 54}, {72, 72}}},
ShowSelection->True,
ShowCellLabel->False,
CellLabelAutoDelete->True,
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Book"}, "Textbook.nb", CharacterEncoding -> 
       "WindowsANSI"]]], 
   Cell[
    StyleData["BookChapterTitle"], FontColor -> GrayLevel[0.5]], 
   Cell[
    StyleData["Section"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["Subsection"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["TableTitle"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["PageBreak"], Editable -> True, CellMargins -> {{0, 0}, {1, 1}},
     CellBracketOptions -> {
     "Color" -> RGBColor[0.500008, 0.500008, 1], "Margins" -> {Inherited, 3}, 
      "Thickness" -> 1, "Widths" -> {5, 5}}, 
    CellElementSpacings -> {"CellMinHeight" -> 1}, 
    ConversionRules :> {"TeX" -> {"\n\n\\pagebreak", 
        $CellContext`NoOutput[], ""}, "HTML" -> {"<br class=\"PageBreak\">", 
        $CellContext`NoOutput[], ""}}, PageBreakAbove -> Automatic, 
    CellSize -> {Automatic, 9.120000000000005}, TabFilling -> "- ", 
    TabSpacings -> 1000, FontSize -> 6, FontColor -> GrayLevel[0.700008]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Hyperlink", StyleDefinitions -> StyleData["Link"]], 
       ContextMenu -> FEPrivate`FrontEndResource["ContextMenus", "Hyperlink"],
        FontVariations -> {"Underline" -> True}, FontColor -> 
       RGBColor[0, 0, 1], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["Hyperlink", "Condensed"], FontSize -> 11], 
      Cell[
       StyleData[
       "Hyperlink", "Printout", StyleDefinitions -> StyleData["Link"]], 
       ContextMenu -> FEPrivate`FrontEndResource["ContextMenus", "Hyperlink"],
        FontVariations -> {"Underline" -> True}, FontColor -> 
       RGBColor[0, 0, 1], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ReferenceSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["ReferenceSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["EndnoteSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["EndnoteSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ExerciseSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["ExerciseSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    StyleData["BookChapterNumber"], Background -> 
    RGBColor[0.9333333333333333, 0.1803921568627451, 0.1411764705882353]], 
   Cell[
    StyleData["EquationNumbered"], CellFrame -> True, CellFrameColor -> 
    RGBColor[0.501961, 0, 0], FontColor -> 
    RGBColor[0.5019607843137255, 0., 0.]], 
   Cell[
    CellGroupData[{
      Cell[
      "Figure", "Subsubsection", FontFamily -> "Times New Roman", FontSize -> 
       12, FontColor -> RGBColor[0, 0, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Figure"], Editable -> False, 
          CellMargins -> {{12, Inherited}, {8, 6}}, CellGroupingRules -> 
          "InputGrouping", ConversionRules :> {"TeX" -> {"\n\\begin{center}", 
              $CellContext`ExtractFigure[], "\n\\end{center}"}}, 
          TaggingRules :> {
           "CounterSettings" -> {"CounterTarget" -> "Style:FigureCaption"}, 
            "ExtraConversionRules" -> {
             "General" -> {
               "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, 
              "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}}, 
          PageBreakAbove -> False, Hyphenation -> True, CounterIncrements -> 
          "Figure", FontFamily -> "Times New Roman", FontSize -> 12, 
          FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["Figure", "Printout"], 
          CellMargins -> {{2, Inherited}, {6, 4}}, Magnification -> 0.8], 
         Cell[
          StyleData["Figure", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, Inherited}, {6, 4}}, Magnification -> 0.8]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FigureCaption"], CellMargins -> {{12, 10}, {6, 2}}, 
          CellGroupingRules -> "OutputGrouping", 
          ConversionRules :> {"TeX" -> {"\n\\caption{", "}"}}, 
          TaggingRules :> {
           "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "Figure"}, 
              "CounterTarget" -> "Cell", "XRefPrefix" -> "Figure"}, 
            "ExtraConversionRules" -> {
             "General" -> {"NestingLevel" -> 90}, 
              "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}}, 
          PageBreakAbove -> False, Hyphenation -> True, CounterIncrements -> 
          "FigureCaption", CounterAssignments -> {{"Nil", 0}}, FontFamily -> 
          "Times New Roman", FontSize -> 12, FontWeight -> "Plain", FontSlant -> 
          "Plain", 
          FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}, 
          FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["FigureCaption", "Printout"], 
          CellMargins -> {{2, 2}, {4, 1}}], 
         Cell[
          StyleData["FigureCaption", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 2}, {4, 1}}, LineSpacing -> {2, 1}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FigureCaptionLabel"], Editable -> False, 
          ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, FontFamily -> "Times New Roman", 
          FontSize -> 12, FontWeight -> "Bold", FontColor -> 
          RGBColor[0, 0, 1]], 
         Cell[
          StyleData["FigureCaptionLabel", "Printout"]], 
         Cell[
          StyleData["FigureCaptionLabel", "DoubleSpacedPrintout"]]}, Open]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell[
      "Tables", "Subsubsection", FontFamily -> "Times New Roman", FontColor -> 
       RGBColor[0, 0, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableTitle"], PageWidth -> 530, 
          CellMargins -> {{12, 10}, {1, 7}}, CellGroupingRules -> 
          "InputGrouping", 
          ConversionRules :> {"TeX" -> {"\n\\caption{", Automatic, "} "}}, 
          TaggingRules :> {
           "ExtraConversionRules" -> {
             "General" -> {
               "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, 
              "TeX" -> {"CellGroupEnvironment" -> "table"}}, 
            "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "TableTitle"}, 
              "CounterTarget" -> "Cell", "XRefPrefix" -> "Table"}}, 
          LineSpacing -> {1, 2}, CounterIncrements -> "TableTitle", 
          FontFamily -> "Times New Roman", FontWeight -> "Plain", FontColor -> 
          RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{40}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableTitle", "Printout"], 
          CellMargins -> {{2, 10}, {1, 5}}, FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["TableTitle", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 10}, {1, 5}}, FontFamily -> "Times New Roman", 
          FontSize -> 10]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableTitleLabel"], Editable -> True, 
          ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, LineSpacing -> {1, 2}, 
          CounterIncrements -> "TableTitleLabel", 
          CounterAssignments -> {{"Nil", 0}}, FontFamily -> "Times New Roman",
           FontWeight -> "Bold", FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{40}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableTitleLabel", "Printout"]], 
         Cell[
          StyleData["TableTitleLabel", "DoubleSpacedPrintout"], FontSize -> 
          10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Table"], Editable -> True, PageWidth -> WindowWidth, 
          CellMargins -> {{12, 10}, {4, 1}}, CellGroupingRules -> 
          "OutputGrouping", 
          ConversionRules :> {
           "TeX" -> {"\n\\begin{tabular}\n", Automatic, "\n\\end{tabular}"}, 
            "HTML" -> {{"", Automatic, ""}, {"", Automatic, ""}}}, 
          TaggingRules :> {
           "ExtraConversionRules" -> {
             "General" -> {"NestingLevel" -> 90}, 
              "TeX" -> {"CellGroupEnvironment" -> "table"}}, 
            "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "TableTitle"}, 
              "CounterTarget" -> "CellGroup"}}, CellHorizontalScrolling -> 
          True, CounterIncrements -> "Table", 
          CounterAssignments -> {{"TableNote", 0}}, FontFamily -> 
          "Times New Roman", FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}}, 
            GridBoxDividers -> {
             "Columns" -> {False, {False}, False}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                AbsoluteThickness[2], {False}, 
                AbsoluteThickness[0.5]}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {"Columns" -> {{
                 Scaled[0.503]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}, GridDefaultElement :> 
            Cell["Data", "TableText"]}], 
         Cell[
          StyleData["Table", "Printout"], PageWidth -> PaperWidth, 
          CellMargins -> {{2, 10}, {3, 1}}], 
         Cell[
          StyleData["Table", "DoubleSpacedPrintout"], PageWidth -> PaperWidth,
           CellMargins -> {{2, 10}, {3, 1}}, FontSize -> 10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableNote"], Editable -> True, 
          CellMargins -> {{12, 10}, {7, -3}}, CellGroupingRules -> 
          "OutputGrouping", ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, 
          TaggingRules :> {
           "CounterSettings" -> {
             "CounterFormat" -> {"Table"}, "CounterTarget" -> "CellGroup"}}, 
          LineSpacing -> {1, 1}, ParagraphSpacing -> {0.3, 0}, 
          CounterIncrements -> "TableNote", FontFamily -> "Times New Roman", 
          FontSize -> 10, FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["TableNote", "Printout"], 
          CellMargins -> {{2, 10}, {5, -2}}], 
         Cell[
          StyleData["TableNote", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 10}, {5, -2}}, LineSpacing -> {2, 1}, FontSize -> 
          9]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Inline Table Styles", "Subsubsubsection", FontFamily -> 
          "Times New Roman", FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableColumnHead"], Editable -> True, 
             ConversionRules :> {
              "TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic, ""}}}, 
             FontFamily -> "Times New Roman", FontSlant -> "Italic", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableColumnHead", "Printout"]], 
            Cell[
             StyleData["TableColumnHead", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableSpanHead"], Editable -> True, 
             ConversionRules :> {
              "TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic, ""}}}, 
             TextAlignment -> Center, FontFamily -> "Times New Roman", 
             FontSlant -> "Italic", FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableSpanHead", "Printout"]], 
            Cell[
             StyleData["TableSpanHead", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableText"], Editable -> True, TextAlignment -> Left, 
             LineSpacing -> {1, 1}, FontFamily -> "Times New Roman", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableText", "Printout"]], 
            Cell[
             StyleData["TableText", "DoubleSpacedPrintout"], 
             LineSpacing -> {2, 1}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableSpanText"], Editable -> True, TextAlignment -> 
             Center, LineSpacing -> {1, 1}, FontFamily -> "Times New Roman", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["TableSpanText", "Printout"]], 
            Cell[
             StyleData["TableSpanText", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          StyleData["TableSubGrid"], FontFamily -> "Times New Roman", 
          FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {{0.1}}, 
              "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.27999999999999997`]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
            Cell["Data", "TableText"]}], 
         Cell[
          StyleData["TableMasterGrid"], FontFamily -> "Times New Roman", 
          FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                 Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.004]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableLineElement"], Editable -> False, 
          CellFrame -> {{0, 0}, {0.5, 0}}, 
          CellElementSpacings -> {"CellMinHeight" -> 1}, 
          ConversionRules :> {"HTML" -> {{"&nbsp;", 
               $CellContext`NoOutput[], ""}, {"", Automatic, ""}}}, 
          CellSize -> {Inherited, 1.25}, TabFilling -> " ", TabSpacings -> 
          1000, FontFamily -> "Times New Roman", FontSize -> 1, FontColor -> 
          RGBColor[0, 0, 1]], 
         Cell[
          StyleData["TableBlankElement"], Editable -> False, 
          CellElementSpacings -> {"CellMinHeight" -> 1}, 
          CellSize -> {Inherited, 1.25}, FontFamily -> "Times New Roman", 
          FontSize -> 1, FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanLeft"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanLeft", "Printout"]], 
            Cell[
             StyleData["SpanLeft", "DoubleSpacedPrintout"], FontSize -> 14]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanCenter"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanCenter", "Printout"]], 
            Cell[
             StyleData["SpanCenter", "DoubleSpacedPrintout"], FontSize -> 
             14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanRight"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanRight", "Printout"]], 
            Cell[
             StyleData["SpanRight", "DoubleSpacedPrintout"], FontSize -> 14]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AppendixSection"], 
             CellMargins -> {{12, 12}, {24, 48}}, FontColor -> 
             GrayLevel[0.5]], 
            Cell[
             StyleData["AppendixSection", "Printout"], 
             CellMargins -> {{12, 12}, {24, 48}}, FontColor -> 
             GrayLevel[0.5]]}, Open]]}, Open]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> "11.3 for Microsoft Windows (64-bit) (March 6, 2018)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "endnote1"->{
  Cell[633516, 12616, 803, 14, 36, "Endnote",ExpressionUUID->"b3009463-b40e-4460-8fa3-3f0af7ed7d3d",
   CellTags->"endnote1"]},
 "endnote2"->{
  Cell[634322, 12632, 621, 12, 19, "Endnote",ExpressionUUID->"512df4dc-4f4f-4a0e-87ea-f8d6b3b2f162",
   CellTags->"endnote2"]},
 "endnote3"->{
  Cell[634946, 12646, 574, 12, 19, "Endnote",ExpressionUUID->"ca39658a-6f89-4471-b226-bba1b245bf56",
   CellTags->"endnote3"]},
 "endnoteB1"->{
  Cell[1084293, 21787, 354, 7, 19, "Endnote",ExpressionUUID->"8a8dbbca-ea7f-470f-a418-427fe592f403",
   CellTags->"endnoteB1"]},
 "endnoteB2"->{
  Cell[1084650, 21796, 291, 5, 19, "Endnote",ExpressionUUID->"7b78bedb-204f-48e0-9d50-1c3490c362a1",
   CellTags->"endnoteB2"]},
 "endnoteB3"->{
  Cell[1084944, 21803, 469, 6, 19, "Endnote",ExpressionUUID->"581dd8be-9c0d-420a-a967-939666dd9014",
   CellTags->"endnoteB3"]},
 "endnoteB4"->{
  Cell[1085416, 21811, 463, 9, 19, "Endnote",ExpressionUUID->"352b27bb-1e08-4e2b-84cf-01ecce45ab6a",
   CellTags->"endnoteB4"]},
 "endnoteB5"->{
  Cell[1085882, 21822, 353, 8, 19, "Endnote",ExpressionUUID->"b5ae3fb2-efc5-464c-9049-59d226f356f9",
   CellTags->"endnoteB5"]},
 "endnoteB6"->{
  Cell[1086238, 21832, 325, 5, 19, "Endnote",ExpressionUUID->"b8ebd3ca-8764-45ac-8355-429073b4d5fe",
   CellTags->"endnoteB6"]},
 "endnoteB7"->{
  Cell[1086566, 21839, 494, 9, 19, "Endnote",ExpressionUUID->"bf34c120-c0ae-41fb-9f37-0b7c1e4c6924",
   CellTags->"endnoteB7"]},
 "endnoteB8"->{
  Cell[1087063, 21850, 403, 8, 19, "Endnote",ExpressionUUID->"8238c18c-b4c9-49a2-957b-b430ddd34b01",
   CellTags->"endnoteB8"]},
 "endnoteB9"->{
  Cell[1087469, 21860, 434, 8, 19, "Endnote",ExpressionUUID->"e8993717-7018-470c-9df8-cd469c109af7",
   CellTags->"endnoteB9"]},
 "endnoteB10"->{
  Cell[1087906, 21870, 611, 11, 36, "Endnote",ExpressionUUID->"7db8e622-eaf2-4483-8555-d2579bb40034",
   CellTags->"endnoteB10"]},
 "endnoteB11"->{
  Cell[1088520, 21883, 445, 9, 19, "Endnote",ExpressionUUID->"c80fbf61-c897-4c30-8fcc-63c89c611ef2",
   CellTags->"endnoteB11"]},
 "endnoteB12"->{
  Cell[1088968, 21894, 432, 9, 19, "Endnote",ExpressionUUID->"f885dc5a-2725-43f0-a2dc-763048bea186",
   CellTags->"endnoteB12"]},
 "endnoteB13"->{
  Cell[1089403, 21905, 462, 9, 19, "Endnote",ExpressionUUID->"6a496287-8ce0-4b81-87cf-c44046bea38c",
   CellTags->"endnoteB13"]},
 "endnote14"->{
  Cell[1089868, 21916, 472, 9, 19, "Endnote",ExpressionUUID->"824f6084-a21d-4bea-a39f-37cd3aa926da",
   CellTags->"endnote14"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"endnote1", 1113877, 22444},
 {"endnote2", 1114020, 22447},
 {"endnote3", 1114163, 22450},
 {"endnoteB1", 1114307, 22453},
 {"endnoteB2", 1114452, 22456},
 {"endnoteB3", 1114597, 22459},
 {"endnoteB4", 1114742, 22462},
 {"endnoteB5", 1114887, 22465},
 {"endnoteB6", 1115032, 22468},
 {"endnoteB7", 1115177, 22471},
 {"endnoteB8", 1115322, 22474},
 {"endnoteB9", 1115467, 22477},
 {"endnoteB10", 1115613, 22480},
 {"endnoteB11", 1115761, 22483},
 {"endnoteB12", 1115908, 22486},
 {"endnoteB13", 1116055, 22489},
 {"endnote14", 1116201, 22492}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[1488, 33, 272, 5, 156, "BookChapterNumber",ExpressionUUID->"490f6bc5-578d-4fe8-a3aa-27c5f67fd3c2"],
Cell[1763, 40, 284, 6, 130, "BookChapterTitle",ExpressionUUID->"523614c2-4ed0-452d-be92-07e3620deee7",
 CounterAssignments->{{"BookChapterNumber", 11}}],
Cell[2050, 48, 678, 9, 55, "Epigraph",ExpressionUUID->"159f5df2-1f8f-4042-989c-5cfc6e795fe4"],
Cell[2731, 59, 438, 10, 51, "EpigraphAuthor",ExpressionUUID->"6750cc83-8604-4e10-9194-45e876d0a97f"],
Cell[3172, 71, 424, 10, 19, "Input",ExpressionUUID->"e45e90ec-0f01-46ac-9eba-c18b52276273",
 CellOpen->False],
Cell[3599, 83, 190, 3, 57, "Section",ExpressionUUID->"2328d445-9881-4e61-975f-31aaa93f5457"],
Cell[3792, 88, 341, 8, 40, "Text",ExpressionUUID->"d143e6ad-de63-400d-a590-66f44ea315a8"],
Cell[4136, 98, 327, 7, 19, "Item1",ExpressionUUID->"08f56092-ce3a-4022-84ee-4608b23dcee6"],
Cell[4466, 107, 268, 6, 19, "Item1",ExpressionUUID->"91003fae-bdfb-449e-9bc3-bc96818466d2"],
Cell[4737, 115, 288, 6, 19, "Item1",ExpressionUUID->"c29adc24-8871-4722-89ac-a46d28282351"],
Cell[5028, 123, 208, 3, 57, "Section",ExpressionUUID->"7596808b-bb68-4cbd-a172-f6b412fa869f"],
Cell[5239, 128, 1052, 16, 76, "Text",ExpressionUUID->"f8ea72d1-b6c3-4123-bb98-f3b9144dde61"],
Cell[6294, 146, 882, 20, 41, "Text",ExpressionUUID->"2fef7653-ba7c-4305-b11c-a8f91b129124"],
Cell[CellGroupData[{
Cell[7201, 170, 254, 4, 57, "Section",ExpressionUUID->"7d1d0a08-4129-42e7-bdc6-7d822c773c10"],
Cell[7458, 176, 1232, 19, 77, "Text",ExpressionUUID->"aefcc9ed-fecd-4359-81d2-ce4dd41f2dbd"],
Cell[8693, 197, 774, 24, 41, "Text",ExpressionUUID->"41a413df-f927-42a6-b13d-802e26ad0209"],
Cell[9470, 223, 286, 8, 23, "Text",ExpressionUUID->"3ac466cc-1059-424b-86eb-90ded96f419b"],
Cell[9759, 233, 400, 13, 47, "EquationNumbered",ExpressionUUID->"e983adf2-dd10-4a55-8087-9694b9b9b204"],
Cell[10162, 248, 281, 5, 23, "Text",ExpressionUUID->"15a15b70-0e1b-4f25-bdfe-e5ffcf9115d1"],
Cell[CellGroupData[{
Cell[10468, 257, 2757, 54, 19, "Input",ExpressionUUID->"a266a4fc-6be5-4a64-a64d-96140e026a1d",
 CellOpen->False],
Cell[13228, 313, 2951, 55, 97, "Output",ExpressionUUID->"e4bc0f35-2d30-43d0-b92f-0b4525892c8e"]
}, Open  ]],
Cell[16194, 371, 235, 7, 19, "Input",ExpressionUUID->"1e3cd73b-54ec-449a-bade-b64979d2cd32",
 CellOpen->False],
Cell[16432, 380, 215, 6, 23, "Text",ExpressionUUID->"a21b0567-8460-405d-9a2e-06ae2149c794"],
Cell[16650, 388, 467, 15, 75, "EquationNumbered",ExpressionUUID->"e58e6a32-ce7e-4d64-b5af-d7eb1aeff97a"],
Cell[17120, 405, 173, 3, 23, "Text",ExpressionUUID->"cd93dad0-3874-4771-8ad9-9ccd894c13c1"],
Cell[CellGroupData[{
Cell[17318, 412, 1551, 33, 19, "Input",ExpressionUUID->"142fc510-057a-4758-92e0-c6d9487a2b14",
 CellOpen->False],
Cell[18872, 447, 1502, 30, 97, "Output",ExpressionUUID->"3c37305f-7431-4306-a1d8-b25a30919ff5"]
}, Open  ]],
Cell[20389, 480, 296, 9, 19, "Input",ExpressionUUID->"44c3878c-63e0-4d75-8cc7-272cec170ae2",
 CellOpen->False],
Cell[20688, 491, 615, 14, 23, "Text",ExpressionUUID->"6e13381c-8207-498a-9a39-965cf76fff6b"],
Cell[CellGroupData[{
Cell[21328, 509, 4150, 107, 19, "Input",ExpressionUUID->"0955eda2-fd37-4f04-8c4b-a0d03944d36e",
 CellOpen->False],
Cell[25481, 618, 4166, 103, 200, "Output",ExpressionUUID->"fd36026a-901a-40dd-9fcb-0d3e4e2f5c24"]
}, Open  ]],
Cell[29662, 724, 403, 9, 23, "TableTitle",ExpressionUUID->"98137634-82bc-4121-8c07-fdb9511d6eb3"],
Cell[30068, 735, 806, 23, 41, "Text",ExpressionUUID->"553944a8-e009-43c7-bf55-782bd4471eb1"],
Cell[CellGroupData[{
Cell[30899, 762, 2549, 66, 19, "Input",ExpressionUUID->"e1d5caac-e80a-4565-973c-503295af8ec9",
 CellOpen->False],
Cell[33451, 830, 20111, 412, 231, "Output",ExpressionUUID->"2eb4ec3a-6c57-455b-ba8a-b5e4b93be2e4"]
}, Open  ]],
Cell[53577, 1245, 353, 6, 23, "FigureCaption",ExpressionUUID->"9fa08701-5f12-4fb7-8d63-88b408b9c414"],
Cell[53933, 1253, 290, 6, 23, "Text",ExpressionUUID->"41425822-b8f9-4b1b-a2d9-be39bc90856f"],
Cell[CellGroupData[{
Cell[54248, 1263, 795, 21, 19, "Input",ExpressionUUID->"14b51b68-ea71-4f8f-9614-f9e4f941719f",
 CellOpen->False],
Cell[55046, 1286, 1528, 33, 19, "Output",ExpressionUUID->"f4e4e960-6074-41c9-84ef-b6b9952bd88f",
 CellOpen->False]
}, Open  ]],
Cell[56589, 1322, 392, 8, 23, "Text",ExpressionUUID->"3c1c0856-c84d-44f5-a74f-7393ae761cdb"],
Cell[CellGroupData[{
Cell[57006, 1334, 3261, 88, 19, "Input",ExpressionUUID->"86bda604-b261-403f-9007-210ca01e4957",
 CellOpen->False],
Cell[60270, 1424, 18774, 390, 214, "Output",ExpressionUUID->"d49ec413-23c5-4c87-8908-aa65d5f08ad0"]
}, Open  ]],
Cell[79059, 1817, 345, 6, 23, "FigureCaption",ExpressionUUID->"320efb51-ba45-435b-b700-b97c93c0fe8a"],
Cell[79407, 1825, 1300, 29, 70, "Text",ExpressionUUID->"24c34107-dbcb-4895-858f-cca09af9a54a"],
Cell[80710, 1856, 175, 3, 29, "Input",ExpressionUUID->"31c96cb4-f514-4538-9744-b25a8e8f41b3"],
Cell[80888, 1861, 476, 13, 75, "EquationNumbered",ExpressionUUID->"12f90bd8-f00b-4577-891d-7ed995f22e3b"],
Cell[81367, 1876, 395, 10, 23, "Text",ExpressionUUID->"dcf9dbad-bb12-4388-94e2-263ff5ac23ad"],
Cell[81765, 1888, 295, 8, 19, "Input",ExpressionUUID->"38e8aada-95da-48f6-a089-37c5212b8590",
 CellOpen->False],
Cell[82063, 1898, 453, 12, 75, "EquationNumbered",ExpressionUUID->"3844815d-ce2b-44d5-b58f-1da091fe7b57"],
Cell[82519, 1912, 518, 12, 23, "Text",ExpressionUUID->"5513c0b1-25e4-47e5-94ae-71d136dbeec9"],
Cell[CellGroupData[{
Cell[83062, 1928, 601, 16, 19, "Input",ExpressionUUID->"fc030d15-5450-4937-adca-a3d1a00d89bf",
 CellOpen->False],
Cell[83666, 1946, 97461, 1594, 366, "Output",ExpressionUUID->"7a2f477c-b293-44c1-9baa-43377d3714d5"]
}, Open  ]],
Cell[181142, 3543, 343, 6, 23, "FigureCaption",ExpressionUUID->"75c4cd99-f8d3-41ba-9a17-dc46d12fabbf"],
Cell[181488, 3551, 188, 3, 34, "Subsection",ExpressionUUID->"e2043eb5-3d85-45a7-a3d0-97478abea2ea"],
Cell[181679, 3556, 1014, 27, 33, "Text",ExpressionUUID->"c4272ec8-214e-46fb-a7ed-3a716de95cac"],
Cell[182696, 3585, 300, 9, 19, "Input",ExpressionUUID->"e127bbd4-1798-4ad5-b185-c7d092fcd898",
 CellOpen->False],
Cell[182999, 3596, 546, 13, 49, "EquationNumbered",ExpressionUUID->"b7efd1c8-1c18-4e60-aca9-7953138fa04d"],
Cell[CellGroupData[{
Cell[183570, 3613, 698, 18, 19, "Input",ExpressionUUID->"8651a7ff-d7c0-4d5e-b1a8-e247c1d0e361",
 CellOpen->False],
Cell[184271, 3633, 137885, 2254, 356, "Output",ExpressionUUID->"a038d144-fc8e-4caa-b0fc-3dad7bbfa42e"]
}, Open  ]],
Cell[322171, 5890, 344, 6, 23, "FigureCaption",ExpressionUUID->"6513bf7f-b0b3-435b-a8cc-24b49162ef76"],
Cell[322518, 5898, 707, 17, 25, "Text",ExpressionUUID->"6ce66fa9-874a-4002-8eaf-393670956b4b"],
Cell[323228, 5917, 311, 10, 19, "Input",ExpressionUUID->"08fe6670-d5bc-4692-b3d9-83a9f0e3d030",
 CellOpen->False],
Cell[323542, 5929, 717, 20, 73, "EquationNumbered",ExpressionUUID->"e258da06-2692-42cd-8a76-d1fce5e33bef"],
Cell[324262, 5951, 931, 20, 43, "Text",ExpressionUUID->"19264a49-6a53-4878-bbb1-c4925302bd8c"],
Cell[325196, 5973, 796, 23, 73, "EquationNumbered",ExpressionUUID->"3561cfe5-12ab-464d-afe8-b63eb1bd164b"],
Cell[CellGroupData[{
Cell[326017, 6000, 1392, 35, 19, "Input",ExpressionUUID->"e95b09b4-c7be-48c0-865b-3772ffcb0d08",
 CellOpen->False],
Cell[327412, 6037, 229, 5, 23, "Text",ExpressionUUID->"08426511-8682-41af-9807-b4e6871874a9"]
}, Open  ]],
Cell[327656, 6045, 144, 3, 23, "Text",ExpressionUUID->"5a18046e-45fd-499c-9497-177bd291c6b7"],
Cell[327803, 6050, 581, 15, 27, "Text",ExpressionUUID->"72ea9e61-38a7-4515-9322-44f8edb6ead5"],
Cell[328387, 6067, 361, 8, 23, "Text",ExpressionUUID->"6feccb38-4222-496d-b4f0-03d0e75c5624"],
Cell[328751, 6077, 1103, 34, 19, "Input",ExpressionUUID->"e1ec6a4b-e986-4563-9e50-482e359a8c1f",
 CellOpen->False],
Cell[329857, 6113, 414, 11, 72, "EquationNumbered",ExpressionUUID->"73da6945-bf2a-4486-a73d-a264dfe63213"],
Cell[330274, 6126, 841, 20, 41, "Text",ExpressionUUID->"33e53099-e98c-4e94-9c7d-a557ac2d7be8"],
Cell[CellGroupData[{
Cell[331140, 6150, 1588, 43, 19, "Input",ExpressionUUID->"e402c83b-c579-48a6-a098-7e919692c74a",
 CellOpen->False],
Cell[332731, 6195, 225, 5, 23, "Text",ExpressionUUID->"938e4ca1-131f-4258-8386-81a456e8e40b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[332993, 6205, 414, 10, 19, "Input",ExpressionUUID->"712774a8-7ad1-4e66-a632-fcc638e054d9",
 CellOpen->False],
Cell[333410, 6217, 5158, 100, 228, "Output",ExpressionUUID->"e52a7867-ff99-4aa5-90c2-abb05f869abf"]
}, Open  ]],
Cell[338583, 6320, 315, 6, 23, "FigureCaption",ExpressionUUID->"39e7aa13-767a-4660-917a-5b7304935019"],
Cell[338901, 6328, 210, 6, 23, "Text",ExpressionUUID->"68a0bc5d-c907-403f-bc2d-97c93b4c1364"]
}, Open  ]],
Cell[CellGroupData[{
Cell[339148, 6339, 252, 4, 57, "Section",ExpressionUUID->"c32ff3dd-b6a8-45c9-b84f-c37acf1bd9a4"],
Cell[339403, 6345, 1754, 44, 107, "Text",ExpressionUUID->"489ceca1-bd04-4d86-b174-a1021bf403ba"],
Cell[341160, 6391, 282, 5, 34, "Subsection",ExpressionUUID->"4427457a-d638-4001-be30-8883b5257216"],
Cell[341445, 6398, 433, 11, 68, "Text",ExpressionUUID->"a4a4d0f9-3922-4ccd-ba84-438a17146866"],
Cell[341881, 6411, 290, 8, 45, "EquationNumbered",ExpressionUUID->"a4a59e0c-2c10-4d98-88c4-6991cf8e23b3"],
Cell[342174, 6421, 199, 4, 22, "Text",ExpressionUUID->"dd1be429-aef7-497b-804b-a11ebd48c066"],
Cell[CellGroupData[{
Cell[342398, 6429, 1549, 34, 19, "Input",ExpressionUUID->"9ceb9ab7-aaae-48c4-bcb7-0ebb502572a1",
 CellOpen->False],
Cell[343950, 6465, 1465, 29, 76, "Output",ExpressionUUID->"d3b000da-0178-450a-86d0-46cf679a5a0d"]
}, Open  ]],
Cell[345430, 6497, 207, 6, 19, "Input",ExpressionUUID->"7628869f-08ae-4ade-aa93-8e64bf88a1c4",
 CellOpen->False],
Cell[345640, 6505, 221, 6, 22, "Text",ExpressionUUID->"db2f12b0-e380-4f19-b224-cff2bc605577"],
Cell[345864, 6513, 575, 17, 51, "EquationNumbered",ExpressionUUID->"f6056f63-f41f-4fe4-8fbb-c746b7655b94"],
Cell[346442, 6532, 146, 3, 22, "Text",ExpressionUUID->"6c0a6905-6063-466f-9df5-61663fc676b4"],
Cell[CellGroupData[{
Cell[346613, 6539, 1335, 31, 19, "Input",ExpressionUUID->"3708aa31-09b6-4c2b-8ee8-e58e7632292c",
 CellOpen->False],
Cell[347951, 6572, 1160, 25, 60, "Output",ExpressionUUID->"3d282edb-88ce-4b15-b545-17908919d391"]
}, Open  ]],
Cell[349126, 6600, 223, 3, 22, "Text",ExpressionUUID->"94dd4361-cb99-4873-ba13-3aebaf58b830"],
Cell[349352, 6605, 399, 13, 19, "Input",ExpressionUUID->"df1b7405-5ef6-4b5d-bf29-5fc9c68b5dbb",
 CellOpen->False],
Cell[349754, 6620, 715, 23, 51, "EquationNumbered",ExpressionUUID->"35bfe2ac-c683-4f6a-806c-c04503517d7e"],
Cell[350472, 6645, 343, 7, 22, "Text",ExpressionUUID->"e7a6a46f-2ae5-4a97-8575-5bbf46051b15"],
Cell[CellGroupData[{
Cell[350840, 6656, 3713, 102, 19, "Input",ExpressionUUID->"dba24ba8-9882-49b8-a887-7fa3c7f93523",
 CellOpen->False],
Cell[354556, 6760, 11305, 227, 179, "Output",ExpressionUUID->"11489df0-82f3-407c-9432-6286c260857d"]
}, Open  ]],
Cell[365876, 6990, 310, 6, 21, "FigureCaption",ExpressionUUID->"5b323a37-a1c1-4c95-8092-368ccf9203fb"],
Cell[366189, 6998, 942, 19, 71, "Text",ExpressionUUID->"23100fcb-fc31-4759-9f9a-38abfa0a8149"],
Cell[CellGroupData[{
Cell[367156, 7021, 2180, 58, 19, "Input",ExpressionUUID->"3e480f71-6ae5-432f-82a0-d3028f22774d",
 CellOpen->False],
Cell[369339, 7081, 30310, 556, 248, "Output",ExpressionUUID->"c9690214-d947-4f71-a639-8b363d5fec29"]
}, Open  ]],
Cell[399664, 7640, 332, 6, 21, "FigureCaption",ExpressionUUID->"1df8ae19-13c6-4dfb-bfab-6e07940bd18c"],
Cell[399999, 7648, 626, 15, 38, "Text",ExpressionUUID->"5a792228-ecfd-4336-9aca-0841c19a5609"],
Cell[400628, 7665, 570, 15, 64, "EquationNumbered",ExpressionUUID->"0366a229-5d56-471a-943e-2859c397610e"],
Cell[CellGroupData[{
Cell[401223, 7684, 2329, 62, 19, "Input",ExpressionUUID->"2e55ae85-25df-4cb9-8100-964461c4ee20",
 CellOpen->False],
Cell[403555, 7748, 33609, 626, 260, "Output",ExpressionUUID->"fbd90040-0c6c-454b-9b6e-caa5cda5c71e"]
}, Open  ]],
Cell[437179, 8377, 408, 10, 21, "FigureCaption",ExpressionUUID->"5af91dc9-53c0-45d5-912a-e639d82a86ce"],
Cell[437590, 8389, 440, 10, 38, "Text",ExpressionUUID->"c8e58a32-3797-4810-b986-e5b405ca6e24"],
Cell[438033, 8401, 178, 3, 34, "Subsection",ExpressionUUID->"06feed62-19d6-47ba-b9a5-6e793fc2e0af"],
Cell[438214, 8406, 295, 8, 19, "Text",ExpressionUUID->"b433bc84-6052-484d-b73b-134a91ea59b9"],
Cell[438512, 8416, 336, 10, 45, "EquationNumbered",ExpressionUUID->"5e7a73fd-568a-4a10-9f62-bedcb50e16b2"],
Cell[438851, 8428, 347, 9, 22, "Text",ExpressionUUID->"07cdc2e8-4924-4250-9c21-efeb58c405b1"],
Cell[439201, 8439, 344, 11, 62, "EquationNumbered",ExpressionUUID->"5364d62b-f74e-445d-9e33-2fbf0b5660a2"],
Cell[439548, 8452, 175, 3, 22, "Text",ExpressionUUID->"0a3bca0d-16bd-40f0-ab08-7748c495fe37"],
Cell[CellGroupData[{
Cell[439748, 8459, 1305, 31, 19, "Input",ExpressionUUID->"db9371fd-29c1-43f7-8f16-01906a0dddbd",
 CellOpen->False],
Cell[441056, 8492, 1261, 26, 60, "Output",ExpressionUUID->"753c3399-c64d-4a4d-bb5b-ca72c307697f"]
}, Open  ]],
Cell[442332, 8521, 239, 8, 19, "Input",ExpressionUUID->"ceb0b782-0924-424b-a422-2631f559d10b",
 CellOpen->False],
Cell[442574, 8531, 629, 14, 54, "Text",ExpressionUUID->"31756a4d-e912-43c8-9f0b-eb95d741a552"],
Cell[443206, 8547, 337, 10, 45, "EquationNumbered",ExpressionUUID->"7157b7d1-6f3b-4138-9f93-5fd685676bde"],
Cell[443546, 8559, 146, 3, 22, "Text",ExpressionUUID->"0c19cee7-a6d7-4213-bbd4-baf68c1356d1"],
Cell[443695, 8564, 398, 12, 46, "EquationNumbered",ExpressionUUID->"24d4e8c1-f848-4f2c-8b25-979301679a0d"],
Cell[444096, 8578, 291, 9, 19, "Input",ExpressionUUID->"d5eac5e4-7534-4573-a26e-41697a904637",
 CellOpen->False],
Cell[444390, 8589, 1465, 40, 72, "Text",ExpressionUUID->"37c05bf1-2cd8-4e37-bb77-f45752ffbbcb"],
Cell[445858, 8631, 972, 22, 71, "Text",ExpressionUUID->"008ab9e0-78c1-402e-b7b5-ec2cd330f646"],
Cell[446833, 8655, 342, 6, 38, "Text",ExpressionUUID->"13114382-a669-4efc-ae80-a0dfde679649"]
}, Open  ]],
Cell[CellGroupData[{
Cell[447212, 8666, 179, 3, 58, "Section",ExpressionUUID->"6d1e3c9a-00f9-4a1e-a21a-f90fe7cab4b1"],
Cell[447394, 8671, 856, 16, 71, "Text",ExpressionUUID->"126907e2-8c49-4af7-8907-4abbcf9df289"],
Cell[CellGroupData[{
Cell[448275, 8691, 897, 24, 19, "Input",ExpressionUUID->"89073643-7b05-4684-943e-351c541eff94",
 CellOpen->False],
Cell[449175, 8717, 16037, 327, 249, "Output",ExpressionUUID->"e7b311ba-4be2-41ab-8c42-62dbb4253cda"]
}, Open  ]],
Cell[465227, 9047, 328, 6, 21, "FigureCaption",ExpressionUUID->"2e089009-ff3c-4690-bef6-eb6d65054f01"],
Cell[CellGroupData[{
Cell[465580, 9057, 3049, 72, 19, "Input",ExpressionUUID->"e64b14b7-51f4-45db-8805-b0364df8826b",
 CellOpen->False],
Cell[468632, 9131, 761, 21, 54, "Text",ExpressionUUID->"ffbc8bf6-42e9-4b09-86e3-4ce4f4c8b77a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[469430, 9157, 554, 16, 19, "Input",ExpressionUUID->"90e5c9dc-c2c6-4f92-aab7-581093e80546",
 CellOpen->False],
Cell[469987, 9175, 3787, 77, 210, "Output",ExpressionUUID->"ac96fc06-d81c-4ae9-affe-4dff358ec8c5"]
}, Open  ]],
Cell[473789, 9255, 324, 6, 21, "FigureCaption",ExpressionUUID->"9154248a-7e28-484f-a385-bf23fe75fd32"],
Cell[474116, 9263, 753, 23, 38, "Text",ExpressionUUID->"52a2846b-a63d-4e47-aacf-f34755caf916"],
Cell[474872, 9288, 317, 8, 19, "Input",ExpressionUUID->"2177c85e-35fd-4c65-b0b4-91de91c16cce",
 CellOpen->False],
Cell[475192, 9298, 1559, 54, 68, "EquationNumbered",ExpressionUUID->"b09f6e7b-48f5-4aee-ac30-c98f6f142626"],
Cell[CellGroupData[{
Cell[476776, 9356, 2327, 56, 19, "Input",ExpressionUUID->"26fd0192-907a-4253-8a2f-b6ad59655e5f",
 CellOpen->False],
Cell[479106, 9414, 582, 16, 38, "Text",ExpressionUUID->"b23b7460-3994-469c-8db9-2179d45ecebe"]
}, Open  ]],
Cell[479703, 9433, 645, 17, 25, "Text",ExpressionUUID->"2743c2d1-0c8c-4ef1-bb84-876143e6a13d"],
Cell[CellGroupData[{
Cell[480373, 9454, 1015, 27, 19, "Input",ExpressionUUID->"468746ad-4151-4734-a007-80adbeeb2766",
 CellOpen->False],
Cell[481391, 9483, 18119, 373, 248, "Output",ExpressionUUID->"45e72b94-bf2e-4519-9783-49664a890682"]
}, Open  ]],
Cell[499525, 9859, 391, 7, 21, "FigureCaption",ExpressionUUID->"ff6fe751-47e3-485b-b6fd-50b6e6c85aa0"],
Cell[499919, 9868, 772, 26, 38, "Text",ExpressionUUID->"69763583-7724-499e-bd95-a0f63ae11ef1"],
Cell[500694, 9896, 523, 16, 19, "Input",ExpressionUUID->"8fe133d9-38cd-4be8-9740-09cfb5e55ee5",
 CellOpen->False],
Cell[501220, 9914, 554, 16, 51, "EquationNumbered",ExpressionUUID->"3bef5d15-a62e-4349-85ed-72a39b87ffd7"],
Cell[501777, 9932, 989, 28, 58, "EquationNumbered",ExpressionUUID->"93f37ed3-3e15-4efb-9142-9c0e49515e08"],
Cell[502769, 9962, 286, 9, 22, "Text",ExpressionUUID->"d21bdd02-dc9e-4353-9305-4e6f28b9ecab"],
Cell[CellGroupData[{
Cell[503080, 9975, 1019, 27, 19, "Input",ExpressionUUID->"9afc4faf-35d0-4cdf-827b-4ff9ae4bd096",
 CellOpen->False],
Cell[504102, 10004, 18119, 357, 248, "Output",ExpressionUUID->"5fdcafad-bac4-4253-8cbe-b2fdb8a9792c"]
}, Open  ]],
Cell[522236, 10364, 391, 7, 21, "FigureCaption",ExpressionUUID->"78e47451-8b53-4dbf-ab75-ecb5d09c569f"],
Cell[CellGroupData[{
Cell[522652, 10375, 425, 10, 22, "Text",ExpressionUUID->"e475e5f1-3437-4af5-ae8a-74bca70f6260"],
Cell[CellGroupData[{
Cell[523102, 10389, 706, 22, 49, "Input",ExpressionUUID->"841adf44-b83e-483b-90ca-7f3485224099"],
Cell[523811, 10413, 679, 11, 30, "Output",ExpressionUUID->"3f0541ac-03ef-4fc7-a6a5-0be8049f672d"],
Cell[524493, 10426, 652, 10, 30, "Output",ExpressionUUID->"24a7c6c2-aaaf-44e1-a5ad-2f73166eec2f"]
}, Open  ]]
}, Open  ]],
Cell[525172, 10440, 990, 26, 54, "Text",ExpressionUUID->"05d31169-dc4f-47fa-91b4-1decc40f76ee"],
Cell[CellGroupData[{
Cell[526187, 10470, 2277, 56, 19, "Input",ExpressionUUID->"7049d511-0f28-4766-be2e-dc166a624187",
 CellOpen->False],
Cell[528467, 10528, 64113, 1196, 337, "Output",ExpressionUUID->"b6704b92-c1e5-40d0-b4fb-e89a421e3080"]
}, Open  ]],
Cell[592595, 11727, 436, 8, 23, "FigureCaption",ExpressionUUID->"61d6a2fd-eb84-445b-8df1-cb2e7a0807b6"],
Cell[593034, 11737, 1617, 42, 59, "Text",ExpressionUUID->"86241d3e-5de3-4012-aa50-8564821cfe4d"],
Cell[CellGroupData[{
Cell[594676, 11783, 208, 6, 19, "Input",ExpressionUUID->"c83c8b67-9034-4563-a619-a6bb1a5ea7b9",
 CellOpen->False],
Cell[594887, 11791, 709, 11, 19, "Output",ExpressionUUID->"85387180-b206-4f68-a286-fc57e3e1022d",
 CellOpen->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[595633, 11807, 1067, 28, 19, "Input",ExpressionUUID->"116e3ce9-f9c2-4141-bac3-8bb85228f2e0",
 CellOpen->False],
Cell[596703, 11837, 15912, 325, 329, "Output",ExpressionUUID->"ec970bc8-1b64-4a3d-93f0-a9ed64a3e5b8"]
}, Open  ]],
Cell[612630, 12165, 367, 7, 23, "FigureCaption",ExpressionUUID->"2974a7da-d202-4044-bfe1-8c77fe2a6834"],
Cell[613000, 12174, 663, 14, 41, "Text",ExpressionUUID->"7b6f13a9-3cf9-4cb3-8546-58cbb5d3f470"]
}, Open  ]],
Cell[CellGroupData[{
Cell[613700, 12193, 184, 3, 57, "Section",ExpressionUUID->"a9f57b21-73aa-446a-ac9b-bb580a65cbef"],
Cell[613887, 12198, 656, 11, 71, "Text",ExpressionUUID->"29b96d37-cf49-4f7f-98a0-c1a45e540c13"],
Cell[614546, 12211, 776, 13, 71, "Text",ExpressionUUID->"55f0682c-49fb-4fc1-97f1-13c206ff5aa7"],
Cell[615325, 12226, 919, 15, 87, "Text",ExpressionUUID->"a8add357-9f26-4539-8965-1ff7cf643ac6"],
Cell[616247, 12243, 578, 10, 54, "Text",ExpressionUUID->"66673e56-9cf3-4450-a600-fce0737725d5"],
Cell[CellGroupData[{
Cell[616850, 12257, 2329, 39, 19, "Input",ExpressionUUID->"5c68a581-cb08-4e6a-a476-da329233c2c9",
 CellOpen->False],
Cell[619182, 12298, 669, 13, 54, "Text",ExpressionUUID->"47b2063a-1b4f-4a52-92f3-c72573e4c8e0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[619888, 12316, 1051, 22, 19, "Input",ExpressionUUID->"909cebfa-9bb6-4b91-849f-e58b4f63da95",
 CellOpen->False],
Cell[620942, 12340, 2888, 59, 182, "Output",ExpressionUUID->"80ed5702-30d1-4bdc-8f4b-28bc7018e69d"]
}, Open  ]],
Cell[623845, 12402, 385, 7, 23, "Text",ExpressionUUID->"48ce1d3d-92d2-4582-bde4-375ec733b3e5"],
Cell[CellGroupData[{
Cell[624255, 12413, 936, 27, 19, "Input",ExpressionUUID->"8351170e-f38d-4b7f-807e-1fab89c75f47",
 CellOpen->False],
Cell[625194, 12442, 3660, 76, 337, "Output",ExpressionUUID->"b915bf8e-ca1c-4738-a132-a9b87e3128f0"]
}, Open  ]],
Cell[628869, 12521, 356, 7, 23, "FigureCaption",ExpressionUUID->"06430960-1078-4851-b768-c2a4626457fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[629262, 12533, 161, 3, 57, "Section",ExpressionUUID->"5a3dec89-e831-48e9-adc5-61cc43be9aa9"],
Cell[629426, 12538, 1289, 20, 95, "Text",ExpressionUUID->"c4fb6d61-fe25-45d3-b68f-5abbfdbf9671"],
Cell[630718, 12560, 1675, 27, 113, "Text",ExpressionUUID->"648544d5-8a26-4ea4-9a00-98ce44f34b2e"],
Cell[632396, 12589, 600, 10, 54, "Text",ExpressionUUID->"2eb7c207-9210-47c9-9b0c-ad963a4bd1fd"],
Cell[632999, 12601, 253, 5, 23, "Text",ExpressionUUID->"d8576da9-71d6-4149-8d67-b6614369918a"]
}, Open  ]],
Cell[633267, 12609, 246, 5, 104, "EndnoteSection",ExpressionUUID->"627631ac-7460-4b28-9780-85f173b331b9"],
Cell[633516, 12616, 803, 14, 36, "Endnote",ExpressionUUID->"b3009463-b40e-4460-8fa3-3f0af7ed7d3d",
 CellTags->"endnote1"],
Cell[634322, 12632, 621, 12, 19, "Endnote",ExpressionUUID->"512df4dc-4f4f-4a0e-87ea-f8d6b3b2f162",
 CellTags->"endnote2"],
Cell[634946, 12646, 574, 12, 19, "Endnote",ExpressionUUID->"ca39658a-6f89-4471-b226-bba1b245bf56",
 CellTags->"endnote3"],
Cell[635523, 12660, 191, 3, 104, "ReferenceSection",ExpressionUUID->"6873e46f-3a9d-43af-b980-9565d5d79881"],
Cell[635717, 12665, 454, 9, 19, "Reference",ExpressionUUID->"24fad992-02cf-40c9-a254-be810d57dddb"],
Cell[636174, 12676, 442, 10, 19, "Reference",ExpressionUUID->"9a8033a0-15c5-4273-b776-153dffb256ed"],
Cell[636619, 12688, 375, 9, 19, "Reference",ExpressionUUID->"5d036c94-f01c-4dbd-b22d-78637657ad92"],
Cell[636997, 12699, 186, 3, 104, "ExerciseSection",ExpressionUUID->"f1697f94-15e7-41af-a688-b037c1067749"],
Cell[637186, 12704, 298, 6, 19, "Item1Exercise",ExpressionUUID->"1a65c771-d7fe-4508-b831-88e76c506689"],
Cell[637487, 12712, 406, 8, 35, "Item1Exercise",ExpressionUUID->"98381d37-48e4-4529-ab3f-9c292eb498ed"],
Cell[CellGroupData[{
Cell[637918, 12724, 243, 5, 104, "AppendixSection",ExpressionUUID->"bfe46b9d-e74c-49c5-ae42-40835e0fbfe0"],
Cell[638164, 12731, 322, 7, 23, "Text",ExpressionUUID->"3b10b7cb-1ac6-4f3d-bc5d-cab7f23bc27c"],
Cell[638489, 12740, 166, 3, 34, "Subsection",ExpressionUUID->"4a3f87e1-27b9-46bd-89de-623a6a1d771d"],
Cell[638658, 12745, 324, 7, 22, "Text",ExpressionUUID->"324459a7-23f6-476e-9ec2-316e30561f7d"],
Cell[638985, 12754, 664, 15, 41, "Text",ExpressionUUID->"fbcdb526-4b9a-4fb4-9339-e6af5f1d9cc9"],
Cell[639652, 12771, 484, 15, 53, "EquationNumbered",ExpressionUUID->"966dcd7e-08f8-4294-99fe-57845e88c4e3"],
Cell[640139, 12788, 353, 11, 19, "Input",ExpressionUUID->"b68d1134-58cc-4bc3-bc55-454bdc5dbc05",
 CellOpen->False],
Cell[640495, 12801, 757, 22, 73, "EquationNumbered",ExpressionUUID->"f68a920e-a559-45e3-b135-b7d244cf8aa2"],
Cell[641255, 12825, 303, 8, 19, "Input",ExpressionUUID->"7e22e402-1df1-41b5-a4e0-a116dbca6bc1",
 CellOpen->False],
Cell[641561, 12835, 276, 6, 23, "Text",ExpressionUUID->"bf2a2686-beb1-4bf4-bc32-c24428ebe89c"],
Cell[CellGroupData[{
Cell[641862, 12845, 1644, 43, 19, "Input",ExpressionUUID->"4deb2561-0f82-4ed4-b4da-d2fe6c99d010",
 CellOpen->False],
Cell[643509, 12890, 213, 5, 23, "Text",ExpressionUUID->"f3428b5b-85be-4239-bc09-4206b5c4cb8a"]
}, Open  ]],
Cell[643737, 12898, 288, 6, 23, "Text",ExpressionUUID->"448a04ad-80d4-463c-9972-757738e51560"],
Cell[CellGroupData[{
Cell[644050, 12908, 4067, 110, 19, "Input",ExpressionUUID->"b27b521f-9753-4603-bb28-d631245e8139",
 CellOpen->False],
Cell[648120, 13020, 27638, 531, 333, "Output",ExpressionUUID->"3f89c632-b343-47e4-ae1f-d2631da8f406"]
}, Open  ]],
Cell[675773, 13554, 445, 8, 23, "FigureCaption",ExpressionUUID->"0523f7c0-b6a2-4a42-a4e4-50a58ae957ae"],
Cell[676221, 13564, 695, 11, 71, "Text",ExpressionUUID->"462a4d4a-4e72-44ff-a6b3-cf48c39f6fb3"],
Cell[676919, 13577, 153, 3, 34, "Subsection",ExpressionUUID->"0c2dec00-09a7-45f0-a267-ddbf6ed90821"],
Cell[677075, 13582, 1076, 22, 58, "Text",ExpressionUUID->"0909a0e0-a21f-4dda-8de1-aa1fe5dc0248"],
Cell[678154, 13606, 459, 8, 23, "Text",ExpressionUUID->"683d47b2-f207-448e-b998-89d6b212f8be"],
Cell[CellGroupData[{
Cell[678638, 13618, 2904, 76, 19, "Input",ExpressionUUID->"7b4179df-5abf-4342-970a-fa0f1f5263ec",
 CellOpen->False],
Cell[681545, 13696, 2497, 63, 489, "Output",ExpressionUUID->"a12696df-d0dd-4dfa-a979-a82198b33fa1"],
Cell[684045, 13761, 352, 8, 23, "TableTitle",ExpressionUUID->"8e51c144-2182-4627-b9e3-5713ee6902d8"],
Cell[CellGroupData[{
Cell[684422, 13773, 1281, 27, 19, "Input",ExpressionUUID->"1a085106-bb19-4078-8213-714a4d56374c",
 CellOpen->False],
Cell[685706, 13802, 500, 11, 41, "Text",ExpressionUUID->"9d80d3b0-ff14-4f3b-902b-f8496231f54e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[686243, 13818, 385, 9, 19, "Input",ExpressionUUID->"2ba636e5-7a5f-4d9e-85c0-c139e1c76f38",
 CellOpen->False],
Cell[686631, 13829, 2345, 54, 330, "Output",ExpressionUUID->"3cb3dcb9-e91c-4ae3-a4fc-83b3d79f2048"]
}, Open  ]],
Cell[688991, 13886, 408, 8, 21, "FigureCaption",ExpressionUUID->"b542a433-a548-4476-84ee-437de38b5bd5"],
Cell[689402, 13896, 325, 6, 22, "Text",ExpressionUUID->"ee258d64-baf8-4a04-b543-939fbd251de3"],
Cell[689730, 13904, 606, 11, 54, "Text",ExpressionUUID->"02259672-99cc-41ef-af18-b51224306ffa"]
}, Open  ]],
Cell[690351, 13918, 300, 6, 22, "Text",ExpressionUUID->"39cd9c9f-9364-4a88-9318-fb5297f14980"],
Cell[CellGroupData[{
Cell[690676, 13928, 2221, 70, 19, "Input",ExpressionUUID->"731063cd-8627-4bc1-8456-8edeacf5d91c",
 CellOpen->False],
Cell[692900, 14000, 27805, 480, 184, "Output",ExpressionUUID->"68676b85-9eaa-4654-bff0-674e863681d6"]
}, Open  ]],
Cell[720720, 14483, 450, 8, 21, "FigureCaption",ExpressionUUID->"bb1b7d11-c01e-42ed-939f-fdb6d47fc915"],
Cell[CellGroupData[{
Cell[721195, 14495, 403, 13, 19, "Text",ExpressionUUID->"850ce2ac-4ac9-48c1-af2f-4c9affeb563b",
 CellOpen->False],
Cell[721601, 14510, 991, 31, 157, "Input",ExpressionUUID->"17b196e2-4695-4aed-ab82-70535b247d4f",
 CellOpen->False]
}, Closed]],
Cell[722607, 14544, 312, 6, 19, "Text",ExpressionUUID->"ac011a65-6bb1-4be4-8997-bc30752d49fc"],
Cell[722922, 14552, 565, 19, 66, "EquationNumbered",ExpressionUUID->"e4b34c7e-1937-4e96-a8ae-369baecc7c39"],
Cell[723490, 14573, 567, 19, 66, "EquationNumbered",ExpressionUUID->"3fe12ab8-2ecd-4c8b-a07f-768a3a3dbfec"],
Cell[724060, 14594, 353, 9, 22, "Text",ExpressionUUID->"d4b7b872-cd94-4241-b3e0-0ebaac0a5322"],
Cell[724416, 14605, 653, 16, 41, "Text",ExpressionUUID->"ab558e32-b7cb-412e-a5f2-8582ea84810c"],
Cell[725072, 14623, 23814, 398, 184, "Output",ExpressionUUID->"3c3799ed-8299-4851-9b25-8275e03a9516"],
Cell[748889, 15023, 155, 3, 23, "Text",ExpressionUUID->"ed9533f4-136c-4bf8-963b-62343bbc9f29"],
Cell[749047, 15028, 36750, 609, 216, "Output",ExpressionUUID->"7c4ebe7f-d3ee-469c-8c1e-4b1d96e25758"],
Cell[785800, 15639, 166, 3, 23, "Text",ExpressionUUID->"edfef7ad-aae4-4bff-92f2-a77de6293e3d"],
Cell[785969, 15644, 38224, 635, 291, "Output",ExpressionUUID->"10627555-1733-473a-8bc9-392136817a40"],
Cell[824196, 16281, 479, 9, 41, "Text",ExpressionUUID->"2555106c-82cf-4a12-89fb-708fbb7707f5"],
Cell[824678, 16292, 769, 14, 41, "Text",ExpressionUUID->"f61c95f4-e191-4763-a0bb-1c0c857cc1f9"],
Cell[CellGroupData[{
Cell[825472, 16310, 17136, 473, 19, "Input",ExpressionUUID->"d0264414-fbbd-4836-b4ea-b9d8cb981170",
 CellOpen->False,
 CellID->146366557],
Cell[842611, 16785, 14035, 276, 495, "Output",ExpressionUUID->"918f8f9e-cd2d-461f-bea0-ac3630d432f0"]
}, Open  ]],
Cell[856661, 17064, 459, 11, 23, "FigureCaption",ExpressionUUID->"f93f0697-10c0-406d-90f2-db8526ad8e31"]
}, Open  ]],
Cell[857135, 17078, 207, 3, 104, "AppendixSection",ExpressionUUID->"852e6115-6dda-4d87-968c-dbe7b3497045"],
Cell[857345, 17083, 172, 3, 28, "Subsection",ExpressionUUID->"d8b1cac3-ab9d-44ef-84ba-102d8b18f695"],
Cell[857520, 17088, 152, 3, 28, "Subsection",ExpressionUUID->"e00b743a-4774-4d5e-a40a-0307d8d18be7"],
Cell[857675, 17093, 3448, 65, 160, "Text",ExpressionUUID->"92027fc9-83b8-436d-a97b-935048bc4e48"],
Cell[861126, 17160, 172, 3, 34, "Subsection",ExpressionUUID->"1382be44-0009-4063-bb8d-a5bb7b617c02"],
Cell[861301, 17165, 4702, 76, 354, "Text",ExpressionUUID->"8d1ccffb-f807-4200-b697-21c396144295"],
Cell[CellGroupData[{
Cell[866028, 17245, 2965, 55, 19, "Input",ExpressionUUID->"d3d61809-d88a-4f7d-99b9-50c9388ec5e1",
 CellOpen->False],
Cell[868996, 17302, 1767, 41, 629, "Output",ExpressionUUID->"9155f976-1c38-428f-aff2-755d608e6d77"]
}, Open  ]],
Cell[870778, 17346, 259, 6, 23, "FigureCaption",ExpressionUUID->"dc4e4512-c6ad-44f7-a7cd-8e8d33d5c9d0"],
Cell[871040, 17354, 172, 3, 34, "Subsection",ExpressionUUID->"88488f33-4c09-4713-abf4-e345e1ad3798"],
Cell[871215, 17359, 150, 3, 28, "Subsection",ExpressionUUID->"a8d3cf0e-5975-488e-bd0d-625c0719242f"],
Cell[871368, 17364, 1787, 29, 130, "Text",ExpressionUUID->"170fd733-e3ce-421a-a81e-1640236baf11"],
Cell[CellGroupData[{
Cell[873180, 17397, 3122, 59, 19, "Input",ExpressionUUID->"69015a34-45b4-4a5b-8481-bda424864528",
 CellOpen->False],
Cell[876305, 17458, 2600, 62, 629, "Output",ExpressionUUID->"47fd5c9f-b0f0-4536-8831-ad913d69f12b"]
}, Open  ]],
Cell[878920, 17523, 283, 6, 23, "FigureCaption",ExpressionUUID->"bdb85538-3c38-424f-b893-a3257a7f2ecf"],
Cell[879206, 17531, 175, 3, 34, "Subsection",ExpressionUUID->"851d9aed-8b1a-49dc-8998-21ae20971b40"],
Cell[879384, 17536, 152, 3, 28, "Subsection",ExpressionUUID->"264950f8-3a69-45c5-b69d-5a6b32021120"],
Cell[879539, 17541, 1543, 25, 76, "Text",ExpressionUUID->"1270bca9-c72a-4072-bf2a-931423e69ed2"],
Cell[CellGroupData[{
Cell[881107, 17570, 3664, 73, 19, "Input",ExpressionUUID->"203d85b8-2ffc-424c-881f-2ad372f95cb3",
 CellOpen->False],
Cell[884774, 17645, 2759, 67, 629, "Output",ExpressionUUID->"2f3b3755-99ed-4680-b741-4631bb81633d"]
}, Open  ]],
Cell[887548, 17715, 347, 7, 23, "FigureCaption",ExpressionUUID->"277ce481-133d-4412-8b01-6bab6321f119"],
Cell[887898, 17724, 179, 3, 34, "Subsection",ExpressionUUID->"42908803-72f2-4cfd-b8c0-1d2544f93850"],
Cell[888080, 17729, 150, 3, 28, "Subsection",ExpressionUUID->"11355ac4-501d-4e75-a8a9-67b9674ed6ef"],
Cell[888233, 17734, 1350, 23, 80, "Text",ExpressionUUID->"3b8a7719-fe4a-4e1a-944b-abd3c38f08d7"],
Cell[889586, 17759, 263, 3, 23, "Text",ExpressionUUID->"d19864e5-144b-43a9-883d-4277dba4d796"],
Cell[889852, 17764, 185, 3, 23, "Text",ExpressionUUID->"83da4465-d946-463a-bb6d-82dcfc43c7f0"],
Cell[CellGroupData[{
Cell[890062, 17771, 4249, 87, 19, "Input",ExpressionUUID->"96bd59e1-b9d9-4b11-852e-139d011f2594",
 CellOpen->False],
Cell[894314, 17860, 2547, 62, 629, "Output",ExpressionUUID->"3d96f78e-44c8-4b63-81db-5047a97e5425"]
}, Open  ]],
Cell[896876, 17925, 340, 7, 23, "FigureCaption",ExpressionUUID->"1cfc5704-36ef-45d3-be1a-e2d97d9a2047"],
Cell[897219, 17934, 172, 3, 34, "Subsection",ExpressionUUID->"249cb447-2b2e-4f1d-9618-b86a05ca129d"],
Cell[897394, 17939, 150, 3, 28, "Subsection",ExpressionUUID->"71cf07aa-d524-45ca-a1ac-bfab50d42a56"],
Cell[897547, 17944, 1966, 41, 120, "Text",ExpressionUUID->"c3f6672c-a43f-4a10-99ab-f1c573567119"],
Cell[CellGroupData[{
Cell[899538, 17989, 5105, 106, 19, "Input",ExpressionUUID->"e0ab0ffe-638c-49df-878a-7d9bf3b89a78",
 CellOpen->False],
Cell[904646, 18097, 4608, 106, 549, "Output",ExpressionUUID->"d17a7ab3-6b1d-4201-83cb-5428c855c750"]
}, Open  ]],
Cell[909269, 18206, 344, 7, 23, "FigureCaption",ExpressionUUID->"9abba2fe-6883-4e1d-84bd-6b3e7dfe86a5"],
Cell[909616, 18215, 623, 10, 23, "Text",ExpressionUUID->"b21fe22a-d67d-4b2b-9e07-3698cb0dc877"],
Cell[910242, 18227, 185, 2, 23, "Text",ExpressionUUID->"379fa787-1c7c-4e8f-8555-51594cae12da"],
Cell[910430, 18231, 305, 6, 23, "Text",ExpressionUUID->"ebed1824-7c99-4a5b-a2e8-1d85986c93a1"],
Cell[910738, 18239, 284, 4, 23, "Text",ExpressionUUID->"c115f6e5-faf0-4211-aae8-4aa95fa1055d"],
Cell[911025, 18245, 164, 3, 23, "Text",ExpressionUUID->"124323fd-2775-4b96-89ae-8e41fcbece89"],
Cell[911192, 18250, 207, 2, 23, "Text",ExpressionUUID->"2281defe-b7a8-4d6b-a56d-d5d01c706050"],
Cell[911402, 18254, 1008, 20, 45, "Text",ExpressionUUID->"f38c7c94-4620-4988-ac7c-1bc2925e6ca5"],
Cell[912413, 18276, 223, 4, 34, "Subsection",ExpressionUUID->"a2fc4833-8fcf-4d98-8418-12c65007a177"],
Cell[912639, 18282, 150, 3, 28, "Subsection",ExpressionUUID->"8541187a-7fad-4604-9e13-e8baae1eb3ef"],
Cell[912792, 18287, 541, 9, 22, "Text",ExpressionUUID->"a0517f1e-8042-49aa-b36b-0b91f2ca795e"],
Cell[CellGroupData[{
Cell[913358, 18300, 5960, 125, 19, "Input",ExpressionUUID->"1ec1fa1b-0d27-440c-860d-f631b0af1b6b",
 CellOpen->False],
Cell[919321, 18427, 6282, 144, 764, "Output",ExpressionUUID->"444b945b-1eec-4454-836d-e5fec8dc1b86"]
}, Open  ]],
Cell[925618, 18574, 335, 7, 23, "FigureCaption",ExpressionUUID->"7869a79f-3603-4d55-ba57-7089a51e87fc"],
Cell[925956, 18583, 529, 10, 23, "Text",ExpressionUUID->"90547a4c-a152-4448-a8c6-dc5c577ac9ed"],
Cell[CellGroupData[{
Cell[926510, 18597, 8216, 174, 19, "Input",ExpressionUUID->"d0938010-84f5-4add-9dfd-ddd89c489b35",
 CellOpen->False],
Cell[934729, 18773, 9613, 218, 764, "Output",ExpressionUUID->"7e9d83fd-9902-4935-b04f-65879763820f"]
}, Open  ]],
Cell[944357, 18994, 328, 7, 23, "FigureCaption",ExpressionUUID->"9d5718e5-7c2a-4b1e-b254-8049fdf98c14"],
Cell[944688, 19003, 277, 4, 34, "Subsection",ExpressionUUID->"af250846-1662-422a-ac73-8f7df9dc3a68"],
Cell[944968, 19009, 203, 4, 28, "Subsection",ExpressionUUID->"e4aa3ed4-2663-4d74-8a62-093c596a261a"],
Cell[945174, 19015, 5284, 92, 358, "Text",ExpressionUUID->"2bbdf89f-0fda-4c52-b856-8f073b4185bc"],
Cell[CellGroupData[{
Cell[950483, 19111, 47136, 955, 19, "Input",ExpressionUUID->"1eca4d13-ca65-4c1b-902d-b1d26dd97d76",
 CellOpen->False],
Cell[997622, 20068, 28277, 539, 885, "Output",ExpressionUUID->"d1c2d2c6-1b97-4a83-a1cb-44d445a91c23"]
}, Open  ]],
Cell[1025914, 20610, 337, 7, 23, "FigureCaption",ExpressionUUID->"662c6a94-f488-405a-994b-1ea5319f0ebb"],
Cell[1026254, 20619, 324, 5, 34, "Subsection",ExpressionUUID->"d87e75f4-9306-4be2-bb5e-42235d450be3"],
Cell[1026581, 20626, 251, 4, 28, "Subsection",ExpressionUUID->"ff4fa5c6-5266-4b0d-b5dd-cb45b9d8f29b"],
Cell[1026835, 20632, 2818, 42, 202, "Text",ExpressionUUID->"09ac5e58-e5e7-4d4a-88ba-0ce17e6eea10"],
Cell[CellGroupData[{
Cell[1029678, 20678, 8877, 186, 19, "Input",ExpressionUUID->"12332cca-b807-4671-9b95-aab12eff81a2",
 CellOpen->False],
Cell[1038558, 20866, 9737, 220, 816, "Output",ExpressionUUID->"d9c75405-588d-47be-8a31-e51bdef7dda0"]
}, Open  ]],
Cell[1048310, 21089, 321, 7, 23, "FigureCaption",ExpressionUUID->"686e5ef4-e73d-4ab6-a0fd-41a119d1b5c6"],
Cell[1048634, 21098, 324, 5, 34, "Subsection",ExpressionUUID->"34ca9be2-cf7e-4848-bd04-1d5d4a218c52"],
Cell[1048961, 21105, 304, 5, 28, "Subsection",ExpressionUUID->"c9e132ef-2300-4182-a47e-9a473a2366d3"],
Cell[1049268, 21112, 807, 14, 40, "Text",ExpressionUUID->"b6774d9f-8e63-4f0f-9a6e-ce0320a92b77"],
Cell[1050078, 21128, 343, 6, 23, "Text",ExpressionUUID->"278d9c1f-2a38-4d7b-9a7f-15181e4efb68"],
Cell[1050424, 21136, 27770, 533, 885, "Output",ExpressionUUID->"1193b183-9bfd-4ea1-9738-8bb4eccf0df7"],
Cell[1078197, 21671, 352, 8, 23, "FigureCaption",ExpressionUUID->"fc22523e-7590-45e8-9c42-61c83f08682f"],
Cell[1078552, 21681, 311, 5, 34, "Subsection",ExpressionUUID->"15574c31-b6be-4955-8f4d-2cc300040024"],
Cell[1078866, 21688, 302, 5, 28, "Subsection",ExpressionUUID->"1644fd9c-b500-411e-80c1-674f3fb0b631"],
Cell[1079171, 21695, 1039, 20, 80, "Text",ExpressionUUID->"24eaa7f5-faeb-4b88-965f-e01be51af090"],
Cell[1080213, 21717, 1686, 26, 113, "Text",ExpressionUUID->"49635779-a5ad-40a9-8bfe-dc95ff2cc82a"],
Cell[1081902, 21745, 822, 13, 41, "Text",ExpressionUUID->"e503f42e-1c39-4fba-aaeb-af660d084191"],
Cell[1082727, 21760, 1385, 20, 77, "Text",ExpressionUUID->"0d85a131-b881-4dbe-9503-b692bdc63e90"],
Cell[1084115, 21782, 175, 3, 104, "EndnoteSection",ExpressionUUID->"ea369955-4e1b-46b8-bcf5-dd29b586f48b"],
Cell[1084293, 21787, 354, 7, 19, "Endnote",ExpressionUUID->"8a8dbbca-ea7f-470f-a418-427fe592f403",
 CellTags->"endnoteB1"],
Cell[1084650, 21796, 291, 5, 19, "Endnote",ExpressionUUID->"7b78bedb-204f-48e0-9d50-1c3490c362a1",
 CellTags->"endnoteB2"],
Cell[1084944, 21803, 469, 6, 19, "Endnote",ExpressionUUID->"581dd8be-9c0d-420a-a967-939666dd9014",
 CellTags->"endnoteB3"],
Cell[1085416, 21811, 463, 9, 19, "Endnote",ExpressionUUID->"352b27bb-1e08-4e2b-84cf-01ecce45ab6a",
 CellTags->"endnoteB4"],
Cell[1085882, 21822, 353, 8, 19, "Endnote",ExpressionUUID->"b5ae3fb2-efc5-464c-9049-59d226f356f9",
 CellTags->"endnoteB5"],
Cell[1086238, 21832, 325, 5, 19, "Endnote",ExpressionUUID->"b8ebd3ca-8764-45ac-8355-429073b4d5fe",
 CellTags->"endnoteB6"],
Cell[1086566, 21839, 494, 9, 19, "Endnote",ExpressionUUID->"bf34c120-c0ae-41fb-9f37-0b7c1e4c6924",
 CellTags->"endnoteB7"],
Cell[1087063, 21850, 403, 8, 19, "Endnote",ExpressionUUID->"8238c18c-b4c9-49a2-957b-b430ddd34b01",
 CellTags->"endnoteB8"],
Cell[1087469, 21860, 434, 8, 19, "Endnote",ExpressionUUID->"e8993717-7018-470c-9df8-cd469c109af7",
 CellTags->"endnoteB9"],
Cell[1087906, 21870, 611, 11, 36, "Endnote",ExpressionUUID->"7db8e622-eaf2-4483-8555-d2579bb40034",
 CellTags->"endnoteB10"],
Cell[1088520, 21883, 445, 9, 19, "Endnote",ExpressionUUID->"c80fbf61-c897-4c30-8fcc-63c89c611ef2",
 CellTags->"endnoteB11"],
Cell[1088968, 21894, 432, 9, 19, "Endnote",ExpressionUUID->"f885dc5a-2725-43f0-a2dc-763048bea186",
 CellTags->"endnoteB12"],
Cell[1089403, 21905, 462, 9, 19, "Endnote",ExpressionUUID->"6a496287-8ce0-4b81-87cf-c44046bea38c",
 CellTags->"endnoteB13"],
Cell[1089868, 21916, 472, 9, 19, "Endnote",ExpressionUUID->"824f6084-a21d-4bea-a39f-37cd3aa926da",
 CellTags->"endnote14"]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature zw0RAS6DaICOfA1aAxwfs@rV *)
