(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.3' *)

(***************************************************************************)
(*                                                                         *)
(*                                                                         *)
(*  Under the Wolfram FreeCDF terms of use, this file and its content are  *)
(*  bound by the Creative Commons BY-SA Attribution-ShareAlike license.    *)
(*                                                                         *)
(*        For additional information concerning CDF licensing, see:        *)
(*                                                                         *)
(*         www.wolfram.com/cdf/adopting-cdf/licensing-options.html         *)
(*                                                                         *)
(*                                                                         *)
(***************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1088,         20]
NotebookDataLength[    824413,      17169]
NotebookOptionsPosition[    764847,      16071]
NotebookOutlinePosition[    790333,      16636]
CellTagsIndexPosition[    790010,      16623]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["4", "BookChapterNumber",
 CellChangeTimes->{3.528492590492605*^9, 3.528499420936284*^9, 
  3.5284995081652737`*^9, 3.5284995843256297`*^9, 3.528499767981134*^9},
 Background->RGBColor[
  0.9333333333333333, 0.1803921568627451, 
   0.1411764705882353],ExpressionUUID->"d084675e-1f48-4c27-9aa3-74335a81c878"],

Cell["Fundamental Real Estate Analysis", "BookChapterTitle",
 CellChangeTimes->{3.5284926024132867`*^9},
 TextAlignment->Center,ExpressionUUID->"d3362101-4e6d-4195-bf54-4419e2da7fd2"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["\[OpenCurlyDoubleQuote]Compound interest is the \
eighth wonder of the world.\[CloseCurlyDoubleQuote]",
 CharacterEncoding -> "WindowsANSI"]], "Epigraph",
 CellChangeTimes->{3.528492821815836*^9},
 TextAlignment->Center,ExpressionUUID->"e3cd5e66-09d9-45a2-b054-a1ae1df2e71d"],

Cell[TextData[{
 StyleBox["Attributed to ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["Albert Einstein",
  FontWeight->"Bold",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" and others",
  CharacterEncoding -> "WindowsANSI"]
}], "EpigraphAuthor",
 CellChangeTimes->{3.5284928363066645`*^9},
 TextAlignment->Center,ExpressionUUID->"f60ce0ab-7ff3-404e-9901-222e0cfbc57c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Rasterize", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "350"}]}], "]"}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.528493297890066*^9, {3.539519764986305*^9, 3.53951978448042*^9}, {
   3.6960758975026054`*^9, 3.6960758983298063`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"13c991fd-09dd-4341-8668-ada36b7443a6"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Introduction"
}], "Section",
 CellChangeTimes->{
  3.531447062879056*^9},ExpressionUUID->"501c19dd-a6be-4de3-9eee-\
0e150f8ad538"],

Cell[TextData[{
 "There are a number of excellent real estate analysis programs for \
practitioner use in \[OpenCurlyDoubleQuote]numbers crunching\
\[CloseCurlyDoubleQuote].  Essentially, these are variant forms of \
spreadsheets that perform ",
 StyleBox["numerical",
  FontSlant->"Italic"],
 " analysis. A simple Excel version of such a program is included with the \
electronic files for this chapter to provide the reader with a fully \
elaborated example in a familiar context. Programs such as these all perform \
the same basic tasks, usually offering different menus of reporting and \
printing options to dress up the appearance of the analysis for use with \
clients. In this chapter we will:"
}], "Text",
 CellChangeTimes->{{3.528492878095055*^9, 
  3.5284929012523794`*^9}},ExpressionUUID->"a767a825-305c-4635-996e-\
17f7e6211dac"],

Cell[CellGroupData[{

Cell["\<\
List all the relevant variables required to perform a complete multiperiod \
discounted cash flow analysis of a real estate investment;\
\>", "Item1",
 CellChangeTimes->{{3.5284929175843134`*^9, 
  3.528492918651375*^9}},ExpressionUUID->"51242407-7869-4fa3-af21-\
4843224b0fba"],

Cell["\<\
Perform that analysis, computing various performance measures, including net \
present value and internal rate of return;\
\>", "Item1",
 CellChangeTimes->{{3.5284929255027666`*^9, 
  3.5284929271618614`*^9}},ExpressionUUID->"caa0a88d-d4d7-41cc-9a26-\
fa1d4fde0b76"],

Cell["Demonstrate the interdependencies between the variables;", "Item1",
 CellChangeTimes->{{3.528492932987195*^9, 
  3.5284929342372665`*^9}},ExpressionUUID->"a9eaccee-4009-439d-a087-\
9aac08378104"],

Cell["\<\
Set up a series of scenarios based on the variables for simple risk \
evaluation via sensitivity testing; and\
\>", "Item1",
 CellChangeTimes->{{3.5284929407466383`*^9, 
  3.528492942187721*^9}},ExpressionUUID->"f2adb2dd-d39f-432f-a317-\
22921dcee4eb"],

Cell["\<\
Introduce ways in which data may be used to further understand the process.\
\>", "Item1",
 CellChangeTimes->{3.5284929499091625`*^9, 
  3.5409350280922947`*^9},ExpressionUUID->"8267b4dc-c169-4fcb-9490-\
58222f62729e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". The role of computational aids"
}], "Subsection",
 CellChangeTimes->{3.531446664268257*^9, 
  3.53144708322322*^9},ExpressionUUID->"c2882114-d9be-4e9f-8be1-3c6ede104d09"],

Cell[TextData[{
 "Much of the heavy lifting of this chapter is done by",
 StyleBox[" Mathematica.",
  FontSlant->"Italic"],
 " Technical computing software performs a different function than \
spreadsheet programs. It can, and we will, make any numerical calculation \
that can be done by a spreadsheet program.  The primary value of the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " approach is to perform ",
 StyleBox["symbolic",
  FontSlant->"Italic"],
 " analysis.  That is, rather than operating on the numbers of a specific \
real estate project, it solves for the ",
 StyleBox["relationships",
  FontVariations->{"Underline"->True}],
 " between the variables used in the mathematics to reach the conclusions \
that drive business decisions for ",
 StyleBox["all",
  FontSlant->"Italic"],
 " projects. In that, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " (a) offers the ability to solve almost any equation for almost any \
variable, thus providing a more general view of the process not tied to any \
particular investment, and (b) permits one to look behind spreadsheet icons \
at their inner workings to more fully understand the total process."
}], "Text",
 CellChangeTimes->{
  3.528493016813989*^9, {3.5299292725084925`*^9, 
   3.5299292811169853`*^9}},ExpressionUUID->"caa99c8b-d50e-4bd6-8b55-\
79a878182ad1"],

Cell["\<\
There are several good reasons for employing the power of Mathematica: \
\>", "Text",ExpressionUUID->"07320564-30bc-40d9-ad26-bd73fae49f49"],

Cell[CellGroupData[{

Cell[TextData[{
 "Understanding general rules permits one to draw on that knowledge when \
encountering exceptions, when addressing more complex problems and when using \
data. Simply stated, there are a few rules that virtually always work. The \
deductive reasoning behind those rules is expressed in symbols and equations. \
Familiarity with those symbols and equations leaves one with an understanding \
of ",
 StyleBox["why",
  FontSlant->"Italic"],
 " good business decisions ",
 StyleBox["are",
  FontSlant->"Italic"],
 " good business decisions."
}], "Item1",
 CellChangeTimes->{{3.528493045025603*^9, 
  3.528493047436741*^9}},ExpressionUUID->"df6de716-b81a-4ead-a95e-\
ce326e550e18"],

Cell["\<\
The market is competitive. Principals and brokers compete for the best deals. \
Many decisions must be made very fast. Although spreadsheets are ubiquitous, \
in a competition between two parties one of whom knows only how to click on \
an Excel icon and the other knows what is happening behind that icon, the \
latter is able to react more swiftly, avoid fundamental errors and perhaps \
consummate better transactions.\
\>", "Item1",
 CellChangeTimes->{{3.528493050006888*^9, 
  3.5284930599854584`*^9}},ExpressionUUID->"f51e2ac0-6197-4d70-9c1c-\
1e97da5ea34f"],

Cell["\<\
The use of data can be tricky. The old saying \[OpenCurlyDoubleQuote]You can \
prove anything with numbers\[CloseCurlyDoubleQuote] is only true for a loose \
definition of \[OpenCurlyDoubleQuote]prove\[CloseCurlyDoubleQuote].  The \
analyst who is well grounded in the theory of real estate and its underlying \
mathematics is able to separate the proper use of data from the improper.  \
Understanding symbolic analysis is how one becomes well grounded in theory.\
\>", "Item1",
 CellChangeTimes->{{3.5284930514189687`*^9, 
  3.5284930659828014`*^9}},ExpressionUUID->"e6a2a547-589a-441a-aa58-\
d5d6d73e86ea"],

Cell["\<\
We can observe sale prices and, to some extent, extrapolate returns investors \
achieve. Risk is another matter, much harder to observe. Behind every sale \
observation in our database are two parties, a buyer and a seller. These \
players engaged in a negotiation arriving at the price we see in our data. \
Inherent in that negotiation was an evaluation of the risk attendant to \
choices made by each party. We are curious about how that process works. It \
is useful to understand risk/return trade-offs each party must make to reach \
agreement on price.\
\>", "Item1",
 CellChangeTimes->{{3.528493052130009*^9, 
  3.5284930720971513`*^9}},ExpressionUUID->"5a064ab7-3b2a-468a-b1d6-\
f2b9f2910834"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does the job we need done here, but with all powerful software one must \
use it only where appropriate. Below we will see that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do things that are trivial or even silly.  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is agnostic about the appropriateness or usefulness of its conclusions. \
It, like all software, is merely a tool in the hands of the user. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is a powerful tool, so powerful that it will ALWAYS return the right \
answer. But the real power in the hands of a careful user is ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ability to guide the user to asking the right questions.  Very often \
when an answer generated by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is not the expected answer it is because one has asked the wrong question."
}], "Text",
 CellChangeTimes->{
  3.5284930908072214`*^9},ExpressionUUID->"ba5d15b0-96b9-408e-b093-\
cad78018684f"],

Cell[TextData[{
 "In this chapter, because we are interested in the nuts and bolts, we will \
keep most symbolic manipulation visible using common abbreviations in the \
notation. More ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " syntax and programming statements will be revealed in this chapter than \
were shown in prior chapters. The non-programmer can safely ignore these.  In \
a later chapter we will create some \"modules\" that will automate this \
process. Modules are ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s equivalent of the icons one uses in a spreadsheet program.  Once one \
knows the inner workings of the process - but not before - it is efficient to \
automate repetitive tasks with modules and icons."
}], "Text",
 CellChangeTimes->{
  3.528493108753248*^9, {3.528493474557171*^9, 3.5284934948963337`*^9}, {
   3.5299293193571725`*^9, 3.5299293198692017`*^9}, {3.5395238046363597`*^9, 
   3.53952380463836*^9}},ExpressionUUID->"8ae747fa-6a16-4492-b534-\
43fbf3dd3f60"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "A note about the font style below may be helpful. Throughout this book in \
general when a variable, such as ",
 StyleBox["noi,",
  FontSlant->"Italic"],
 " is used in the text it is in italics. But if ",
 StyleBox["noi",
  FontWeight->"Bold"],
 " is used in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " syntax it is bold. Likewise, ",
 StyleBox["data",
  FontWeight->"Bold"],
 " and ",
 StyleBox["data",
  FontWeight->"Bold"],
 " ",
 StyleBox["names",
  FontWeight->"Bold"],
 " are bold. The occasional exception may be found when a text paragraph \
containing output is produced by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " in which case no font style may be applied. These, sometimes regrettable, \
formatting issues never affect the meaning of the subject or any computations."
}], "Text",
 CellChangeTimes->{{3.5395238196692195`*^9, 3.5395239468584943`*^9}, {
   3.5395241325351143`*^9, 3.5395243352507095`*^9}, 
   3.696229083413658*^9},ExpressionUUID->"158c13c7-06d5-476c-b74a-\
84d4ddb177db"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Deterministic variables of discounted cash flow analysis"
}], "Section",
 ShowCellBracket->True,
 CellChangeTimes->{
  3.5314471275767565`*^9, {3.5337337544351244`*^9, 
   3.5337337682939167`*^9}},ExpressionUUID->"f934f5f0-6b0e-44cd-85ef-\
501d0795a71e"],

Cell["\<\
General inputs, rule of thumb measures and other investment performance \
variable definitions are:\
\>", "Text",ExpressionUUID->"c1df8cd1-7950-4aad-8702-399ae929d640"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"dp\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[SubscriptBox[\"cf\", \"0\"],FontSlant->\"Italic\
\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[SubscriptBox[\"cf\", \"n\"],FontSlant->\"Italic\
\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[SubscriptBox[\"cr\", \"i\"],FontSlant->\"Italic\
\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[SubscriptBox[\"cr\", \"o\"],FontSlant->\"Italic\
\"]\)\>\"", ",", "\"\<\!\(\*StyleBox[\"r\",FontSlant->\"Italic\"]\)\>\"", 
          ",", "\"\<\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"n\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"k\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"grm\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"ppu\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"ccRet\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"npv\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"irr\",FontSlant->\"Italic\"]\)\>\""}], "}"}], 
        ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "14"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<down payment, made at \
\!\(\*StyleBox[\"t\",FontSlant->\"Italic\"]\)=0 and assumed to be Jan 1 of \
the acquisition year\>\"", ",", 
          "\"\<initial after-tax cash flow \
(\!\(\*StyleBox[\"atcf\",FontSlant->\"Italic\"]\)) to be received at the end \
of year 1\>\"", ",", 
          "\"\<subsequent year cash flows, compounded annually based on \
growth rate, \!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<'going-in' capitalization rate, the capitalization rate at \
purchase\>\"", ",", 
          "\"\<'going-out' capitalization rate, the capitalization rate at \
sale\>\"", ",", 
          "\"\<discount rate (when \!\(\*StyleBox[\"npv\",FontSlant->\"Italic\
\"]\) = 0 this is the internal rate of return)\>\"", ",", 
          "\"\<growth rate for cash flow, mentioned above\>\"", ",", 
          "\"\<specific year of the holding period (an iterator in \
\!\(\*StyleBox[\"Mathematica\",FontSlant->\"Italic\"]\) statements)\>\"", 
          ",", "\"\<length of holding period (also year of sale, presumed to \
occur on Dec 31)\>\"", ",", "\"\<gross rent multiplier\>\"", ",", 
          "\"\<price per unit\>\"", ",", "\"\<cash on cash return\>\"", ",", 
          "\"\<net present value\>\"", ",", 
          "\"\<internal rate of return\>\""}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 ShowCellBracket->True,
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.53306371655307*^9, 3.533064022929594*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"3742a61a-2086-4bd6-95c2-68f5481b0609"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"dp\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"down payment, made at \
\\!\\(\\*StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"]\\)=0 and assumed to be \
Jan 1 of the acquisition year\"\>"},
     {"\<\"\\!\\(\\*StyleBox[SubscriptBox[\\\"cf\\\", \
\\\"0\\\"],FontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"=\"\>", "\<\"initial \
after-tax cash flow \
(\\!\\(\\*StyleBox[\\\"atcf\\\",FontSlant->\\\"Italic\\\"]\\)) to be received \
at the end of year 1\"\>"},
     {"\<\"\\!\\(\\*StyleBox[SubscriptBox[\\\"cf\\\", \
\\\"n\\\"],FontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"=\"\>", "\<\"subsequent \
year cash flows, compounded annually based on growth rate, \\!\\(\\*StyleBox[\
\\\"g\\\",FontSlant->\\\"Italic\\\"]\\)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[SubscriptBox[\\\"cr\\\", \
\\\"i\\\"],FontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"=\"\>", "\<\"'going-in' \
capitalization rate, the capitalization rate at purchase\"\>"},
     {"\<\"\\!\\(\\*StyleBox[SubscriptBox[\\\"cr\\\", \
\\\"o\\\"],FontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"=\"\>", "\<\"'going-out' \
capitalization rate, the capitalization rate at sale\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"discount rate (when \
\\!\\(\\*StyleBox[\\\"npv\\\",FontSlant->\\\"Italic\\\"]\\) = 0 this is the \
internal rate of return)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"g\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"growth rate for cash flow, mentioned above\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"n\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"specific year of the holding period (an iterator in \
\\!\\(\\*StyleBox[\\\"Mathematica\\\",FontSlant->\\\"Italic\\\"]\\) \
statements)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"k\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"length of holding period (also year of sale, presumed to \
occur on Dec 31)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"grm\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"gross rent multiplier\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"ppu\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"price per unit\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"ccRet\\\",FontSlant->\\\"Italic\\\"]\\)\"\>",\
 "\<\"=\"\>", "\<\"cash on cash return\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"npv\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"net present value\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"irr\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"internal rate of return\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 ShowCellBracket->True,
 ShowCellLabel->False,
 CellChangeTimes->{3.533064025025714*^9, 3.5330720570431185`*^9, 
  3.533681643640625*^9, 3.533733672209421*^9, 3.53375335009375*^9, 
  3.539520100792512*^9, 3.5395211179766912`*^9, 3.539521226744913*^9, 
  3.5395224244274163`*^9, 3.5395231368831663`*^9, 3.540125208631635*^9, 
  3.5409350192077866`*^9, 3.5409353032570333`*^9, 3.5409353992995267`*^9, 
  3.540935511580949*^9, 3.540936008742385*^9, 3.5409375494615088`*^9, 
  3.540937917245778*^9, 3.5410030328921795`*^9, 3.5415996475883613`*^9, 
  3.5432391073481317`*^9, 3.6960758823843837`*^9, 3.6962290236235642`*^9, 
  3.6962316557840986`*^9, 3.696232173566645*^9, 3.731420932622281*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"981521c9-bd72-46c7-bd81-172c4989cb9c"]
}, Open  ]],

Cell["Operating variable definitions are:", "Text",ExpressionUUID->"8f11489f-264d-48e2-ae1d-0bf88e0be307"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"gsi\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"vac\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"vacrt\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"egi\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"exp\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"exprt\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"noi\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"btcf\",FontSlant->\"Italic\"]\)\>\""}], "}"}],
         ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "8"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<gross scheduled income\>\"", ",", "\"\<vacancy \>\"", ",", 
          "\"\<vacancy factor (a rate multiplied times gsi)\>\"", ",", 
          "\"\<effective gross income\>\"", ",", "\"\<operating expenses\>\"",
           ",", "\"\<expense factor (a rate multiplied times egi)\>\"", ",", 
          "\"\<net operating income (debt free cash flow)\>\"", ",", 
          "\"\<before-tax cash flow\>\""}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.5330644063975267`*^9, 3.5330645941042633`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"12035555-cf5d-402b-8069-ca3b54680384"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"gsi\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"gross scheduled income\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"vac\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"vacancy \"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"vacrt\\\",FontSlant->\\\"Italic\\\"]\\)\"\>",\
 "\<\"=\"\>", "\<\"vacancy factor (a rate multiplied times gsi)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"egi\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"effective gross income\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"exp\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"operating expenses\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"exprt\\\",FontSlant->\\\"Italic\\\"]\\)\"\>",\
 "\<\"=\"\>", "\<\"expense factor (a rate multiplied times egi)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"noi\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"net operating income (debt free cash flow)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"btcf\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"before-tax cash flow\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 ShowCellLabel->False,
 CellChangeTimes->{3.533064596304389*^9, 3.533072057104122*^9, 
  3.533681643734375*^9, 3.533733672605444*^9, 3.5337533501875*^9, 
  3.5395201012785397`*^9, 3.5395211180226946`*^9, 3.539521230425123*^9, 
  3.539522424474419*^9, 3.539523136929169*^9, 3.540125209130664*^9, 
  3.540935019659813*^9, 3.540935303315037*^9, 3.5409353993495293`*^9, 
  3.5409355692372465`*^9, 3.540936008785387*^9, 3.540937549911535*^9, 
  3.5409379177098045`*^9, 3.541003033472213*^9, 3.541599648046387*^9, 
  3.5432391078561606`*^9, 3.69607588240544*^9, 3.6962290236396065`*^9, 
  3.696231655809165*^9, 3.6962321736418447`*^9, 3.731420932673428*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"b4d5e9b0-1a7d-420b-8fa1-aa0a2480f790"]
}, Open  ]],

Cell["Financing variable definitions are:", "Text",ExpressionUUID->"9eb85e29-6558-49b1-9d60-b97c0324d8c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"ltv\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"dcr\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"ds\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"i\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"initln\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"t\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"bal\",FontSlant->\"Italic\"], \
StyleBox[\"n\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"int\",FontSlant->\"Italic\"], \
StyleBox[\"n\",FontSlant->\"Italic\"]]\)\>\""}], "}"}], ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "8"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<loan-to-value ratio\>\"", ",", "\[IndentingNewLine]", 
          "\"\<debt coverage ratio\>\"", ",", "\[IndentingNewLine]", 
          "\"\<debt service (usually paid monthly but often annualized)\>\"", 
          ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          "\"\<interest rate (per payment period - if monthly, then \
\!\(\*StyleBox[\"i\",FontSlant->\"Italic\"]\) = annual interest/12) \>\"", 
          ",", "\[IndentingNewLine]", "\"\<initial loan balance\>\"", ",", 
          "\[IndentingNewLine]", 
          "\"\<time period in payment periods over which the loan is fully \
amortized(if monthly, then \!\(\*StyleBox[\"t\",FontSlant->\"Italic\"]\) = \
years over which loan is amortized \!\(\(TraditionalForm\`*\)\)12)\>\"", ",", 
          "\[IndentingNewLine]", 
          "\"\<balance at end of period \
\!\(\*StyleBox[\"n\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\[IndentingNewLine]", 
          "\"\<interest paid over the 12 months prior to \
\!\(\*StyleBox[\"n\",FontSlant->\"Italic\"]\)\>\""}], "}"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.5330644063975267`*^9, 3.5330645941042633`*^9}, {
  3.533064664649298*^9, 3.533064885952956*^9}, {3.5330649297114587`*^9, 
  3.533064957132027*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"b916afe2-bb15-45d1-b3b2-e70c3f8d658b"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"ltv\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"loan-to-value ratio\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"dcr\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"debt coverage ratio\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"ds\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"debt service (usually paid monthly but often \
annualized)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"i\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"interest rate (per payment period - if monthly, then \\!\\(\
\\*StyleBox[\\\"i\\\",FontSlant->\\\"Italic\\\"]\\) = annual interest/12) \
\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"initln\\\",FontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"=\"\>", "\<\"initial loan balance\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"time period in payment periods over which the loan is fully \
amortized(if monthly, then \
\\!\\(\\*StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"]\\) = years over which \
loan is amortized \\!\\(\\(TraditionalForm\\`*\\)\\)12)\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"bal\\\",FontSlant->\\\"Italic\\\
\"], StyleBox[\\\"n\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", "\<\
\"balance at end of period \
\\!\\(\\*StyleBox[\\\"n\\\",FontSlant->\\\"Italic\\\"]\\)\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"int\\\",FontSlant->\\\"Italic\\\
\"], StyleBox[\\\"n\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", "\<\
\"interest paid over the 12 months prior to \
\\!\\(\\*StyleBox[\\\"n\\\",FontSlant->\\\"Italic\\\"]\\)\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 ShowCellLabel->False,
 CellChangeTimes->{{3.5330649455773664`*^9, 3.533064963255378*^9}, 
   3.533072057164126*^9, 3.533681643828125*^9, 3.533733672976465*^9, 
   3.533753350265625*^9, 3.5395201018685737`*^9, 3.539521118072697*^9, 
   3.539521234947382*^9, 3.5395224245194216`*^9, 3.5395231369741716`*^9, 
   3.5401252097156973`*^9, 3.5409350203168497`*^9, 3.5409353033740396`*^9, 
   3.540935399391532*^9, 3.5409356573712873`*^9, 3.5409360088293896`*^9, 
   3.540937550438565*^9, 3.5409379182538357`*^9, 3.5410030340932484`*^9, 
   3.541599648549416*^9, 3.54323910837219*^9, 3.69607588242048*^9, 
   3.6962290236676817`*^9, 3.696231655884365*^9, 3.6962321737030077`*^9, 
   3.7314209327065043`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"cf90ee9d-6aa2-4e93-85c1-07fb0f8f0eb6"]
}, Open  ]],

Cell["Income tax variable definitions are:", "Text",ExpressionUUID->"7c7b4fbe-453a-4b67-a1f9-346b24b36275"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"tx\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"txrt\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"txbl\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"basis\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"land\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"depr\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"dprt\",FontSlant->\"Italic\"]\)\>\""}], "}"}],
         ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "7"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<income tax consequences\>\"", ",", "\[IndentingNewLine]", 
          "\"\<ordinary income tax rate\>\"", ",", "\[IndentingNewLine]", 
          "\"\<real estate taxable income\>\"", ",", "\[IndentingNewLine]", 
          "\"\<income tax basis (\!\(\*StyleBox[\"dp\",FontSlant->\"Italic\"]\
\) + \!\(\*StyleBox[\"initln\",FontSlant->\"Italic\"]\) - \
\!\(\*StyleBox[\"accdepn\",FontSlant->\"Italic\"]\))\>\"", ",", 
          "\[IndentingNewLine]", 
          "\"\<allocation of tax basis to land (given as a percent of total \
value)\>\"", ",", "\[IndentingNewLine]", "\"\<annual depreciation\>\"", ",", 
          "\[IndentingNewLine]", "\"\<depreciation rate\>\""}], "}"}]}], 
       "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.5330644063975267`*^9, 3.5330645941042633`*^9}, {
  3.533064664649298*^9, 3.533064885952956*^9}, {3.5330649297114587`*^9, 
  3.533064957132027*^9}, {3.5330650356915207`*^9, 3.533065159933627*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"bae7ae4f-8557-468a-9754-29ac0b406eed"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"tx\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"income tax consequences\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"txrt\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"ordinary income tax rate\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"txbl\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"real estate taxable income\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"basis\\\",FontSlant->\\\"Italic\\\"]\\)\"\>",\
 "\<\"=\"\>", "\<\"income tax basis (\\!\\(\\*StyleBox[\\\"dp\\\",FontSlant->\
\\\"Italic\\\"]\\) + \\!\\(\\*StyleBox[\\\"initln\\\",FontSlant->\\\"Italic\\\
\"]\\) - \\!\\(\\*StyleBox[\\\"accdepn\\\",FontSlant->\\\"Italic\\\"]\\))\"\>\
"},
     {"\<\"\\!\\(\\*StyleBox[\\\"land\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"allocation of tax basis to land (given as a percent of \
total value)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"depr\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"annual depreciation\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"dprt\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"depreciation rate\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 ShowCellLabel->False,
 CellChangeTimes->{3.533065161001688*^9, 3.5330720572231293`*^9, 
  3.533681643921875*^9, 3.5337336733024836`*^9, 3.533753350359375*^9, 
  3.5395201023225994`*^9, 3.5395211181176996`*^9, 3.5395212391776237`*^9, 
  3.5395224245644245`*^9, 3.5395231370191746`*^9, 3.540125210324732*^9, 
  3.5409350220949516`*^9, 3.540935303432043*^9, 3.540935399434534*^9, 
  3.540935703429922*^9, 3.5409360088723927`*^9, 3.540937551069601*^9, 
  3.5409379187568645`*^9, 3.5410030348552923`*^9, 3.541599649058445*^9, 
  3.543239108836217*^9, 3.6960758824375253`*^9, 3.6962290236977615`*^9, 
  3.6962316559034157`*^9, 3.696232173765179*^9, 3.7314209327285643`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"9010f483-4c58-4186-879a-45e3e18ff4fe"]
}, Open  ]],

Cell["\<\
Equity reversion (net after-tax sale proceeds) variable definitions are:\
\>", "Text",ExpressionUUID->"80664b60-e85e-403b-a51b-c421e72a841c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"sp\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"accdp\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"cgtx\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"cg\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"cgrt\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"recaprt\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"sc\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"scrt\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"endbal\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"ppmt\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"er\",FontSlant->\"Italic\"]\)\>\""}], "}"}], 
        ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "11"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<sale price calculated as \
\!\(\*FormBox[FractionBox[SubscriptBox[StyleBox[\"noi\",FontSlant->\"Italic\"]\
, RowBox[{\"k\", \"+\", \"1\"}]], \
SubscriptBox[StyleBox[\"cr\",FontSlant->\"Italic\"], \"o\"]],TraditionalForm]\
\)\>\"", ",", "\[IndentingNewLine]", "\"\<accumulated depreciation\>\"", ",", 
          "\[IndentingNewLine]", 
          "\"\<capital gains tax \
(\!\(\*StyleBox[\"cg\",FontSlant->\"Italic\"]\) * \
\!\(\*StyleBox[\"cgrt\",FontSlant->\"Italic\"]\))\>\"", ",", 
          "\"\<capital gain (\!\(\*StyleBox[\"sp\",FontSlant->\"Italic\"]\) - \
\!\(\*StyleBox[\"basis\",FontSlant->\"Italic\"]\) - \
\!\(\*StyleBox[\"sc\",FontSlant->\"Italic\"]\))\>\"", ",", 
          "\"\<capital gain tax rate (assumed to be a flat percentage of \
gain)\>\"", ",", "\"\<tax rate on depreciation recapture\>\"", ",", 
          "\[IndentingNewLine]", 
          "\"\<sale costs (\!\(\*StyleBox[\"scrt\",FontSlant->\"Italic\"]\) * \
\!\(\*StyleBox[\"sp\",FontSlant->\"Italic\"]\))\>\"", ",", 
          "\[IndentingNewLine]", "\"\<sale cost rate\>\"", ",", 
          "\"\<balance of loan outstanding at the time of sale\>\"", ",", 
          "\"\<prepayment penalty on loan\>\"", ",", "\[IndentingNewLine]", 
          "\"\<after-tax equity reversion \
(\!\(\*StyleBox[\"sp\",FontSlant->\"Italic\"]\) - \
\!\(\*StyleBox[\"sc\",FontSlant->\"Italic\"]\) - \
\!\(\*StyleBox[\"endbal\",FontSlant->\"Italic\"]\) - \
\!\(\*StyleBox[\"ppmt\",FontSlant->\"Italic\"]\) - \
\!\(\*StyleBox[\"cgtx\",FontSlant->\"Italic\"]\))\>\""}], "}"}]}], "}"}], 
      "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.5330652440974407`*^9, 3.533065546568741*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"c5758b8c-e4e2-4550-a078-ff23152305b6"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"sp\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"sale price calculated as \
\\!\\(\\*FormBox[FractionBox[SubscriptBox[StyleBox[\\\"noi\\\",FontSlant->\\\"\
Italic\\\"], RowBox[{\\\"k\\\", \\\"+\\\", \\\"1\\\"}]], \
SubscriptBox[StyleBox[\\\"cr\\\",FontSlant->\\\"Italic\\\"], \
\\\"o\\\"]],TraditionalForm]\\)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"accdp\\\",FontSlant->\\\"Italic\\\"]\\)\"\>",\
 "\<\"=\"\>", "\<\"accumulated depreciation\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"cgtx\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"capital gains tax (\\!\\(\\*StyleBox[\\\"cg\\\",FontSlant->\
\\\"Italic\\\"]\\) * \
\\!\\(\\*StyleBox[\\\"cgrt\\\",FontSlant->\\\"Italic\\\"]\\))\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"cg\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"capital gain \
(\\!\\(\\*StyleBox[\\\"sp\\\",FontSlant->\\\"Italic\\\"]\\) - \
\\!\\(\\*StyleBox[\\\"basis\\\",FontSlant->\\\"Italic\\\"]\\) - \
\\!\\(\\*StyleBox[\\\"sc\\\",FontSlant->\\\"Italic\\\"]\\))\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"cgrt\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"capital gain tax rate (assumed to be a flat percentage of \
gain)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"recaprt\\\",FontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"=\"\>", "\<\"tax rate on depreciation recapture\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"sc\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"sale costs \
(\\!\\(\\*StyleBox[\\\"scrt\\\",FontSlant->\\\"Italic\\\"]\\) * \
\\!\\(\\*StyleBox[\\\"sp\\\",FontSlant->\\\"Italic\\\"]\\))\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"scrt\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"sale cost rate\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"endbal\\\",FontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"=\"\>", "\<\"balance of loan outstanding at the time of sale\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"ppmt\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"prepayment penalty on loan\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"er\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"after-tax equity reversion \
(\\!\\(\\*StyleBox[\\\"sp\\\",FontSlant->\\\"Italic\\\"]\\) - \
\\!\\(\\*StyleBox[\\\"sc\\\",FontSlant->\\\"Italic\\\"]\\) - \
\\!\\(\\*StyleBox[\\\"endbal\\\",FontSlant->\\\"Italic\\\"]\\) - \
\\!\\(\\*StyleBox[\\\"ppmt\\\",FontSlant->\\\"Italic\\\"]\\) - \
\\!\\(\\*StyleBox[\\\"cgtx\\\",FontSlant->\\\"Italic\\\"]\\))\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 ShowCellLabel->False,
 CellChangeTimes->{3.5330655474327908`*^9, 3.5330720572801323`*^9, 
  3.533681644*^9, 3.5337336736995068`*^9, 3.5337533504375*^9, 
  3.5395201027976265`*^9, 3.5395211181627026`*^9, 3.5395212433348618`*^9, 
  3.539522424610427*^9, 3.5395231370641766`*^9, 3.540125211037773*^9, 
  3.540935022788992*^9, 3.540935303492047*^9, 3.5409353994765368`*^9, 
  3.5409358058987827`*^9, 3.540936008914395*^9, 3.540937551787642*^9, 
  3.5409379192568927`*^9, 3.541003035590334*^9, 3.541599649804488*^9, 
  3.543239109304243*^9, 3.696075882452565*^9, 3.6962290237478952`*^9, 
  3.69623165596859*^9, 3.696232173824331*^9, 3.7314209327636566`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"1113a6eb-01d4-4d11-a2ca-dd8b524cc4cb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Single year relationships and project data"
}], "Section",
 CellChangeTimes->{{3.531447172614333*^9, 3.5314471956356497`*^9}, {
  3.5337337862069416`*^9, 
  3.533733793785375*^9}},ExpressionUUID->"aaf1dc06-7e0b-4c7c-b2ed-\
f23b22deebb8"],

Cell[TextData[{
 "Relationships between the variables ",
 StyleBox["for a single first year",
  FontSlant->"Italic"],
 " are as follows:"
}], "Text",ExpressionUUID->"d14d56ac-f9f4-4342-8d32-8ccc64ded481"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vac", "=", 
   RowBox[{"gsi", "*", "vacrt"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"egi", "=", 
   RowBox[{"gsi", "-", "vac"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"exp", "=", 
   RowBox[{"egi", "*", "exprt"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"noi", "=", 
   RowBox[{"gsi", "-", "vac", "-", "exp"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ds", "=", 
   RowBox[{"12", " ", 
    RowBox[{"(", 
     RowBox[{"i", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"1", "/", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "i"}], ")"}], "t"]}]}], ")"}]}], ")"}], " ", 
    "initln"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"btcf", "=", 
   RowBox[{"noi", "-", "ds"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"grm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"dp", "+", "initln"}], ")"}], "/", "gsi"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ppu", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"dp", "+", "initln"}], ")"}], "/", "units"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dcr", "=", 
   RowBox[{"noi", "/", "ds"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ltv", "=", 
   RowBox[{"initln", "/", 
    RowBox[{"(", 
     RowBox[{"dp", "+", "initln"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"basis", "=", 
   RowBox[{"dp", "+", "initln"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"depn", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"basis", "-", 
      RowBox[{"(", 
       RowBox[{"basis", "*", "land"}], ")"}]}], ")"}], "*", "dprt"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["bal", "12"], "=", 
   RowBox[{
    RowBox[{"ds", "/", "12"}], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"1", "/", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "i"}], ")"}], 
         RowBox[{"t", "-", "12"}]]}]}], ")"}], "/", "i"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["int", "t"], "=", 
   RowBox[{"ds", "-", 
    RowBox[{"(", 
     RowBox[{"initln", "-", 
      SubscriptBox["bal", "12"]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"txbl", "=", 
   RowBox[{"noi", "-", 
    SubscriptBox["int", "t"], "-", "depn"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tx", "=", 
   RowBox[{"txbl", "*", "txrt"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cf0", "=", 
   RowBox[{"btcf", "-", "tx"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cri", "=", 
   RowBox[{"noi", "/", 
    RowBox[{"(", 
     RowBox[{"dp", "+", "initln"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ccRet", "=", 
   RowBox[{"cf0", "/", "dp"}]}], ";"}]}], "Input",
 CellMargins->{{242, 10}, {5, 10}},
 CellChangeTimes->{3.5284933498900404`*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"173e8461-e5f2-44fc-af02-8e0bd59a6506"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "First year relationships between the variables"
}], "FigureCaption",
 CellChangeTimes->{{3.5285715177039833`*^9, 3.5285715264204817`*^9}, 
   3.540935828210059*^9},
 TextAlignment->Center,ExpressionUUID->"80b30629-ef8b-4f2c-9472-813a44fe734e"]
}, Open  ]],

Cell[TextData[{
 "As an example of a specific project, details are entered below in a list of \
rules named \"",
 StyleBox["data", "Input"],
 "\". These match the companion Excel worksheet ",
 Cell[BoxData[
  FormBox[
   RowBox[{"provided", 
    SuperscriptBox[".", 
     ButtonBox["1",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote1"]]}], TraditionalForm]],ExpressionUUID->
  "7770f82d-1bda-4e73-814b-e5419ac2e5fb"]
}], "Text",
 CellChangeTimes->{{3.528495167461999*^9, 3.528495211322508*^9}, {
  3.528637817850135*^9, 
  3.528637840179412*^9}},ExpressionUUID->"647e302b-4a8c-4bc2-ad38-\
ddc9cae63ef5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "units", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dp", "->", "375000"}], ",", "\n", "\t\t", 
     RowBox[{"gsi", "->", "200000"}], ",", "\n", "\t\t", 
     RowBox[{"vacrt", "->", ".1"}], ",", "\n", "\t\t", 
     RowBox[{"exprt", "->", ".35"}], ",", "\n", "\t\t", 
     RowBox[{"txrt", "->", ".35"}], ",", "\n", "\t\t", 
     RowBox[{"dprt", "->", 
      FractionBox["1", "27.5"]}], ",", "\n", "\t\t", 
     RowBox[{"land", "->", ".3"}], ",", "\n", "\t\t", 
     RowBox[{"cro", "->", ".0936"}], ",", "\n", "\t\t", 
     RowBox[{"g", "->", ".03"}], ",", "\n", "\t\t", 
     RowBox[{"i", "->", 
      RowBox[{".11", "/", "12"}]}], ",", "\n", "\t\t", 
     RowBox[{"initln", "->", "875000"}], ",", "\n", "\t\t", 
     RowBox[{"t", "->", "360"}], ",", "\n", "\t\t", 
     RowBox[{"r", "->", ".13"}], ",", "\n", "\t\t", 
     RowBox[{"k", "->", "6"}], ",", "\n", "\t", 
     RowBox[{"scrt", "->", ".075"}], ",", "\n", "\t", 
     RowBox[{"cgrt", "->", ".15"}], ",", "\[IndentingNewLine]", 
     RowBox[{"recaprt", "\[Rule]", ".25"}], ",", "\n", "\t", 
     RowBox[{"ppmt", "->", "0"}], ",", "\n", 
     RowBox[{"units", "->", "22"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labels", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Down payment\>\"", ",", "\"\<Gross scheduled income\>\"", ",", 
     "\"\<Vacancy rate\>\"", ",", "\"\<Expense rate\>\"", ",", 
     "\"\<Tax rate\>\"", ",", "\"\<Depreciation rate\>\"", ",", 
     "\"\<Land component\>\"", ",", "\"\<Going-out cap rate\>\"", ",", 
     "\"\<Growth rate\>\"", ",", "\"\<Interest rate (monthly)\>\"", ",", 
     "\"\<Initial loan balance\>\"", ",", "\"\<Loan term (months)\>\"", ",", 
     "\"\<Hurdle rate for \
\!\(\*StyleBox[\"npv\",FontSlant->\"Italic\"]\)\>\"", ",", 
     "\"\<Holding period\>\"", ",", "\"\<Sale cost rate\>\"", ",", 
     "\"\<Capital gain rate\>\"", ",", "\"\<Recapture rate\>\"", ",", 
     "\"\<Prepayment penalty\>\"", ",", "\"\<Number of units\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"labels", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "9"}], "]"}], "]"}], ",", 
          RowBox[{"data", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"1", ";;", "9"}], ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"labels", "[", 
           RowBox[{"[", 
            RowBox[{"10", ";;", "18"}], "]"}], "]"}], ",", 
          RowBox[{"data", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"10", ";;", "18"}], ",", "2"}], "]"}], "]"}]}], "}"}], 
        "]"}], ",", 
       RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
     RowBox[{"StringJoin", "[", 
      RowBox[{
       RowBox[{"ToString", "[", 
        RowBox[{"labels", "[", 
         RowBox[{"[", "19", "]"}], "]"}], "]"}], ",", "\"\<  \>\"", ",", 
       RowBox[{"ToString", "[", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"19", ",", "2"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
     "Bottom"}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.5284933986138268`*^9, {3.5285706043727436`*^9, 3.5285706140492973`*^9}, {
   3.540936052337878*^9, 3.540936154398716*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"a972a0b9-dad1-4f32-b51a-c661ae13ee98"],

Cell[BoxData[
 StyleBox[
  TemplateBox[{TagBox[
     GridBox[{{
       "\"Down payment\"", "375000", "\"Interest rate (monthly)\"", 
        "0.009166666666666667`"}, {
       "\"Gross scheduled income\"", "200000", "\"Initial loan balance\"", 
        "875000"}, {
       "\"Vacancy rate\"", "0.1`", "\"Loan term (months)\"", "360"}, {
       "\"Expense rate\"", "0.35`", 
        "\"Hurdle rate for \
\\!\\(\\*StyleBox[\\\"npv\\\",FontSlant->\\\"Italic\\\"]\\)\"", "0.13`"}, {
       "\"Tax rate\"", "0.35`", "\"Holding period\"", "6"}, {
       "\"Depreciation rate\"", "0.03636363636363636`", "\"Sale cost rate\"", 
        "0.075`"}, {
       "\"Land component\"", "0.3`", "\"Capital gain rate\"", "0.15`"}, {
       "\"Going-out cap rate\"", "0.0936`", "\"Recapture rate\"", "0.25`"}, {
       "\"Growth rate\"", "0.03`", "\"Prepayment penalty\"", "0"}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
    "\"Number of units  22\""},
   "Labeled",
   DisplayFunction->(GridBox[{{
       TagBox[
        ItemBox[
         PaneBox[
          TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
          BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
        "SkipImageSizeLevel"]}, {
       ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
     GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
     AutoDelete -> False, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      BaselinePosition -> {1, 1}]& ),
   InterpretationFunction->(RowBox[{"Labeled", "[", 
      RowBox[{#, ",", #2, ",", "Bottom"}], "]"}]& )],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.5284934010259647`*^9, 3.528494055824417*^9, 
  3.5285705750280657`*^9, 3.528570615966407*^9, 3.5286373179175406`*^9, 
  3.5299294389440126`*^9, 3.533063630213132*^9, 3.5330656576670957`*^9, 
  3.533072057569149*^9, 3.533681644296875*^9, 3.5337336747315655`*^9, 
  3.533753350671875*^9, 3.539520104059699*^9, 3.53952111829771*^9, 
  3.5395212539424686`*^9, 3.5395220022552695`*^9, 3.5395220788306494`*^9, 
  3.5395224247444344`*^9, 3.5395231371991844`*^9, 3.54012521395794*^9, 
  3.5409350240870657`*^9, 3.5409353036280546`*^9, 3.5409353995975437`*^9, 
  3.5409360090374017`*^9, 3.5409361623641715`*^9, 3.5409375530227127`*^9, 
  3.5409379208359833`*^9, 3.5410030367484007`*^9, 3.5415996510855613`*^9, 
  3.543239110745326*^9, 3.696075882546816*^9, 3.696229023881277*^9, 
  3.6962316562603655`*^9, 3.696232174061963*^9, 3.7314209328408623`*^9},
 TextAlignment->Center,
 CellLabel->"Out[29]=",ExpressionUUID->"6676e7ec-50da-4453-a941-4a0d9d410e7d"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table ", "TableTitleLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "TableTitleLabel"],
 StyleBox[".", "TableTitleLabel"],
 StyleBox[
 CounterBox["TableTitle"], "TableTitleLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "TableTitleLabel"],
 "Input data for sample project"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{104.66666666666666`, 10.}, {1., 7.}},
 CellChangeTimes->{3.52855262372631*^9, 3.5285705618143096`*^9},
 TextAlignment->Center,ExpressionUUID->"b67f97b7-3715-4a7e-9e0a-19535e9ef2f6"],

Cell[TextData[{
 StyleBox["Important",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox[":",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " There are two ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " input conventions that appear repeatedly. First, the convention \"   /.  \
\" may be read as \"given that\". It is used to insert values from the data \
into any equation for the limited purpose of that particular computation. \
Second, the symbol \"\[Rule]\" preceding a numerical value given a variable \
means that value is a \"rule\" to apply to the variable for the specific \
computation only."
}], "Text",
 CellChangeTimes->{
  3.52849355146657*^9},ExpressionUUID->"6d6ae692-7bf6-49c0-925d-22be9556b287"],

Cell["For example, below we see", "Text",ExpressionUUID->"8568345f-52b5-4207-9fc1-3da3d2928e94"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cri", ",", "grm", ",", "ppu", ",", "ccRet", ",", "dcr", ",", "ltv"}], 
    "}"}], "/.", "data"}], "Input"]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.528493569111579*^9},ExpressionUUID->"c16342b1-6496-4c32-b370-\
05b60b08f4b5"],

Cell[TextData[{
 "which may be read as: \[OpenCurlyDoubleQuote]provide a list of values for ",
 StyleBox["cri", "Input"],
 ", ",
 StyleBox["grm", "Input"],
 ", ",
 StyleBox["ppu", "Input"],
 ", ",
 StyleBox["ccRet", "Input"],
 ", ",
 StyleBox["dcr", "Input"],
 ", and ",
 StyleBox["ltv", "Input"],
 " ",
 StyleBox["given the values in",
  FontSlant->"Italic"],
 " \[OpenCurlyDoubleQuote]",
 StyleBox["data", "Input"],
 "\[CloseCurlyDoubleQuote].  When formatted and evaluated the syntax above \
produces the list shown in Table 4.2."
}], "Text",
 CellMargins->{{12, 22}, {3, 5}},
 CellChangeTimes->{{3.528493614794192*^9, 3.5284936954078026`*^9}, {
   3.5284949051229944`*^9, 3.528494908123166*^9}, {3.5299295123742123`*^9, 
   3.529929527039051*^9}, 
   3.5395208614080167`*^9},ExpressionUUID->"b904c31f-dc02-4201-95b1-\
69fd4b4a2bbf"],

Cell["Also, the syntax", "Text",ExpressionUUID->"0eb3e066-71aa-4bac-ad4b-ac2f5c48f57d"],

Cell[BoxData[
 StyleBox[
  RowBox[{"gsi", " ", "\[RightArrow]", " ", "60000"}], "Input"]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.528494947728431*^9, {3.5409361972521667`*^9, 
   3.5409362019984384`*^9}},ExpressionUUID->"e795df80-a921-4b60-949d-\
f47108079e97"],

Cell[TextData[{
 "means that for the purpose of the present calculation the value of ",
 StyleBox["gsi", "Input"],
 " is 60,000."
}], "Text",
 CellChangeTimes->{{3.5409362149021764`*^9, 
  3.5409362160792437`*^9}},ExpressionUUID->"2901b0ff-120a-4879-a49d-\
4c6323804c41"],

Cell["\<\
The relationships defined above handle the simple \"rule of thumb\" tests \
applied to first year performance discussed in Chapter 3. \
\>", "Text",
 CellChangeTimes->{
  3.528495005876757*^9, {3.5284950625389977`*^9, 3.5284950773578453`*^9}, {
   3.5299295336874313`*^9, 
   3.52992953453948*^9}},ExpressionUUID->"dd0585c1-d776-4785-bf9c-\
021ab78c3d18"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{"TableForm", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "cri", ",", "grm", ",", "ppu", ",", "ccRet", ",", "dcr", ",", "ltv"}],
         "}"}], "/.", "data"}], ",", 
      RowBox[{"TableHeadings", "->", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Cap rate\>\"", ",", "\"\<GRM\>\"", ",", "\"\<PPU\>\"", ",", 
          "\"\<After-tax C/C\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"dcr\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"ltv\",FontSlant->\"Italic\"]\)\>\""}], "}"}], 
        "}"}]}]}], "]"}], "]"}], ",", 
   RowBox[{"FontSize", "\[Rule]", "12"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "Times"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5207251221380005`*^9, 3.5207252050307417`*^9}, {
  3.528570684445324*^9, 3.5285706876525073`*^9}, {3.540936240085617*^9, 
  3.5409362546124477`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"834f2267-b6fd-45ca-bb8b-40e28e39bf4e"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Cap rate\"\>",
        HoldForm], "0.0936`"},
      {
       TagBox["\<\"GRM\"\>",
        HoldForm], "6.25`"},
      {
       TagBox["\<\"PPU\"\>",
        HoldForm], "56818.181818181816`"},
      {
       TagBox["\<\"After-tax C/C\"\>",
        HoldForm], "0.05549808254515605`"},
      {
       TagBox["\<\"\\!\\(\\*StyleBox[\\\"dcr\\\",FontSlant->\\\"Italic\\\"]\\)\
\"\>",
        HoldForm], "1.1700707127919252`"},
      {
       TagBox["\<\"\\!\\(\\*StyleBox[\\\"ltv\\\",FontSlant->\\\"Italic\\\"]\\)\
\"\>",
        HoldForm], "0.7`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, {True}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {{False}}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    OutputFormsDump`HeadedColumn],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{
       "Cap rate", "GRM", "PPU", "After-tax C/C", 
        "\!\(\*StyleBox[\"dcr\",FontSlant->\"Italic\"]\)", 
        "\!\(\*StyleBox[\"ltv\",FontSlant->\"Italic\"]\)"}}]]],
  StripOnInput->False,
  FontFamily->Times,
  FontSize->12]], "Output",
 CellChangeTimes->{3.528495019334527*^9, 3.528570575040066*^9, 
  3.528570688296544*^9, 3.528637317934541*^9, 3.5299294392970324`*^9, 
  3.533063630636156*^9, 3.533072057633153*^9, 3.533681644390625*^9, 
  3.533733675366602*^9, 3.53375335078125*^9, 3.5395201050227537`*^9, 
  3.5395211183497133`*^9, 3.5395212783508644`*^9, 3.5395220407424707`*^9, 
  3.539522424793437*^9, 3.539523137247187*^9, 3.5401252148829927`*^9, 
  3.5409350246891003`*^9, 3.540935303687058*^9, 3.540935399640546*^9, 
  3.540936009081404*^9, 3.5409362642239976`*^9, 3.5409375536537485`*^9, 
  3.540937921555024*^9, 3.5410030375104437`*^9, 3.541599651715597*^9, 
  3.543239111529371*^9, 3.696075882621014*^9, 3.696229023927404*^9, 
  3.696231656380685*^9, 3.696231738796953*^9, 3.6962321741682463`*^9, 
  3.731420932881972*^9},
 TextAlignment->Center,
 CellLabel->"Out[30]=",ExpressionUUID->"419dbcab-1ab2-45a5-a5e9-8a1122bf04e9"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table ", "TableTitleLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "TableTitleLabel"],
 StyleBox[".", "TableTitleLabel"],
 StyleBox[
 CounterBox["TableTitle"], "TableTitleLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "TableTitleLabel"],
 "Rule of thumb values for sample project"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{120.66666666666666`, 10.}, {1., 7.}},
 CellChangeTimes->{3.52855262372631*^9, 3.5285706648072004`*^9},
 TextAlignment->Center,ExpressionUUID->"5344b4b2-588e-4441-ac43-4239bd1dd1f2"],

Cell[TextData[{
 "We can also compute the monthly loan payment and first year after-tax cash \
flow. Note that since ",
 StyleBox["ds",
  FontSlant->"Italic"],
 " is defined as an annual amount we must divide out the 12 to obtain the \
monthly payment."
}], "Text",
 CellChangeTimes->{{3.528495332552442*^9, 
  3.5284953466222467`*^9}},ExpressionUUID->"312b7c98-4490-4e25-9c79-\
7294faa4e898"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Print", "[", 
  RowBox[{"\"\<The monthly loan payment is: $\>\"", ",", 
   RowBox[{"AccountingForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ds", "/", "12"}], "/.", "data"}], ",", 
     RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<The first year after-tax cash flow is: $\>\"", ",", 
   RowBox[{"NumberForm", "[", 
    RowBox[{
     RowBox[{"cf0", "/.", "data"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "2"}], "}"}], ",", 
     RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}]}], "]"}]}], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.52849537132966*^9, 3.5284953884726405`*^9}, {
  3.5284954295879917`*^9, 3.528495584372845*^9}, {3.528495615981653*^9, 
  3.528495620889934*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"64833465-9531-4b5a-9f3a-d9aacaf1c3df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The monthly loan payment is: $\"\>", "\[InvisibleSpace]", 
   TagBox[
    InterpretationBox["\<\"8,332.83\"\>",
     8332.829711407236,
     AutoDelete->True],
    AccountingForm[#, DigitBlock -> 3]& ]}],
  SequenceForm["The monthly loan payment is: $", 
   AccountingForm[8332.829711407236, DigitBlock -> 3]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.528495389066674*^9, {3.52849543199813*^9, 3.5284954519762726`*^9}, {
   3.5284954969448447`*^9, 3.528495584838872*^9}, 3.52849562151897*^9, 
   3.528570575353084*^9, 3.5286373179455423`*^9, 3.5299294397100563`*^9, 
   3.5330636312451906`*^9, 3.533072057694156*^9, 3.533681644515625*^9, 
   3.533733675950635*^9, 3.533753350875*^9, 3.539520105810799*^9, 
   3.5395211183947153`*^9, 3.539521283079135*^9, 3.53952242483844*^9, 
   3.5395231373371925`*^9, 3.5401252158940506`*^9, 3.540935025595152*^9, 
   3.5409353037460613`*^9, 3.540935399683549*^9, 3.5409360091234064`*^9, 
   3.540937554480796*^9, 3.540937922324068*^9, 3.541003038685511*^9, 
   3.5415996524886417`*^9, 3.543239112254412*^9, 3.696075882712256*^9, 
   3.696229023945421*^9, 3.696231656472932*^9, 3.696232174266507*^9, 
   3.731420932909052*^9},
 CellLabel->
  "During evaluation of \
In[31]:=",ExpressionUUID->"eebd1088-1943-4da5-a4cf-7c4a1a367163"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The first year after-tax cash flow is: $\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    InterpretationBox["\<\"20,811.78\"\>",
     20811.780954433518`,
     AutoDelete->True],
    NumberForm[#, {9, 2}, DigitBlock -> 3]& ]}],
  SequenceForm["The first year after-tax cash flow is: $", 
   NumberForm[20811.780954433518`, {9, 2}, DigitBlock -> 3]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.528495389066674*^9, {3.52849543199813*^9, 3.5284954519762726`*^9}, {
   3.5284954969448447`*^9, 3.528495584838872*^9}, 3.52849562151897*^9, 
   3.528570575353084*^9, 3.5286373179455423`*^9, 3.5299294397100563`*^9, 
   3.5330636312451906`*^9, 3.533072057694156*^9, 3.533681644515625*^9, 
   3.533733675950635*^9, 3.533753350875*^9, 3.539520105810799*^9, 
   3.5395211183947153`*^9, 3.539521283079135*^9, 3.53952242483844*^9, 
   3.5395231373371925`*^9, 3.5401252158940506`*^9, 3.540935025595152*^9, 
   3.5409353037460613`*^9, 3.540935399683549*^9, 3.5409360091234064`*^9, 
   3.540937554480796*^9, 3.540937922324068*^9, 3.541003038685511*^9, 
   3.5415996524886417`*^9, 3.543239112254412*^9, 3.696075882712256*^9, 
   3.696229023945421*^9, 3.696231656472932*^9, 3.696232174266507*^9, 
   3.7314209329160624`*^9},
 CellLabel->
  "During evaluation of \
In[31]:=",ExpressionUUID->"b3751944-c5c8-4def-8fc2-30c93fd55ff9"]
}, Open  ]],

Cell["\<\
Figures 4.2 and 4.3 show Excel output for first year inputs and computations\
\>", "Text",
 CellChangeTimes->{{3.528571144455635*^9, 3.528571193041414*^9}, {
  3.528571336635627*^9, 
  3.528571336638627*^9}},ExpressionUUID->"a3fa0d13-7ed4-4bf1-ae64-\
222a23f83bc1"],

Cell["", "Text",ExpressionUUID->"5f873c5c-51c3-4cad-8d22-fe984ad6ec3d"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000:=h0@0006`000000000000005X5003@0P00
00000000003=_000HV<00215CDH00040N:<001H4000;0000000000000000000000@00003001Y0@00
3`40000000000000000001b31@1E8P@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0900`000000000940100`000000000
<4020100000400000020?b501`0<0000000000A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P000240000800008P0000`0003ooooo8@0000P0000R0000
30000?ooool:000040000000000000008@0000P0000I000030000?ooo`0H000030000000000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H000000000000001K1@00
d@800280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P000000000
000005/5003A0P008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
6000004000010000F`D00=42000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00000@000040001K1@00d@800280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000100000@0005/5003A0P009`0001P0000100000000002000000000
9@0000`000010000600000`00000P0006@0000`00000P000500000`0000=00004P0000`000020000
9P0001`0000200000000000000000000080002D0000<00000P0001/0000@0000`0400040000f0000
40000<D1000100009@0000`000070020C00006@000300@000@000<@100010000`040004000050000
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@0000`0400080000f000040000<@1000200009@0000`000070020
C00006@000300@000P000<<100020000`0400080000400000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
`04000<0000f000040000<<1000300009@0000`000070020C00006@000300@000`000<8100030000
`04000<0000300000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000`04000@0000f000040000<8100040000
9@0000`000070020C00006@000300@0010000<4100040000`04000@0000200000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@0000`04000D0000f000040000<41000500009@0000`000070020C00006@000300@00
1@000<0100050000`04000D0000100000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00001000P2P0000<00000@0002L0000H0000
0@0000000000P000000002D0000<00000@0002D0000<00000P0001/0000@0000`0400440000f0000
40000<D1001100009@0000`000070020C00006@000300@00@@000<@100110000`040044000050000
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@0000`0400480000f000040000<@1001200009@0000`000070020
C00006@000300@00@P000<<100120000`0400480000400000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
`04004<0000f000040000<<1001300009@0000`000070020C00006@000300@00@`000<8100130000
`04004<0000300000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000`04004@0000f000040000<8100140000
9@0000`000070020C00006@000300@00A0000<4100140000`04004@0000200000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@0000`04004D0000f000040000<41001500009@0000`000070020C00006@000300@00
A@000<0100150000`04004D0000100000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00001000P2P0000<00000@0002L0000H0000
0@0000000000P000000002D0000<00000@0002D0000<00000P0001/0000@00007P<006/0000f0000
400002<3001[00009@0000`000070020C00006@0000N0`00J`000283001[00007P<006/000050000
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00007P<006`0000f000040000283001/00009@0000`000070020
C00006@0000N0`00K0000243001/00007P<006`0000400000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
7P<006d0000f000040000243001]00009@0000`000070020C00006@0000N0`00K@000203001]0000
7P<006d0000300000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@00007P<006h0000f000040000203001^0000
9@0000`000070020C00006@0000N0`00KP0001l3001^00007P<006h0000200000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00007P<006l0000f0000400001l3001_00009@0000`000070020C00006@0000N0`00
K`0001h3001_00007P<006l0000100000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00001000P2P0000<00000@000580001`0@00
0@000?3oool0000000000000002@0@0000000000029806D0K01f0000000000000000000000000000
000000000000000000000000000000000000000000000000001_021HNPLh56`000010<PhK`000@00
L1A/00000038=Vl00@0002Pk<@0]OXQeR281YS00000`00002P0000X000100eT22P0003PDK0100eT2
NDZYME@k<@0:00000@0003PDK01D>c40llR8MH01SGGJB:IY>@0008PR0JH00340E<V8MHPR0JH`0000
>@000080002`?340c3/a03:aQ6V88P6V<00003T0002`?34077Wf0XPR0JH00000000005Pm<@010000
0000000000010000000000000000000000000>8k`dNd?3407`0006RTZ0Kd>c401k64JFAf00P00000
9@0000`000010000600000`000000?l06@0000`0003oool04P0000`000010000E0000:0000040000
0P0006P0000E00000@0000043D9E9@e210000080000>0000C00000000000000000000?oooooooooo
J0000480H@1c06T0H`0P0440KP1Q06`0N@1c06T0L`0;00002@0000P000030000200000@0000;0000
2@0000T0000300001`0000P000030000200001/0000@00009@800180001D0000O0000>L100020000
908001D00001000000@=@UDU3D;W0@000P0000P0001<00000000000000000000oooooooooomL0000
<00b02l0<P0i02l0<@0b00T000090000100000T000090000100000T000090000DP00070100030000
l?ooo`0000000000000009010000000000008TP0I@1/07H000000000000000000000000000000000
0000000000000000000000000000000000000000000006l085Qj1oS;O@L00040b3Q_0001000`c7d7
00000<PfK`010000D3Xa02enR7F88P6V<0000300000:00002P000403F@8:0000n<]m1d03F@9iBZUe
O3Xa00X000010000n<]m1g`j<@3cb8QeP06=MMY8YVTi0000R281YP00<@1DbHQeR281YS00000i0000
0P000=Pk<@3d>S40<[64JHPR0JH`0000>@000=Pk<@0LNOH2R281Y/2Q^0800000P3`a004000000000
00000040002CHGmY1mcOA`0000000000A`0004H0002d0000IA5iMA`k<@07/HAYI7H02000000U0000
300000<0000H000030000000001D0000T000024300020000R@<001D00001000000@=@UDU3D8Q0`00
0P0000/0001<00000000000000000000oooooooooomT0000801=0440DP1;04D0E00P05H0@@1<0030
100000d0000;0000300000X0000;00002@0000@0000;00002`0000T0000U000030000040000H0000
30000000o`0K0000400009X4000B0000E00007P0001K10000P0009T4000E00000@0000043D9E9@e2
F`@0008000070000C00000000000000000000?ooooooooooG0000340<P0e0300<00`030000090000
2@0000T0000900002@0000T0000900009@0000`000030000600000`000000000E00008@0002g1000
0P0000L5000E00000@0000043D9E9@e2]`@0008000090000C00000000000000000000?oooooooooo
H0000340<00`02h0<00`0300<00U0?lP2@0000T000090000100000T0000900002@0000T0000>0000
9@0000`000010000600000`000000?l0E0000=00000400005`000;<0000Z00000@0000043D9E9@e2
100001L0000F0000C00000000000000000000?ooooooooooN00004<0J01Q0700M01U0780800d0200
@P1Q07<0I@0P04D0N01Q06d0L01/06D02`0000T0000900002@0000D0000900001@0000@000090000
100000/000090000200000T0000400002`0000L0000900003@0000T0000300002@0002D0000<0000
0`0001P0000<0000000005@0002D0000<@8001L0002W0P00:P000040000010e2EBD=@S42000G0000
300004`00000000000000000003oooooooooof@000170580801B04D0CP1D0200C@1E04`0E00=0000
300000@0000<00002`0000/000090000100000d0000<00002@0000T0000U000030000040000H0000
30000000o`0K0000400001D3000W0000E00006@0003f0P005`0001@3000Z00000@0000043D9E9@e2
mP8001L000040000C00000000000000000000?ooooooooooE00003H0;P0b03D02@0000@000090000
2@0002D0000<00000`0001P0000<0000000005@0001`00008@<001L0001J0`00:P000040000010e2
EBD=@R43000G00001P0004`00000000000000000003ooooooooooeP0000P04`0C`1104h0D`040000
2@0000`0000;00002`0000/0000K0000400009X4000W0000E0000700001T10005`0009T4000Z0000
0@0000043D9E9@e2I0@001L000060000C00000000000000000000?ooooooooooF00003P0=`0e0300
<00`00T0000900002@0000T0000900002@0005@0001l0000`0@001L000071@00:P000040000010e2
EBD=@/04000G0000200004`00000000000000000003ooooooooooe`0000g0300;P0`0300<00`02D0
2@0000T0000400002@0000T0000900002@0000h0001D0000H00002D5000G0000@@D002X000010000
00@=@UDU3D8U1@005`0000<0001<00000000000000000000oooooooooomD0000C01D05H00:P90000
2@0000/0001D0000U0000342000/0000U`8003l00001000000@=@UDU3D8a0P00;00000`0001<0000
0000000000000000oooooooooomT0000D01B04T0@`1502l0E@1>04T0E00P03d02P0000`000050000
2`0000/000040000300000/0000500002@0000@0000900009@0000`000010000600000`000000?l0
6`000100000E0`00?00005@0001/0000j08002`0000D0`00?`000040000010e2EBD=@^P2000/0000
1@0004`00000000000000000003ooooooooooeP0000e03H0>00a03P00:P900002@0000T000090000
2@0002D0000<00000`0001P0000<0000000005@0002800008@<002`0001l0`00?`000040000010e2
EBD=@R43000/00002P0004`00000000000000000003oooooooooof00000P04d0EP0P04D0D@1E04T0
E01I00@0000=00002`0000@0000;0000300000`0000500002@0000/0000U000030000040000H0000
30000000o`0K0000400009X4000l0000E0000700001T1000;00009T4000o00000@0000043D9E9@e2
I0@002`000060000C00000000000000000000?ooooooooooF00003<0=`0e0300<00`00T000090000
2@0000T0000900002@0002D0000<00000`0001P0000<0000000005@0001l0000`0@002`000071@00
?`000040000010e2EBD=@/04000/0000200004`00000000000000000003ooooooooooe`0000c0300
;P0`0300<00`02D02@0000T0000400002@0000T0000900002@0000h0001D0000N00007l100110000
^`4005@00001000000@=@UDU3D9o0@00@@0000L0001<00000000000000000000oooooooooomL0000
8`0P05D0CP1905@0D`0050T000040000300000/0000500002@0000/0001B0000L04000@0003`oooo
0000000000000000T04000000000000PB01U06`0MP00000000000000000000000000000000000000
0000000000000000000000000000000000000000K`0PF7X7R15n1`000@38>6l000400<0AOPL00000
b3I_0040000X>c40;Gj8MHPR0JH`0000<00000X0000:0000@0=I0PX000284Gh7@0=I0WU:ZGED>c40
2P00004000284Gh7E3/a0??8R7F00HeefTRVJCT000288P6V000a05C9R7F88P6V<00003T000020000
/3`a0<`k<@0b/HAYR281YS00000i0000/3`a01aimP:88P6V00000000001H?C400@00000000000000
0@0000000000000000000000003R>l=7]3`a01l0001XY:P6m3/a00NaQ6UTMP08000002D0000<0000
100001/0000@00009@800540001D0000F00001<200110000908005@00001000000@=@UDU3D8C0P00
@@000080001<00000000000000000000oooooooooom@0000<P0b00T0000900009@0000`000030000
E00008@000190P00EP0009`2001Y00000@0000043D9E9@e2B@8005H000090000C000000000000000
00000?ooooooooooH00004D0F00^0200C01?0440CP1C00302`0000/000040000100000T0000<0000
2`0000/0000;0000E00008P000300P00EP0001H3001Y00000@0000043D9E9@e2`08005H0000:0000
C00000000000000000000?ooooooooooH0000200800P0480@@1<0440CP1304D0100000@000040000
2`0000/0000900002`0000/0000;00002`0005@0001`0000?`<005H0001k0`00J@000040000010e2
EBD=@Sl3001F00001P0004`00000000000000000003ooooooooooeP0001=04l0801@04d0E00=0000
300000@0000:00003@0000T0001D0000R0000?P3001F0000A`@006T00001000000@=@UDU3D;h0`00
EP0000X0001<00000000000000000000oooooooooomP0000800P04T0CP1D0200DP1105@0A@040000
100000D0000;00002@0000@0000<00002`0000T0000;0000E00007`0002]1000EP000045001Y0000
0@0000043D9E9@e2[@@005H000080000C00000000000000000000?ooooooooooG00004<0C`1>05<0
E01104h0E00;0000300000/0000;00002@0000/0000;00002@0005@0001l00005@D005H0001A1@00
J@000040000010e2EBD=@QD5001F0000200004`00000000000000000003ooooooooooe`0000P0200
800P05@0A@1B04d0100000@000040000100000T0000;0000300000d0001D0000`00000@0001[0000
a@0007h00001000000@=@UDU3D840000J`0001<0001<00000000000000000000oooooooooomd0000
@@1C05<0A@1C05<0A@140200C01104h0A00P05H0@@1<05D0A@0H00/0000;00002`0000/0000;0000
2`0000/0000<0000100000T0000;00002`0000`0000400002`0000/000090000300000/0000U0000
30000040000H000030000000o`0K0000400002D2001k0000E00008@0003I0@00J`0002@2001n0000
0@0000043D9E9@e2f@4006/000090000C00000000000000000000?ooooooooooH00003<0<00`0300
<00`02h0<00`000X2@0000T0000900002@0000T000090000100000T0000900009@0000`000030000
600000`000000000E00007`0000a0P00J`0007P2001n00000@0000043D9E9@e2<@8006/000080000
C00000000000000000000?ooooooooooG0000200<@1C05@0801=05@0A`0400002@0000/000090000
100000d0000900003@000580001`0@001@000?3oool0000000000000002@0@0000000000029806D0
K01f0000000000000000000000000000000000000000000000000000000000000000000000000000
001_021HNPMX1Wh700010<PhK`000@00X0In1`000038=Vl00@0002Pk<@0]OXQeR281YS00000`0000
2P0000X000100eT22P0006P6OPM00eT2NDZYME@k<@0:00000@0006P6OPMD>c40llR8MH01SGGJB:IY
>@0008PR0JH00340E<V8MHPR0JH`0000>@000080002`?340c3/a03:aQ6V88P6V<00003T0002`?340
77Wf0XPR0JH00000000005Pm<@0100000000000000010000000000000000000000000>8k`dNd?340
7`0006RTZ0Kd>c401k64JFAf00P000009@0000`0000500006`000100000E0`00N`0005@000240000
b@8006/0000D0`00OP000040000010e2EBD=@/T2001[00002@0004`00000000000000000003ooooo
ooooof00000h03L0=@0`0300<00^0300<00000T0000900002@0000T0000900002@0000@000090000
2@0001/0000@0000U0<007/0001D0000N00005X3001[0000T`<007h00001000000@=@UDU3D9J0`00
J`0000L0001<00000000000000000000oooooooooomL0000>00c03<0<P0^03P0<`1O:0T000090000
2@0000T0000400002@0000T0001D0000L00006T4001[0000WP@007h00001000000@=@UDU3D9Y1000
J`0000H0001<00000000000000000000oooooooooomH0000<@0a02h0<00`02D02@0000T000040000
2@0000T0000>00009@0000`0000300006`000100001B1@00N`0005@0001`00008@D006/0001A1@00
OP000040000010e2EBD=@R45001[00001P0004`00000000000000000003ooooooooooeP0000c03H0
<00^0300<00900002@0000T0000400002@0000T0001D0000`00000@000200000`00009<000010000
00@=@UDU3D840000P00001<0001<00000000000000000000oooooooooomd0000@@1C05<0A@1C05<0
A@140200B@1=0500EP1=05@0801F0440C00500/0000;00002`0000/0000;00002`0000/0000<0000
100000D0000=00002P0000/0000=00002@0000@0000;00002`0000T0000U000030000040000H0000
30000000o`0K0000400002D2002@0000E00008@0003I0@00P00002@2002C00000@0000043D9E9@e2
f@40080000090000C00000000000000000000?ooooooooooH00003L0<00`0300<00`02h0<00`01@0
2@0000T0000900002@0000T000090000100000T000090000600000`0000000009@0000`000030000
E000070000040000ZP000400002m00000@0000043D9E9@e210000:X000060000C000000000000000
00000?ooooooooooF00002D0801<0440CP1400h0000400002@0000/0000;0000300005@0001`0000
m0400:X0000Y0P00_@000040000010e2EBD=@_@1002Z00001P0004`00000000000000000003ooooo
oooooeP0000c0300;P0`03009@0900002@0000@0000900002@0000h0001D0000X00000@0002o0000
UP000=800001000000@=@UDU3D840000_`0000h0001<00000000000000000000oooooooooomX0000
9@0P04T0C@1@0580C`1F04D0C@1504h0E01C00h0000400001@0000d0000:0000300000`0000;0000
2`0000d0000;00002`0000T0000;0000E0000700003d0@00_`0002T2003B00000@0000043D9E9@e2
m0400;l000060000C00000000000000000000?ooooooooooF00003L0<00^0300<00U00T000090000
100000T0000900003P0005@00030000010000>T0002?0000o0000040000010e2EBD=@P@0003Y0000
4`0004`00000000000000000003oooooooooog@0000P0200800P0200800P0480@@1C04T0D`0P04<0
C`1404D0800m01@0100000@000040000100000@000040000100000/0000;00002`0000D0000;0000
100000/0000<0000300000/0000400002@0002D0000<00001@0001/0000@00009@800?T0001D0000
I00000H2003Y000090800?`00001000000@=@UDU3D860P00j@0000@0001<00000000000000000000
oooooooooomD0000<@0^0300<0090000100000T0000900009@0000`0000300006`000100002g0@00
3P4005@000280000HP400?h0002f0@004@400040000010e2EBD=@V81003n00002P0004`000000000
00000000003oooooooooof00000a0380=@0`0300<00`02h0<00`00T0000900002@0000T000090000
2@0000T0000400002@0000T0001D0000R0000<<1003n00008@8001410001000000@=@UDU3D;30@00
oP0000X0001<00000000000000000000oooooooooomP0000801104<0@P0P0400801104<0D@040000
2`0000/0000;000010000100000400002`0000/0000<0000E0000=0000040000;@400=`000100@00
0@0000043D9E9@e2100002d1000F0000C00000000000000000000?ooooooooooN00004L0DP1?05<0
D`0P0500C`1D04D0CP1D04T0@@1<0200B@1>04<0C`1=04D03@0000`0000<00002`0000/000040000
2P0000`0000900002`0000/0000900001@0000/000090000100000D0000;00002`0000`0000=0000
2`0005@0001h0000j`4002d1000Y0P00@0400040000010e2EBD=@^/1000]0@001`0004`000000000
00000000003ooooooooooe`0000a0300<00^0300<00U000D2@0000T000090000100000T000090000
3P0001/0000@00005@<003d1001D0000Q0000<T2000]0@0050<004010001000000@=@UDU3D;90P00
;@4000T0001<00000000000000000000oooooooooomP0000<P0`0300<00`0300;P0`030082090000
2@0000T0000900002@0000T0000400002@0000T0001D0000T0000243000]0@00S0<0040100010000
00@=@UDU3D8Q0`00;@4000/0001<00000000000000000000oooooooooomT0000801B04D0CP1D0200
D`1304P0A@14030`100000`0000;00002`0000T0000400002`0000/0000<00002`0000`0001D0000
O0000?L3000]0@00B0@004010001000000@=@UDU3D;g0`00;@4000P0001<00000000000000000000
oooooooooomL0000@@1F04L0801B04D0CP1D00/0000;00003@0000@0000<00002`0000/000090000
E00006@000321000;@400>`400100@000@0000043D9E9@e2`P@002d100040000C000000000000000
00000?ooooooooooE0000580A@1>05@0300000/0000;00002@0005@0001`00003`D002d100171@00
@0400040000010e2EBD=@Pl5000]0@001P0004`00000000000000000003ooooooooooeP0000S05D0
CP1905@0D`090000300000/0000500002@0000/0001D0000U00000@000120@00OP0005D100010000
00@=@UDU3D840000@P4000`0001<00000000000000000000oooooooooomT0000C01505<0D`0j05H0
@@130440CP1305T02@0000/0000;00002`0000@0000;00002`0000/0000;00002`0000/0000;0000
9@0000`000050000E0000700003d0@00@P4002T2001E0@000@0000043D9E9@e2m040048100060000
C00000000000000000000?ooooooooooF0000340<00^0300<00U00T000090000100000T000090000
3P0002D0000<00000`0001/0000@00005@<00581001D0000O0000=8200120@0050<005D100010000
00@=@UDU3D;B0P00@P4000P0001<00000000000000000000oooooooooomL0000<P0`0300<00`02h0
<00`00T0000900002@0000T000090000100000T000090000DP00070100060000loooo`0000000000
000009010000000000008440LP1Y0640K00000000000000000000000000000000000000000000000
000000000000000000000000000006l085Qj1g0AK0000040b3Q_0001002X4F`000000<PfK`000000
:3/a02enR7F88P6V<0000300000:00002P000403F@8:0000L15/0403F@9iBZUeE3/a00X000010000
L15/05@k<@3cb8QeP06=MMY8YVTi0000R281YP00<@1DbHQeR281YS00000i00000P000;0l<@3<>c40
<[64JHPR0JH`0000>@000;0l<@0LNOH2R281YP0000000000F3da0040000000000000004000000000
0000000000000000hS_3Ak@l<@0O0000J:BX1_@k<@07/HAYI7H02000000U0000300000H0001D0000
Q000020300150@00G@<005@10001000000@=@UDU3D8P0`00A@4000T0001<00000000000000000000
oooooooooomP0000<@0P0480DP0P0340801204406`070000100000T000090000100000L000040000
2@0000T0001B0000L04000L0003`oooo0000000000000000T040000000000000@@1b06T0H@1/0000
000000000000000000000000000000000000000000000000000000000000000000000000K`0PF7X7
<0Un1`000@38>6l0004006P9OPL00000b3I_0000000X>c40;Gj8MHPR0JH`0000<00000X0000:0000
@0=I0PX0000`2Gh7@0=I0WU:ZGED>c402P000040000`2Gh7E3/a0??8R7F00HeefTRVJCT000288P6V
000a05C9R7F88P6V<00003T000020000/3`a0<`k<@0b/HAYR281YS00000i0000/3`a01aimP:88P6V
00000000001H?C400@000000000000000@0000000000000000000000003R>l=7]3`a01l0001XY:P6
m3/a00NaQ6UTMP08000002D0000<00001`0001/0000@0000VP@00581001D0000L00006T400130@00
V@@005@10001000000@=@UDU3D9Y1000@`4000H0001<00000000000000000000oooooooooomH0000
=@0e0300;P0`03002@0000T000090000100000T0000900009@0000`0000300006`00010000031@00
DP4005@0001T0000g`@0048100021@00E@400040000010e2EBD=@]l400120@00100004`000000000
00000000003ooooooooooe@0000e03D0<00`00T0000900002@0000T0000K000040000585001B0@00
E00005P000101@00@P400545001E0@000@0000043D9E9@e2@0D0048100020000C000000000000000
00000?ooooooooooD0000340<00900002@0005@0003<0000100005L1003K0000JP400040000010e2
EBD=@P@0001G0@005@0004`00000000000000000003oooooooooogP0001505P0D01504<0E01504@0
80170580C`1C05<0801904h0@`1?04d0A@11H`/0000;00002P0000/0000;00002@0000/0000<0000
100000d0000<0000300000/0000;0000100000D0000;00002`0000`0000=00002`0005@0001`0000
m04005L1000Y0P00JP400040000010e2EBD=@_@1001G0@001P0004`00000000000000000003ooooo
oooooeP0000i0300;P0`03009@0900002@0000@0000900002@0000h0000K0000400001D3001W0@00
E00008@000390P00E`4001@3001Z0@000@0000043D9E9@e2b@8005L100090000C000000000000000
00000?ooooooooooH0000340>00`0300<00`02h0<00`00002@0000T0000900002@0000T000090000
100000T0000900009@0000`000060000E00008@0000P0`00FP4005H3001Y0@000@0000043D9E9@e2
80<005X100090000C00000000000000000000?ooooooooooH000038080120780800a0200@P1Q06<0
1`0000@000090000100000@000070000100000T0000700009@0000`0000700006`000100002J1000
I`4005@0001`0000J@@005P1002I1000J@400040000010e2EBD=@VT4001H0@001P0004`000000000
00000000003ooooooooooeP0000g03D0<00^0300<00900002@0000T0000400002@0000T0000U0000
300000<0000K0000400000<5001W0@00E00006@0003O1000E`400085001Z0@000@0000043D9E9@e2
g`@005L100040000C00000000000000000000?ooooooooooE00003<0=`0e03002@0000T000090000
2@0001/0000@0000DPD006L1001D0000E00004T5001G0@00D@D006X10001000000@=@UDU3D991@00
E`400040001<00000000000000000000oooooooooom@0000=@00T`T0001D0000X00000@0001/0@00
S00007l10001000000@=@UDU3D840000K04000h0001<00000000000000000000oooooooooomX0000
C01505<0D`0j0200A@1H0500A@1>05<0A@1C00T0000;00002`0000/000040000100000/0000;0000
2P0000/0000;00002`0000/0000;00009@0000`000060000E00008@0000P0`00K`4005H3001n0@00
0@0000043D9E9@e280<006l100090000C00000000000000000000?ooooooooooH000038080120780
800b0200@P1Q00001`0000@000090000100000@000070000100000T0000700009@0000`000070000
6`000100002J1000O04005@0001`0000J@@006d1002I1000OP400040000010e2EBD=@VT4001]0@00
1P0004`00000000000000000003ooooooooooeP0000h03D0<00^0300<00900002@0000T000040000
2@0000T0000U0000300000<0000K0000400000<5001l0@00E00006@0003O1000K0400085001o0@00
0@0000043D9E9@e2g`@006`100040000C00000000000000000000?ooooooooooE00003<0=00`0300
2@0000T0000900002@0001/0000@0000DPD007`1001D0000E00004T5001/0@00D@D007l100010000
00@=@UDU3D991@00K0400040001<00000000000000000000oooooooooom@0000=008:0T0001D0000
]00000@000210@00UP0009@10001000000@=@UDU3D840000P@400140001<00000000000000000000
oooooooooom`0000800P05@0@@1H04D0D`0P02P09@0P05H0@@1<05D0A@0Y0?lU100000@000090000
2`0000/0000;00002`0000@0000500003P0000@0000;00002`0000T0000<00002`0000D0001D0000
K0000?d100210@00:@8009@10001000000@=@UDU3D;m0@00P@4000D0001<00000000000000000000
oooooooooomH0000<00^0300<00U08012@0000@0000900002@0000h0001D0000Q000024300210@00
HP<009@10001000000@=@UDU3D8Q0`00P@4000T0001<00000000000000000000oooooooooomP0000
<`0P0480LP0P0380801206400?l90000100000/000050000100000T0000400002`0000T0000U0000
300000L0000K0000400009X4002A0@00E00007P0001P1000PP4009T4002C0@000@0000043D9E9@e2
H0@0088100070000C00000000000000000000?ooooooooooG0000340<P0e0300;P0`030000090000
2@0000T000090000100000T0000900009@0000`0000300006`00010000031@00T@4005@0001T0000
g`@0084100021@00U0400040000010e2EBD=@]l400210@00100004`00000000000000000003ooooo
oooooe@0000c03L0=@0`00T0000900002@0000T0000K000040000585002A0@00E00005@000191@00
P@400545002D0@000@0000043D9E9@e2B@D0084100010000C00000000000000000000?oooooooooo
D00003<000090000E000090000040000UP4006X0002Y0@000@0000043D9E9@e2100009H1000;0000
C00000000000000000000?ooooooooooI0000200801904h0D`1E0580@@1>04<0A@0000@000040000
1@0000/0000;0000300000`0000;00002`0000/0000;0000E00006`0003m0@00UP4002T2002Y0@00
0@0000043D9E9@e2o@4009H100050000C00000000000000000000?ooooooooooF0000300;P0`0300
9@00K0T0000400002@0000T0000>00006`00010000031@00YP4005@0001D0000nP@009H100021@00
Z@400040000010e2EBD=@_X4002F0@000@0004`00000000000000000003ooooooooooe00000`0030
2@0005@0002@000010000:/1001G0000_P400040000010e2EBD=@P@0002[0@002`0004`000000000
00000000003oooooooooof@0000P0200E@1D04T0C01905@0B@1505<003<40000100000`000090000
1@0000T0000500002@0000D0000;00002`0005@0001/0000o@400:/1000Y0P00_P400040000010e2
EBD=@_d1002[0@001@0004`00000000000000000003ooooooooooeP0000`02h0<00`02D0Q@090000
100000T0000900003P000580001`0@0020000?3oool0000000000000002@0@000000000002110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
001_021HNPNX77h700010<PhK`000@00h1an1`000038=Vl0000002Pk<@0]OXQeR281YS00000`0000
2P0000X000100eT22P000:PLOPM00eT2NDZYME@k<@0:00000@000:PLOPMD>c40llR8MH01SGGJB:IY
>@0008PR0JH00340E<V8MHPR0JH`0000>@000080002`?340c3/a03:aQ6V88P6V<00003T0002`?340
77Wf0XPR0JH00000000005Pm<@0100000000000000010000000000000000000000000>8k`dNd?340
7`0006RTZ0Kd>c401k64JFAf00P000009@0000`000080000E00007P0000Q0`00[04005L3002m0@00
0@0000043D9E9@e28@<00:`100070000C00000000000000000000?ooooooooooG00004`0H@1e06h0
I01b07T07`0900002@0000P0000800002@0000D0000700009@0000`0000300006`000100002J1000
^`4005@0001`0000J@@00:/1002I1000_P400040000010e2EBD=@VT4002[0@001P0004`000000000
00000000003ooooooooooeP0000b03H0=P0^03H0=`0900002@0000T0000400002@0000T0000K0000
400000<5002k0@00E0000600003X1000Z`400085002n0@000@0000043D9E9@e2j0@00:/100030000
C00000000000000000000?ooooooooooE0000380=P0g00002@0000T000090000E00009@000040000
`04006P0003C0@000@0000043D9E9@e210000<01000<0000C00000000000000000000?oooooooooo
I0000200801:0440CP1905@0C`1B04T0@@1<00@000040000200000/0000;00001@0000T0000<0000
300000D0000;00002@0005@0001/0000o@400<01000Y0P00d`400040000010e2EBD=@_d100300@00
1@0004`00000000000000000003ooooooooooeP0000`02h0<00`02D0JFh90000100000T000090000
3P0005@0002L000010000=D1001n0000j0400040000010e2EBD=@P@0003E0@003@0004`000000000
00000000003oooooooooofP0000P0200C01104h0A01C04<0@@1@04T0CP170595100000@000090000
2`0000/0000<00002`0000/0000;00002P0000D0000;00003@0005@0001/0000o@400=D1000Y0P00
j0400040000010e2EBD=@_d1003E0@001@0004`00000000000000000003ooooooooooeP0000`02h0
<00`02D0A2090000100000T0000900003P0005@0001`00008@<00=D1001F0`00j0400040000010e2
EBD=@R43003E0@001P0004`00000000000000000003ooooooooooeP0000P05@0C`1D0440C0040000
2@0000`0000900002`0000T0000K0000400000<5003U0@00E00006`0003F1000e@400085003X0@00
0@0000043D9E9@e2eP@00=D100050000C00000000000000000000?ooooooooooF0000340=P0f03H0
=`1>D`T0000900002@0000T0000900006`000100001B1@00i@4005@0001H0000@0D00=D1001A1@00
j0400040000010e2EBD=@T05003E0@000P0004`00000000000000000003ooooooooooe00000b0380
2@0000T0001D0000R00000@0003Z0@00FP000?d10001000000@=@UDU3D840000jP4000X0001<0000
0000000000000000oooooooooomP0000800P05<0E@1@0500C01904D0D`040000100000/0000<0000
2P0000X0000900001@0000/0000;0000E00006`0003m0@00jP4002T2003m0@000@0000043D9E9@e2
o@400>X100050000C00000000000000000000?ooooooooooF0000300;P0`03009@1>0`T000040000
2@0000T0000>0000E00007`0000Q0`00jP4007@3003m0@000@0000043D9E9@e28@<00>X100080000
C00000000000000000000?ooooooooooG0000200@@1F04D0DP1104L0A@0400002`0000/0000;0000
300000/0000=00002`0005@0002P000010000?l1002=00004P800040000010e2EBD=@P@0003o0@00
3P0004`00000000000000000003oooooooooofP0000P0200DP150500C01104<0A@1=04D0CP1D05<0
100000@0000<00002`0000X0000900002`0000/0000;00003@0000/0000;00002@0000/0001D0000
K0000?d1003o0@00:@8001820001000000@=@UDU3D;m0@00o`4000D0001<00000000000000000000
oooooooooomH0000<00^0300<00U04EC2@0000@0000900002@0000h0001D0000L00000@0000D0P00
>00002L20001000000@=@UDU3D840000508000H0001<00000000000000000000oooooooooomH0000
800P04P0EP1104<0100000@0000<00002`0000/0000;0000E00006`0003m0@00508002T2000W0P00
0@0000043D9E9@e2o@4001@200050000C00000000000000000000?ooooooooooF0000300;P0`0300
9@13A@T0000400002@0000T0000>0000E00009`000040000:@8007h0000l0P000@0000043D9E9@e2
100002T2000=0000C00000000000000000000?ooooooooooJ0000200801=0440B@1>05@0A@1>0440
CP1304D04P040000100000d0000;00001@0000/0000900002`0000/0000;00002`0000/0000;0000
E00006`0003m0@00:@8002T2000l0P000@0000043D9E9@e2o@4002T200050000C000000000000000
00000?ooooooooooF0000300;P0`03009@00A@T0000400002@0000T0000>0000E0000:`000040000
?P800940001A0P000@0000043D9E9@e2100003h2000@0000C00000000000000000000?oooooooooo
K0000200801@0580C`160200C@1705@0;P0P0400801O02D0100000@0000:0000300000`0000:0000
100000d0000=00002@0000@000040000400000@0000900003P0005@0001/0000o@4003h2000Y0P00
D@800040000010e2EBD=@_d1000n0P001@0004`00000000000000000003ooooooooooeP0000`02h0
<00`02D0M6P90000100000T0000900003P0005@000300000100005<200300000IP800040000010e2
EBD=@P@0001C0P004`0004`00000000000000000003oooooooooog@0000P0200@`1104d0801B04D0
B@1=0480E@1B05<0A@1=04D0CP1D065c100000@0000;00002`0000d000040000300000/000050000
3@0000/0000<0000300000/0000;00003@0000/0000;00002@0005@0001/0000o@4005<2000Y0P00
IP800040000010e2EBD=@_d1001C0P001@0004`00000000000000000003ooooooooooeP0000`02h0
<00`02D0Yd@90000100000T0000900003P0005@0002d0000100006P2002Y0000N`800040000010e2
EBD=@P@0001X0P004@0004`00000000000000000003oooooooooog00000P0200@@1304<0E@1=05D0
C01105@0A@140200A@1H050000040000100000/0000;00002`0000`0000=0000300000T0000;0000
2@0000/0000<0000100000/0000;00002P0002D0000<00000@0001P0000<0000003o05@0001`0000
m04006P2000Y0P00N`800040000010e2EBD=@_@1001X0P001P0004`00000000000000000003ooooo
oooooeP0000c03D0;P0`03009@0900002@0000@0000900002@0000h0000U0000300000<0000H0000
30000000000K000040000;02001h0P00E00007`0001]0P00J0800:l2001k0P000@0000043D9E9@e2
K@8006P200080000C00000000000000000000?ooooooooooG00003H0<`0`0300<00^0300<0090000
2@0000T0000900002@0000@0000900002@0005@0003H0000X0<006P200261000N`800040000010e2
EBD=@Z03001X0P005`0004`00000000000000000003oooooooooog`0001B04D0D@1E04T0DP1504@0
801B0440E0150200C`160200DP1505@0E@1B04h0000<00002`0000`0000<00001@0000`0000;0000
300000@0000<00002`0000T0000;0000100000`0000:0000100000`0000;00002@0000`0000<0000
2`0002D0000<00000@0001P0000<0000003o05@0001`00008@D006P2001F1@00N`800040000010e2
EBD=@R45001X0P001P0004`00000000000000000003ooooooooooeP0000a03<0;P0`03009@090000
2@0000@0000900002@0000h0000H000030000000000U0000300000<0001D0000Z0000:03001m0P00
<P@009020001000000@=@UDU3D:P0`00O@8000l0001<00000000000000000000oooooooooom/0000
D01B04l0BP0P04h0C`190200@`180440CP1704D0000:0000300000`000080000100000/0000<0000
1@0000@0000;0000300000/0000;00003@0000/0000U000030000040000H000030000000o`1D0000
K00002X5001m0P00EPD009020001000000@=@UDU3D8Z1@00O@8000D0001<00000000000000000000
oooooooooomH0000<`0^0300<00U00002@0000@0000900002@0000h0000H000030000000000U0000
300000<0001D0000X00000@0002B0P00T0000:D20001000000@=@UDU3D840000TP8000h0001<0000
0000000000000000oooooooooomX0000E01?05@0@@1<0200A@1H0500A@1>05<0A@1C00T0000<0000
2@0000/000090000100000/0000;00002P0000/0000;00002`0000/0000;0000E0000700003d0@00
TP8002T2002U0P000@0000043D9E9@e2m040098200060000C00000000000000000000?oooooooooo
F00003<0=@0^0300<00U00T000090000100000T0000900003P0001/0000@00005@<00:82001D0000
O0000=82002B0P0050<00:D20001000000@=@UDU3D;B0P00TP8000P0001<00000000000000000000
oooooooooomL0000=P0c0300<00`02h0<00`00T0000900002@0000T000090000100000T000090000
E0000;P0002P0`00TP8004d4002U0P000@0000043D9E9@e2X0<00982000B0000C000000000000000
00000?ooooooooooL00004L0C`1904h0A`0P04l0E@1D0200@`110500801B0440E01500d0000<0000
1@0000/0000=0000100000`0000<00002@0000@0000;00002`0000X000040000300000/000090000
2`0002D0000<00000@0001P0000<0000003o05@0001/0000:PD00982001F1@00Y@800040000010e2
EBD=@RX5002B0P001@0004`00000000000000000003ooooooooooeP0000i02h0<`0f02D000090000
100000T0000900003P0001P0000<0000000002D0000<00000`0005@00034000010000:L200370000
^P800040000010e2EBD=@P@0002W0P00500004`00000000000000000003oooooooooog@0001>04D0
E00P04l0D0150580@@1D04T0CP170200B@1>04<0C`1=04D02`0000/000090000100000`0000:0000
2`0000`0000;00002@0000D0000;00003@0000@0000500002`0000/0000<00003@0000/0000K0000
400001D3002g0P00E00008@000390P00Y`8001@3002j0P000@0000043D9E9@e2b@800:L200090000
C00000000000000000000?ooooooooooH0000340<@0g0300<00`02h0<00`00002@0000T000090000
2@0000T000090000100000T000090000E0000<0000040000_0800;/0003?0P000@0000043D9E9@e2
10000;`2000C0000C00000000000000000000?ooooooooooM00004d0@@1B04/0A@1D0200EP1104`0
80130440D00P0580@@1D04D0000=00002`0000`0000:00002`0000T0000400002`0000/000090000
100000/0000;00002P0000@0000<00002`0000T0000;00009@0000`000010000600000`000000?l0
E00006`0003m0@00_08002T2003?0P000@0000043D9E9@e2o@400;`200050000C000000000000000
00000?ooooooooooF00003T0;P0c03H09@013`T0000400002@0000T0000>0000600000`000000000
9@0000`0000=00208P0000`0003ooooo8@0000P0000U000030000040000I000030000?ooo`0H0000
30000000000N00006000000000000000F`D00=42000W0000600000T00000000000000000000U0000
300000T0000D0000300000d0000B000030000080000X000030000080000V00007000008000000000
00000000000000009@0000`0000200006`00010000020000ooooocH0000@0000W0<00?oooolU0000
300000L0081<0000I000000000000000ooooooooool20000oooooiX3000100008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000020000
6`000100000200000@0003H0000@0000W0<00040000U0000300000L0081<0000I000008000010000
V`<00040000200000@0009X3000100008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000200006`000100002L0`00ooooocH0000@0000
XP@00?oooolU0000300000L0081<0000I000000000000000oooooooooonL0`00ooooo`H100010000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000200006`000100002L0`000@0003H0000@0000XP@00040000U0000300000L0081<0000
I00009`300010000X@@00040002L0`000@0000H1000100008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000200006`000100003ooooo
ooooocH0000@00000P000?oooolU0000300000L0081<0000I000000000000000oooooooooooooooo
ooooo`<0000100008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000200006`000100000100000@0003H0000@00000P000040000U0000
300000L0081<0000I0000040000100000@000040000100000@000040000100008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009`0001P0000:0000
00000=[Lg@0000009@0000`0000:0000:00000`000090000600000`0003Jg=d06@0000`0003Jg=d0
:00000`0000200009P0001`0000200000000000000000000f]cM02D0000<00000P0001/0000@0000
00000000000f000040000000003ooooo9@0000`000070020C00006@00000000000000?oooooooooo
0000000000010000ooooob40l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000_`400000000f000040000;l1003ooooo
9@0000`000070020C00006@00000000000000?oooooooooo_`40000000010000ooooob40l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@0000;@800000000f0000400002d2003ooooo9@0000`000070020C00006@000000000
00000?oooooooooo;@80000000010000ooooob40l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@0000^0800000000f0000
40000;P2003ooooo9@0000`000070020C00006@00000000000000?oooooooooo^080000000010000
ooooob40l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00007@<00000000f0000400001d3003ooooo9@0000`000070020
C00006@00000000000000?oooooooooo7@<0000000010000ooooob40l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
W0<00000000f0000400009`3003ooooo9@0000`000070020C00006@00000000000000?oooooooooo
W0<0000000010000ooooob40l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000XP@00000000f000040000:84003ooooo
9@0000`000070020C00006@00000000000000?ooooooooooXP@0000000010000ooooob40l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00002`D00000000f0000400000/5003ooooo9@0000`000070020C00006@000000000
00000?oooooooooo2`D0000000010000ooooob40l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@0000FPD00000000f0000
400005X5003ooooo9@0000`000070020C00006@00000000000000?ooooooooooFPD0000000010000
ooooob40l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@0000_`400080000f000040000;l1001E00009@0000`000070020
C00006@0002o0@000P000;l1001D0000_`40008000010000D`000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
;@800080000f0000400002d2001E00009@0000`000070020C00006@0000]0P000P0002d2001D0000
;@80008000010000D`000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000^0800080000f000040000;P2001E0000
9@0000`000070020C00006@0002h0P000P000;P2001D0000^080008000010000D`000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00007@<00080000f0000400001d3001E00009@0000`000070020C00006@0000M0`00
0P0001d3001D00007@<0008000010000D`000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@0000W0<00080000f0000
400009`3001E00009@0000`000070020C00006@0002L0`000P0009`3001D0000W0<0008000010000
D`000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@0000XP@00080000f000040000:84001E00009@0000`000070020
C00006@0002R10000P000:84001D0000XP@0008000010000D`000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
2`D00080000f0000400000/5001E00009@0000`000070020C00006@0000;1@000P0000/5001D0000
2`D0008000010000D`000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000_`4005H0000f000040000;l1000B0@00
9@0000`000070020C00006@0002o0@00EP000;l1000A0@00_`4005H000010000_0000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@0000;@8005H0000f0000400002d2000B0@009@0000`000070020C00006@0000]0P00
EP0002d2000A0@00;@8005H000010000_0000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@0000^08005H0000f0000
40000;P2000B0@009@0000`000070020C00006@0002h0P00EP000;P2000A0@00^08005H000010000
_0000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00007@<005H0000f0000400001d3000B0@009@0000`000070020
C00006@0000M0`00EP0001d3000A0@007@<005H000010000_0000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
W0<005H0000f0000400009`3000B0@009@0000`000070020C00006@0002L0`00EP0009`3000A0@00
W0<005H000010000_0000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000XP@005H0000f000040000:84000B0@00
9@0000`000070020C00006@0002R1000EP000:84000A0@00XP@005H000010000_0000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00002`D005H0000f0000400000/5000B0@009@0000`000070020C00006@0000;1@00
EP0000/5000A0@002`D005H000010000_0000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@00000P0002`1000f0000
400001d3000/0@009@0000`000070020C00006@000020000;04001`3000/0@000P0002`1000K0`00
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00000P000441000f0000400001d300110@009@0000`000070020
C00006@000020000@@4001`300110@000P000441000K0`000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
0P0005H1000f0000400001d3001F0@009@0000`000070020C00006@000020000EP4001`3001F0@00
0P0005H1000K0`000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@00000P0006/1000f0000400001d3001[0@00
9@0000`000070020C00006@000020000J`4001`3001[0@000P0006/1000K0`000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00000P000801000f0000400001d300200@009@0000`000070020C00006@000020000
P04001`300200@000P000801000K0`000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@00000P0009D1000f0000
400001d3002E0@009@0000`000070020C00006@000020000U@4001`3002E0@000P0009D1000K0`00
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00000P000:X1000f0000400001d3002Z0@009@0000`000070020
C00006@000020000ZP4001`3002Z0@000P000:X1000K0`000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
0P000;l1000f0000400001d3002o0@009@0000`000070020C00006@000020000_`4001`3002o0@00
0P000;l1000K0`000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@00000P000=@1000f0000400001d3003D0@00
9@0000`000070020C00006@000020000e04001`3003D0@000P000=@1000K0`000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00000P000>T1000f0000400001d3003Y0@009@0000`000070020C00006@000020000
j@4001`3003Y0@000P000>T1000K0`000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@00000P000?h1000f0000
400001d3003n0@009@0000`000070020C00006@000020000oP4001`3003n0@000P000?h1000K0`00
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00000P0001<2000f0000400001d3000C0P009@0000`000070020
C00006@0000200004`8001`3000C0P000P0001<2000K0`000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
0P0002P2000f0000400001d3000X0P009@0000`000070020C00006@000020000:08001`3000X0P00
0P0002P2000K0`000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@00000P0003d2000f0000400001d3000m0P00
9@0000`000070020C00006@000020000?@8001`3000m0P000P0003d2000K0`000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00000P000582000f0000400001d3001B0P009@0000`000070020C00006@000020000
DP8001`3001B0P000P000582000K0`000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@00000P0006L2000f0000
400001d3001W0P009@0000`000070020C00006@000020000I`8001`3001W0P000P0006L2000K0`00
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00000P0007`2000f0000400001d3001l0P009@0000`000070020
C00006@000020000O08001`3001l0P000P0007`2000K0`000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
0P000942000f0000400001d3002A0P009@0000`000070020C00006@000020000T@8001`3002A0P00
0P000942000K0`000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@00000P000:H2000f0000400001d3002V0P00
9@0000`000070020C00006@000020000YP8001`3002V0P000P000:H2000K0`000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00000P000;/2000f0000400001d3002k0P009@0000`000070020C00006@000020000
^`8001`3002k0P000P000;/2000K0`000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002L0000H00002@00000000000000000002D0000<0000
2@0001P0000<0000000001T0000<0000oooo02P0000<00000P0002H0000L00000P00000000000000
00000000000U000030000080000K000040000?ooool20000=P000100003oooood08002D0000<0000
1`00P4`0001T000000000000003oooooooooooooool200000@000<h2000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U000030000080000K0000
4000004000020000=P00010000010000d08002D0000<00001`00P4`0001T00000@00008000010000
c`800040000200000@000<h2000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000X0000X0000300000T0000H000030000=[Lg@0I0000
30000=[Lg@0X000030000080000V0000700000800000000000000000003Jg=d09@0000`000020000
6`000100002o0@004`4003H0000@0000_`400=02000U0000300000L0081<0000I0000;l1000C0@00
_`400<l2002o0@004`400040002m0@008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000200006`000100000]0P004`4003H0000@0000
;@800=02000U0000300000L0081<0000I00002d2000C0@00;@800<l2000]0P004`400040002m0@00
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000200006`000100002h0P004`4003H0000@0000^0800=02000U0000300000L0081<0000
I0000;P2000C0@00^0800<l2002h0P004`400040002m0@008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009`0001P0000900000000000000000000
9@0000`000090000600000`0000000006@0000`0003oool0:00000`0000200009P0001`000020000
0000000000000000000002D0000<00000P0001/0000@00007@<001<1000f0000400001d3003A0P00
9@0000`000070020C00006@0000M0`004`4001d3003@0P007@<001<100010000_P400240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
2P0002P0000<00002@0001P0000<0000f]cM01T0000<0000f]cM02P0000<00000P0002H0000L0000
0P0000000000000000000=[Lg@0U000030000080000K0000400009`3000C0@00=P000100002L0`00
d08002D0000<00001`00P4`0001T0000W0<001<1002L0`00c`8009`3000C0@000@000;d1000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
30000080000K000040000:84000C0@00=P000100002R1000d08002D0000<00001`00P4`0001T0000
XP@001<1002R1000c`800:84000C0@000@000;d1000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K0000400000/5000C0@00
=P000100000;1@00d08002D0000<00001`00P4`0001T00002`D001<1000;1@00c`8000/5000C0@00
0@000;d1000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000W0000600000T00000000000000000000U0000300000T0000H000030000000000I0000
30000?ooo`0X000030000080000V0000700000800000000000000000000000009@0000`000020000
6`000100001I1@000P0003H0000@0000F@D00=02000U0000300000L0081<0000I00005T500020000
F@D00<l2001I1@000P000040003>0P008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000200006`000100001K1@000P0003H0000@0000
F`D00=02000U0000300000L0081<0000I000000000000000oooooooooomK1@000P000040003>0P00
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000:0000:00000`000090000600000`0003Jg=d06@0000`0003Jg=d0:00000`000020000
9P0001`0000200000000000000000000f]cM02D0000<00000P0001/0000@000000000=42000f0000
40000000003B0P009@0000`000070020C00006@00000000000000?oooooooooo00000=4200010000
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002L0000H00002@00000000000000000002D0000<00002@0001P0000<0000000001T0000<0000
oooo02P0000<00000P0002H0000L00000P0000000000000000000000000U000030000080000K0000
4000004000010000=P000100000100000P0002D0000<00001`00P4`0001T00000@00004000010000
0@000040000100000@000040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U000030000080000K000040000?oooooooooo=P000100003ooooo
0P0002D0000<00001`00P4`0001T000000000000003ooooooooooooooooooooo0@0000<0000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000X0000X0000300000T0000H000030000=[Lg@0I000030000=[Lg@0X000030000080000V0000
700000800000000000000000003Jg=d09@0000`0000200006`000100002o0@00d@8003H0000@0000
_`400=82000U0000300000L0081<0000I000000000000000oooooooooono0@00d@80004000010000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000200006`000100000]0P00d@8003H0000@0000;@800=82000U0000300000L0081<0000
I000000000000000ooooooooool]0P00d@800040000100008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000200006`000100002h0P00
d@8003H0000@0000^0800=82000U0000300000L0081<0000I000000000000000oooooooooonh0P00
d@800040000100008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000200006`000100000M0`00d@8003H0000@00007@<00=82000U0000
300000L0081<0000I000000000000000oooooooooolM0`00d@800040000100008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000020000
6`000100002L0`00d@8003H0000@0000W0<00=82000U0000300000L0081<0000I000000000000000
oooooooooonL0`00d@800040000100008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000200006`000100002R1000d@8003H0000@0000
XP@00=82000U0000300000L0081<0000I000000000000000oooooooooonR1000d@80004000010000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000200006`000100000;1@00d@8003H0000@00002`D00=82000U0000300000L0081<0000
I000000000000000ooooooooool;1@00d@800040000100008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000200006`000100001J1@00
d@8003H0000@0000FPD00=82000U0000300000L0081<0000I000000000000000oooooooooomJ1@00
d@800040000100008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009`0001P00009000000000000000000009@0000`000090000600000`000000000
6@0000`0003oool0:00000`0000200009P0001`0000200000000000000000000000002D0000<0000
0P0001/0000@0000F`D00?oooolf0000400005/5000200009@0000`000070020C00006@000000000
00000?ooooooooooF`D00?ooool100000`000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@0000F@D00040000f0000
400005T5000200009@0000`000070020C00006@0001I1@000@0005T500010000F@D0004000010000
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@0000XP@00?oooolf0000400005T5003ooooo9@0000`000070020
C00006@00000000000000?ooooooooooXP@00?oooong00000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
XP@00040000f0000400005T5000100009@0000`000070020C00006@0002R10000@0005P500010000
XP@00040002g00000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000F@D00040000f0000400005X500010000
9@0000`000070020C00006@0001I1@000@0005T500010000F@D00040000100000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@0000F@D00?oooolf0000400005`5003ooooo9@0000`000070020C00006@000000000
00000?ooooooooooF@D00?ooool300000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00002P0002P0000<00002@0001P0000<0000
f]cM01T0000<0000f]cM02P0000<00000P0002H0000L00000P0000000000000000000=[Lg@0U0000
30000080000K000040000080000F0000=P000100001I1@005P0002D0000<00001`00P4`0001T0000
0P0001H0001H1@005P000080000F0000E`D00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K000040000080000[0000
=P000100001I1@00:`0002D0000<00001`00P4`0001T00000P0002/0001H1@00:`000080000[0000
E`D00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U000030000080000K00004000008000100000=P000100001I1@00@00002D0000<0000
1`00P4`0001T00000P000400001H1@00@000008000100000E`D00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000W0000600000T000000000
00000000000U0000300000T0000H000030000000000I000030000?ooo`0X000030000080000V0000
700000800000000000000000000000009@0000`0000200006`00010000020000E@0003H0000@0000
F@D005D0000U0000300000L0081<0000I0000080001E0000F0D005D000020000E@0005L500010000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000:0000:00000`000090000600000`0003Jg=d06@0000`0003Jg=d0:00000`000020000
9P0001`0000200000000000000000000f]cM02D0000<00000P0001/0000@00000P0006X0000f0000
400005T5001Z00009@0000`000070020C00006@000020000JP0005P5001Z00000P0006X0001G1@00
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00000P0007l0000f0000400005T5001o00009@0000`000070020
C00006@000020000O`0005P5001o00000P0007l0001G1@000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
0P0009@0000f0000400005T5002D00009@0000`000070020C00006@000020000U00005P5002D0000
0P0009@0001G1@000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@00000P000:T0000f0000400005T5002Y0000
9@0000`000070020C00006@000020000Z@0005P5002Y00000P000:T0001G1@000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@00000P000;h0000f0000400005T5002n00009@0000`000070020C00006@000020000
_P0005P5002n00000P000;h0001G1@000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00000P0001/0000@00000P000=<0000f0000
400005T5003C00009@0000`000070020C00006@000020000d`0005P5003C00000P000=<0001G1@00
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@00000P000>P0000f0000400005T5003X00009@0000`000070020
C00006@000020000j00005P5003X00000P000>P0001G1@000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
0P000?d0000f0000400005T5003m00009@0000`000070020C00006@000020000o@0005P5003m0000
0P000?d0001G1@000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002L0000H00002@00000000000000000002D0000<00002@0001P0000<0000
000001T0000<0000oooo02P0000<00000P0002H0000L00000P0000000000000000000000000U0000
30000080000K000040000080000B0@00=P000100001I1@004P4002D0000<00001`00P4`0001T0000
0P000181001H1@004P400080000B0@00E`D00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000X0000X0000300000T0000H0000
30000=[Lg@0I000030000=[Lg@0X000030000080000V0000700000800000000000000000003Jg=d0
9@0000`0000200006`000100000N0`00;04003H0000@0000F@D002`1000U0000300000L0081<0000
I00001h3000/0@00F0D002`1000N0`00;04003/2000100008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000200006`000100000N0`00
@@4003H0000@0000F@D00441000U0000300000L0081<0000I00001h300110@00F0D00441000N0`00
@@4003/2000100008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000200006`000100000N0`00EP4003H0000@0000F@D005H1000U0000
300000L0081<0000I00001h3001F0@00F0D005H1000N0`00EP4003/2000100008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000020000
6`000100000N0`00J`4003H0000@0000F@D006/1000U0000300000L0081<0000I00001h3001[0@00
F0D006/1000N0`00J`4003/2000100008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000200006`000100000N0`00P04003H0000@0000
F@D00801000U0000300000L0081<0000I00001h300200@00F0D00801000N0`00P04003/200010000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000200006`000100000N0`00U@4003H0000@0000F@D009D1000U0000300000L0081<0000
I00001h3002E0@00F0D009D1000N0`00U@4003/2000100008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000200006`000100000N0`00
ZP4003H0000@0000F@D00:X1000U0000300000L0081<0000I00001h3002Z0@00F0D00:X1000N0`00
ZP4003/2000100008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000200006`000100000N0`00_`4003H0000@0000F@D00;l1000U0000
300000L0081<0000I00001h3002o0@00F0D00;l1000N0`00_`4003/2000100008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000020000
6`000100000N0`00e04003H0000@0000F@D00=@1000U0000300000L0081<0000I00001h3003D0@00
F0D00=@1000N0`00e04003/2000100008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000200006`000100000N0`00j@4003H0000@0000
F@D00>T1000U0000300000L0081<0000I00001h3003Y0@00F0D00>T1000N0`00j@4003/200010000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000200006`000100000N0`00oP4003H0000@0000F@D00?h1000U0000300000L0081<0000
I00001h3003n0@00F0D00?h1000N0`00oP4003/2000100008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000200006`000100000N0`00
4`8003H0000@0000F@D001<2000U0000300000L0081<0000I00001h3000C0P00F0D001<2000N0`00
4`8003/2000100008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000200006`000100000N0`00:08003H0000@0000F@D002P2000U0000
300000L0081<0000I00001h3000X0P00F0D002P2000N0`00:08003/2000100008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000020000
6`000100000N0`00?@8003H0000@0000F@D003d2000U0000300000L0081<0000I00001h3000m0P00
F0D003d2000N0`00?@8003/2000100008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000200006`000100000N0`00DP8003H0000@0000
F@D00582000U0000300000L0081<0000I00001h3001B0P00F0D00582000N0`00DP8003/200010000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000200006`000100000N0`00I`8003H0000@0000F@D006L2000U0000300000L0081<0000
I00001h3001W0P00F0D006L2000N0`00I`8003/2000100008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000200006`000100000N0`00
O08003H0000@0000F@D007`2000U0000300000L0081<0000I00001h3001l0P00F0D007`2000N0`00
O08003/2000100008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000200006`000100000N0`00T@8003H0000@0000F@D00942000U0000
300000L0081<0000I00001h3002A0P00F0D00942000N0`00T@8003/2000100008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000020000
6`000100000N0`00YP8003H0000@0000F@D00:H2000U0000300000L0081<0000I00001h3002V0P00
F0D00:H2000N0`00YP8003/2000100008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000200006`000100000N0`00^`8003H0000@0000
F@D00;/2000U0000300000L0081<0000I00001h3002k0P00F0D00;/2000N0`00^`8003/200010000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9`0001P00009000000000000000000009@0000`000090000600000`0000000006@0000`0003oool0
:00000`0000200009P0001`0000200000000000000000000000002D0000<00000P0001/0000@0000
ooooom02000f0000400005`5003@0P009@0000`000070020C00006@000000000d08005X5003@0P00
ooooom02001M1@000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00001000P2P0000<00002@0002D0000<00003@00P280000<0000
ooooob40000800009@0000`0000100006@0000`0003oool0600000`0000000007P0001P000010000
0@0005/5003A0P008P0000`0003oooooAP0003@0000X0000ADe6:bY0000T000060000000P3l00020
0000P000P3l000200000P4H0000L0000400004E=AR/2@00030000000000>000050000000000@0000
5000
\>"], "Graphics",
 Editable->False,
 TextAlignment->Center,
 ImageSize->{613.3333333333333, 322.7893391748813},
 ImageMargins->{{304.66666666666663`, 0.}, {0., 
  0.}},ExpressionUUID->"5c0f47ed-ee26-4ef6-b65a-7a7a00e869b1"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Input and first year operations for sample project"
}], "FigureCaption",
 CellChangeTimes->{{3.528571255844006*^9, 3.528571270806862*^9}, 
   3.540935836835552*^9},
 TextAlignment->Center,ExpressionUUID->"78e50677-7997-4e11-bc3d-6ebaa2820682"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002ML0@0006`0000200000@000:T1002X0000
00000000003@>P00AQL00215CDH00040G2L006T000050000000000000000000000@00003001Y0@00
3`40000000000000000001b31@1E8P@0AP0009`9002>2@00AdA9@`4008000`00?;3H0@00001f2@00
0@090003^`@000@0=0000000100000<1200500002`8000001@0000`2a@>52@D000090P0000050000
0@;oool0100000@13@0400000P4200<0000N00@0000W0Ooo0`0001h0100002L1ool300007P050000
0@;oool01@0000T2000000@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PC30h<9
000000@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PC30h<9000001`0003k0/ko
00000000T0400000000045AYKFEc84iUMb1BKfeQKP0000000000000000000000100002d100040000
104=00@000020@409@00038:1P0;01@0001>AE@PCe15DT5DBDi784U>@dm=AB@07`0O00d0900L01l0
8@0S01l04@0T02@03@0A02@08@0T02`07`050000508c0=074000038:1P0j1`H0000a<CL`<30I01T0
6@0I01T06@0T0000<PY600/04`0004a5De<j84a?@DhPD45ICDE>E5=57P0O01`0700>00d07P0T02<0
900=01`08`0T02`07`0T01l0700O0000<PY60:X4400004I9DU=D85U5@E8PCdi<FCXK01408@0L01l0
3@0T01l08`0Q00d0900T01h0900>01`0000b2XH02`0>0000820P820PBDiDAE95De@=00d03@0=00d0
3@0A02@07`0O02407`0L01l01@0001@2/`0;1`l0000b2XH0SPH50000>CH`=CD`6@0I01T06@0I01h0
000b2/H02`0?0000820P820PD599CT=9D45<>Pd03@0=00d03@0=01`08@0A02@08@0A01`08`0N00D0
000D0_<02`L=0000<P[60:L6100003<i<cTI01T06@0I03@0000b2PH12`0N0000820P820PE4mD@D`P
A4E2E21CAE9FBD=582HPA4=B3@0=00d03@0=00d07`0T01l08`0N00d0900O02407`0=01`07`0Q02@0
4@0Q01l03@0V00d0900Q02401@0001@2<`4;1`l0000b2PH1SPH50000>CTi>C@`6@0I01T06@0I00D0
000D0S<1d0L@0000<PX60D871P0002di>CTi=1406@0I01T06@0I00D0000D0S<1J0T?0000<PX60OL8
1@00034^<CL`=1T03@0I01T06@0X0000<PY60@/05P0004=1DdPPATa?Eb12ADI?DTDPE45HAE<Q02<0
700T00d06`0N02@0;P0=02407`0K02@08@0O00d07`0S02@07`0L00T0000b2TH1Q0D100008=d=00D0
000D0W<1d0L?0000<PY60E<71@00034g<30f=1T06@0I01T06@050000509c0G/83`00038:AP7n1`D0
000a=c0`=S@I01T06@0I01T03`00038:AP7g20D0000d;SDc9C@I00d06@0I02X08P00038:QP4;0180
001@C5EC>R1@DTU>8511FDe5CU@L01h0900L00h03@0L02404@0T00d0700S02@0;00O02@07`050000
50:c0M073@00038:QP5/1`@0000c>C<i6@0I01T06@0E0000<P[60@/02@0005=E@ReDCeA1C0DL02@0
8@0A01l0900O02<07P05000050;c0M073`00038:aP5C1`D0000b<3Td=C@I01T06@0I01T08P00038:
1P8;0180001<AE=C>R14AE1BAD=9@EA9CdhN01l0700L00h03@0T01l0700Q01l08@0A02<07`0A02@0
900@0000<PY60Y`21P0004a9ATDP?Ah04@0K01l03@0L00d0000b2TH2R`<40000<SL^=AT06@0=01T0
3`00038:AP;e0`D0001IAD5BDcdT01l08`0Q01`04000038:QP9l0PH0001<@Di483dN02<0900T00d0
700L0000n`;>o`000000090100000000011DJFeULb1>IGLPDVm]HFh00000000000000000000000@0
000]0@404000038:QP9=0`H0000c=cD`<30I01T06@0I01T06@040000;@4002@0000b2/H22`0C0000
@Di>ED5<84A5D2M>84A5A5E3E5PS02@0900T02<07P0=02@07`0L00P0900=02@07`0T02@08@0O00D0
000D0_<2d0L@0000<P[60T871P0002dc<CPa>1406@0I01T06@0I0240000b2PH32`0A0000DTDPE45H
@D9<AB19CT=?CDE38@0O00d07`0S02@08`0Q01h07`0=0140900Q02@0;00O00D0000D0S<3d0L@0000
<PX60d871P0002da<3Pg=1406@0I01T06@0I01T0000b2TH32`0<0000BDi3Cde585A1F4EC4@0T0240
900/01l03@0O02<0900O01`0:`00038:AP?e0aP0001D@EPP@U91@d]5E3dc=BDP@dm=@R1C9THO02<0
900=02408@0S02408`0O01l0700I01T0:P0=0240900/02403@0L02H06`050000509c0m073`00038:
AP=K1`D0000]<cP`=S@A01T06@0I01T01@0001@2L`=k20d0000b2TH35`P40000<cP`=QT06@0I01T0
70000?/2c_l00000002@0@000000000@E6U]IG<PCVEg859_KF5^0000000000000000000000040000
;@4200D000090P00o`0500002@800000100002d1000I0000<PZ60`/030000456E4EB85A1F213AR<0
6`0O01l08@0=01l08`0T00d08@0K00D0000D0[<3N`P?0000<PZ60oh71@00038`>34b=1T06@0I01T0
6@0C0000<PZ60j`8200003D^=C@i>34U6@0=01T06@0I01T06@0Z01`0003k0Q001`000000_0800000
0@828U=iLgAUK@0000000000000D0P00N`P00>@400000000100002d10`040000l04000@0003`0@80
10000?010@0400009`7oo`<0000000004@0000`0000800002`000100002[0@00Z@0000T0000@0000
Z`400:T0000:000040000000000000002@00010000252@00a@<001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P000240000800008P0000`0003ooooo8@0000P0000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<000000000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P000000000000008<900330`008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N00006000000000000000P`T00<<3001B0000
L0400040003>oooo0000000000000000T04000000000000@E01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h0000000000000000000000000000000000000000000000000002P002P000009M8eGH00000
L3Ae2P00001`=7D:00000:?K07P7000000X0000000010000000009Q1eGH000001000100000020000
0000000000000000L3Ae2P00000@2P0000000009000000000P000P00003P9bHQ0000008000800000
L>ak:00000010000000006TAnOkn1`00001f0P00002T5o[noPL0050kmaP000000c7ioP0000040000
0000000000000000<aDQ0P0000330`00000007<>14X00000n3?mo_h70000000000000040001TMP08
000002D0000<00000@0001@0000<00003@000180000<00000@0005@0003400000P000040001/0000
30000040000fZ/E07<35@0/000060000500004`00000000000000000003oooooooooog@0001>04D0
E00P04l0D0150580@@1D04T0CP170200B@1>04<0C`1=04D0900001l0000O00003@0002@0000L0000
7`000240000S00007`000140000T0000900000d0000A000090000240000T0000;00001l0000K0000
40000=07000c0000E000070000140@000@0005h1000<00000@0003JZaD0L`<E0>PL000H000060000
C00000000000000000000?ooooooooooF0000340<@0g0300<00`01T0000I00006@0001T0000I0000
6@0005@0003000000P0000`0001T00005`000040000fZ/E07<35@0/0001600004`0004`000000000
00000000003oooooooooog@0001<04D0D`1C03X0801<04l0@@1>0200D01105T0C@1504h0E01C0000
7P0001l0000L0000700000h0000=00007P0002@0000S0000900000d0000L00008`0002@0000/0000
7`0002@0000O0000700005@0002/0000d@0000`0000O0@005`000040000fZ/E07<35@:X400160000
400004`00000000000000000003oooooooooof`0001604T0DP1C05@0801I04D0@@1B0200C`1>04`0
F@0j01/0000A00008@0001`0000O00003@0002@0000O00008`000240000=0000900002@0000N0000
900000h0001D0000X0000080000G0000>@00028000010000=Z[5@1c0aD0;0000QP0000h0001<0000
0000000000000000oooooooooomX0000800P0200800P0200B@1>05@0A@1B04D0D`1D00d0000=0000
3@0000d0000=00003@000140000T00007`0001l0000Q00007`0001`0000O00006`000100000;1`00
/`0005@0001/00009P4001L0000k0@008P000040000fZ/E07<35@8h6002600001@0004`000000000
00000000003ooooooooooeP0000i03H0<00e03D0000I00006@0001T0000I00006@0005@0002X0000
0P0002<0000l0000;P000040000fZ/E07<35@0/0003600003`0004`00000000000000000003ooooo
ooooof`0000P0200800P0200801@0580B@1>04<0B@1@0440C00000d0000=00003@0000d0000=0000
3@0001`0000Q00004@0002@0000Q00004@0001`0000S00007P0001/0000@00002`L00?<0001D0000
I00002X1000S0000>`4002h000010000=Z[5@1c0aD2W1P00aP0000@0001<00000000000000000000
oooooooooomD0000<`0i03<0>@0I00006@0001T0000I0000E000000100020000;P0008T0000i0000
0@0003JZaD0L`<E02`0000H1000N0000C00000000000000000000?ooooooooooR0000200800P0200
800P05@0C`1D0440C00P04@0A@1205@0801C04D0DP1F04T0@`1502009P0P04@0@`1B00d0000=0000
3@0000d0000=00003@0001l0000T00007`0002<0000N00003@0002@0000O00008@0001l0000=0000
700001l0000Q000090000140000Q00007`0000d0000V00003@0002@0000Q00008@0001/0000@0000
2`L003<1001D0000K00002H1000^0000>`4003T000010000=Z[5@1c0aD2>1P001P4000D0001<0000
0000000000000000oooooooooomH0000>@0i03T0>@0d00006@0001T0000I00006@0001T0000K0000
40000=07000c0@00E000070000160@00;P0005h1000i00000@0003JZaD0L`<E0@PL000H100060000
C00000000000000000000?ooooooooooF00002d0>@0i03T0>@0d0140000I00006@0001T0000I0000
6@0001/0000@0000J0T003<1001D0000K0000981000^0000Y@4003T000010000=Z[5@1c0aD3g2000
1P4000D0001<00000000000000000000oooooooooomH0000<@0^0340=`0`00006@0000d0000I0000
6@0001T0001D0000d0000080000i0000M@0004@000010000=Z[5@1c0aD0;0000AP4001H0001<0000
0000000000000000oooooooooomh0000@`1105<0B00P04H0C01?05L0801204D0AP1?0580A@0P05@0
@@1H04D0D`0Q00008`0001`0000T00003@0001/0000N0000900002h0000=00008@0001l0000K0000
90000240000O00003@0001l0000S0000900001l0000L0000E00005@0003g0000>@000?T000140000
0@0003JZaD0L`<E0Q0D004H100010000C00000000000000000000?ooooooooooD0000200000=0000
6`000100003@1`00L`4005@0001/0000B@4003T0001N0@00A0000040000fZ/E07<35@5<700160@00
1@0004`00000000000000000003ooooooooooeP0000a03L0<00`03H0000I00006@0001T0000I0000
6@0001/0000@0000N`P007<1001D0000K00006L1000i0000O04004@000010000=Z[5@1c0aD3n1`00
AP4000D0001<00000000000000000000oooooooooomH0000<@0g0300<00f00006@0001T0000I0000
6@0001T0001D0000K0000981000i0000Z@4004@000010000=Z[5@1c0aD3g2000AP4000D0001<0000
0000000000000000oooooooooomH0000=00^03D0<`0U00006@0000d0000I00006@0002X0001D0000
^000008000140000G00004l000010000=Z[5@1c0aD0;0000QP400180001<00000000000000000000
oooooooooom`0000D01<05D0D`0j0200D01B04T0CP0P0500@@1I04d0A@1>05@0700001h0000T0000
700000h0000=000070000240000A0000900000d0000L00008`0002@0000/00007`0002@0000O0000
6`000100003@1`00/`4005@0001T0000C@4004@0001N0@00C`000040000fZ/E07<35@6`700260@00
100004`00000000000000000003ooooooooooe@0000c03T0<`0i01T0000I00006@0001T0001D0000
Q0000080001@0000<P0005/000010000=Z[5@1c0aD0;0000aP4000T0001<00000000000000000000
oooooooooomP0000D`1E0480;@1D04l0E01104`0000L000090000240000A00007`0002@0000O0000
8`0001h0000K000040000=07003c0@00E00006`000190@00D00005h1001K00000@0003JZaD0L`<E0
D`L00<H100050000C00000000000000000000?ooooooooooF0000380<00i03@0=@0001T0000I0000
6@0001T0000I0000E0000;P000020000F`0005/0001V00000@0003JZaD0L`<E02`0000H2000B0000
C00000000000000000000?ooooooooooL00004`0A@1C05<0>P0P04@0A@1@0580A@1304T0@@1D04T0
C`1>01h0000O0000700001`0000>00003@0002@0000O000070000240000O00008@000140000S0000
7`000140000T0000900005@0001`0000M@0006H0002>0000L@000040000fZ/E07<35@9`200160P00
1P0004`00000000000000000003ooooooooooeP0001<04T0AP150200?@0N00004@0001/0000O0000
3@0001`0001D0000I00009l0001V0000[P00074000010000=Z[5@1c0aD2;0`00AP8000@0001<0000
0000000000000000oooooooooomD0000<P0g02h0=@0I00006@0000d0000I0000E00006`0002b0000
IP000<h0001a00000@0003JZaD0L`<E0m@<004H200050000C00000000000000000000?oooooooooo
F00005T0A@110580D`0002@0000O00008`000240000L0000E0000700001_0000L@0008h0001l0000
0@0003JZaD0L`<E0O08008H200060000C00000000000000000000?ooooooooooF00004`0@@1>04@0
800m01h0000S0000900002@0000=000070000580001`0@000P000<koool0000000000000002@0@00
00000000011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP000000000000000000000000000000
0000000000000000000004`0@@1>04@0800m0000001@0580A@1304T0@@1D04T0C`1>0440F01505<0
@`1502009P0P04@0@`1B0?h700010000000006TAnOkn1`00d0L00000000c5B42000007<>14/00000
hbKio_h7000400000000000000000000d0L00000000c5B42000002@J104000003H;mo_h700000000
00000040000000000@000000000@??LH000000P0000000000000000000000000000001P000000000
000000000000000000000<Z>K0000000P>PX6FAf00P000009@0000`000020000E0000700002D0000
L@000:h0001l00000@0003JZaD0L`<E0C@<008H200060000C00000000000000000000?oooooooooo
F00003<0=`0e0300<00`01T0000I00006@0001T0000I00006@0002D0000<00000@0005@000300000
0P0007`0001V0000Q`000040000fZ/E07<35@0/000360P004`0004`00000000000000000003ooooo
ooooog@0001104h0CP1E0440C00P04@0A@1@02L0CP0P04@0A@1405D0@`1D00008`0002@0000T0000
900002<0000N00003@0002@0000O0000700000P0000T00003@0002@0000O0000900002@0000Q0000
7`0001/0000@0000d0L00?<2001D0000L00004H1001l0000GP4008L000010000=Z[5@1c0aD121`00
aP8000H0001<00000000000000000000oooooooooomH0000;@0c0340>00a03P04@0001T0000I0000
6@0001T0000I0000E0000;@000020000R00005d0002C00000@0003JZaD0L`<E02`0000H3000A0000
C00000000000000000000?ooooooooooL0000580A@0P05@0@@1H0440@P1<04D0801904h0@`1?04d0
A@000240000O00003@0001l0000S0000900002<0000Q00007P0001l0000=00004@0002@0000Q0000
900002`0000O00006`000100003@1`00<`<005@0001`0000AP4008P0001N0@00T`000040000fZ/E0
7<35@48700060`001P0004`00000000000000000003ooooooooooeP0000]0340<00h03L0=00A0000
6@0001T0000I00006@0001T0001D0000U0000080002C0000@P0009h000010000=Z[5@1c0aD0;0000
AP<000`0001<00000000000000000000oooooooooomT0000B@1>04<0C`1=04D0801D0440F01505<0
4@0002@0000Q0000900002`0000O00003@0001l0000S0000900001l0000L0000E0000=`0002b0000
T`000381002N00000@0003JZaD0L`<E0m@<004H3000H0000C00000000000000000000?oooooooooo
O00005@0@@1H0200@P1B0440@`1;04D0E00m03<0=@0U0200@`1?04d0@P0P05<09P1601l0000S0000
900000d0000Q00008@0002<0000Q00008`0001l0000O0000700001T0000I0000:P0000d0000Q0000
900002`0000Q00003@0001`0000V00006`0001/0000@0000d0L007<3001D0000K00004X1002C0000
GP4009h000010000=Z[5@1c0aD1K1`00AP<000D0001<00000000000000000000oooooooooomH0000
;@0c03P0<00f00004@0001T0000I00006@0001T0000K0000400007/8001c0`00E00006@0001[0@00
T`0007`1002N00000@0003JZaD0L`<E05`P004H300040000C00000000000000000000?oooooooooo
E00003<0>00`03H06@0001T0000I00006@000580001`0@000`000<koool0000000000000002@0@00
00000000011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP000000000000000000000000000000
0000000000000000000003<0>00`03H040QO0000001;04D0E00m03<0=@0U0200@`1?04d0@P0P05<0
9P1600000000000060000000000000000000000000000000bXi/00000020j2PII7H0200000000000
hbKio_h7000400000000000000000000d0L00000000c5B420000050kmaP00000317jo_h7001@>oLH
0000004000000000>7TD:IJA000@??LH000000P00000000000000000000000000000010000000000
000000000000000000000>B@K0000000P>PX6FAf00P000009@0000`000030000600000`000000?l0
600000`0000000009@0000`000010000E00009@000020000WP0003h0002X00000@0003JZaD0L`<E0
2`0008H3000<0000C00000000000000000000?ooooooooooI0000440AP1D04D0DP0P05@0@@1H0200
@`1602<0000K00007`0001l0000Q00003@0001l0000S0000900000d0000Q00006`0001/0000@0000
N`P00;<3001D0000K00006L1002N0000O0400:P000010000=Z[5@1c0aD3n1`00QP<000D0001<0000
0000000000000000oooooooooomH0000<P0`03P0<@0b00006@0001T0000I00006@0001T0001D0000
O00008D1002N0000Z@400:P000010000=Z[5@1c0aD2/2000QP<000P0001<00000000000000000000
oooooooooomL0000=@0^03D0=00i03P0<@0U01T0000=00006@0001T0000I00006@0001T0000Z0000
DP00070100040000400000L00000000000000;`2000000000@828U<0N@1c07@0I@1]000000000000
0000000000000000000000000000000000000000000000000000000000000000=@0^03D0=00i03P0
<@0U05P0801304H043cg600000080000000000000000000000000000000@00000000000000000000
00000000003TT6`00000083X:1UTMP0800000000003S9_WnoPL000@00000000000000000003@1`00
000003<E8@800000D3_g6000000<4O[noPL0050kmaP000000@000000000hNA@YUY40010lmaP00000
2000000000000000000000000000000080000000000000000000000000000000`95/0000003`l_TH
I7H02000000U0000300000@0000X000030000040000X0000300000<0000X000030000080000R0000
30000?oooolU0000300000L0080U000030000000080`0000300000l0081;00004000000000050000
:00000`0000400003P0001@000000000400001@0
\>"], "Graphics",
 Editable->False,
 ImageSize->{569, 225},
 ImageMargins->{{332.3333333333333, 0.}, {0., 
  0.}},ExpressionUUID->"f267ac96-fe35-4a53-a189-853d7ba54d60"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Input and first year operations for sample project"
}], "FigureCaption",
 CellChangeTimes->{{3.528571309560078*^9, 3.5285713269080706`*^9}, 
   3.5409358385006475`*^9},
 TextAlignment->Center,ExpressionUUID->"81d29c6f-b0c3-4ecb-b86a-bd7d21d572ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Multi-year relationships"
}], "Section",
 CellChangeTimes->{
  3.531447172614333*^9, 3.531447225331348*^9, {3.533733822770033*^9, 
   3.5337338248301506`*^9}},ExpressionUUID->"84aeb17e-b80f-43ee-b81e-\
f6b28d02a6eb"],

Cell["\<\
For a multi-year projection we need computations spanning the years of the \
holding period.\
\>", "Text",ExpressionUUID->"34fe0024-65e9-46e7-93a6-5cbf7d2137dd"],

Cell["\<\
For instance, we need a method for expressing each end-of-year loan balance. \
Figure 4.4 displays functions that produce metrics for various years.\
\>", "Text",
 CellChangeTimes->{
  3.5284956862916746`*^9, {3.529929583053255*^9, 
   3.5299296242036085`*^9}},ExpressionUUID->"68c785ea-d1f1-46f5-88d9-\
303cf571c4db"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"bal", "[", "n_", "]"}], ":=", 
   RowBox[{
    FractionBox["ds", "12"], " ", 
    FractionBox[
     RowBox[{"1", "-", 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "i"}], ")"}], 
        RowBox[{"t", "-", 
         RowBox[{"n", "*", "12"}]}]]]}], "i"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cf", "[", "n_", "]"}], ":=", 
   RowBox[{
    RowBox[{"noi", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "g"}], ")"}], 
      RowBox[{"n", "-", "1"}]]}], "-", "ds", "-", 
    RowBox[{"yrtx", "[", "n", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"int", "[", "n_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"ds", "/.", "data"}], ")"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bal", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "-", 
      RowBox[{"bal", "[", "n", "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"netop", "[", "n_", "]"}], ":=", 
   RowBox[{"noi", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "g"}], ")"}], 
     RowBox[{"n", "-", "1"}]]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yrtx", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"noi", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "g"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], "-", 
     RowBox[{"int", "[", "n", "]"}], "-", "depn"}], ")"}], "*", 
   "txrt"}]}]}], "Input",
 CellMargins->{{161.33333333333331`, 10.}, {5., 10.}},
 CellChangeTimes->{3.5284956984593706`*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"a84575d8-7215-4473-89f2-7d6fce540706"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Multi-year relationships between the variables"
}], "FigureCaption",
 CellChangeTimes->{{3.5285715740512066`*^9, 3.528571583504747*^9}, 
   3.540935841651828*^9},
 TextAlignment->Center,ExpressionUUID->"79db8417-6cf7-4410-a5ca-571af17b71dc"]
}, Open  ]],

Cell["\<\
Below is the output of a module that produces an amortization table for the \
loan.\
\>", "Text",
 CellChangeTimes->{{3.5299296318790474`*^9, 
  3.5299296329061065`*^9}},ExpressionUUID->"835d7a33-2fe7-4734-bb3d-\
afe20912061b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Amort", "[", 
   RowBox[{
   "interestrate_", ",", " ", "payment_", ",", " ", "initialbalance_", ",", 
    " ", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "interest", ",", " ", "principal", ",", " ", "remainingLoan", ",", " ", 
      "periods"}], "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"tbl", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
        "\"\<n\>\"", ",", " ", "\"\<Payment\>\"", ",", " ", 
         "\"\<Interest\>\"", ",", " ", "\"\<Principal\>\"", ",", " ", 
         "\"\<Balance\>\""}], "}"}], "}"}]}], ";", "\n", "  ", 
     RowBox[{"remainingLoan", " ", "=", " ", "initialbalance"}], ";", "\n", 
     "  ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"interest", " ", "=", " ", 
         RowBox[{"interestrate", "*", "remainingLoan"}]}], ";", "\n", "   ", 
        RowBox[{"principal", " ", "=", " ", 
         RowBox[{"payment", " ", "-", " ", "interest"}]}], ";", "\n", "   ", 
        RowBox[{"remainingLoan", " ", "=", " ", 
         RowBox[{"remainingLoan", " ", "-", " ", "principal"}]}], ";", "\n", 
        "   ", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"tbl", ",", " ", 
          RowBox[{"{", 
           RowBox[{
           "periods", ",", " ", "payment", ",", " ", "interest", ",", " ", 
            "principal", ",", " ", "remainingLoan"}], "}"}]}], "]"}]}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"periods", ",", " ", "1", ",", " ", "n"}], "}"}]}], "]"}], 
     ";", "\n", "  ", 
     RowBox[{"TableForm", "[", "tbl", "]"}]}]}], "\n", "  ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Amort", "[", 
  RowBox[{
   RowBox[{".11", "/", "12"}], ",", 
   RowBox[{
    RowBox[{"(", 
     FractionBox[
      FractionBox[".11", "12"], 
      RowBox[{"1", "-", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[".11", "12"]}], ")"}], "360"]]}]], ")"}], " ", 
    "875000"}], ",", "875000", ",", "12"}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.520773328476245*^9, 3.5207733339125557`*^9}, {
  3.520773461972881*^9, 3.5207734657440968`*^9}, {3.5207735304667983`*^9, 
  3.5207735533271055`*^9}, {3.520773661656302*^9, 3.520773696183277*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"58f08c9f-69c7-4670-a73a-edc24e24470e"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"n\"\>", "\<\"Payment\"\>", "\<\"Interest\"\>", "\<\"Principal\"\>", \
"\<\"Balance\"\>"},
    {"1", "8332.829711407236`", "8020.833333333333`", "311.99637807390263`", 
     "874688.0036219261`"},
    {"2", "8332.829711407236`", "8017.973366534322`", "314.8563448729137`", 
     "874373.1472770531`"},
    {"3", "8332.829711407236`", "8015.087183372987`", "317.7425280342486`", 
     "874055.4047490188`"},
    {"4", "8332.829711407236`", "8012.174543532673`", "320.6551678745627`", 
     "873734.7495811443`"},
    {"5", "8332.829711407236`", "8009.2352044938225`", "323.59450691341317`", 
     "873411.1550742309`"},
    {"6", "8332.829711407236`", "8006.2689215137825`", "326.56078989345315`", 
     "873084.5942843374`"},
    {"7", "8332.829711407236`", "8003.275447606426`", "329.5542638008101`", 
     "872755.0400205365`"},
    {"8", "8332.829711407236`", "8000.254533521585`", "332.5751778856511`", 
     "872422.4648426508`"},
    {"9", "8332.829711407236`", "7997.205927724299`", "335.62378368293685`", 
     "872086.8410589679`"},
    {"10", "8332.829711407236`", "7994.129376373872`", "338.70033503336344`", 
     "871748.1407239345`"},
    {"11", "8332.829711407236`", "7991.024623302733`", "341.80508810450283`", 
     "871406.3356358301`"},
    {"12", "8332.829711407236`", "7987.891409995109`", "344.93830141212675`", 
     "871061.3973344179`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.52849571592237*^9, 3.528570575758107*^9, 
  3.528637317963543*^9, 3.5299294403090906`*^9, 3.5330636320432367`*^9, 
  3.5330658160191526`*^9, 3.533072057825164*^9, 3.533681644859375*^9, 
  3.5337336767736826`*^9, 3.53375335121875*^9, 3.539520106898861*^9, 
  3.539521118521723*^9, 3.53952130485038*^9, 3.539522424964447*^9, 
  3.5395231374631996`*^9, 3.5401252169921136`*^9, 3.5409350270392346`*^9, 
  3.540935303880069*^9, 3.540935399797555*^9, 3.540936009238413*^9, 
  3.5409375560228844`*^9, 3.540937923625143*^9, 3.5410030400025864`*^9, 
  3.5415996539357243`*^9, 3.5432391135174847`*^9, 3.696075882806506*^9, 
  3.6962290240928125`*^9, 3.6962316566895075`*^9, 3.696232174477068*^9, 
  3.7314209329812365`*^9},
 TextAlignment->Center,
 CellLabel->
  "Out[39]//TableForm=",ExpressionUUID->"8e64274b-be2e-4d1a-9050-\
a6a252b1b084"]
}, Open  ]],

Cell[TextData[{
 "The ending balance of the loan (",
 StyleBox["endbal", "Input"],
 ") is simply the balance at the end of the holding period, ",
 StyleBox["k", "Input"]
}], "Text",ExpressionUUID->"f8cd2ee7-ddad-4546-80c3-d39dea0992a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"endbal", " ", "=", 
  RowBox[{
   RowBox[{"bal", "[", "k", "]"}], "/.", "data"}]}]], "Input",
 CellMargins->{{66, 0}, {5, 10}},
 CellLabel->"In[40]:=",ExpressionUUID->"2a7dd540-50a7-41e9-9869-83bc18801339"],

Cell[BoxData["843381.1350420993`"], "Output",
 CellChangeTimes->{3.5284958062245345`*^9, 3.528570576000121*^9, 
  3.5286373179715433`*^9, 3.5299294405711055`*^9, 3.533063632708275*^9, 
  3.533072057882167*^9, 3.533681644953125*^9, 3.533733677113702*^9, 
  3.5337533513125*^9, 3.5395201075799003`*^9, 3.539521118564725*^9, 
  3.5395213099596725`*^9, 3.5395224251474576`*^9, 3.5395231375062017`*^9, 
  3.5401252179851704`*^9, 3.5409350275052614`*^9, 3.540935303940072*^9, 
  3.5409353998385572`*^9, 3.5409360092794156`*^9, 3.5409375564799104`*^9, 
  3.540937924313182*^9, 3.5410030406156216`*^9, 3.5415996544607544`*^9, 
  3.5432391142035236`*^9, 3.6960758828325925`*^9, 3.6962290241429453`*^9, 
  3.696231656715577*^9, 3.6962321745422406`*^9, 3.7314209329972787`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"33987c5d-f497-4a3f-bc09-bdac3fe59bd8"]
}, Open  ]],

Cell[TextData[{
 "We also need information about how much interest is paid each year, which \
is a function of the debt service, the beginning of year balance and the end \
of year balance on the loan.  While we are at it, we also create a table \
showing each year's interest that we name \"",
 StyleBox["intpd", "Input"],
 "\""
}], "Text",ExpressionUUID->"b831eb13-9b0d-4051-a9e2-3335f3008c18"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"intpd", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"int", "[", "n", "]"}], "/.", "data"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", 
       RowBox[{"k", "/.", "data"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "intpd", "]"}]}], "Input",
 CellMargins->{{19.333333333333332`, 10.}, {5., 10.}},
 CellChangeTimes->{{3.5219012404744616`*^9, 3.521901266338941*^9}, {
   3.521901471806693*^9, 3.521901471984703*^9}, 3.5299296642318983`*^9},
 CellLabel->"In[41]:=",ExpressionUUID->"c5a70aef-f4ec-4cfe-a657-ad58ed7e610b"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {"96055.35387130501`"},
     {"95599.5833546085`"},
     {"95091.07160414779`"},
     {"94523.71546573204`"},
     {"93890.70553527074`"},
     {"93184.44443235651`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.528495835121187*^9, 3.5285705762911377`*^9, 
  3.528637317980544*^9, 3.52992944082912*^9, 3.529929666900051*^9, 
  3.5330636332423053`*^9, 3.5330720579411707`*^9, 3.53368164503125*^9, 
  3.5337336776507325`*^9, 3.533753351390625*^9, 3.5395201082779403`*^9, 
  3.5395211186087275`*^9, 3.539521314793949*^9, 3.5395224251934605`*^9, 
  3.5395231375512047`*^9, 3.540125219854277*^9, 3.540935028058293*^9, 
  3.540935304018077*^9, 3.540935399897561*^9, 3.540936009341419*^9, 
  3.540937557114947*^9, 3.540937924917217*^9, 3.541003041270659*^9, 
  3.541599655017786*^9, 3.5432391148805623`*^9, 3.6960758828656645`*^9, 
  3.696229024206114*^9, 3.6962316568649745`*^9, 3.696232174659553*^9, 
  3.7314209330273576`*^9},
 CellLabel->
  "Out[42]//TableForm=",ExpressionUUID->"f84011aa-30d6-4bef-bb07-\
cc5ec1eca147"]
}, Open  ]],

Cell["\<\
We can \"pick out\" any specific year of interest paid, for instance here is \
year 3 interest paid.\
\>", "Text",ExpressionUUID->"daf01f6a-0db0-4736-8785-bb5527983bea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"intpd", "[", 
  RowBox[{"[", "3", "]"}], "]"}]], "Input",
 PageWidth->PaperWidth,
 CellLabel->"In[43]:=",ExpressionUUID->"ac0ee380-17e5-4446-a581-69f54532e936"],

Cell[BoxData["95091.07160414779`"], "Output",
 CellChangeTimes->{3.5284958649168916`*^9, 3.528496398056385*^9, 
  3.5285705766081557`*^9, 3.5286373179885445`*^9, 3.529929441089135*^9, 
  3.5330636336873302`*^9, 3.5330720579991736`*^9, 3.533681645125*^9, 
  3.533733678112759*^9, 3.53375335146875*^9, 3.539520108927977*^9, 
  3.5395211186517305`*^9, 3.5395213189451866`*^9, 3.5395224252364626`*^9, 
  3.5395231375932074`*^9, 3.5401252208273325`*^9, 3.540935028671328*^9, 
  3.540935304094081*^9, 3.5409353999575644`*^9, 3.540936009400422*^9, 
  3.540937557603975*^9, 3.54093792550325*^9, 3.54100304216471*^9, 
  3.5415996555008135`*^9, 3.5432391154615955`*^9, 3.6960758828967466`*^9, 
  3.6962290242692823`*^9, 3.6962316569321527`*^9, 3.6962321747146997`*^9, 
  3.731420933055448*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"990b6772-bbc1-4b13-bee7-e579147c0bea"]
}, Open  ]],

Cell[TextData[{
 "We often assume that income grows by some rate over the holding period.  \
Here, for simplicity, we assume the unlikely case of monotonic growth in a \
fixed unchanging percentage each year.  \"",
 StyleBox["netop", "Input"],
 "\" calculates the NOI for any specific year, ",
 StyleBox["n",
  FontSlant->"Italic"],
 ", of the holding period.  Notice that ",
 StyleBox["netop", "Input"],
 " is a function not a variable name. A function is indicated by [",
 StyleBox["var_ ", "Input"],
 "] where ",
 StyleBox["var", "Input"],
 " is the variable upon which the function is dependent for its value. We \
cannot use the name \"",
 StyleBox["noi", "Input"],
 "\" because it is already in use as a variable name for occasions when we \
wish to use it in a dataset. ",
 StyleBox["netop[k]", "Input"],
 " is the net operating income for year ",
 StyleBox["k", "Input"],
 ", the final year."
}], "Text",
 CellChangeTimes->{
  3.528498387187157*^9},ExpressionUUID->"9d92a758-8c0c-41e7-9c2f-\
2c8ae90ebe24"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"netop", "[", "k", "]"}], "/.", "data"}]], "Input",
 CellChangeTimes->{{3.5219012783746295`*^9, 3.521901282311855*^9}, {
  3.5219014647582903`*^9, 3.5219014649483013`*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"b8c07901-cde4-47c3-b33c-873e7536cc8e"],

Cell[BoxData["135635.06669309997`"], "Output",
 CellChangeTimes->{3.528498392188443*^9, 3.5285705769511757`*^9, 
  3.528637317996545*^9, 3.529929441418154*^9, 3.5330636340353503`*^9, 
  3.5330720580571766`*^9, 3.533681645421875*^9, 3.5337336785767856`*^9, 
  3.5337533515625*^9, 3.5395201094020042`*^9, 3.5395211186937323`*^9, 
  3.539521322624397*^9, 3.539522425280465*^9, 3.53952313763721*^9, 
  3.5401252220174007`*^9, 3.540935029358367*^9, 3.5409353041520844`*^9, 
  3.5409353999985666`*^9, 3.540936009441425*^9, 3.540937558270013*^9, 
  3.5409379260132794`*^9, 3.5410030428367486`*^9, 3.541599656026844*^9, 
  3.5432391159506235`*^9, 3.696075882912792*^9, 3.6962290243264575`*^9, 
  3.6962316570013375`*^9, 3.6962321747578144`*^9, 3.731420933823476*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"b6253fe5-fbe7-4ce3-b8b3-4f31e0fc0f8b"]
}, Open  ]],

Cell[TextData[{
 "A multi-period projection requires variables whose values change over the \
holding period. If, as we do here, the change in value is simple compounded \
annual growth, the convention is to compound the value from the day of \
purchase.  Compounding of cash flows, however, is offset one year.  The idea \
is that an investor on January 1 makes a decision to purchase based on his \
expectation of the income to be received at the end of the year. Thus, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["cf", 
     RowBox[{"1", " "}]],
    FontWeight->"Plain",
    FontSlant->"Italic"], TraditionalForm]], "Input",ExpressionUUID->
  "1b950993-9eab-4027-ab48-3372e44c7f12"],
 " is the initial cash flow to be received at the end of year one. The first \
year of compounding is 12 months later at the end of year two, hence only ",
 StyleBox["n",
  FontSlant->"Italic"],
 "-1 years of ",
 StyleBox["compounded",
  FontSlant->"Italic"],
 " ",
 StyleBox["cash flows",
  FontSlant->"Italic"],
 " occur during the investor's holding period.  This has repercussions when \
considering the equity reversion at the time of sale.Value compounds for the \
full ",
 StyleBox["n",
  FontSlant->"Italic"],
 " periods.  The rationale is that at the time of sale, the next investor \
anticipates the end-of-year income (to be received 12 months after his \
acquisition) in making his acquisition decision.  So the first investor \
collects the first cash flow without any compounding and ",
 StyleBox["n",
  FontSlant->"Italic"],
 "-1 years of compounded cash flows but receives the benefit of ",
 StyleBox["n",
  FontSlant->"Italic"],
 " years of compounded cash flow because he prices the property for sale on \
the basis of ",
 StyleBox["n",
  FontSlant->"Italic"],
 " compounded cash flows. Figure 4.5 displays the sample project in \
spreadsheet form, having used the equations shown in Figure 4.4 with the \
input data from Table 4.1."
}], "Text",
 CellChangeTimes->{{3.528571656568926*^9, 3.5285717018205147`*^9}, {
  3.5409363435625353`*^9, 
  3.5409363435635357`*^9}},ExpressionUUID->"1488cbf9-8c65-487d-8672-\
7b1fd0e48ab1"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0006N80@0006`000000000000009P3003g0@00
00000000003EOP00N4D00215CDH00040R6L001P200050000000000000000000000@00003001Y0@00
3`40000000000000000001b31@1E8P@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0900`000000000940100`000000000
<4020100000400000020?b501`0<0000000000A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P000240000800008P0000`0003ooooo8@0000P0000R0000
30000?ooool:000040000000000000008@0000P0000I000030000?ooo`0H000030000000000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H000000000000002I0`00
n0400280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P000000000
000009T3003h0@008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
6000004000010000V@<00?P1000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00000@000040002I0`00n0400280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000100000@0009T3003h0@009`0001P0000100000000002000000000
9@0000`000010000600000`00000P0006@0000`00000P000500000`0000=00004P0000`000020000
9P0001`0000200000000000000000000080002D0000<00000P0001/0000@0000E0400=80000f0000
400005T1003B00009@0000`000070020C00006@0001D0@00dP0005P1003B0000E0400=8000050000
0@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00000P0001/0000@0000E0400=<0000f0000400005P1003C00009@0000`000070020
C00006@0001D0@00d`0005L1003C0000E0400=<0000400000@000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00000P0001/0000@0000
E0400=@0000f0000400005L1003D00009@0000`000070020C00006@0001D0@00e00005H1003D0000
E0400=@0000300000@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000P0001/0000@0000E0400=D0000f0000400005H1003E0000
9@0000`000070020C00006@0001D0@00e@0005D1003E0000E0400=D0000200000@000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
0P0001/0000@0000E0400=H0000f0000400005D1003F00009@0000`000070020C00006@0001D0@00
eP0005@1003F0000E0400=H0000100000@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00001000P2P0000<00000@000580001`0@00
0@000?3oool0000000000000002@0@0000000000029806D0K01f0000000000000000000000000000
000000000000000000000000000000000000000000000000001H1X3JQ@1hN8H000010<PkF0H00@00
/7R600000038>EP60@00000e?P0]OVUdV1/1ac00000`00002P0000X000100nD22P0007QhQP100nD2
ND[ZMB`e?P0:00000@0007QhQP0/=Ch0llQYM801KWBW5Kl_>@0009PK0LL003h0E<UYM9PK0LL`0000
>@0000800028=Sh0Y3Dn06?Y56BH6`77<00003T00028=Sh077WZ0YPK0LO0lGP30000030g?P010000
000000000001000086T7I5f>a_T00000000004L00016000000WZ0P09jP;<=Ch0=>TDI6Af00P00000
9@0000`000010000600000`0000000006@0000`0003oool04P0000`000010000E0000=00000n0000
2@000?l0000L00000@0000043D9E9@e2?P0000T0000F0000C00000000000000000000?oooooooooo
N0000480A@1704T0CP1>04T0CP170200C`160200F@150440DP0P02d0;@0]03h02`0000/0000=0000
1@0000/0000;00001@0000/0000=0000100000`0000:0000100000/0000;00002`0000`000040000
1@0000D0000500002@000580001`0@000`000>Soool0000000000000002@0@000000000000110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
001H1X3JQ@2X?5P600010<QkF0H00@00h3aH1P000038NEP600000=Pe?P0]OVUdV1/1ac00000`0000
2P0000X000100nD22P000:PlF0I00nD2ND[ZM@@f?P0:00000@000:PlF0H4=Sh0llQYM801KWBW5Kl_
>@0009PK0LL003h0E<UYM9PK0LL`0000>@000080001P=ch0O3Hn06?Y56BH6`77<00003T0001P=ch0
77WZ0YPK0LL00000000000Ph?P0100000000000000010000000000000000000000000;n@a?UT=ch0
7`0006Q1^@>T=Sh0=>TDI6Af00P000009@0000`0000300006`000100000^0@006@0005@0001D0000
8@4000@0000]0@007P000040000010e2EBD=@R41000400000@0004`00000000000000000003ooooo
oooooe00000a00003@0001/0000@0000OP4001T0001D0000E000074100040000O@4001h000010000
00@=@UDU3D9a0@0010000040001<00000000000000000000oooooooooom@0000<P0000d0000K0000
40000<h1000I0000E00005@000310@0010000<d1000N00000@0000043D9E9@e2`@4000@000010000
C00000000000000000000?ooooooooooD00003<0000=00006`000100000N0P006@0005@0001D0000
4@8000@0000M0P007P000040000010e2EBD=@Q42000400000@0004`00000000000000000003ooooo
oooooe00000d00003@0001/0000@0000KP8001T0001D0000E000064200040000K@8001h000010000
00@=@UDU3D9Q0P0010000040001<00000000000000000000oooooooooom@0000=@0000d0000K0000
40000;h2000I0000E00005@0002a0P0010000;d2000N00000@0000043D9E9@e2/@8000@000010000
C00000000000000000000?ooooooooooD00003H0000=00006`000100000C0`006@0005@0001D0000
1P<000@0000B0`007P000040000010e2EBD=@PH3000400000@0004`00000000000000000003ooooo
oooooe00000g00003@0001/0000@0000KP<001T0001D0000E000064300040000K@<001h000010000
00@=@UDU3D9Q0`0010000040001<00000000000000000000oooooooooom@0000>00000d0000U0000
30000040001D0000[00007L0000X0000o`0003/00001000000@=@UDU3D9g0000:0000100001<0000
0000000000000000oooooooooom/0000A@1>04@0801?04H0801I04D0@@1B0200;@0]02d0?P0;0000
2`0000`000040000300000X0000400002`0000/0000;0000300000@0000500001@0000D000090000
9@0000`0000300006`000100000^0@00>00005@0001D00008@4002<0000]0@00?@000040000010e2
EBD=@R41000S00000@0004`00000000000000000003ooooooooooe00000`00003@0001/0000@0000
OP4003P0001D0000E0000741000S0000O@4003d00001000000@=@UDU3D9a0@008`000040001<0000
0000000000000000oooooooooom@0000<@0000d0000K000040000<h1000h0000E00005@000310@00
8`000<d1000m00000@0000043D9E9@e2`@4002<000010000C00000000000000000000?oooooooooo
D0000380000=00006`000100000N0P00>00005@0001D00004@8002<0000M0P00?@000040000010e2
EBD=@Q42000S00000@0004`00000000000000000003ooooooooooe00000c00003@0001/0000@0000
KP8003P0001D0000E0000642000S0000K@8003d00001000000@=@UDU3D9Q0P008`000040001<0000
0000000000000000oooooooooom@0000=00000d0000K000040000;h2000h0000E00005@0002a0P00
8`000;d2000m00000@0000043D9E9@e2/@8002<000010000C00000000000000000000?oooooooooo
D00003D0000=00006`000100000C0`00>00005@0001D00001P<002<0000B0`00?@000040000010e2
EBD=@PH3000S00000@0004`00000000000000000003ooooooooooe00000f00003@0001/0000@0000
KP<003P0001D0000E0000643000S0000K@<003d00001000000@=@UDU3D9Q0`008`000040001<0000
0000000000000000oooooooooom@0000=`0000d0000U000030000040001D0000K00000@0000o0000
>@0005800001000000@=@UDU3D840000?`0000D0001<00000000000000000000oooooooooomH0000
EP1104`0E@1500002`0000/000090000300000/0000K0000400004/1001?0000E00007P0000<0@00
?`0004X1001B00000@0000043D9E9@e2304003l000070000C00000000000000000000?oooooooooo
G0000340<P0e0300<00`0300000900002@0000T0000900002@0000T0000900006`000100002K0@00
C`0005@0001h0000G04003l0002J0@00DP000040000010e2EBD=@U`1000o00001`0004`000000000
00000000003ooooooooooe`0000a0380>00g03D0<00`00002@0000T0000900002@0000T000090000
2@0001/0000@0000j`4004l0001D0000N0000:`1000o0000jP4005800001000000@=@UDU3D:/0@00
?`0000L0001<00000000000000000000oooooooooomL0000<@0c0380=P0a0380=@0000T000090000
2@0000T0000900002@0000T0000K0000400003/2001?0000E00007P0003l0@00?`0003X2001B0000
0@0000043D9E9@e2o04003l000070000C00000000000000000000?ooooooooooG0000340<`0f03D0
>@0`03T0000900002@0000T0000900002@0000T0000900006`000100002;0P00C`0005@0001h0000
C08003l0002:0P00DP000040000010e2EBD=@T`2000o00001`0004`00000000000000000003ooooo
oooooe`0000a03@0<00f03P0>00f00002@0000T0000900002@0000T0000900002@0001/0000@0000
f`8004l0001D0000N00009`2000o0000fP8005800001000000@=@UDU3D:L0P00?`0000L0001<0000
0000000000000000oooooooooomL0000<@0d03@0>@0`03T0<`0000T0000900002@0000T000090000
2@0000T0000K0000400003D3001?0000E00007P0003f0P00?`0003@3001B00000@0000043D9E9@e2
mP8003l000070000C00000000000000000000?ooooooooooG0000340=00i0380=@0f03D000090000
2@0000T0000900002@0000T0000900006`000100002@0`00C`0005@0001h0000D@<003l0002?0`00
DP000040000010e2EBD=@U43000o00001`0004`00000000000000000003ooooooooooe`0000a03D0
<`0g03<0=00b00002@0000T0000900002@0000T0000900002@0005@0001/0000100005@0000i0000
I`000040000010e2EBD=@P@0001D00001@0004`00000000000000000003ooooooooooeP0001<04l0
@@1>05<000090000300000/0000;00002`0001/0000@0000B`4006@0001D0000L00001D1001D0000
BP4006L00001000000@=@UDU3D8E0@00E00000H0001<00000000000000000000oooooooooomH0000
>00g03D0<00`03002@0000T0000900002@0000T0000900006`000100002K0@00I00005@0001`0000
I@4005@0002J0@00I`000040000010e2EBD=@VD1001D00001P0004`00000000000000000003ooooo
oooooeP0000h03L0<@0`03H0<@0900002@0000T0000900002@0000T0000K000040000>/1001T0000
E0000700002e0@00E0000>X1001W00000@0000043D9E9@e2]@4005@000060000C000000000000000
00000?ooooooooooF00003P0=P0f03H0=P0g00T0000900002@0000T0000900002@0001/0000@0000
>`8006@0001D0000L00000D2001D0000>P8006L00001000000@=@UDU3D850P00E00000H0001<0000
0000000000000000oooooooooomH0000>00f0340=`0f03@02@0000T0000900002@0000T000090000
6`000100002;0P00I00005@0001`0000E@8005@0002:0P00I`000040000010e2EBD=@UD2001D0000
1P0004`00000000000000000003ooooooooooeP0000h03D0=P0b03T0=00900002@0000T000090000
2@0000T0000K000040000=/2001T0000E0000700002U0P00E0000=X2001W00000@0000043D9E9@e2
Y@8005@000060000C00000000000000000000?ooooooooooF00003P0=@0`0340>@0a00T000090000
2@0000T0000900002@0001/0000@0000=@<006@0001D0000L0000?l2001D0000=0<006L000010000
00@=@UDU3D;o0P00E00000H0001<00000000000000000000oooooooooomH0000>00d03<0<`0h0340
2@0000T0000900002@0000T0000900006`000100002@0`00I00005@0001`0000FP<005@0002?0`00
I`000040000010e2EBD=@UX3001D00001P0004`00000000000000000003ooooooooooeP0000h03<0
=@0g03P0=00900002@0000T0000900002@0000T0001D0000L00000@0001Y0000?`0007`000010000
00@=@UDU3D840000J@0000H0001<00000000000000000000oooooooooomH0000A@1A05D0B@1D05T0
2`0000`0000<00001@0000T0000;00006`000100001;0@00N@0005@0001`00005@4006T0001:0@00
O0000040000010e2EBD=@QD1001Y00001P0004`00000000000000000003ooooooooooeP0000c03L0
=@0`0300<00900002@0000T0000900002@0000T0000K0000400009/1001i0000E0000700001U0@00
J@0009X1001l00000@0000043D9E9@e2I@4006T000060000C00000000000000000000?oooooooooo
F00003@0<@0f03@0<`0i00T0000900002@0000T0000900002@0001/0000@0000j`4007T0001D0000
L0000;D1001Y0000jP4007`00001000000@=@UDU3D:e0@00J@0000H0001<00000000000000000000
oooooooooomH0000=00e03T0=00e03P02@0000T0000900002@0000T0000900006`000100000k0P00
N@0005@0001`00001@8006T0000j0P00O0000040000010e2EBD=@PD2001Y00001P0004`000000000
00000000003ooooooooooeP0000e0300=00a03@0=@0900002@0000T0000900002@0000T0000K0000
400008/2001i0000E0000700001E0P00J@0008X2001l00000@0000043D9E9@e2E@8006T000060000
C00000000000000000000?ooooooooooF00003D0=@0`03D0>@0b00T0000900002@0000T000090000
2@0001/0000@0000f`8007T0001D0000L0000:D2001Y0000fP8007`00001000000@=@UDU3D:U0P00
J@0000H0001<00000000000000000000oooooooooomH0000=@0i03P0>@0`03802@0000T000090000
2@0000T0000900006`000100000e0`00N@0005@0001`0000o`8006T0000d0`00O0000040000010e2
EBD=@_l2001Y00001P0004`00000000000000000003ooooooooooeP0000f03@0>@0a03P0=0090000
2@0000T0000900002@0000T0000K000040000903001i0000E0000700001J0`00J@0008l3001l0000
0@0000043D9E9@e2FP<006T000060000C00000000000000000000?ooooooooooF00003L0<00a03D0
=@0i00T0000900002@0000T0000900002@0005@0002h0000100009<0002n0000YP000040000010e2
EBD=@P@0002C00004P0004`00000000000000000003oooooooooog0000170580C`1C05<0801C04<0
B01504@0801904h0@`1?04d0A@0=0000300000`0000;00002`0000@0000;00002`0000`0000;0000
300000@0000500002`0000/0000<00003@0000/0000K0000400009/1002S0000E0000700001U0@00
T`0009X1002V00000@0000043D9E9@e2I@4009<000060000C00000000000000000000?oooooooooo
F0000380<00`0300<00`00T0000900002@0000T0000900002@0005@0003X000010000:P0003l0000
^`000040000010e2EBD=@P@0002X00006P0004`00000000000000000003ooooooooooh00001<04D0
D`1C03X0EP1104<0@@1>04<0F@0P02H080130580A@1404T0E00P04`0C`1C05<02@0000/0000;0000
2`0000@0000;00002`0000/0000;00002`0000/0000;0000100000/0000400002`0000`0000;0000
300000D000090000100000T0000<00002`0000/0000K0000400009/1002h0000E00006`0001^0@00
Z00009X1002k00000@0000043D9E9@e2KP400:P000050000C00000000000000000000?oooooooooo
F0000380<00`0300<01`I@T0000900002@0000T000090000E0000=0000040000_@000=h0003@0000
0@0000043D9E9@e210000;d0000F0000C00000000000000000000?ooooooooooN00004D0AP1604D0
@`1D04T0EP150200A`1B04l0D`1C0200B@1>04<0C`1=04D02`0000X0000:00002`0000/000090000
1@0000/0000;0000100000d0000<0000300000/0000;0000100000D0000;00002`0000`0000=0000
2`0001/0000@0000V`400<d0001D0000L00006D1002m0000VP400=000001000000@=@UDU3D9U0@00
_@0000H0001<00000000000000000000oooooooooomH0000<@0h0300<00`03002@0000T000090000
2@0000T000090000E0000:0000040000dP0008`0003U00000@0000043D9E9@e210000=80000>0000
C00000000000000000000?ooooooooooJ00004`0A@1C05<0>P0P04D0F01@04D0CP1C04D0D`090000
2`0000/0000;0000100000@0000;00002`0000X0000;00002`0000/0000;00002`0001/0000@0000
V`400>80001D0000K00006h1003B0000VP400>D00001000000@=@UDU3D9^0@00dP0000D0001<0000
0000000000000000oooooooooomH0000=P0c0300<00`06hP2@0000T0000900002@0000T0001D0000
a00000@0003W0000a`000?X00001000000@=@UDU3D840000i`0001@0001<00000000000000000000
oooooooooomd0000CP1505@0801?0500A@1B0440E01904h0A`0P04T0CP1304l0C@1500/0000;0000
2@0000@0000<00002P0000/0000<00002`0000T0000500002`0000d0000400001@0000/0000;0000
300000d0000;00006`000100002K0@00m`0005@0001`0000I@400>L0002J0@00nP000040000010e2
EBD=@VD1003W00001P0004`00000000000000000003ooooooooooeP0000a0340=`0`0300<0090000
2@0000T0000900002@0000T0000K000040000>/1003g0000E0000700002e0@00i`000>X1003j0000
0@0000043D9E9@e2]@400>L000060000C00000000000000000000?ooooooooooF0000340<P0`03D0
<@0`00T0000900002@0000T0000900002@0001/0000@0000>`800?L0001D0000L00000D2003W0000
>P800?X00001000000@=@UDU3D850P00i`0000H0001<00000000000000000000oooooooooomH0000
<@0b03@0<@0b03D02@0000T0000900002@0000T0000900006`000100002;0P00m`0005@0001`0000
E@800>L0002:0P00nP000040000010e2EBD=@UD2003W00001P0004`00000000000000000003ooooo
oooooeP0000a0380=`0h03@0>@0900002@0000T0000900002@0000T0000K000040000=/2003g0000
E0000700002U0P00i`000=X2003j00000@0000043D9E9@e2Y@800>L000060000C000000000000000
00000?ooooooooooF0000340<`0a03H0>00e00T0000900002@0000T0000900002@0001/0000@0000
=@<00?L0001D0000L0000?l2003W0000=0<00?X00001000000@=@UDU3D;o0P00i`0000H0001<0000
0000000000000000oooooooooomH0000<@0c03D0=P0c03D02@0000T0000900002@0000T000090000
6`000100002@0`00m`0005@0001`0000FP<00>L0002?0`00nP000040000010e2EBD=@UX3003W0000
1P0004`00000000000000000003ooooooooooeP0000a03<0>@0g0300=00900002@0000T000090000
2@0000T0001D0000`00000@0003l0000/`0000l10001000000@=@UDU3D840000o00001<0001<0000
0000000000000000oooooooooomd0000@`110500B@1D0440C01905X0@@1D04T0C`1>0200DP1105@0
A@1>;P/0000;00002P0000D0000900002`0000T0000500002P0000/0000900001@0000`0000;0000
100000`0000;00002@0000/0001D0000K00007<1003l0000W`4000l10001000000@=@UDU3D9c0@00
o00000D0001<00000000000000000000oooooooooomH0000>@0^03<0=P0U028n2@0000@000090000
2@0000h0001D0000K0000<<1003l0000k`4000l10001000000@=@UDU3D;30@00o00000D0001<0000
0000000000000000oooooooooomH0000>@0^03<0=P0U07QD2@0000@0000900002@0000h0001D0000
K00001<2003l0000?`8000l10001000000@=@UDU3D8C0P00o00000D0001<00000000000000000000
oooooooooomH0000>@0^03<0=P0U06Uc2@0000@0000900002@0000h0001D0000K00006<2003l0000
S`8000l10001000000@=@UDU3D9S0P00o00000D0001<00000000000000000000oooooooooomH0000
>@0^03<0=P0U06DP2@0000@0000900002@0000h0001D0000K0000;<2003l0000g`8000l100010000
00@=@UDU3D:c0P00o00000D0001<00000000000000000000oooooooooomH0000>@0^03<0=P0U06Mb
2@0000@0000900002@0000h0001D0000K00000d3003l0000>@<000l10001000000@=@UDU3D8=0`00
o00000D0001<00000000000000000000oooooooooomH0000>@0^03<0=P0U0>032@0000@000090000
2@0000h0001D0000K00006P3003l0000U0<000l10001000000@=@UDU3D9X0`00o00000D0001<0000
0000000000000000oooooooooomH0000>@0^03<0=P0U00002@0000@0000900002@0000h0001D0000
a00000@0000V0@00a`0003T10001000000@=@UDU3D8400009P4001@0001<00000000000000000000
oooooooooomd0000CP1505@0801?0500A@1B0440E01904h0A`0P04T0CP1304l0C@1500/0000;0000
2@0000@0000<00002P0000/0000<00002`0000T0000500002`0000d0000400001@0000/0000;0000
300000d0000;00006`000100002K0@00=P4005@0001`0000I@4002H1002J0@00>@400040000010e2
EBD=@VD1000V0@001P0004`00000000000000000003ooooooooooeP0000a0340=`0`0300<0090000
2@0000T0000900002@0000T0000K000040000>/1000f0@00E0000700002e0@009P400>X1000i0@00
0@0000043D9E9@e2]@4002H100060000C00000000000000000000?ooooooooooF0000340<P0`03D0
<@0`00T0000900002@0000T0000900002@0001/0000@0000>`8003H1001D0000L00000D2000V0@00
>P8003T10001000000@=@UDU3D850P009P4000H0001<00000000000000000000oooooooooomH0000
<@0b03@0<@0b03D02@0000T0000900002@0000T0000900006`000100002;0P00=P4005@0001`0000
E@8002H1002:0P00>@400040000010e2EBD=@UD2000V0@001P0004`00000000000000000003ooooo
oooooeP0000a0380=`0h03@0>@0900002@0000T0000900002@0000T0000K000040000=/2000f0@00
E0000700002U0P009P400=X2000i0@000@0000043D9E9@e2Y@8002H100060000C000000000000000
00000?ooooooooooF0000340<`0a03H0>00e00T0000900002@0000T0000900002@0001/0000@0000
=@<003H1001D0000L0000?l2000V0@00=0<003T10001000000@=@UDU3D;o0P009P4000H0001<0000
0000000000000000oooooooooomH0000<@0c03D0=P0c03D02@0000T0000900002@0000T000090000
6`000100002@0`00=P4005@0001`0000FP<002H1002?0`00>@400040000010e2EBD=@UX3000V0@00
1P0004`00000000000000000003ooooooooooeP0000a03<0>@0g0300=00900002@0000T000090000
2@0000T0001D0000`00000@0000k0@00/`0004h10001000000@=@UDU3D840000>`4001<0001<0000
0000000000000000oooooooooomd0000C01505<0D`0j0200B@1>05@0A@1B04D0D`1D0200D01=05@0
D`0000T0000;00002`0000/000040000100000D0000;00002@0000/0000<00002`0000/000090000
100000X0000=00002@0000/0000K0000400009/1001;0@00E00006`0001^0@00>`4009X1001>0@00
0@0000043D9E9@e2KP4003/100050000C00000000000000000000?ooooooooooF00003T0=P0`03D0
=@0000T0000900002@0000T0000900006`000100003[0@00B`4005@0001/0000_P4003/1003Z0@00
CP400040000010e2EBD=@[h1000k0@001@0004`00000000000000000003ooooooooooeP0000i03D0
=P0`0300000900002@0000T0000900002@0001/0000@0000>`8004/1001D0000K00000h2000k0@00
>P8004h10001000000@=@UDU3D8>0P00>`4000D0001<00000000000000000000oooooooooomH0000
>@0e0300>@0a00002@0000T0000900002@0000T0000K0000400008/2001;0@00E00006`0001N0P00
>`4008X2001>0@000@0000043D9E9@e2GP8003/100050000C00000000000000000000?oooooooooo
F00003T0=00e0380=00000T0000900002@0000T0000900006`000100003K0P00B`4005@0001/0000
[P8003/1003J0P00CP400040000010e2EBD=@Zh2000k0@001@0004`00000000000000000003ooooo
oooooeP0000i03<0>00i0340000900002@0000T0000900002@0001/0000@0000=@<004/1001D0000
K00000P3000k0@00=0<004h10001000000@=@UDU3D880`00>`4000D0001<00000000000000000000
oooooooooomH0000>@0c0340>00d00002@0000T0000900002@0000T0000K000040000903001;0@00
E00006`0001S0`00>`4008l3001>0@000@0000043D9E9@e2H`<003/100050000C000000000000000
00000?ooooooooooF00003T0<P0c03T0=P0000T0000900002@0000T000090000E0000;P000040000
D0400:d0001S0@000@0000043D9E9@e210000501000B0000C00000000000000000000?oooooooooo
L00004`0A@1C05<0>P0P04@0A@1@0580A@1304T0@@1D04T0C`1>00T0000;00002`0000/000040000
100000`0000;00002P0000`0000;00002`0000D0000;00002@0000D0000<00002`0001/0000@0000
V`400601001D0000K00006h1001@0@00VP4006<10001000000@=@UDU3D9^0@00D04000D0001<0000
0000000000000000oooooooooomH0000<`0a03P0<@0h00002@0000T0000900002@0000T0000K0000
40000>/1001P0@00E00006`0002n0@00D0400>X1001S0@000@0000043D9E9@e2_P40050100050000
C00000000000000000000?ooooooooooF00003<0<@0h0340>00000T0000900002@0000T000090000
6`000100000k0P00H04005@0001/00003P800501000j0P00H`400040000010e2EBD=@Ph2001@0@00
1@0004`00000000000000000003ooooooooooeP0000c0340>00a03P0000900002@0000T000090000
2@0001/0000@0000R`800601001D0000K00005h2001@0@00RP8006<10001000000@=@UDU3D9N0P00
D04000D0001<00000000000000000000oooooooooomH0000<`0a03P0<@0h00002@0000T000090000
2@0000T0000K000040000=/2001P0@00E00006`0002^0P00D0400=X2001S0@000@0000043D9E9@e2
[P80050100050000C00000000000000000000?ooooooooooF00003<0<@0h0340>00000T000090000
2@0000T0000900006`000100000e0`00H04005@0001/000020<00501000d0`00H`400040000010e2
EBD=@PP3001@0@001@0004`00000000000000000003ooooooooooeP0000c0340>00a03P000090000
2@0000T0000900002@0001/0000@0000T0<00601001D0000K00006<3001@0@00S`<006<100010000
00@=@UDU3D9S0`00D04000D0001<00000000000000000000oooooooooomH0000<`0a03P0<@0h0000
2@0000T0000900002@0000T0001D0000]00000@0001U0@00ZP0007P10001000000@=@UDU3D840000
I@400140001<00000000000000000000oooooooooom`0000DP150200E01105P0@@1204`0A@0P04T0
CP1304l0C@150000300000/0000400002@0000/0000;00002`0000/0000900002`0000@000050000
2`0000/0000<00003@0000/0000K0000400009/1001e0@00E0000700001Y0@00I@4009X1001h0@00
0@0000043D9E9@e2J@4006D100060000C00000000000000000000?ooooooooooF00002d0<@0`03P0
=`0d00D0000900002@0000T0000900002@0001/0000@0000j`4007D1001D0000K0000<81001U0@00
jP4007P10001000000@=@UDU3D;20@00I@4000D0001<00000000000000000000oooooooooomH0000
;@0f03T0<00h00001@0000T0000900002@0000T0000K0000400003/2001e0@00E00006`0000B0P00
I@4003X2001h0@000@0000043D9E9@e24P8006D100050000C00000000000000000000?oooooooooo
F00002d0<P0g03P0=00000D0000900002@0000T0000900006`000100002;0P00M@4005@0001T0000
I`8006D1002:0P00N0400040000010e2EBD=@VL2001U0@00100004`00000000000000000003ooooo
oooooe@0000a03D0<00g00T0000900002@0000T0000K000040000=/2001e0@00E00006@0002g0P00
I@400=X2001h0@000@0000043D9E9@e2]`8006D100040000C00000000000000000000?oooooooooo
E00003D0>@0g03H02@0000T0000900002@0001/0000@0000=@<007D1001D0000K00000P3001U0@00
=0<007P10001000000@=@UDU3D880`00I@4000D0001<00000000000000000000oooooooooomH0000
<@0`03H0<`0b00002@0000T0000900002@0000T0000K000040000903001e0@00E00006`0001S0`00
I@4008l3001h0@000@0000043D9E9@e2H`<006D100050000C00000000000000000000?oooooooooo
F0000340=@0d03P0>@0000T0000900002@0000T000090000E0000<@000040000S`400<L0002R0@00
0@0000043D9E9@e2100008l1000D0000C00000000000000000000?ooooooooooM00004h0A@1D0200
C`1@04D0DP1105@0B@1>04L0801904h0@`1?04d0A@0;00002`0000T000040000300000X0000;0000
300000/0000900001@0000/0000=0000100000D0000;00002`0000`0000=00002`0001/0000@0000
V`4009l1001D0000L00006D1002?0@00VP400:810001000000@=@UDU3D9U0@00S`4000H0001<0000
0000000000000000oooooooooomH0000<@0a03L0<00`03002@0000T0000900002@0000T000090000
6`000100003[0@00W`4005@0001`0000]@4008l1003Z0@00XP400040000010e2EBD=@[D1002?0@00
1P0004`00000000000000000003ooooooooooeP0000a0380<00e0340<00900002@0000T000090000
2@0000T0000K0000400003/2002O0@00E000070000050P00S`4003X2002R0@000@0000043D9E9@e2
1@8008l100060000C00000000000000000000?ooooooooooF0000340<P0d0340<P0e00T000090000
2@0000T0000900002@0001/0000@0000R`8009l1001D0000L00005D2002?0@00RP800:8100010000
00@=@UDU3D9E0P00S`4000H0001<00000000000000000000oooooooooomH0000<@0b03L0>00d03T0
2@0000T0000900002@0000T0000900006`000100003K0P00W`4005@0001`0000Y@8008l1003J0P00
XP400040000010e2EBD=@ZD2002?0@001P0004`00000000000000000003ooooooooooeP0000a03<0
<@0f03P0=@0900002@0000T0000900002@0000T0000K0000400003D3002O0@00E0000700003o0P00
S`4003@3002R0@000@0000043D9E9@e2o`8008l100060000C00000000000000000000?oooooooooo
F0000340<`0e03H0<`0e00T0000900002@0000T0000900002@0001/0000@0000T0<009l1001D0000
L00005X3002?0@00S`<00:810001000000@=@UDU3D9J0`00S`4000H0001<00000000000000000000
oooooooooomH0000<@0c03T0=`0`03@02@0000T0000900002@0000T000090000E0000<0000040000
Y0400:h0002g0@000@0000043D9E9@e210000:@1000C0000C00000000000000000000?oooooooooo
M00004`0A@1C05<0>P0P05@0C`1D0440C00P04`0CP0P0500C@1D05<0000900002`0000/0000;0000
100000@000090000300000T0000;00002@0000@0000900002`0000@0000:00003@0000T0000;0000
6`000100002K0@00]04005@0001/0000KP400:@1002J0@00]`400040000010e2EBD=@Vh1002T0@00
1@0004`00000000000000000003ooooooooooeP0000i03T0>@0i03@0000900002@0000T000090000
2@0001/0000@0000j`400;@1001D0000K0000;h1002T0@00jP400;L10001000000@=@UDU3D:n0@00
Y04000D0001<00000000000000000000oooooooooomH0000>@0i03T0>@0d00002@0000T000090000
2@0000T0000K0000400003/2002d0@00E00006`0000>0P00Y04003X2002g0@000@0000043D9E9@e2
3P800:@100050000C00000000000000000000?ooooooooooF00003T0>@0i03T0=00000T000090000
2@0000T0000900006`000100002;0P00]04005@0001/0000GP800:@1002:0P00]`400040000010e2
EBD=@Uh2002T0@001@0004`00000000000000000003ooooooooooeP0000i03T0>@0i03@000090000
2@0000T0000900002@0001/0000@0000f`800;@1001D0000K0000:h2002T0@00fP800;L100010000
00@=@UDU3D:^0P00Y04000D0001<00000000000000000000oooooooooomH0000>@0i03T0>@0d0000
2@0000T0000900002@0000T0000K0000400003D3002d0@00E00006`000080`00Y04003@3002g0@00
0@0000043D9E9@e220<00:@100050000C00000000000000000000?ooooooooooF00003T0>@0i03T0
=00000T0000900002@0000T0000900006`000100002@0`00]04005@0001/0000H`<00:@1002?0`00
]`400040000010e2EBD=@V<3002T0@001@0004`00000000000000000003ooooooooooeP0000i03T0
>@0i03@0000900002@0000T0000900002@0005@00034000010000;T1003<0000c0400040000010e2
EBD=@P@0002i0@00500004`00000000000000000003oooooooooog@0001204D0AP1?0580A@0P05@0
@@1H0200@`1105<0B00P04H0C01?05L02`0000/0000:0000300000`0000;0000100000T0000;0000
2`0000@0000;00002`0000/0000<0000100000X000090000300000l0000K0000400009/100390@00
E00006`0001^0@00^@4009X1003<0@000@0000043D9E9@e2KP400;T100050000C000000000000000
00000?ooooooooooF0000340=`0`0300=P0000T0000900002@0000T0000900006`000100003[0@00
b@4005@0001/0000_P400;T1003Z0@00c0400040000010e2EBD=@[h1002i0@001@0004`000000000
00000000003ooooooooooeP0000b0300=@0a03H0000900002@0000T0000900002@0001/0000@0000
>`800<T1001D0000K00000h2002i0@00>P800<`10001000000@=@UDU3D8>0P00^@4000D0001<0000
0000000000000000oooooooooomH0000<P0d0340<`0a00002@0000T0000900002@0000T0000K0000
400008/200390@00E00006`0001N0P00^@4008X2003<0@000@0000043D9E9@e2GP800;T100050000
C00000000000000000000?ooooooooooF0000380=`0h03D0=@0000T0000900002@0000T000090000
6`000100003K0P00b@4005@0001/0000[P800;T1003J0P00c0400040000010e2EBD=@Zh2002i0@00
1@0004`00000000000000000003ooooooooooeP0000c0340=P0i0340000900002@0000T000090000
2@0001/0000@0000=@<00<T1001D0000K00000P3002i0@00=0<00<`10001000000@=@UDU3D880`00
^@4000D0001<00000000000000000000oooooooooomH0000<`0e03H0=00a00002@0000T000090000
2@0000T0000K00004000090300390@00E00006`0001S0`00^@4008l3003<0@000@0000043D9E9@e2
H`<00;T100050000C00000000000000000000?ooooooooooF00003<0>@0g0340<00000T000090000
2@0000T000090000E0000;@000040000cP400:L0003Q0@000@0000043D9E9@e210000<h1000A0000
C00000000000000000000?ooooooooooL00004T0CP1304l0C@150200E01105P0801504H0AP1504<0
E00000D0000;00002`0000`0000=00002`0000@0000900002`0000/0000400002`0000X0000:0000
2`0000/0000900006`000100002K0@00gP4005@0001T0000M`400<h1002J0@00h@400040000010e2
EBD=@WL1003>0@00100004`00000000000000000003ooooooooooe@0000c03P0<00f00T000090000
2@0000T0000K000040000>/1003N0@00E00006@000370@00cP400>X1003Q0@000@0000043D9E9@e2
a`400<h100040000C00000000000000000000?ooooooooooE0000380=00a03P02@0000T000090000
2@0001/0000@0000>`800=h1001D0000H0000202003>0@00>P800>410001000000@=@UDU3D8P0P00
cP4000<0001<00000000000000000000oooooooooomD0000>@0g03@0000900002@0000T0000K0000
400008/2003N0@00E00006@0001[0P00cP4008X2003Q0@000@0000043D9E9@e2J`800<h100040000
C00000000000000000000?ooooooooooE00002d0=@0b03P01@0000T0000900002@0001/0000@0000
f`800=h1001D0000K0000;82003>0@00fP800>410001000000@=@UDU3D:b0P00cP4000D0001<0000
0000000000000000oooooooooomH0000;@0b0300>@0a00001@0000T0000900002@0000T0000K0000
400003D3003N0@00E00006`0000<0`00cP4003@3003Q0@000@0000043D9E9@e230<00<h100050000
C00000000000000000000?ooooooooooF00002d0<`0g0380<@0000D0000900002@0000T000090000
6`000100002@0`00gP4005@0001/0000I`<00<h1002?0`00h@400040000010e2EBD=@VL3003>0@00
1@0004`00000000000000000003ooooooooooeP0000]03D0=00b0340000500002@0000T000090000
2@0005@00030000010000><1002n0000mP400040000010e2EBD=@P@0003S0@004`0004`000000000
00000000003oooooooooog@0001104H0E0150580801D0440F00P04<0@@1C04P0801604`0C`1G0000
2`0000X0000900002`0000`0000400002@0000/0000;0000100000/0000;00002`0000`000040000
2P0000T0000<00003`0001/0000@0000V`400?<1001D0000K00006h1003S0@00VP400?H100010000
00@=@UDU3D9^0@00h`4000D0001<00000000000000000000oooooooooomH0000<P0`03P0<@0b0000
2@0000T0000900002@0000T0000K000040000>/1003c0@00E00006`0002n0@00h`400>X1003f0@00
0@0000043D9E9@e2_P400><100050000C00000000000000000000?ooooooooooF0000380<P0i03<0
=00000T0000900002@0000T0000900006`000100000k0P00l`4005@0001/00003P800><1000j0P00
mP400040000010e2EBD=@Ph2003S0@001@0004`00000000000000000003ooooooooooeP0000b03D0
<@0`03H0000900002@0000T0000900002@0001/0000@0000R`800?<1001D0000K00005h2003S0@00
RP800?H10001000000@=@UDU3D9N0P00h`4000D0001<00000000000000000000oooooooooomH0000
<P0g03<0<P0h00002@0000T0000900002@0000T0000K000040000=/2003c0@00E00006`0002^0P00
h`400=X2003f0@000@0000043D9E9@e2[P800><100050000C00000000000000000000?oooooooooo
F0000380>@0e03T0>@0000T0000900002@0000T0000900006`000100000e0`00l`4005@0001/0000
20<00><1000d0`00mP400040000010e2EBD=@PP3003S0@001@0004`00000000000000000003ooooo
oooooeP0000c0340>@0b0300000900002@0000T0000900002@0001/0000@0000T0<00?<1001D0000
K00006<3003S0@00S`<00?H10001000000@=@UDU3D9S0`00h`4000D0001<00000000000000000000
oooooooooomH0000<`0d0380>00i00002@0000T0000900002@0000T0000U0000300000d0080R0000
30000?oooolQ0000200002D0000<00000@0001T0000<0000oooo01P0000<0000000001h0000H0000
00000000002I0`00n04002L0000H000010000000003Jg=d0000002D0000<0000100001P0000<0000
f]cM01T0000<0000f]cM01@0000<00003@000180000<00000P0002P0000<00000P0002H0000L0000
0P0000000000000000000=[Lg@0U000030000080000K00004000000000000000=P00010000000000
n@4002D0000<00001`00P4`0001T00000000000000000000m`400000000000000@000?T1000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
30000080000K0000400000<100000000=P00010000030@00n@4002D0000<00001`00P4`0001T0000
0`40000000030@00m`4000<1000000000@000?T1000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K0000400005<100000000
=P000100001C0@00n@4002D0000<00001`00P4`0001T0000D`400000001C0@00m`4005<100000000
0@000?T1000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U000030000080000K000040000:<100000000=P000100002S0@00n@4002D0000<0000
1`00P4`0001T0000X`400000002S0@00m`400:<1000000000@000?T1000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U000030000080000K0000
40000?<100000000=P000100003c0@00n@4002D0000<00001`00P4`0001T0000l`400000003c0@00
m`400?<1000000000@000?T1000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U000030000080000K0000400004<200000000=P00010000130P00
n@4002D0000<00001`00P4`0001T0000@`80000000130P00m`4004<2000000000@000?T1000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
30000080000K0000400009<200000000=P000100002C0P00n@4002D0000<00001`00P4`0001T0000
T`800000002C0P00m`4009<2000000000@000?T1000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K000040000><200000000
=P000100003S0P00n@4002D0000<00001`00P4`0001T0000h`800000003S0P00m`400><200000000
0@000?T1000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U000030000080000K0000400003d300000000=P000100000m0`00n@4002D0000<0000
1`00P4`0001T0000?@<00000000m0`00m`4003d3000000000@000?T1000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U000030000080000K0000
400009P300000000=P000100002H0`00n@4002D0000<00001`00P4`0001T0000V0<00000002H0`00
m`4009P3000000000@000?T1000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U000030000080000K00004000000000000000=P000100002J0`00
000002D0000<00001`00P4`0001T000000000000002H0`000000000000000000VP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
30000080000K000040000000000O0000=P000100002J0`007`0002D0000<00001`00P4`0001T0000
000001l0002H0`007`000000000O0000VP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K000040000000000n0000
=P000100002J0`00?P0002D0000<00001`00P4`0001T0000000003h0002H0`00?P000000000n0000
VP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U000030000080000K000040000000001C0000=P000100002J0`00D`0002D0000<0000
1`00P4`0001T0000000005<0002H0`00D`000000001C0000VP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U000030000080000K0000
40000000001X0000=P000100002J0`00J00002D0000<00001`00P4`0001T0000000006P0002H0`00
J0000000001X0000VP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U000030000080000K000040000000001m0000=P000100002J0`00
O@0002D0000<00001`00P4`0001T0000000007d0002H0`00O@000000001m0000VP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
30000080000K000040000000002B0000=P000100002J0`00TP0002D0000<00001`00P4`0001T0000
00000980002H0`00TP000000002B0000VP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K000040000000002W0000
=P000100002J0`00Y`0002D0000<00001`00P4`0001T000000000:L0002H0`00Y`000000002W0000
VP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U000030000080000K000040000000002l0000=P000100002J0`00_00002D0000<0000
1`00P4`0001T000000000;`0002H0`00_0000000002l0000VP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U000030000080000K0000
40000000003A0000=P000100002J0`00d@0002D0000<00001`00P4`0001T000000000=40002H0`00
d@000000003A0000VP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U000030000080000K000040000000003V0000=P000100002J0`00
iP0002D0000<00001`00P4`0001T000000000>H0002H0`00iP000000003V0000VP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
30000080000K000040000000003k0000=P000100002J0`00n`0002D0000<00001`00P4`0001T0000
00000?/0002H0`00n`000000003k0000VP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K000040000000000@0@00
=P000100002J0`00404002D0000<00001`00P4`0001T000000000101002H0`0040400000000@0@00
VP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U000030000080000K000040000000000U0@00=P000100002J0`009@4002D0000<0000
1`00P4`0001T0000000002D1002H0`009@400000000U0@00VP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U000030000080000K0000
40000000000j0@00=P000100002J0`00>P4002D0000<00001`00P4`0001T0000000003X1002H0`00
>P400000000j0@00VP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U000030000080000K000040000000001?0@00=P000100002J0`00
C`4002D0000<00001`00P4`0001T0000000004l1002H0`00C`400000001?0@00VP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
30000080000K000040000000001T0@00=P000100002J0`00I04002D0000<00001`00P4`0001T0000
000006@1002H0`00I0400000001T0@00VP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K000040000000001i0@00
=P000100002J0`00N@4002D0000<00001`00P4`0001T0000000007T1002H0`00N@400000001i0@00
VP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U000030000080000K000040000000002>0@00=P000100002J0`00SP4002D0000<0000
1`00P4`0001T0000000008h1002H0`00SP400000002>0@00VP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U000030000080000K0000
40000000002S0@00=P000100002J0`00X`4002D0000<00001`00P4`0001T000000000:<1002H0`00
X`400000002S0@00VP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U000030000080000K000040000000002h0@00=P000100002J0`00
^04002D0000<00001`00P4`0001T000000000;P1002H0`00^0400000002h0@00VP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
30000080000K000040000000003=0@00=P000100002J0`00c@4002D0000<00001`00P4`0001T0000
00000<d1002H0`00c@400000003=0@00VP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U000030000080000K000040000000003R0@00
=P000100002J0`00hP4002D0000<00001`00P4`0001T000000000>81002H0`00hP400000003R0@00
VP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U000030000080000K000040000000003g0@00=P000100002J0`00m`4002D0000<0000
1`00P4`0001T000000000?L1002H0`00m`400000003g0@00VP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000@0080U0000
300000d0080R000030000?oooolQ0000200002D0000<00000@0001T0000<0000f]cM01P0000<0000
f]cM01h0000H00000@000040002I0`00n0400280000<0000ooooodH0000d0000:00004E=AR/Z@000
900001P00000080o0000P0000800080o0000P00008160000700001000015CDH[0T0000`000000000
3P0001@000000000400001@0
\>"], "Graphics",
 Editable->False,
 TextAlignment->Center,
 ImageSize->{597.6666666666665, 327.32844335778316`},
 ImageMargins->{{335.3333333333333, 0.}, {0., 
  0.}},ExpressionUUID->"afe76573-9407-4e6b-a5b1-2c93f3e7bf2a"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Multi-year projections for sample project"
}], "FigureCaption",
 CellChangeTimes->{{3.5285720006906085`*^9, 3.528572009036086*^9}, 
   3.5409358465661087`*^9},
 TextAlignment->Center,ExpressionUUID->"9f0bc178-6fae-411c-833a-e0d109ce405e"],

Cell["\<\
We need a function that defines the after-tax cash flow in any given year.  \
With that we can compute any specific year's cash flow (here we calculate \
cash flow from year #3, given the data. Note that, when rounded, this matches \
the third number in the last line of Figure 4.5).\
\>", "Text",
 CellChangeTimes->{{3.529929785357826*^9, 3.529929804724934*^9}, {
  3.5299298799302354`*^9, 3.52992988507753*^9}, {3.540936373751262*^9, 
  3.540936375846382*^9}},ExpressionUUID->"9f05bb1b-e6ee-49bb-aeef-\
106616187109"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cf", "[", "3", "]"}], "/.", "data"}]], "Input",
 CellChangeTimes->{
  3.521898462300559*^9, {3.5219012874861507`*^9, 3.52190129079434*^9}, {
   3.521901461633111*^9, 3.521901461818122*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"79e3b415-7ed3-40b7-b8fb-0cbd4c01a3dd"],

Cell[BoxData["25105.72716092852`"], "Output",
 CellChangeTimes->{3.528498447832626*^9, 3.528570577402201*^9, 
  3.528637318004545*^9, 3.5299294417421722`*^9, 3.5330636344193726`*^9, 
  3.533072058147182*^9, 3.5336816455625*^9, 3.53373367917582*^9, 
  3.533753351875*^9, 3.5395201100180397`*^9, 3.5395211187367353`*^9, 
  3.539521330213831*^9, 3.5395224253234673`*^9, 3.539523137679212*^9, 
  3.54012522340948*^9, 3.540935030225417*^9, 3.540935304287092*^9, 
  3.540935400039569*^9, 3.540936009482427*^9, 3.5409375590930595`*^9, 
  3.5409379266963186`*^9, 3.5410030435047865`*^9, 3.54159965683589*^9, 
  3.5432391165656586`*^9, 3.6960758829378567`*^9, 3.6962290243474903`*^9, 
  3.696231657102607*^9, 3.6962321748159685`*^9, 3.7314209339217367`*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"f192e523-8f79-448b-bf21-978baba875c7"]
}, Open  ]],

Cell[TextData[{
 "We need to be able to calculate the annual income tax consequence of owning \
the property.  Below we create a function to do this, assuming growing \
income, fixed interest on the loan and straight line depreciation.  The \
illustration is for Year #3 income tax due. We use a different format to \
reflect dollars and cents and the accounting convention for negative numbers. \
Also, note that the sign convention differs between Excel and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Below the value is shown as a negative number. The same amount in Figure \
4.5 (third number in the second to list line) is shown as a positive. The \
answer does not change because subtracting a negative number is the same as \
adding."
}], "Text",
 CellChangeTimes->{
  3.5284985578809204`*^9, {3.5299299182134247`*^9, 
   3.529930044276635*^9}},ExpressionUUID->"4922c5be-fcfe-4a53-ac3e-\
cd985337dae6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"AccountingForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"yrtx", "[", "3", "]"}], "/.", "data"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}]}], "]"}], ",", "Red"}], "]"}]], "Input",
 CellMargins->{{21.333333333333332`, 10.}, {5., 10.}},
 CellChangeTimes->{{3.5218985677395897`*^9, 3.5218985718898277`*^9}, {
  3.5219014588419514`*^9, 3.5219014595709934`*^9}, {3.521932466105466*^9, 
  3.521932540026694*^9}, {3.5219326184201775`*^9, 3.5219326268606606`*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"5bbd8293-f2e1-44cd-9aa8-26d6d120dbc2"],

Cell[BoxData[
 StyleBox[
  TagBox[
   InterpretationBox["\<\"(974.38)\"\>",
    -974.3836978153674,
    AutoDelete->True],
   AccountingForm[#, {5, 2}]& ],
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontColor->RGBColor[1, 0, 0]]], "Output",
 CellMargins->{{17.333333333333332`, 10.}, {10., 5.}},
 CellChangeTimes->{3.528498571706711*^9, 3.5285705777732224`*^9, 
  3.5286373180125456`*^9, 3.529929441996187*^9, 3.5330636347503915`*^9, 
  3.5330720582051854`*^9, 3.533681645734375*^9, 3.5337336795088387`*^9, 
  3.53375335203125*^9, 3.539520110500067*^9, 3.539521118855742*^9, 
  3.539521334416071*^9, 3.539522425391472*^9, 3.5395231377222147`*^9, 
  3.5401252240345163`*^9, 3.5409350308504524`*^9, 3.5409353043640966`*^9, 
  3.5409354001205735`*^9, 3.5409360095414305`*^9, 3.5409375597690983`*^9, 
  3.5409379273873577`*^9, 3.5410030440628185`*^9, 3.54159965752993*^9, 
  3.543239117204695*^9, 3.6960758829920006`*^9, 3.696229024399629*^9, 
  3.6962316572239285`*^9, 3.696232174901196*^9, 3.73142093395784*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"16ff2924-243a-44d5-8098-c473cc5f6fc9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Sale variables relationships"
}], "Section",
 CellChangeTimes->{
  3.531447172614333*^9, 3.531447254092993*^9, {3.533733849154542*^9, 
   3.533733851511677*^9}},ExpressionUUID->"039b09af-de90-4794-b425-\
df1e4d74d61a"],

Cell["\<\
Relationships between the variables affecting the sale of the property at the \
end of the holding period are shown in Figure 4.6:\
\>", "Text",
 CellChangeTimes->{
  3.528570759507617*^9, {3.528572109896855*^9, 
   3.5285721188833685`*^9}},ExpressionUUID->"5f0fedf1-6812-4540-8110-\
b25d4384d6ec"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"noi", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "g"}], ")"}], "k"]}], ")"}], "/", "cro"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"cg", "=", 
   RowBox[{"sp", "-", "sc", "-", "basis", "+", 
    RowBox[{"accdp", "[", "k", "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cgtx", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"cg", "-", 
       RowBox[{"accdp", "[", "k", "]"}]}], ")"}], "*", "cgrt"}], "+", 
    RowBox[{
     RowBox[{"accdp", "[", "k", "]"}], "*", "recaprt"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sc", " ", "=", " ", 
   RowBox[{"scrt", "*", "sp"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"er", "=", 
   RowBox[{"sp", "-", "sc", "-", "cgtx", "-", "endbal", "-", "ppmt"}]}], 
  ";"}]}], "Input",
 CellMargins->{{16.866666666666653`, 18.}, {5., 10.}},
 CellLabel->"In[47]:=",ExpressionUUID->"b4ed6779-ef9b-4084-831a-3623261a0d5f"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Sale variable relationships for sample project"
}], "FigureCaption",
 CellChangeTimes->{{3.528572048114321*^9, 3.5285720627461576`*^9}, 
   3.5409358500183067`*^9},
 TextAlignment->Center,ExpressionUUID->"dfd5b5f3-6a82-48c5-8797-f773f913e548"]
}, Open  ]],

Cell[TextData[{
 "We need a way to determine the amount of depreciation deduction taken \
through any specific time period. This is needed for the annual tax \
consequence and to determine cost basis at the time of sale so that the \
capital gain amount may be calculated.  Here is the accumulated depreciation \
for the project life, through the end year, ",
 StyleBox["k", "Input"],
 "."
}], "Text",
 CellChangeTimes->{
  3.5285707975457926`*^9},ExpressionUUID->"7939cd26-53e7-49ef-a8f0-\
b5bebd001e2a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"accdp", "[", "n_", "]"}], ":=", 
  RowBox[{"depn", "*", "n"}]}], "\n", 
 RowBox[{
  RowBox[{"accdp", "[", "k", "]"}], "/.", "data"}]}], "Input",
 CellMargins->{{18, 10}, {5, 10}},
 CellLabel->"In[52]:=",ExpressionUUID->"7ace3c26-b6fa-4232-b176-c729806df117"],

Cell[BoxData["190909.0909090909`"], "Output",
 CellChangeTimes->{3.5285708016000247`*^9, 3.528637318023546*^9, 
  3.5299294427072277`*^9, 3.5330636354974337`*^9, 3.533066228245731*^9, 
  3.533072058332193*^9, 3.5336816459375*^9, 3.533733680247881*^9, 
  3.53375335234375*^9, 3.5395201118821464`*^9, 3.539521118975749*^9, 
  3.539521343675601*^9, 3.539522425611484*^9, 3.5395231378422213`*^9, 
  3.54012522532059*^9, 3.540935031718502*^9, 3.5409353044421015`*^9, 
  3.5409354002855835`*^9, 3.5409360096004343`*^9, 3.540937560775156*^9, 
  3.540937928589427*^9, 3.5410030453518925`*^9, 3.541599658550988*^9, 
  3.5432391185027695`*^9, 3.6960758830190725`*^9, 3.696229024456807*^9, 
  3.696231657287097*^9, 3.6962321750024652`*^9, 3.731420933989919*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"6b22a398-2d3d-40c3-85e8-cc9be0df0c54"]
}, Open  ]],

Cell[TextData[{
 "The alert reader will note we have taken some liberties with one \
computation. At this stage we provide a simplified approach to capital gain \
tax rates, assuming they are \"flat\" and applied to the entire gain. In \
fact, IRS regulations as of 2011 tax the gain at different rates depending on \
how long one owns the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"property", 
    SuperscriptBox[".", 
     ButtonBox["2",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote2"]]}], TraditionalForm]],ExpressionUUID->
  "17ee27f3-fe7a-4c4a-bfdc-e411ba2e1115"],
 "  Also, capital gain tax on that portion of the gain created by taking \
depreciation deductions is levied at a different \"recapture\" rate. Congress \
tinkers endlessly with the tax code and tax rates. Making precise tax \
computations is best done at the time of any particular analysis. The goal \
here is to be general and a flat capital gain tax serves that purpose."
}], "Text",
 CellChangeTimes->{
  3.528570813781721*^9, {3.528572140650614*^9, 3.528572166121071*^9}, {
   3.528572232795884*^9, 3.5285722393182573`*^9}, {3.528637891602353*^9, 
   3.528637900039836*^9}, {3.528638161855811*^9, 
   3.528638161855811*^9}},ExpressionUUID->"9d098fcc-b232-4f95-a1ce-\
495d78bb2538"],

Cell["\<\
For most of the history of capital gain taxes the important issue has been \
the spread between ordinary income tax rates and capital gain tax rates. To \
the extent that the latter is lower than the former, US tax policy rewards \
the long term ownership of depreciable assets by allowing taxpayers to \
convert ordinary income, otherwise taxed at a higher rate, to capital gain \
income that will be taxed at a lower rate. Figure 4.7 displays the after-tax \
consequences of a sale in each year of the holding period.\
\>", "Text",
 CellChangeTimes->{{3.5285722071494174`*^9, 
  3.528572225172448*^9}},ExpressionUUID->"fbf83167-a184-442d-8721-\
a042dd5389fb"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0007I00@0006`000000000000007@3002:0P00
00000000003PN@00^eT00215CDH00040@7H005L200070000000000000000000000@00003001Y0@00
3`40000000000000000001b31@1E8P@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0900`000000000940100`000000000
<4020100000400000020?b501`0<0000000000A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P000240000800008P0000`0003ooooo8@0000P0000R0000
30000?ooool:000040000000000000008@0000P0000I000030000?ooo`0H000030000000000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H000000000000001e0`00
R`800280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P000000000
000007D3002;0P008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
6000004000010000M@<008/2000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00000@000040001e0`00R`800280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000100000@0007D3002;0P00DP00070100010000l?ooo`0000000000
000009010000000000008TP0I@1/07H0000000000000000000000000000000000000000000000000
000000000000000000000000000005L64>:50>0iF0H000400;IG1P01000H>UP60000002dE`H10000
03Dn02enJGBH6`77<0000300000:00002P000403i@8:0000h3UH1T03i@9iB^Ye;3Dn00X000010000
h3UH1R`e?P3cb6UdP05^M<<;Cf@i0000V1/1a`00?P1DbFUdV1/1ac00000i00000P0008Pf?P2T=Ch0
HnTDI9PK0LL`0000>@0008Pf?P0LNNX2V1/1ad15:@H00000<3Ln00400000000000000040000PJ@MT
GHk6n@0000000000A`0004H0002d0000IA7EML`e?P0djAATI7H02000000U000030000040000D0000
300000d0000B000030000040001D0000d00000l000090000d00001`00001000000@=@UDU3D8?0000
2@0001H0001<00000000000000000000oooooooooomh0000@P1504L0B@1>04h0B@1>04L0801?04H0
801I04D0@@1B0200;@0]02d0?P0;00002`0000d0000500002`0000/0000500002`0000d000040000
300000X0000400002`0000/0000;0000300000@0000500001@0000D000090000DP00070100020000
j?ooo`0000000000000009010000000000000440LP1Y0640K0000000000000000000000000000000
0000000000000000000000000000000000000000000005L64>:507QhQP0000400;IG1P01002`N8H0
0000002dE`H00000f3Dn02enJGBH6`77<0000300000:00002P000403i@8:0000N7R60403i@9iB^Ye
13Hn00X000010000N7R600@f?P3cb6UdP05^M<<;Cf@i0000V1/1a`00?P1DbFUdV1/1ac00000i0000
0P00060g?P1l=Sh0HnTDI9PK0LL`0000>@00060g?P0LNNX2V1/1a`000000000023Pn004000000000
00000040000000000000000000000000_i34nF@g?P0O0000J46i0j@f?P0djAATI7H02000000U0000
30000080000K0000400000@1000I0000E00005@0003g0000100000<1000N00000@0000043D9E9@e2
m`0000@000010000C00000000000000000000?ooooooooooD0000340000=00006`000100001R0@00
6@0005@0001D0000E@4000@0001Q0@007P000040000010e2EBD=@UD1000400000@0004`000000000
00000000003ooooooooooe00000b00003@0001/0000@0000``4001T0001D0000E0000;H100040000
`P4001h00001000000@=@UDU3D:f0@0010000040001<00000000000000000000oooooooooom@0000
<`0000d0000K0000400002@2000I0000E00005@0000G0P00100002<2000N00000@0000043D9E9@e2
5`8000@000010000C00000000000000000000?ooooooooooD00003@0000=00006`00010000250P00
6@0005@0001D0000N08000@000240P007P000040000010e2EBD=@WP2000400000@0004`000000000
00000000003ooooooooooe00000e00003@0001/0000@0000iP8001T0001D0000E0000=T200040000
i@8001h00001000000@=@UDU3D;I0P0010000040001<00000000000000000000oooooooooom@0000
=P0000d0000K0000400004L3000I0000E00005@0000j0`00100004H3000N00000@0000043D9E9@e2
>P<000@000010000C00000000000000000000?ooooooooooD00003L0000=00009@0000`000010000
E0000:`000180000:0000=00000k00000@0000043D9E9@e2B00002P0000@0000C000000000000000
00000?ooooooooooK00004D0CP140200C`160200F@150440DP0P02d0;@0]03h02`0000/0000<0000
100000`0000:0000100000/0000;00002`0000`0000400001@0000D0000500002@0002D0000<0000
0P0001/0000@0000104003P0001D0000E0000?L0000S00000`4003d00001000000@=@UDU3D;g0000
8`000040001<00000000000000000000oooooooooom@0000<00000d0000K000040000681000h0000
E00005@0001E0@008`000641000m00000@0000043D9E9@e2E@4002<000010000C000000000000000
00000?ooooooooooD0000340000=00006`00010000330@00>00005@0001D0000]P4002<000320@00
?@000040000010e2EBD=@[H1000S00000@0004`00000000000000000003ooooooooooe00000b0000
3@0001/0000@0000908003P0001D0000E00001L2000S00008`8003d00001000000@=@UDU3D8G0P00
8`000040001<00000000000000000000oooooooooom@0000<`0000d0000K0000400008D2000h0000
E00005@0001h0P008`0008@2000m00000@0000043D9E9@e2N08002<000010000C000000000000000
00000?ooooooooooD00003@0000=00006`000100003V0P00>00005@0001D0000f@8002<0003U0P00
?@000040000010e2EBD=@]T2000S00000@0004`00000000000000000003ooooooooooe00000e0000
3@0001/0000@0000A`<003P0001D0000E00003X3000S0000AP<003d00001000000@=@UDU3D8j0`00
8`000040001<00000000000000000000oooooooooom@0000=P0000d0000U000030000040001D0000
K00000@0000o0000>@0005800001000000@=@UDU3D840000?`0000D0001<00000000000000000000
oooooooooomH0000EP1104`0E@1500002`0000/000090000300000/0000K0000400002H1001?0000
E00007P0003W0000?`0002D1001B00000@0000043D9E9@e2i`0003l000070000C000000000000000
00000?ooooooooooG0000340<P0e0300<00`0300000900002@0000T0000900002@0000T000090000
6`00010000270@00C`0005@0001h0000B04003l000260@00DP000040000010e2EBD=@TP1000o0000
1`0004`00000000000000000003ooooooooooe`0000a0380>00g03D0<00`00002@0000T000090000
2@0000T0000900002@0001/0000@0000j04004l0001D0000N0000:T1000o0000i`40058000010000
00@=@UDU3D:Y0@00?`0000L0001<00000000000000000000oooooooooomL0000<@0c0380=P0a0380
=@0000T0000900002@0000T0000900002@0000T0000K0000400004T2001?0000E00007P0000:0P00
?`0004P2001B00000@0000043D9E9@e22P8003l000070000C00000000000000000000?oooooooooo
G0000340<`0f03D0>@0`03T0000900002@0000T0000900002@0000T0000900006`000100002Z0P00
C`0005@0001h0000J`8003l0002Y0P00DP000040000010e2EBD=@V/2000o00001`0004`000000000
00000000003ooooooooooe`0000a03@0<00f03P0>00f00002@0000T0000900002@0000T000090000
2@0001/0000@00002`<004l0001D0000N0000<`2000o00002P<005800001000000@=@UDU3D;<0P00
?`0000L0001<00000000000000000000oooooooooomL0000<@0d03@0>@0`03T0<`0000T000090000
2@0000T0000900002@0000T0000K0000400006`3001?0000E00007P0000]0`00?`0006/3001B0000
0@0000043D9E9@e2;@<003l000070000C00000000000000000000?ooooooooooG0000340=00i0380
=@0f03D0000900002@0000T0000900002@0000T000090000E00006`000040000E00003T0001W0000
0@0000043D9E9@e2100005@000050000C00000000000000000000?ooooooooooF00004`0C`1104h0
D`0000T0000<00002`0000/0000;00006`000100000V0@00I00005@0001`0000l00005@0000U0@00
I`000040000010e2EBD=@_00001D00001P0004`00000000000000000003ooooooooooeP0000h03L0
=@0`0300<00900002@0000T0000900002@0000T0000K0000400008L1001T0000E0000700001A0@00
E00008H1001W00000@0000043D9E9@e2D@4005@000060000C00000000000000000000?oooooooooo
F00003P0=`0a0300=P0a00T0000900002@0000T0000900002@0001/0000@0000j04006@0001D0000
L0000;81001D0000i`4006L00001000000@=@UDU3D:b0@00E00000H0001<00000000000000000000
oooooooooomH0000>00f03H0=P0f03L02@0000T0000900002@0000T0000900006`00010000190P00
I00005@0001`00004`8005@000180P00I`000040000010e2EBD=@Q<2001D00001P0004`000000000
00000000003ooooooooooeP0000h03H0<@0g03H0=00900002@0000T0000900002@0000T0000K0000
40000:X2001T0000E0000700001d0P00E0000:T2001W00000@0000043D9E9@e2M08005@000060000
C00000000000000000000?ooooooooooF00003P0=@0f0380>@0d00T0000900002@0000T000090000
2@0001/0000@00002`<006@0001D0000L0000=D2001D00002P<006L00001000000@=@UDU3D;E0P00
E00000H0001<00000000000000000000oooooooooomH0000>00e0300<@0i03402@0000T000090000
2@0000T0000900006`000100001/0`00I00005@0001`0000=P<005@0001[0`00I`000040000010e2
EBD=@SH3001D00001P0004`00000000000000000003ooooooooooeP0000h03@0<`0c03P0<@090000
2@0000T0000900002@0000T0001D0000L00000@0001Y0000?`0007`00001000000@=@UDU3D840000
J@0000H0001<00000000000000000000oooooooooomH0000A@1A05D0B@1D05T02`0000`0000<0000
1@0000T0000;00006`000100000V0@00N@0005@0001`0000l00006T0000U0@00O0000040000010e2
EBD=@_00001Y00001P0004`00000000000000000003ooooooooooeP0000c03L0=@0`0300<0090000
2@0000T0000900002@0000T0000K0000400008L1001i0000E0000700001A0@00J@0008H1001l0000
0@0000043D9E9@e2D@4006T000060000C00000000000000000000?ooooooooooF00003@0<@0f03@0
<`0i00T0000900002@0000T0000900002@0001/0000@0000j04007T0001D0000L0000;81001Y0000
i`4007`00001000000@=@UDU3D:b0@00J@0000H0001<00000000000000000000oooooooooomH0000
=00e03T0=00e03P02@0000T0000900002@0000T0000900006`00010000190P00N@0005@0001`0000
4`8006T000180P00O0000040000010e2EBD=@Q<2001Y00001P0004`00000000000000000003ooooo
oooooeP0000e0300=00a03@0=@0900002@0000T0000900002@0000T0000K000040000:X2001i0000
E0000700001d0P00J@000:T2001l00000@0000043D9E9@e2M08006T000060000C000000000000000
00000?ooooooooooF00003D0=@0`03D0>@0b00T0000900002@0000T0000900002@0001/0000@0000
2`<007T0001D0000L0000=D2001Y00002P<007`00001000000@=@UDU3D;E0P00J@0000H0001<0000
0000000000000000oooooooooomH0000=@0i03P0>@0`03802@0000T0000900002@0000T000090000
6`000100001/0`00N@0005@0001`0000=P<006T0001[0`00O0000040000010e2EBD=@SH3001Y0000
1P0004`00000000000000000003ooooooooooeP0000f03@0>@0a03P0=00900002@0000T000090000
2@0000T0001D0000a00000@0002C0000c`000:H00001000000@=@UDU3D840000T`0001@0001<0000
0000000000000000oooooooooomd0000@@1304<0DP1E04D0A00P04@0A@1@0580A@1304T0@@1D04T0
C`1>00/0000;00002`0000`0000<00002`0000`000040000300000/0000:0000300000/0000;0000
1@0000/0000900001@0000`0000;00006`00010000270@00X`0005@0001/0000FP4009<000260@00
YP000040000010e2EBD=@UX1002C00001@0004`00000000000000000003ooooooooooeP0000c0340
>00a03P0000900002@0000T0000900002@0001/0000@0000j0400:<0001D0000K0000;/1002C0000
i`400:H00001000000@=@UDU3D:k0@00T`0000D0001<00000000000000000000oooooooooomH0000
=P0c03H0<`0f00002@0000T0000900002@0000T0000K0000400004T2002S0000E00006`0000L0P00
T`0004P2002V00000@0000043D9E9@e2708009<000050000C00000000000000000000?oooooooooo
F00003T0=@0d03D0=@0000T0000900002@0000T0000900006`000100002Z0P00X`0005@0001`0000
M08009<0002Y0P00YP000040000010e2EBD=@W@2002C00001P0004`00000000000000000003ooooo
oooooeP0000a0380=`0b03L0<`0900002@0000T0000900002@0000T0000K0000400000/3002S0000
E0000700003E0P00T`0000X3002V00000@0000043D9E9@e2e@8009<000060000C000000000000000
00000?ooooooooooF0000340=@0i0300>@0a00T0000900002@0000T0000900002@0001/0000@0000
K0<00:<0001D0000L00003H3002C0000J`<00:H00001000000@=@UDU3D8f0`00T`0000H0001<0000
0000000000000000oooooooooomH0000<@0i0300>@0`03T02@0000T0000900002@0000T000090000
E0000;P000040000Z0000:l0002k00000@0000043D9E9@e210000:P0000B0000C000000000000000
00000?ooooooooooL00005<0@@1<04D0801304l0D`1D0200D0150580@`1504h0E00j00/0000;0000
2@0000/0000400002`0000`0000;00002@0000@0000:00002`0000`0000;00002`0000/000090000
10000580001`0@000`000?3oool0000000000000002@0@0000000000029806D0K01f000000000000
0000000000000000000000000000000000000000000000000000000000000000001G1Q3RQ@2`MHH0
0001002fE`H00@00j7F600000000]5L60@000=Pe?P0]OVUdV1/1ac00000`00002P0000X000100nD2
2P000;1eQP100nD2ND[ZM@@f?P0:00000@000;1eQP04=Sh0llQYM801KWC32dmT>@0009PK0LL003h0
E<UYM9PK0LL`0000>@000080001P=ch0O3Hn06?Y56BH6`77<00003T0001P=ch077WZ0YPK0LL00000
000000Ph?P0100000000000000010000000000000000000000000;n@a?UT=ch07`0006Q1^@>T=Sh0
=>TDI6Af00P000009@0000`000030000600000`000000?l0E00006`0002T0000_@000=00003@0000
0@0000043D9E9@e2Y0000;d000050000C00000000000000000000?ooooooooooF00003L0;P0e0300
9@0000T0000400002@0000T0000>00009@0000`000010000600000`0000000006`00010000270@00
c@0005@0001/0000FP400;d000260@00d0000040000010e2EBD=@UX1002m00001@0004`000000000
00000000003ooooooooooeP0000i03H0=@0f0380000900002@0000T0000900002@0001/0000@0000
j0400<d0001D0000K0000;/1002m0000i`400=000001000000@=@UDU3D:k0@00_@0000D0001<0000
0000000000000000oooooooooomH0000>@0i03@0=@0i00002@0000T0000900002@0000T0000K0000
400004T2003=0000E0000700000C0P00_@0004P2003@00000@0000043D9E9@e24`800;d000060000
C00000000000000000000?ooooooooooF0000340<00b03@0=00c00T0000900002@0000T000090000
2@0001/0000@0000ZP800<d0001D0000L00007@2002m0000Z@800=000001000000@=@UDU3D9d0P00
_@0000H0001<00000000000000000000oooooooooomH0000<@0`03D0=@0a03H02@0000T000090000
2@0000T0000900006`000100000;0`00c@0005@0001`0000e@800;d0000:0`00d0000040000010e2
EBD=@]D2002m00001P0004`00000000000000000003ooooooooooeP0000a0300>00f03P0<P090000
2@0000T0000900002@0000T0000K0000400006`3003=0000E0000700000f0`00_@0006/3003@0000
0@0000043D9E9@e2=P<00;d000060000C00000000000000000000?ooooooooooF0000340<@0a03T0
=00b00T0000900002@0000T0000900002@0005@00034000010000=8000390000i@000040000010e2
EBD=@P@0003B0000500004`00000000000000000003oooooooooog@0001202d0E01105P0801C0440
C01505<0801@0580C`1304D0A@1405<02`0000D0000900002`0000/0000400002`0000/000090000
2`0000/0000400002P0000`0000<00002`0000/0000;0000300000/0000K0000400008L1003R0000
E0000700001A0@00dP0008H1003U00000@0000043D9E9@e2D@400=8000060000C000000000000000
00000?ooooooooooF00003<0<@0i03P0=`0f00T0000900002@0000T0000900002@0001/0000@0000
j0400>80001D0000L0000;81003B0000i`400>D00001000000@=@UDU3D:b0@00dP0000H0001<0000
0000000000000000oooooooooomH0000<`0e03T0>@0i03T02@0000T0000900002@0000T000090000
6`00010000190P00hP0005@0001`00004`800=8000180P00i@000040000010e2EBD=@Q<2003B0000
1P0004`00000000000000000003ooooooooooeP0000d0300<@0g0300<@0900002@0000T000090000
2@0000T0000K000040000:X2003R0000E0000700001d0P00dP000:T2003U00000@0000043D9E9@e2
M0800=8000060000C00000000000000000000?ooooooooooF00003@0=00e0300=`0f00T000090000
2@0000T0000900002@0001/0000@00002`<00>80001D0000L0000=D2003B00002P<00>D000010000
00@=@UDU3D;E0P00dP0000H0001<00000000000000000000oooooooooomH0000=00i0300<P0b0300
2@0000T0000900002@0000T0000900006`000100001/0`00hP0005@0001`0000=P<00=80001[0`00
i@000040000010e2EBD=@SH3003B00001P0004`00000000000000000003ooooooooooeP0000e03<0
=`0b03@0<P0900002@0000T0000900002@0000T0001D0000^00001L0003l0000_P0000l100010000
00@=@UDU3D8G0000o0000180001<00000000000000000000oooooooooom`0000@P1105<0B@1C0200
@`1104`0@`1E04`0@@1D04T0C`1>03X02`0000/0000;00001@0000/0000400002`0000/000090000
2`0000`0000900002`0000T000050000300000/000040000E0000:`0000400009P400:40000i0@00
0@0000043D9E9@e2100002H1000@0000C00000000000000000000?ooooooooooK00004L0DP1?05<0
D`0P05<0@@1<04D0801@0580B@1304D03@0000`0000<00002`0000/0000400002`0000/000090000
2`0000@0000:0000300000D0000;00002`0001/0000@0000Q`4003H1001D0000N00004P1000V0@00
QP4003T10001000000@=@UDU3D980@009P4000L0001<00000000000000000000oooooooooomL0000
<@0b03P0=`0e0300<00000T0000900002@0000T0000900002@0000T0000K000040000>P1000f0@00
E00007P0002Y0@009P400>L1000i0@000@0000043D9E9@e2Z@4002H100070000C000000000000000
00000?ooooooooooG0000340<`0b03H0<@0b03D0000900002@0000T0000900002@0000T000090000
6`00010000190P00=P4005@0001h00002P8002H100180P00>@400040000010e2EBD=@PX2000V0@00
1`0004`00000000000000000003ooooooooooe`0000a03<0=P0e03T0<00i00002@0000T000090000
2@0000T0000900002@0001/0000@0000ZP8003H1001D0000N00006/2000V0@00Z@8003T100010000
00@=@UDU3D9[0P009P4000L0001<00000000000000000000oooooooooomL0000<@0d0300=P0h03P0
=P0000T0000900002@0000T0000900002@0000T0000K0000400000/3000f0@00E00007P0003<0P00
9P4000X3000i0@000@0000043D9E9@e2c08002H100070000C00000000000000000000?oooooooooo
G0000340=00d03T0<00i03<0000900002@0000T0000900002@0000T0000900006`000100001/0`00
=P4005@0001h0000;@<002H1001[0`00>@400040000010e2EBD=@Rd3000V0@001`0004`000000000
00000000003ooooooooooe`0000a03@0>@0b03D0=P0e00002@0000T0000900002@0000T000090000
2@0005@0002L0000100003/100200000CP400040000010e2EBD=@P@0000k0@003@0004`000000000
00000000003oooooooooofP0001?0580B@1704T0CP1104`0801304l0D`1D0000300000`000050000
3@0000D0000;00002`0000T0000400002`0000`0000;00002@0001/0000@0000Q`4004/1001D0000
N00004P1000k0@00QP4004h10001000000@=@UDU3D980@00>`4000L0001<00000000000000000000
oooooooooomL0000<@0b03D0<00`0300<00000T0000900002@0000T0000900002@0000T0000K0000
40000>P1001;0@00E00007P0002Y0@00>`400>L1001>0@000@0000043D9E9@e2Z@4003/100070000
C00000000000000000000?ooooooooooG0000340<P0e0300<00`0300000900002@0000T000090000
2@0000T0000900006`00010000190P00B`4005@0001h00002P8003/100180P00CP400040000010e2
EBD=@PX2000k0@001`0004`00000000000000000003ooooooooooe`0000a0380=@0`0300<00`0000
2@0000T0000900002@0000T0000900002@0001/0000@0000ZP8004/1001D0000N00006/2000k0@00
Z@8004h10001000000@=@UDU3D9[0P00>`4000L0001<00000000000000000000oooooooooomL0000
<@0b03D0<00`0300<00000T0000900002@0000T0000900002@0000T0000K0000400000/3001;0@00
E00007P0003<0P00>`4000X3001>0@000@0000043D9E9@e2c08003/100070000C000000000000000
00000?ooooooooooG0000340<P0e0300<00`0300000900002@0000T0000900002@0000T000090000
6`000100001/0`00B`4005@0001h0000;@<003/1001[0`00CP400040000010e2EBD=@Rd3000k0@00
1`0004`00000000000000000003ooooooooooe`0000a0380=@0`0300<00`00002@0000T000090000
2@0000T0000900002@0005@0002d000010000501002Y0000H`400040000010e2EBD=@P@0001@0@00
4@0004`00000000000000000003oooooooooog00001<04D0D`1C0200A0150500DP1504<0B@1105@0
B@1?04h0000900002`0000/0000;0000100000`0000;00002P0000`0000;00002`0000D0000;0000
2@0000D0000<00002`0001/0000@0000Q`400601001D0000L00005D1001@0@00QP4006<100010000
00@=@UDU3D9E0@00D04000H0001<00000000000000000000oooooooooomH0000;@0c0340>00a03P0
1@0000T0000900002@0000T0000900006`000100003X0@00H04005@0001`0000]P400501003W0@00
H`400040000010e2EBD=@[H1001@0@001P0004`00000000000000000003ooooooooooeP0000]03H0
<`0f03<0=P0500002@0000T0000900002@0000T0000K0000400004T2001P0@00E0000700000G0P00
D04004P2001S0@000@0000043D9E9@e25`80050100060000C00000000000000000000?oooooooooo
F00002d0>@0e03@0=@0e00D0000900002@0000T0000900002@0001/0000@0000ZP800601001D0000
N00006l2001@0@00Z@8006<10001000000@=@UDU3D9_0P00D04000L0001<00000000000000000000
oooooooooomL0000;@0a0380=`0b03L0<`0000D0000900002@0000T0000900002@0000T0000K0000
400000/3001P0@00E00007P0003@0P00D04000X3001S0@000@0000043D9E9@e2d080050100070000
C00000000000000000000?ooooooooooG00002d0<@0e03T0<00i0340000500002@0000T000090000
2@0000T0000900006`000100001/0`00H04005@0001h0000<@<00501001[0`00H`400040000010e2
EBD=@S43001@0@001`0004`00000000000000000003ooooooooooe`0000]0340>@0`03T0<00i0000
1@0000T0000900002@0000T0000900002@0005@0002d0000100006D1002T0000N0400040000010e2
EBD=@P@0001U0@004@0004`00000000000000000003oooooooooog00001@04`0E@1C0200@`1?05<0
E00P04l0AP0P05<0@@1<04D0000:00002@0000`0000;0000100000/0000<00002`0000T000040000
300000X0000400002`0000/0000900002`0001/0000@0000Q`4007D1001D0000K00005X1001U0@00
QP4007P10001000000@=@UDU3D9J0@00I@4000D0001<00000000000000000000oooooooooomH0000
>@0f03D0=P0b00002@0000T0000900002@0000T0000K000040000>P1001e0@00E00006`0002k0@00
I@400>L1001h0@000@0000043D9E9@e2^`4006D100050000C00000000000000000000?oooooooooo
F00003T0>@0d03D0>@0000T0000900002@0000T0000900006`00010000190P00M@4005@0001`0000
4`8006D100180P00N0400040000010e2EBD=@Q<2001U0@001P0004`00000000000000000003ooooo
oooooeP0000a0300<P0d03@0<`0900002@0000T0000900002@0000T0000K000040000:X2001e0@00
E0000700001d0P00I@400:T2001h0@000@0000043D9E9@e2M08006D100060000C000000000000000
00000?ooooooooooF0000340<00e03D0<@0f00T0000900002@0000T0000900002@0001/0000@0000
2`<007D1001D0000L0000=D2001U0@002P<007P10001000000@=@UDU3D;E0P00I@4000H0001<0000
0000000000000000oooooooooomH0000<@0`03P0=P0h03802@0000T0000900002@0000T000090000
6`000100001/0`00M@4005@0001`0000=P<006D1001[0`00N0400040000010e2EBD=@SH3001U0@00
1P0004`00000000000000000003ooooooooooeP0000a0340<@0i03@0<P0900002@0000T000090000
2@0000T0001D0000^00000@0001j0@00/`0008d10001000000@=@UDU3D840000NP400180001<0000
0000000000000000oooooooooom`0000C`1D04P0A@1B0200@P1105<0B@1C0200@@1404X0E@1C05@0
300000T0000<00002`0000`0000400002`0000/0000;00001@0000/0000400002`0000`000080000
300000/000090000E000090000040000S`4006X0002R0@000@0000043D9E9@e2100008l1000;0000
C00000000000000000000?ooooooooooI0000440@`120200@@1D0200D`1104`0A@0000/0000;0000
2`0000@0000;00002@0000@0000;00002`0000T0000;00006`00010000270@00W`4005@0001h0000
B04008l100260@00XP400040000010e2EBD=@TP1002?0@001`0004`00000000000000000003ooooo
oooooe`0000a03<0<@0d03L0=00d00002@0000T0000900002@0000T0000900002@0001/0000@0000
j04009l1001D0000N0000:T1002?0@00i`400:810001000000@=@UDU3D:Y0@00S`4000L0001<0000
0000000000000000oooooooooomL0000<@0b03P0=@0h0380<`0000T0000900002@0000T000090000
2@0000T0000K0000400004T2002O0@00E00007P0000:0P00S`4004P2002R0@000@0000043D9E9@e2
2P8008l100070000C00000000000000000000?ooooooooooG0000340<P0e03H0>@0h03T000090000
2@0000T0000900002@0000T0000900006`000100002Z0P00W`4005@0001h0000J`8008l1002Y0P00
XP400040000010e2EBD=@V/2002?0@001`0004`00000000000000000003ooooooooooe`0000a0380
<P0h0380=00d00002@0000T0000900002@0000T0000900002@0001/0000@00002`<009l1001D0000
N0000<`2002?0@002P<00:810001000000@=@UDU3D;<0P00S`4000L0001<00000000000000000000
oooooooooomL0000<@0a03T0>@0e03T0<@0000T0000900002@0000T0000900002@0000T0000K0000
400006`3002O0@00E00007P0000]0`00S`4006/3002R0@000@0000043D9E9@e2;@<008l100070000
C00000000000000000000?ooooooooooG0000340<@0g0340<00c03<0000900002@0000T000090000
2@0000T000090000E00009@000040000Y0400740002g0@000@0000043D9E9@e210000:@1000<0000
C00000000000000000000?ooooooooooI00004<0@@1@04T0E01104`080170440B@1>00/0000;0000
2P0000D0000900002`0000T0000400003@0000/0000500002`0001/0000@0000Q`400;@1001D0000
L00005D1002T0@00QP400;L10001000000@=@UDU3D9E0@00Y04000H0001<00000000000000000000
oooooooooomH0000;@0b03L0<P0d03@01@0000T0000900002@0000T0000900006`000100003X0@00
]04005@0001/0000^`400:@1003W0@00]`400040000010e2EBD=@[/1002T0@001@0004`000000000
00000000003ooooooooooeP0000d0300<`0`0380000900002@0000T0000900002@0001/0000@0000
B@800;@1001D0000L00001<2002T0@00B0800;L10001000000@=@UDU3D8C0P00Y04000H0001<0000
0000000000000000oooooooooomH0000<@0`03P0>@0b03002@0000T0000900002@0000T000090000
6`000100002Z0P00]04005@0001`0000M0800:@1002Y0P00]`400040000010e2EBD=@W@2002T0@00
1P0004`00000000000000000003ooooooooooeP0000a03L0>00f03@0<P0900002@0000T000090000
2@0000T0000K0000400000/3002d0@00E0000700003E0P00Y04000X3002g0@000@0000043D9E9@e2
e@800:@100060000C00000000000000000000?ooooooooooF0000380=00i03D0<00b00T000090000
2@0000T0000900002@0001/0000@0000K0<00;@1001D0000L00003H3002T0@00J`<00;L100010000
00@=@UDU3D8f0`00Y04000H0001<00000000000000000000oooooooooomH0000<`0b0340=@0c0380
2@0000T0000900002@0000T000090000E00008@000040000^@4005X0003<0@000@0000043D9E9@e2
10000;T100090000C00000000000000000000?ooooooooooH0000580A@1104`080170440B@1>0000
300000/0000;00002@0000@0000=00002`0000D0000;00006`00010000270@00b@4005@0001`0000
E@400;T100260@00c0400040000010e2EBD=@UD1002i0@001P0004`00000000000000000003ooooo
oooooeP0000]03D0>@0`03H0<`0500002@0000T0000900002@0000T0000K000040000>P100390@00
E0000700002f0@00^@400>L1003<0@000@0000043D9E9@e2]P400;T100060000C000000000000000
00000?ooooooooooF00002d0<P0c03<0<`0d00D0000900002@0000T0000900002@0001/0000@0000
B@800<T1001D0000K00001`2002i0@00B0800<`10001000000@=@UDU3D8L0P00^@4000D0001<0000
0000000000000000oooooooooomH0000<@0c03@0=P0f00002@0000T0000900002@0000T0000K0000
40000:X200390@00E00006`0001m0P00^@400:T2003<0@000@0000043D9E9@e2O@800;T100050000
C00000000000000000000?ooooooooooF00003D0<@0c03L0<00000T0000900002@0000T000090000
6`000100000;0`00b@4005@0001/0000gP800;T1000:0`00c0400040000010e2EBD=@]h2002i0@00
1@0004`00000000000000000003ooooooooooeP0000i0300=00a0340000900002@0000T000090000
2@0001/0000@0000K0<00<T1001D0000L00003H3002i0@00J`<00<`10001000000@=@UDU3D8f0`00
^@4000H0001<00000000000000000000oooooooooomH0000<@0c0300=P0b03<02@0000T000090000
2@0000T000090000E00007`000040000cP400540003Q0@000@0000043D9E9@e210000<h100080000
C00000000000000000000?ooooooooooG00005@0@@1H0200DP1105@0A@0900002`0000/000040000
300000/0000900002`0002D0000<00000`0001P0000<0000003o05@0001`0000m@000<h1000Z0@00
h@400040000010e2EBD=@_D0003>0@001P0004`00000000000000000003ooooooooooeP0000a03D0
;P0`03009@0900002@0000@0000900002@0000h0000U000030000040000H000030000000001D0000
L00005H1003>0@00R`400>410001000000@=@UDU3D9F0@00cP4000H0001<00000000000000000000
oooooooooomH0000<@0e02h0<00`02D02@0000T0000400002@0000T0000>0000E0000700002g0@00
cP400>`1003Q0@000@0000043D9E9@e2]`400<h100060000C00000000000000000000?oooooooooo
F0000340=@0^0300<00U00T000090000100000T0000900003P0005@0001`000060800<h1001=0P00
h@400040000010e2EBD=@QP2003>0@001P0004`00000000000000000003ooooooooooeP0000a03D0
;P0`03009@0900002@0000@0000900002@0000h0001D0000L00007T2003>0@00[P800>4100010000
00@=@UDU3D9i0P00cP4000H0001<00000000000000000000oooooooooomH0000<@0e02h0<00`02D0
2@0000T0000400002@0000T0000>0000E0000700003J0P00cP4000l3003Q0@000@0000043D9E9@e2
fP800<h100060000C00000000000000000000?ooooooooooF0000340=@0^0300<00U00T000090000
100000T0000900003P0005@0001`0000>`<00<h1001`0`00h@400040000010e2EBD=@S/3003>0@00
1P0004`00000000000000000003ooooooooooeP0000a03D0;P0`03009@0900002@0000@000090000
2@0000h0001D0000W00000@0003S0@00S@000?H10001000000@=@UDU3D840000h`4000d0001<0000
0000000000000000oooooooooomX0000DP1504<0C`1F04D0DP1I0200DP1105@0A@0000`0000;0000
2`0000`0000;00002`0000`0000;0000100000`0000;00002@0000/0000U0000300000<0000H0000
30000000o`1D0000L0000?D0003S0@00:P400?H10001000000@=@UDU3D;e0000h`4000H0001<0000
0000000000000000oooooooooomH0000<P0e02h0<00`02D02@0000T0000400002@0000T0000>0000
9@0000`000010000600000`000000000E0000700001F0@00h`4008/1003f0@000@0000043D9E9@e2
EP400><100060000C00000000000000000000?ooooooooooF0000380=@0^0300<00U00T000090000
100000T0000900003P0005@0001`0000]`400><1003/0@00mP400040000010e2EBD=@[L1003S0@00
1P0004`00000000000000000003ooooooooooeP0000b03D0;P0`03009@0900002@0000@000090000
2@0000h0001D0000L00001P2003S0@00C@800?H10001000000@=@UDU3D8H0P00h`4000H0001<0000
0000000000000000oooooooooomH0000<P0e02h0<00`02D02@0000T0000400002@0000T0000>0000
E0000700001i0P00h`400:h2003f0@000@0000043D9E9@e2N@800><100060000C000000000000000
00000?ooooooooooF0000380=@0^0300<00U00T000090000100000T0000900003P0005@0001`0000
fP800><1000?0`00mP400040000010e2EBD=@]X2003S0@001P0004`00000000000000000003ooooo
oooooeP0000b03D0;P0`03009@0900002@0000@0000900002@0000h0001D0000L00003/3003S0@00
L0<00?H10001000000@=@UDU3D8k0`00h`4000H0001<00000000000000000000oooooooooomH0000
<P0e02h0<00`02D02@0000T0000400002@0000T0000>0000E000060000040000n0400280000;0P00
0@0000043D9E9@e210000?P100030000C00000000000000000000?ooooooooooE00005@0@@1H0000
2@0000/0000;00006`00010000270@00208005@0001T0000I`400?P100260@002`800040000010e2
EBD=@VL1003h0@00100004`00000000000000000003ooooooooooe@0000]03T0<00e00D000090000
2@0000T0000K000040000>P100080P00E00006`0002k0@00n0400>L1000;0P000@0000043D9E9@e2
^`400?P100050000C00000000000000000000?ooooooooooF0000340<P0d0300>@0000T000090000
2@0000T0000900006`00010000190P00208005@0001/000070800?P100180P002`800040000010e2
EBD=@Q`2003h0@001@0004`00000000000000000003ooooooooooeP0000b03D0>00h03<000090000
2@0000T0000900002@0001/0000@0000ZP8000P2001D0000K00007d2003h0@00Z@8000/200010000
00@=@UDU3D9m0P00n04000D0001<00000000000000000000oooooooooomH0000<`0i03D0<P0d0000
2@0000T0000900002@0000T0000K0000400000/300080P00E00006`0003N0P00n04000X3000;0P00
0@0000043D9E9@e2gP800?P100050000C00000000000000000000?ooooooooooF00003D0<`0c03<0
=00000T0000900002@0000T0000900006`000100001/0`00208005@0001/0000?`<00?P1001[0`00
2`800040000010e2EBD=@Sl3003h0@001@0004`00000000000000000003ooooooooooeP0000f03L0
<`0b0340000900002@0000T0000900002@0002D0000<00003@00P280000<0000ooooob4000080000
9@0000`0000100006@0000`0003oool0600000`0000000007P0001P0000100008P8002h1000f0P00
500000`0000=00004P0000`000010000E0000=00000100008P800=H0000e0P000@0000043D9E9@e2
00000282000F0000C00000000000000000000?ooooooooooN0000580A@1F04D0DP1C04T0C`1>0200
@`1104`0@`1E04`0@@1D04T0C`1>03X0300000/0000;00002`0000`0000;00001@0000`0000;0000
100000/0000;00002@0000/0000<00002@0000/0000900001@0000`0000;0000100002D0000<0000
3@00P280000<0000ooooob40000800009@0000`0000100006@0000`0003oool0600000`000000000
7P0001P0000100000@0007D3002;0P00500000`0000=00004P0000`000010000E0000<@000040000
C0800<T0001O0P000@0000043D9E9@e2100004`2000D0000C00000000000000000000?oooooooooo
M0000480;@1D0440F00P05<0@@1<04D0D`0P0500DP1?04<0A@1504@0D`0;00001@0000T0000;0000
2`0000@0000;00002`0000T0000;00002`0000@0000:0000300000`0000;00002`0000/0000<0000
2`0001/0000@00009P4005`2001D0000I00000L1001<0P009@4005l20001000000@=@UDU3D870@00
C08000@0001<00000000000000000000oooooooooomD0000<00^0300<0090000100000T000090000
6`00010000270@00G08005@0001`0000D@4004`200260@00G`800040000010e2EBD=@U41001<0P00
1P0004`00000000000000000003ooooooooooeP0000c0340>@0h03L0=P0900002@0000T000090000
2@0000T0000K000040000>P1001L0P00E0000700002b0@00C0800>L1001O0P000@0000043D9E9@e2
/P4004`200060000C00000000000000000000?ooooooooooF00003<0=@0i03T0>@0i00T000090000
2@0000T0000900002@0001/0000@0000B@8005`2001D0000L00001<2001<0P00B08005l200010000
00@=@UDU3D8C0P00C08000H0001<00000000000000000000oooooooooomH0000=00`0340=`0`0340
2@0000T0000900002@0000T0000900006`000100002Z0P00G08005@0001`0000M08004`2002Y0P00
G`800040000010e2EBD=@W@2001<0P001P0004`00000000000000000003ooooooooooeP0000d03@0
=@0`03L0=P0900002@0000T0000900002@0000T0000K0000400000/3001L0P00E0000700003E0P00
C08000X3001O0P000@0000043D9E9@e2e@8004`200060000C00000000000000000000?oooooooooo
F00003@0>@0`0380<P0`00T0000900002@0000T0000900002@0001/0000@0000K0<005`2001D0000
L00003H3001<0P00J`<005l20001000000@=@UDU3D8f0`00C08000H0001<00000000000000000000
oooooooooomH0000=@0c03L0<P0d03802@0000T0000900002@0000T000090000E000060000040000
H@800280001d0P000@0000043D9E9@e21000064200030000C00000000000000000000?oooooooooo
E00005@0@@1H00002@0000/0000;00006`00010000270@00L@8005@0001P0000K040064200260@00
M0800040000010e2EBD=@V`1001Q0P000`0004`00000000000000000003ooooooooooe@0000i0300
=@0000T0000900002@0001/0000@0000j0400742001D0000L0000;H1001Q0P00i`4007@200010000
00@=@UDU3D:f0@00H@8000H0001<00000000000000000000oooooooooomH0000;@0a0380=00`03T0
1@0000T0000900002@0000T0000900006`00010000190P00L@8005@0001`00005`80064200180P00
M0800040000010e2EBD=@QL2001Q0P001P0004`00000000000000000003ooooooooooeP0000]0380
=@0h03P0<`0500002@0000T0000900002@0000T0000K000040000:X2001a0P00E0000700001h0P00
H@800:T2001d0P000@0000043D9E9@e2N080064200060000C00000000000000000000?oooooooooo
F00002d0<`0i03D0<P0d00D0000900002@0000T0000900002@0001/0000@00002`<00742001D0000
L0000=T2001Q0P002P<007@20001000000@=@UDU3D;I0P00H@8000H0001<00000000000000000000
oooooooooomH0000;@0e03<0<`0c03@01@0000T0000900002@0000T0000900006`000100001/0`00
L@8005@0001`0000>P<00642001[0`00M0800040000010e2EBD=@SX3001Q0P001P0004`000000000
00000000003ooooooooooeP0000]03H0=`0c0380<@0500002@0000T0000900002@0000T0001D0000
d00000@0001f0P00fP0008T20001000000@=@UDU3D840000MP8001H0001<00000000000000000000
oooooooooomh0000@@1605@0A@1B0200E01105P080150540801B04D0EP150580D`1904l0CP0;0000
2P0000T0000;0000300000@0000900002`0000/0000400002`0000`000040000300000/0000;0000
2`0000`0000;00001@0000`0000;00006`00010000270@00QP8005@0001`0000D@4007H200260@00
R@800040000010e2EBD=@U41001f0P001P0004`00000000000000000003ooooooooooeP0000c0380
<00g03P0<@0900002@0000T0000900002@0000T0000K000040000>P100260P00E0000700002b0@00
MP800>L100290P000@0000043D9E9@e2/P4007H200060000C00000000000000000000?oooooooooo
F00003<0=00g03D0>@0`00T0000900002@0000T0000900002@0001/0000@0000B@8008H2001D0000
L00001<2001f0P00B08008T20001000000@=@UDU3D8C0P00MP8000H0001<00000000000000000000
oooooooooomH0000<`0g03D0>00a03P02@0000T0000900002@0000T0000900006`000100002Z0P00
QP8005@0001`0000M08007H2002Y0P00R@800040000010e2EBD=@W@2001f0P001P0004`000000000
00000000003ooooooooooeP0000d0300=@0e03D0<P0900002@0000T0000900002@0000T0000K0000
400000/300260P00E0000700003E0P00MP8000X300290P000@0000043D9E9@e2e@8007H200060000
C00000000000000000000?ooooooooooF00003@0<`0f03P0>00f00T0000900002@0000T000090000
2@000580001`0@0010000?3oool0000000000000002@0@0000000000029806D0K01f000000000000
0000000000000000000000000000000000000000000000000000000000000000001G1X3QQ@10FeP6
0001002fE`H00@00N5]H1P000000]5L60@00032[?P0]OVUdTB<1[c00000`00002P0000X000100g@2
2P00041KF0I00g@2ND[ZMEb[?P0:00000@00041KF0ILZch0llQYM801KWC32dmT>@00094S0Jl003h0
E<UYM94S0Jl`0000>@000080002h[3h0e:/n06?Y56BA8`6_<00003T0002h[3h0W4DY1Y4S0Jo;Ik/_
0000062]?P0100000000000000010000J:hn050`e2lBmkT_G:Rd<8bafP7`n;T_f1Z?0^R[?P3lZch0
=>TDI6Af00P000009@0000`000040000600000`0003o00006`000100001/0`00QP8005@0001`0000
=P<007H2001[0`00R@800040000010e2EBD=@SH3001f0P001P0004`00000000000000000003ooooo
oooooeP0000d03H0>@0i0380<@0900002@0000T0000900002@0000T0000H000030000000000U0000
300000d0080R000030000?oooolQ0000200002D0000<0000100001T0000<0000oooo01P0000<0000
000001h0000H000000000000001e0`00R`8002L0000H00001@000000003Jg=d0000002D0000<0000
1@0001P0000<0000f]cM01T0000<0000f]cM01@0000<00003@000180000<00000P0002H0000L0000
1P0000000000000000000=[Lg@0U0000300000H0000K000040000=@000000000=P000100003D0000
8P8002D0000<00001`00P4`0001T0000e0000000003D00008@800=@0000000000@000282000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K000040000=@0000g0P00=P000100003D0000MP8002D0000<00001`00P4`0001T0000
e00003L2003D0000M@800=@0000g0P000@0003l0000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000H0000K00004000000000000000
=P00010000000000S08002D0000<00001`00P4`0001T00000000000000000000RP80000000000000
0@0008`2000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000H0000K000040000=@0002;0P00=P000100003D0000S08002D0000<0000
1`00P4`0001T000000000000003oooooooooom@0002;0P000@000040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000H0000K0000
400002h100000000=P000100000^0@00S08002D0000<00001`00P4`0001T0000;P400000000^0@00
RP8002h1000000000@0008`2000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000H0000K0000400008l100000000=P000100002?0@00
S08002D0000<00001`00P4`0001T0000S`400000002?0@00RP8008l1000000000@0008`2000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K000040000?0100000000=P000100003`0@00S08002D0000<00001`00P4`0001T0000
l0400000003`0@00RP800?01000000000@0008`2000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000H0000K00004000054200000000
=P000100001A0P00S08002D0000<00001`00P4`0001T0000D@800000001A0P00RP80054200000000
0@0008`2000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000H0000K000040000;8200000000=P000100002b0P00S08002D0000<0000
1`00P4`0001T0000/P800000002b0P00RP800;82000000000@0008`2000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000H0000K0000
400001<300000000=P000100000C0`00S08002D0000<00001`00P4`0001T00004`<00000000C0`00
RP8001<3000000000@0008`2000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000H0000K0000400007@300000000=P000100001d0`00
S08002D0000<00001`00P4`0001T0000M0<00000001d0`00RP8007@3000000000@0008`2000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K00004000000000000000=P000100001f0`00000002D0000<00001`00P4`0001T0000
00000000001d0`000000000000000000MP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000H0000K000040000000000O0000
=P000100001f0`007`0002D0000<00001`00P4`0001T0000000001l0001d0`007`000000000O0000
MP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000H0000K000040000000000n0000=P000100001f0`00?P0002D0000<0000
1`00P4`0001T0000000003h0001d0`00?P000000000n0000MP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000H0000K0000
40000000001C0000=P000100001f0`00D`0002D0000<00001`00P4`0001T0000000005<0001d0`00
D`000000001C0000MP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000H0000K000040000000001X0000=P000100001f0`00
J00002D0000<00001`00P4`0001T0000000006P0001d0`00J0000000001X0000MP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K000040000000001m0000=P000100001f0`00O@0002D0000<00001`00P4`0001T0000
000007d0001d0`00O@000000001m0000MP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000H0000K000040000000002B0000
=P000100001f0`00TP0002D0000<00001`00P4`0001T000000000980001d0`00TP000000002B0000
MP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000H0000K000040000000002W0000=P000100001f0`00Y`0002D0000<0000
1`00P4`0001T000000000:L0001d0`00Y`000000002W0000MP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000H0000K0000
40000000002l0000=P000100001f0`00_00002D0000<00001`00P4`0001T000000000;`0001d0`00
_0000000002l0000MP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000H0000K000040000000003A0000=P000100001f0`00
d@0002D0000<00001`00P4`0001T000000000=40001d0`00d@000000003A0000MP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K000040000000003V0000=P000100001f0`00iP0002D0000<00001`00P4`0001T0000
00000>H0001d0`00iP000000003V0000MP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000H0000K000040000000003k0000
=P000100001f0`00n`0002D0000<00001`00P4`0001T000000000?/0001d0`00n`000000003k0000
MP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000H0000K000040000000000@0@00=P000100001f0`00404002D0000<0000
1`00P4`0001T000000000101001d0`0040400000000@0@00MP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000H0000K0000
40000000000U0@00=P000100001f0`009@4002D0000<00001`00P4`0001T0000000002D1001d0`00
9@400000000U0@00MP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000H0000K000040000000000j0@00=P000100001f0`00
>P4002D0000<00001`00P4`0001T0000000003X1001d0`00>P400000000j0@00MP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K000040000000001?0@00=P000100001f0`00C`4002D0000<00001`00P4`0001T0000
000004l1001d0`00C`400000001?0@00MP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000H0000K000040000000001T0@00
=P000100001f0`00I04002D0000<00001`00P4`0001T0000000006@1001d0`00I0400000001T0@00
MP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000H0000K000040000000001i0@00=P000100001f0`00N@4002D0000<0000
1`00P4`0001T0000000007T1001d0`00N@400000001i0@00MP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000H0000K0000
40000000002>0@00=P000100001f0`00SP4002D0000<00001`00P4`0001T0000000008h1001d0`00
SP400000002>0@00MP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000H0000K000040000000002S0@00=P000100001f0`00
X`4002D0000<00001`00P4`0001T000000000:<1001d0`00X`400000002S0@00MP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K000040000000002h0@00=P000100001f0`00^04002D0000<00001`00P4`0001T0000
00000;P1001d0`00^0400000002h0@00MP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000H0000K000040000000003=0@00
=P000100001f0`00c@4002D0000<00001`00P4`0001T000000000<d1001d0`00c@400000003=0@00
MP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000H0000K000040000000003R0@00=P000100001f0`00hP4002D0000<0000
1`00P4`0001T000000000>81001d0`00hP400000003R0@00MP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000H0000K0000
40000000003g0@00=P000100001f0`00m`4002D0000<00001`00P4`0001T000000000?L1001d0`00
m`400000003g0@00MP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000H0000K000040000000000<0P00=P000100001f0`00
308002D0000<00001`00P4`0001T0000000000`2001d0`0030800000000<0P00MP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K000040000000000Q0P00=P000100001f0`008@8002D0000<00001`00P4`0001T0000
00000242001d0`008@800000000Q0P00MP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000H0000K000040000000000f0P00
=P000100001f0`00=P8002D0000<00001`00P4`0001T0000000003H2001d0`00=P800000000f0P00
MP<00040000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000H0000K000040000000001;0P00=P000100001f0`00B`8002D0000<0000
1`00P4`0001T0000000004/2001d0`00B`800000001;0P00MP<00040000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000H0000K0000
40000000001P0P00=P000100001f0`00H08002D0000<00001`00P4`0001T000000000602001d0`00
H0800000001P0P00MP<00040000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000H0000K000040000000001e0P00=P000100001f0`00
M@8002D0000<00001`00P4`0001T0000000007D2001d0`00M@800000001e0P00MP<00040000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000H0000K000040000000002:0P00=P000100001f0`00RP8002D0000<00001`00P4`0001T0000
000008X2001d0`00RP800000002:0P00MP<00040000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000@0080U0000300000d0080R0000
30000?oooolQ0000200002D0000<0000100001T0000<0000f]cM01P0000<0000f]cM01h0000H0000
0@000040001e0`00R`800280000<0000ooooodH0000d0000:00004E=AR/Z@000900001P00000080o
0000P0000800080o0000P00008160000700001000015CDH[0T0000`0000000003P0001@000000000
400001@0
\>"], "Graphics",
 Editable->False,
 TextAlignment->Center,
 ImageSize->{588.3333333333331, 433.141080011309},
 ImageMargins->{{328.99999999999994`, 0.}, {0., 
  0.}},ExpressionUUID->"2dbdc4ff-6cff-40a2-9264-6f598d7e55e0"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Sale computations for sample project"
}], "FigureCaption",
 CellChangeTimes->{{3.5285722649187217`*^9, 3.5285722710110703`*^9}, 
   3.5409358530114775`*^9},
 TextAlignment->Center,ExpressionUUID->"69df0030-c5c2-490d-80c3-82ea414da7fc"],

Cell[TextData[{
 "With these in place we can calculate the after-tax equity reversion, ",
 StyleBox["er. ", "Input"],
 StyleBox["G", "Input",
  FontWeight->"Plain"],
 "iven the data in Table 4.1 we get the same result in the lower right corner \
of Figure 4.7."
}], "Text",
 CellChangeTimes->{{3.5285727495544415`*^9, 3.5285727564568357`*^9}, {
  3.5285727882496543`*^9, 
  3.5285728176123343`*^9}},ExpressionUUID->"a3303430-81ed-419e-aa0d-\
3237e9c83de6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"er", "/.", "data"}]], "Input",
 CellLabel->"In[54]:=",ExpressionUUID->"00c60968-a4f9-4962-ad4c-617dbc4619bb"],

Cell[BoxData["469921.11491303565`"], "Output",
 CellChangeTimes->{3.528570845704547*^9, 3.5286373180315466`*^9, 
  3.5299294431532536`*^9, 3.533063636139471*^9, 3.5330720585172033`*^9, 
  3.53368164603125*^9, 3.533733680667905*^9, 3.533753352421875*^9, 
  3.5395201126741915`*^9, 3.539521119018751*^9, 3.5395213518180666`*^9, 
  3.5395224256544867`*^9, 3.5395231379622283`*^9, 3.5401252264836564`*^9, 
  3.5409350324565444`*^9, 3.5409353045161057`*^9, 3.5409354003495865`*^9, 
  3.540936009753443*^9, 3.54093756136919*^9, 3.5409379293244686`*^9, 
  3.5410030464029527`*^9, 3.5415996591790237`*^9, 3.543239119243812*^9, 
  3.69607588307823*^9, 3.6962290245109253`*^9, 3.696231657409423*^9, 
  3.696232175094711*^9, 3.7314209340210004`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"0a5148c2-30e0-4393-8ac8-98464423ef91"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". The net present value"
}], "Section",
 CellChangeTimes->{
  3.531447172614333*^9, 3.531447274965187*^9, {3.5337338734599323`*^9, 
   3.5337338789592466`*^9}},ExpressionUUID->"c45a02c1-050a-4857-a212-\
22692180be17"],

Cell[TextData[{
 "In order to determine net present value we need a function, Equation 4.1, \
that iterates each annual cash flow, takes the present value of each, sums \
these, adds the total to the present value of the after-tax equity reversion ",
 StyleBox["(er)",
  FontWeight->"Bold"],
 " and subtracts the initial investment (",
 StyleBox["dp", "Input"],
 ")"
}], "Text",
 CellChangeTimes->{
  3.5285708748372135`*^9, {3.528572964338726*^9, 3.5285729692950096`*^9}, {
   3.5299301329547076`*^9, 
   3.5299301345387983`*^9}},ExpressionUUID->"868fbcce-93af-4630-8176-\
8d4654ef0965"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"npv", "=", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "t"], 
      FractionBox[
       SubscriptBox["cf", "n"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "r"}], ")"}], "n"]]}], "+", 
     FractionBox[
      SubscriptBox["er", "t"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "r"}], ")"}], "t"]], "-", "dp"}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.528570893728294*^9},ExpressionUUID->"0b021aae-4ba5-427a-8bd3-\
1164bdabd1b4"],

Cell[BoxData[
 RowBox[{"npv", ":=", 
  RowBox[{
   FractionBox["er", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "r"}], ")"}], "k"]], "+", 
   RowBox[{"(", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "k"], 
     RowBox[{"Evaluate", "[", 
      FractionBox[
       RowBox[{"cf", "[", "n", "]"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "r"}], ")"}], "n"]], "]"}]}], ")"}], "-", 
   "dp"}]}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{3.5219403486843233`*^9},
 CellLabel->"In[55]:=",ExpressionUUID->"2732839e-3362-4b57-b006-c6c8a24c78dd"],

Cell[TextData[{
 "Figure 4.8 displays the results of Equation 4.1 for the sample project. The \
lower right corner matches the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " result"
}], "Text",
 CellChangeTimes->{{3.528572996296554*^9, 
  3.528573077794215*^9}},ExpressionUUID->"fc509b19-59c2-4fbd-a616-\
fa745f7412b2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"npv", "/.", "data"}]], "Input",
 CellLabel->"In[56]:=",ExpressionUUID->"7f8a9778-4ad9-4f3e-b2ca-1c6e06f3ca6e"],

Cell[BoxData[
 RowBox[{"-", "47353.26782151128`"}]], "Output",
 CellChangeTimes->{
  3.5285709289683094`*^9, 3.5286373382177014`*^9, 3.529929465034505*^9, 
   3.533063656211619*^9, 3.533072077707301*^9, 3.533681684046875*^9, 
   3.533733700932064*^9, 3.53375339115625*^9, 3.539520133430379*^9, {
   3.5395211395849276`*^9, 3.539521194738082*^9}, 3.539521386200033*^9, 
   3.5395224448035817`*^9, 3.5395231572163296`*^9, 3.5401252469628277`*^9, 
   3.540935070859741*^9, 3.5409353238902135`*^9, 3.5409354202497253`*^9, 
   3.540936029166553*^9, 3.540937591127892*^9, 3.5409379506696897`*^9, 
   3.5410030857542033`*^9, 3.541599679856207*^9, 3.54323913949197*^9, 
   3.696075890162076*^9, 3.69622903170107*^9, 3.696231664476224*^9, 
   3.6962321821865788`*^9, 3.731420948523571*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"734d778f-d759-4dc9-98f8-a5fedf94894d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztndGR5LhyRTtC+pMVcmPNkAnvY3/lylozf3JE+2QL9XZ7uoZNJhIJkARQ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    "], {{0, 189}, {1035, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{660.3333333333284, Automatic},
  ImageSizeRaw->{1035, 189},
  PlotRange->{{0, 1035}, {0, 189}}]], "Text",
 Editable->False,
 CellChangeTimes->{3.540935924622574*^9},
 TextAlignment->Center,
 TextJustification->0.,ExpressionUUID->"bbd4abea-dc25-41d1-a90d-c77022568533"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Net present value and IRR computations for sample project"
}], "FigureCaption",
 Editable->False,
 CellChangeTimes->{{3.5285728598447495`*^9, 3.528572871636424*^9}, 
   3.5409358597418623`*^9},
 TextAlignment->Center,ExpressionUUID->"1a943f47-9d6e-4562-84dc-5d49a8b94b2a"]
}, Open  ]],

Cell[TextData[{
 "We certainly went to a lot of trouble only to learn that the property has a \
negative net present value. For our sample project this means its return does \
not support its cost of capital. Therefore, the potential buyer/investor will \
reject the project. Simply stated, a negative ",
 StyleBox["npv",
  FontSlant->"Italic"],
 " means this project is a bad deal from the buyer's perspective."
}], "Text",
 CellChangeTimes->{
  3.5285730852926445`*^9, {3.5409364241451445`*^9, 
   3.5409364248861866`*^9}},ExpressionUUID->"d6a9ca38-59a9-4bc4-919a-\
9f979a183714"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Insight into the analysis"
}], "Section",
 CellChangeTimes->{
  3.531447172614333*^9, 3.531447295545364*^9, 3.5337338970982842`*^9, {
   3.540936448459535*^9, 
   3.5409364504736505`*^9}},ExpressionUUID->"648ab817-ebe3-40fd-a5cb-\
8e8a1334f172"],

Cell[TextData[{
 "Above we referred to the variables as \"deterministic\" because we can ",
 StyleBox["determine",
  FontSlant->"Italic"],
 " the outcome - the ",
 StyleBox["npv",
  FontSlant->"Italic"],
 " - by choosing particular ",
 Cell[BoxData[
  FormBox[
   RowBox[{"variables", 
    SuperscriptBox[".", 
     ButtonBox["3",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote3"]]}], TraditionalForm]],ExpressionUUID->
  "d0478067-147d-4fd5-b735-eb5c280f4040"],
 " The outcome changes every time the values of the variables change.  With \
any change in the nominal value of a variable we explicitly ",
 StyleBox["cause",
  FontSlant->"Italic"],
 " a change in return, as measured by the ",
 StyleBox["npv",
  FontSlant->"Italic"],
 ".  But there is usually also a corresponding ",
 StyleBox["implicit",
  FontSlant->"Italic"],
 " change in the risk.  Understanding the inner workings of the variables \
provides an explicit view of risk and insight into the bargaining process. \
Seeing dependencies at the general level allows us to ask \"if-then\" type \
questions about the entire process, not just about a single acquisition. "
}], "Text",
 CellChangeTimes->{
  3.528638271151062*^9, {3.528638369947713*^9, 3.528638388289762*^9}, {
   3.540936441186119*^9, 
   3.5409364444463053`*^9}},ExpressionUUID->"0e4fbc87-070d-44b4-af1f-\
11b84399e7c3"],

Cell["\<\
To illustrate the concept of dependency in a very simple case, we look at the \
deterministic inputs that affect the gross rent multiplier.  We know this \
equation as:\
\>", "Text",ExpressionUUID->"36ba7315-e84f-4531-ba3b-604486fbcb85"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"grm", "=", 
    FractionBox["value", 
     RowBox[{"gross", " ", "scheduled", " ", "income"}]]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.5285731324633427`*^9},ExpressionUUID->"0200d7fe-3daf-4cee-99ea-\
72c5d4471f12"],

Cell[TextData[{
 "Hence it would seem that ",
 StyleBox["grm", "Input"],
 " is simply dependent upon two variables, the value and the gross income.  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " sees it differently.  Because value is  defined above as a combination of \
two other deterministic variables, when evaluating the expression \"",
 StyleBox["grm", "Input"],
 "\" ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " considers and displays not only the variables in the equation above but \
the variables which are the antecedent primitives that make up value."
}], "Text",
 CellChangeTimes->{
  3.540936467701636*^9},ExpressionUUID->"62ff39e9-69e0-42ec-9c53-\
4cd2f0f567ca"],

Cell[CellGroupData[{

Cell[BoxData["grm"], "Input",
 CellLabel->"In[57]:=",ExpressionUUID->"0640e802-6cbb-4288-b619-af6c7a17a101"],

Cell[BoxData[
 FractionBox[
  RowBox[{"dp", "+", "initln"}], "gsi"]], "Output",
 CellChangeTimes->{3.5285731546716127`*^9, 3.528637342096923*^9, 
  3.529929465406526*^9, 3.5330636566766453`*^9, 3.533072077850309*^9, 
  3.533681684234375*^9, 3.533733701397091*^9, 3.533753392078125*^9, 
  3.5395201340114117`*^9, 3.539521139685933*^9, 3.5395215944099417`*^9, 
  3.539522444968591*^9, 3.5395231574543433`*^9, 3.540125247084835*^9, 
  3.5409350709697475`*^9, 3.5409353239982195`*^9, 3.5409354204087343`*^9, 
  3.5409360294085665`*^9, 3.540937591490913*^9, 3.5409379512967253`*^9, 
  3.5410030859122124`*^9, 3.5415996805512466`*^9, 3.543239140156008*^9, 
  3.696075890225399*^9, 3.6962290317622166`*^9, 3.696231664547413*^9, 
  3.6962321822908554`*^9, 3.731420948577716*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"3e7ae65a-f573-4fac-a61f-3a6c2b66e4bf"]
}, Open  ]],

Cell[TextData[{
 "So we see that, given how we have defined the variables, three things \
determine the ",
 StyleBox["grm", "Input"],
 ", not the two we originally thought."
}], "Text",ExpressionUUID->"9e71b58f-587d-4ba0-97bf-b12940068e77"],

Cell[TextData[{
 StyleBox["grm", "Input"],
 " is too simple to illustrate the full benefit of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".   One can easily see what determines ",
 StyleBox["grm", "Input"],
 ".  More difficult and complex examples exist at the other extreme. When we \
look at what affects after-tax cash flow, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["cf", "0"],
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "e2fe09fb-0a7e-4641-987e-a7aa1ef31137"],
 ", we find a really ugly equation that incorporates all of the inputs \
leading to this output."
}], "Text",
 CellChangeTimes->{
  3.5285731782349606`*^9, {3.5285735899995117`*^9, 
   3.528573598145978*^9}},ExpressionUUID->"5f09a23c-731d-4535-8b18-\
1a89238305dc"],

Cell[BoxData[
 RowBox[{"cf0", "//", "TraditionalForm"}]], "Input",
 PageWidth->PaperWidth,
 Evaluatable->False,
 CellOpen->False,
 CellChangeTimes->{{3.5219789440268507`*^9, 
  3.5219789464709907`*^9}},ExpressionUUID->"2ca4c316-401b-453d-8f55-\
d96021329449"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    SubscriptBox["cf", "0"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "txrt"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "dprt"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "land"}], " ", 
            RowBox[{"(", 
             RowBox[{"dp", "+", "initln"}], ")"}]}], "+", "dp", "+", 
           "initln"}], ")"}]}], "-", 
        RowBox[{"exprt", " ", 
         RowBox[{"(", 
          RowBox[{"gsi", "-", 
           RowBox[{"gsi", " ", "vacrt"}]}], ")"}]}], "+", 
        RowBox[{"gsi", " ", 
         RowBox[{"(", 
          RowBox[{"-", "vacrt"}], ")"}]}], "+", "gsi", "-", 
        FractionBox[
         RowBox[{"12", " ", "i", " ", "initln"}], 
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}], 
           RowBox[{"-", "t"}]]}]], "-", 
        FractionBox[
         RowBox[{"initln", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"i", "+", "1"}], ")"}], 
             RowBox[{"12", "-", "t"}]]}], ")"}]}], 
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}], 
           RowBox[{"-", "t"}]]}]], "+", "initln"}], ")"}]}], "-", 
     RowBox[{"exprt", " ", 
      RowBox[{"(", 
       RowBox[{"gsi", "-", 
        RowBox[{"gsi", " ", "vacrt"}]}], ")"}]}], "+", 
     RowBox[{"gsi", " ", 
      RowBox[{"(", 
       RowBox[{"-", "vacrt"}], ")"}]}], "+", "gsi", "-", 
     FractionBox[
      RowBox[{"12", " ", "i", " ", "initln"}], 
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], 
        RowBox[{"-", "t"}]]}]]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5285732350562105`*^9, 
  3.528585314573119*^9},ExpressionUUID->"5ce14eba-0ee4-4cf2-9cae-\
cc5b33545fa5"],

Cell["\<\
Ugly as the (4.3) may seem, it is really nothing more than a fairly long \
algebraic equation. One could, with some difficulty, construct such an \
equation from the formulae underlying the cells of a spreadsheet program.\
\>", "Text",
 CellChangeTimes->{{3.5285734327945204`*^9, 3.528573435146655*^9}, {
  3.529930287784563*^9, 
  3.529930289318651*^9}},ExpressionUUID->"44296690-1903-4d2d-a3a4-\
bf06b2ece7ba"],

Cell[TextData[{
 "Sometimes we can gain more useful insight by giving fixed numeric values to \
some of the variables. This has the beneficial effect of eliminating some of \
the variables as symbols in favor of constants. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " further simplifies these constants by combining them where possible. It \
makes sense to substitute real numbers for those variables out of the owner's \
control. For instance, income tax rates, depreciation rates and land \
assessments are handed down by government.  Taking part of the data from our \
list, below we reproduce Equation 4.3, providing temporary rules for tax \
rates and land assessments, thereby reducing the number of symbolic variables \
to cap rate, loan amount, interest rate, expense and vacancy rates and the \
gross scheduled income in Equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4.4", 
    SuperscriptBox[".", 
     ButtonBox["4",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote4"]]}], TraditionalForm]],ExpressionUUID->
  "eb581a52-af28-4388-95d0-3f11f0f6e478"],
 "  Do these affect cash flow?  They certainly do and the owner has some \
influence on them."
}], "Text",
 CellChangeTimes->{{3.5286384638060813`*^9, 3.5286384638060813`*^9}, {
  3.528638786320528*^9, 
  3.528638786320528*^9}},ExpressionUUID->"b6700f23-8c0b-4c37-91f8-\
fea30f11e780"],

Cell[BoxData[
 RowBox[{"TraditionalForm", "[", 
  RowBox[{
   RowBox[{"cf0", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"txrt", "->", ".35"}], ",", 
      RowBox[{"dprt", "->", 
       RowBox[{"1", "/", "31"}]}], ",", 
      RowBox[{"land", "->", ".3"}]}], "}"}]}], "//", "Simplify"}], 
  "]"}]], "Input",
 PageWidth->PaperWidth,
 Evaluatable->False,
 CellOpen->False,
 CellChangeTimes->{
  3.5219784177367487`*^9, {3.5219790712661285`*^9, 
   3.5219790778875074`*^9}},ExpressionUUID->"471e8dd7-1680-4f09-a745-\
92e99426563b"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    SubscriptBox["cf", "0"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.35`"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.02258064516129032`"}], " ", "dp"}], "+", 
        RowBox[{"exprt", " ", "gsi", " ", 
         RowBox[{"(", 
          RowBox[{"vacrt", "-", "1"}], ")"}]}], "-", 
        RowBox[{"gsi", " ", "vacrt"}], "+", "gsi", "-", 
        FractionBox[
         RowBox[{"12", " ", "i", " ", "initln", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}], "t"]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}], "t"], "-", "1"}]], "-", 
        FractionBox[
         RowBox[{"initln", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"i", "+", "1"}], ")"}], 
             RowBox[{"12", "-", "t"}]]}], ")"}]}], 
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}], 
           RowBox[{"-", "t"}]]}]], "+", 
        RowBox[{"0.9774193548387097`", " ", "initln"}]}], ")"}]}], "+", 
     RowBox[{"exprt", " ", "gsi", " ", 
      RowBox[{"(", 
       RowBox[{"vacrt", "-", "1"}], ")"}]}], "-", 
     RowBox[{"gsi", " ", "vacrt"}], "+", "gsi", "-", 
     FractionBox[
      RowBox[{"12", " ", "i", " ", "initln", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], "t"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], "t"], "-", "1"}]]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5285732890733*^9, 
  3.5285853030684614`*^9},ExpressionUUID->"2484f377-05e0-4ffe-b868-\
ec8d3fc5c526"],

Cell[TextData[{
 "Suppose we have already decided to purchase the property or we already own \
it.  Under those conditions we may know the income, loan details and expense \
and vacancy factors.  Inserting these values as numbers shows us that our \
cash flow is related to some constants and the interest rate. This permits us \
to consider explicitly the risk of variable interest rate loans. We also get \
a feel for the meaning of what is sometimes referred to as \"positive \
leverage\". Using capitalization rate > loan constant as the definition of \
positive leverage, we know that if leverage is positive then cash flow must \
be positive. (If you don't know that you have just discovered an important \
reason to use symbolic analysis). As the last constant term in Equation 4.5 \
is the net operating income, the aggregate of everything before that term \
must be smaller than that number for cash flow to be positive. This is, of \
course, critically dependent on the interest ",
 Cell[BoxData[
  FormBox[
   RowBox[{"rate", 
    SuperscriptBox[".", 
     ButtonBox["5",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote5"]]}], TraditionalForm]],ExpressionUUID->
  "4449a0c7-246a-4b18-9097-e0f0b8117c0e"],
 " "
}], "Text",
 CellChangeTimes->{{3.528573816402461*^9, 3.528573840889862*^9}, {
   3.5285738874925275`*^9, 3.5285738888516054`*^9}, {3.5285739379274125`*^9, 
   3.528573957402526*^9}, 3.528638839086546*^9, {3.5286389181220665`*^9, 
   3.528638931408827*^9}},ExpressionUUID->"06e6504d-5759-458d-99cf-\
ac6156494778"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{
    RowBox[{"cf0", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"txrt", "->", ".35"}], ",", 
       RowBox[{"dprt", "->", 
        RowBox[{"1", "/", "31"}]}], ",", 
       RowBox[{"land", "->", ".3"}], ",", 
       RowBox[{"gsi", "->", "200000"}], ",", 
       RowBox[{"initln", "->", "875000"}], ",", 
       RowBox[{"dp", "->", "375000"}], ",", 
       RowBox[{"vacrt", "->", ".1"}], ",", 
       RowBox[{"exprt", "->", ".35"}], ",", 
       RowBox[{"t", "->", "360"}]}], "}"}]}], "//", "FullSimplify"}], "]"}], 
  ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.528573857965839*^9, 3.5285738656562786`*^9}, 
   3.5285739139920435`*^9},
 CellLabel->"In[58]:=",ExpressionUUID->"b42ec447-f68e-4d6a-92f3-1ebb55ffc610"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    SubscriptBox["cf", "0"], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"10500000", " ", "i"}], 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"i", "+", "1"}], ")"}], "360"]], "-", "1"}]], "-", 
     RowBox[{"0.35`", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"10500000", " ", "i"}], 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"i", "+", "1"}], ")"}], "360"]], "-", "1"}]], "+", 
        FractionBox[
         RowBox[{"875000", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox["1", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"i", "+", "1"}], ")"}], "348"]]}], ")"}]}], 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"i", "+", "1"}], ")"}], "360"]], "-", "1"}]], "+", 
        "963774.1935483871`"}], ")"}]}], "+", "117000.`"}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.528573908921753*^9, {3.5285852528055863`*^9, 
   3.5285852593189588`*^9}},ExpressionUUID->"a884f9f7-6d40-4cd4-b5a6-\
1d8dc429e3c1"],

Cell[CellGroupData[{

Cell[TextData[{
 "Here we calculate the going-in capitalization rate, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["cr",
     FontSlant->"Italic"], "i"], TraditionalForm]],ExpressionUUID->
  "f673faf1-61b1-44dc-8d79-633e6eb94778"],
 ".  Then, by varying the loan interest to a rate above and below the cap \
rate we show first negative leverage then positive leverage, this time using \
capitalization rate > interest rate as our definition. Note the difference in \
cash flow in Table 4.3."
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5285740653126984`*^9, 3.5285740817836404`*^9}, {
  3.528583849088298*^9, 3.528583875674819*^9}, {3.539520526012833*^9, 
  3.539520526433857*^9}},ExpressionUUID->"2dfb1c42-c0e1-4713-9c11-\
df5cb26a887e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cri", "/.", "data"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"positiveLeverage", "=", 
   RowBox[{"cf0", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"txrt", "->", ".35"}], ",", 
      RowBox[{"dprt", "->", 
       RowBox[{"1", "/", "31"}]}], ",", 
      RowBox[{"land", "->", ".3"}], ",", 
      RowBox[{"gsi", "->", "200000"}], ",", 
      RowBox[{"initln", "->", "875000"}], ",", 
      RowBox[{"dp", "->", "375000"}], ",", 
      RowBox[{"vacrt", "->", ".1"}], ",", 
      RowBox[{"exprt", "->", ".35"}], ",", 
      RowBox[{"t", "->", "360"}], ",", 
      StyleBox[
       RowBox[{"i", "->", 
        RowBox[{".095", "/", "12"}]}],
       CellFrame->True,
       Background->GrayLevel[0.849989]]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"negativeLeverage", "=", 
   RowBox[{"cf0", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"txrt", "->", ".35"}], ",", 
      RowBox[{"dprt", "->", 
       RowBox[{"1", "/", "31"}]}], ",", 
      RowBox[{"land", "->", ".3"}], ",", 
      RowBox[{"gsi", "->", "200000"}], ",", 
      RowBox[{"initln", "->", "875000"}], ",", 
      RowBox[{"dp", "->", "375000"}], ",", 
      RowBox[{"vacrt", "->", ".1"}], ",", 
      RowBox[{"exprt", "->", ".35"}], ",", 
      RowBox[{"t", "->", "360"}], ",", 
      StyleBox[
       RowBox[{"i", "->", 
        RowBox[{".09", "/", "12"}]}],
       CellFrame->True,
       Background->GrayLevel[0.849989]]}], "}"}]}]}], ";"}]}], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.5285740653126984`*^9, {3.539521644921831*^9, 3.5395216580285807`*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"6c19997f-aeba-4bf5-acdb-19a1de265856"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SubscriptBox[\(cr\), \(i\)]\)=.0936\>\"", ",", 
       "SpanFromLeft"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<int=.09\>\"", ",", 
       RowBox[{"StringJoin", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[SubscriptBox[\"cf\", \
\"0\"],FontSlant->\"Italic\"]\) = $\>\"", ",", 
         RowBox[{"ToString", "[", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"positiveLeverage", ",", 
            RowBox[{"{", 
             RowBox[{"6", ",", "2"}], "}"}], ",", 
            RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], "]"}]}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<int=.095\>\"", ",", 
       RowBox[{"StringJoin", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[SubscriptBox[\"cf\", \
\"0\"],FontSlant->\"Italic\"]\) = $\>\"", ",", 
         RowBox[{"ToString", "[", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"negativeLeverage", ",", 
            RowBox[{"{", 
             RowBox[{"6", ",", "2"}], "}"}], ",", 
            RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], "]"}]}],
       "}"}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.52857417654206*^9, 3.5285742022625313`*^9}, {
  3.5285742730605807`*^9, 3.5285743101487017`*^9}, {3.5285743443746595`*^9, 
  3.5285743534091763`*^9}, {3.528574413773629*^9, 3.5285745451701446`*^9}, {
  3.528583656355274*^9, 3.5285838093440247`*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"f93c0cb0-ed50-487d-8fc8-31f40fc1447c"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\\!\\(\\*SubscriptBox[\\(cr\\), \\(i\\)]\\)=.0936\"\>", 
     "\[SpanFromLeft]"},
    {"\<\"int=.09\"\>", "\<\"\\!\\(\\*StyleBox[SubscriptBox[\\\"cf\\\", \\\"0\
\\\"],FontSlant->\\\"Italic\\\"]\\) = $26,652.30\"\>"},
    {"\<\"int=.095\"\>", "\<\"\\!\\(\\*StyleBox[SubscriptBox[\\\"cf\\\", \
\\\"0\\\"],FontSlant->\\\"Italic\\\"]\\) = $28,921.20\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.5285743539852095`*^9, {3.528574420225998*^9, 3.528574447047532*^9}, {
   3.5285744807834616`*^9, 3.528574545866184*^9}, {3.5285836611095467`*^9, 
   3.5285836810566874`*^9}, {3.5285837133745356`*^9, 3.528583760895254*^9}, {
   3.528583810378084*^9, 3.5285838244458885`*^9}, 3.5286373437070155`*^9, 
   3.529929466504589*^9, 3.5330636580807257`*^9, 3.533072077992317*^9, 
   3.533681684671875*^9, 3.5337337030031824`*^9, 3.533753395203125*^9, 
   3.539520137658621*^9, 3.539521139894945*^9, {3.539521664740965*^9, 
   3.5395216701982765`*^9}, 3.5395224450615964`*^9, 3.5395231575993514`*^9, 
   3.540125247216842*^9, 3.5409350710747533`*^9, 3.540935324094225*^9, 
   3.5409354205277405`*^9, 3.5409360295285735`*^9, 3.5409375916079197`*^9, 
   3.540937952405789*^9, 3.54100308604922*^9, 3.541599681995329*^9, 
   3.5432391413020735`*^9, 3.6960758902783856`*^9, 3.6962290318484488`*^9, 
   3.6962316647519574`*^9, 3.6962321824282217`*^9, 3.7314209486398807`*^9},
 TextAlignment->Center,
 CellLabel->"Out[62]=",ExpressionUUID->"60a1f667-f8a9-4f21-87f0-568b6884e867"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table ", "TableTitleLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "TableTitleLabel"],
 StyleBox[".", "TableTitleLabel"],
 StyleBox[
 CounterBox["TableTitle"], "TableTitleLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "TableTitleLabel"],
 "Initial cash flow with loan interest above and below the capitalization rate"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{106, 10}, {1, 7}},
 CellChangeTimes->{
  3.52855262372631*^9, {3.5285741024908247`*^9, 3.5285741185827456`*^9}},
 TextAlignment->Center,ExpressionUUID->"84c53da2-6901-44d8-b3c1-f3eb1ad007b6"],

Cell["\<\
Another awful looking equation, 4.6, is what goes into the witches brew we \
call the equity reversion.  Note that since the loan is assumed to be paid \
off at the time of sale, the equation contains a constant, the final loan \
balance. This would only be a constant when the loan is a fixed interest rate \
loan. If the loan carried a variable rate of interest an equation would \
replace the constant.\
\>", "Text",
 CellChangeTimes->{
  3.5285839427326546`*^9, {3.528584099166602*^9, 
   3.528584101200718*^9}},ExpressionUUID->"9f9dbfa6-55c6-4190-8ef5-\
69b3487d5ecf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{"er", "//", "FullSimplify"}], "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5285840093094625`*^9, 3.52858403532095*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"247b6c0a-115e-4288-9f65-970962c3b209"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"er", "=", 
    RowBox[{
     FractionBox["1", "cro"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cro", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"dp", "+", "initln"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"cgrt", "+", 
             RowBox[{"dprt", " ", "k", " ", 
              RowBox[{"(", 
               RowBox[{"land", "-", "1.`"}], ")"}], " ", "recaprt"}]}], 
            ")"}]}], "-", 
          RowBox[{"1.`", " ", "ppmt"}], "-", "843381.1350420993`"}], ")"}]}], 
       "+", 
       RowBox[{"gsi", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"g", "+", "1"}], ")"}], "k"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cgrt", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"exprt", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"scrt", " ", 
                 RowBox[{"(", 
                  RowBox[{"vacrt", "-", "1.`"}], ")"}]}], "-", 
                RowBox[{"1.`", " ", "vacrt"}], "+", "1"}], ")"}]}], "-", 
             RowBox[{"1.`", " ", "scrt", " ", "vacrt"}], "+", "scrt", "+", 
             "vacrt", "-", "1.`"}], ")"}]}], "+", 
          RowBox[{"exprt", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1.`"}], " ", "scrt", " ", "vacrt"}], "+", "scrt", 
             "+", "vacrt", "-", "1.`"}], ")"}]}], "+", 
          RowBox[{"scrt", " ", 
           RowBox[{"(", 
            RowBox[{"vacrt", "-", "1.`"}], ")"}]}], "-", 
          RowBox[{"1.`", " ", "vacrt"}], "+", "1"}], ")"}]}]}], ")"}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.528584031038705*^9, {3.528584642626686*^9, 
   3.5285846471769466`*^9}},ExpressionUUID->"61fc64e5-6cee-4116-8051-\
4bdbfebb6e78"],

Cell["\<\
The capital gain is a little more accessible.  Note below that it is, not \
surprisingly, quite dependent on the going-out capitalization rate.\
\>", "Text",ExpressionUUID->"fc866776-17bf-4a21-bf89-44b704896e83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{"cg", "//", "FullSimplify"}], "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5285841356206865`*^9, 3.5285841702696686`*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"3a3337ae-09be-4c35-b7ca-e7a4873cbd80"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"cg", "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"cro", " ", 
        RowBox[{"(", 
         RowBox[{"dp", "+", "initln"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dprt", " ", "k", " ", 
           RowBox[{"(", 
            RowBox[{"land", "-", "1"}], ")"}]}], "+", "1"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"exprt", "-", "1"}], ")"}], " ", "gsi", " ", 
        RowBox[{"(", 
         RowBox[{"scrt", "-", "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"vacrt", "-", "1"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"g", "+", "1"}], ")"}], "k"]}]}], "cro"]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.528584167509511*^9, {3.5285846328151245`*^9, 
   3.528584635366271*^9}},ExpressionUUID->"4d63d33b-d7a2-4493-94c7-\
928565a4477b"],

Cell["\<\
If we are interested in what drives before-tax cash flow, Equation 4.8 shows \
that it is, of course, heavily dependent on the loan terms and net operating \
income.\
\>", "Text",
 CellChangeTimes->{{3.52858422449977*^9, 
  3.528584228359991*^9}},ExpressionUUID->"13720a1f-62f9-4a02-9ca2-\
fd66f875ddce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{"btcf", "//", "FullSimplify"}], "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5285842395346303`*^9, 3.528584263550004*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"db67d451-c89c-45e7-b51a-7a18c645f1d7"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"btcf", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"exprt", "-", "1"}], ")"}], " ", "gsi", " ", 
      RowBox[{"(", 
       RowBox[{"vacrt", "-", "1"}], ")"}]}], "-", 
     FractionBox[
      RowBox[{"12", " ", "i", " ", "initln", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], "t"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], "t"], "-", "1"}]]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.5285842596017785`*^9, {3.5285846219485035`*^9, 
   3.528584625819725*^9}},ExpressionUUID->"a3d4c865-4941-4ab4-87ea-\
51199ec91720"],

Cell[CellGroupData[{

Cell[TextData[{
 "A look at the variables that influence the tax consequence is the result of \
subtracting the symbolic expression for before-tax cash flow (",
 StyleBox["btcf", "Input"],
 ") from the symbolic expression for after-tax cash flow (",
 StyleBox["cf0 ", "Input"],
 "in the initial year). Note the recognizable components in Equation 4.9. The \
large term inside the parentheses multiplied by the tax rate is the taxable \
income from operating the property. Inside the parenthesis we see the \
components of real estate taxable income. If you stare at it long enough you \
will see the components of the net operating income, the interest deduction \
and the depreciation deduction. "
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.5285843129978323`*^9, {3.5285846050185347`*^9, 3.52858460947079*^9}, {
   3.53306696813105*^9, 
   3.5330669989988155`*^9}},ExpressionUUID->"facfc1be-c68c-41ca-9a14-\
98eb35fe19b4"],

Cell[TextData[{
 "Sometimes ",
 StyleBox["Mathematica's",
  FontSlant->"Italic"],
 " ability to consolidate terms is only marginally useful. When we represent \
the same expression, instructing ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to ",
 StyleBox["FullSimplify", "Input"],
 ", the components are not so clear."
}], "Text",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.528584466568616*^9, 3.52858447730223*^9}, {
  3.5299303609217463`*^9, 3.5299303652039914`*^9}, {3.533066990005301*^9, 
  3.5330669989988155`*^9}, {3.539520757012046*^9, 3.5395207578280926`*^9}, {
  3.5395253456224995`*^9, 
  3.5395253584852347`*^9}},ExpressionUUID->"d428b7af-8d7e-4a99-953b-\
9be74d4a4a3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cf0", "-", "btcf"}], "//", "FullSimplify"}], ";"}]], "Input",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.52858447730223*^9, {3.533066990005301*^9, 3.5330669989988155`*^9}, 
   3.5395205594957485`*^9, {3.539520613737851*^9, 3.5395206240824423`*^9}, {
   3.540936538100662*^9, 3.5409365552006407`*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"e9c1a347-f93e-40f1-987e-278148b8ca24"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{"cf0", "-", "btcf"}], "]"}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.52858431977322*^9, 3.5285843263565965`*^9}, 
   3.5285843746293573`*^9, {3.53952061179774*^9, 3.5395206271056156`*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"18a5dff0-dffa-45d3-af94-15d300b78f5a"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{"-", "txrt"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "dprt"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "land"}], " ", 
          RowBox[{"(", 
           RowBox[{"dp", "+", "initln"}], ")"}]}], "+", "dp", "+", "initln"}],
         ")"}]}], "-", 
      RowBox[{"exprt", " ", 
       RowBox[{"(", 
        RowBox[{"gsi", "-", 
         RowBox[{"gsi", " ", "vacrt"}]}], ")"}]}], "+", 
      RowBox[{"gsi", " ", 
       RowBox[{"(", 
        RowBox[{"-", "vacrt"}], ")"}]}], "+", "gsi", "-", 
      FractionBox[
       RowBox[{"12", " ", "i", " ", "initln"}], 
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"i", "+", "1"}], ")"}], 
         RowBox[{"-", "t"}]]}]], "-", 
      FractionBox[
       RowBox[{"initln", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}], 
           RowBox[{"12", "-", "t"}]]}], ")"}]}], 
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"i", "+", "1"}], ")"}], 
         RowBox[{"-", "t"}]]}]], "+", "initln"}], ")"}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.5285843629966917`*^9},ExpressionUUID->"41e2c703-65d1-4d13-abfd-\
42629c55a426"],

Cell[TextData[{
 "Returning to an exceedingly simple term, as we learned in Chapter 3, the ",
 StyleBox["noi", "Input",
  FontFamily->"Courier New"],
 " (or debt-free-before-tax annual cash flow) is really only a function of \
the gross income and two rates, vacancy and expenses."
}], "Text",
 CellChangeTimes->{{3.5409366868391695`*^9, 
  3.540936704229164*^9}},ExpressionUUID->"91566bda-f5ef-4539-a262-\
7a79509f81a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{"noi", " ", "//", " ", "Simplify"}], "]"}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.528584513287288*^9, 3.528584552450528*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"ecac4f3f-1cf9-480a-b431-746a58c895ca"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"noi", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"exprt", "-", "1"}], ")"}], " ", "gsi", " ", 
     RowBox[{"(", 
      RowBox[{"vacrt", "-", "1"}], ")"}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.528584540951871*^9, 
  3.528584569200486*^9}},ExpressionUUID->"0aace123-1097-44e9-aa40-\
654b4d4848a3"],

Cell[TextData[{
 "Of course the debt service, ",
 StyleBox["ds", "Input"],
 " (the annualized monthly loan payment) is a function of the interest rate, \
the term and the amount borrowed.  Note the constant 12 multiplies out the \
monthly factor. This is necessary because ",
 StyleBox["data", "Input"],
 " provide the interest rate and amortization period in monthly form."
}], "Text",
 CellChangeTimes->{
  3.539520899850216*^9, {3.5395251498643026`*^9, 
   3.5395251504483356`*^9}},ExpressionUUID->"21474f37-354f-4348-af36-\
46bdc42f1d12"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", "ds", "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5285853891873865`*^9, 3.5285854226803026`*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"b2a2d50b-28f8-43e4-b34d-ff22af6fadb8"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"ds", "=", 
    FractionBox[
     RowBox[{"12", " ", "i", " ", "initln"}], 
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"i", "+", "1"}], ")"}], 
       RowBox[{"-", "t"}]]}]]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.528585407632442*^9, 
  3.528585412862741*^9}},ExpressionUUID->"4daeab5b-d217-43ff-afbc-\
cfe61b097328"],

Cell[TextData[{
 "Some readers will recall the Ellwood tables.  The equations underlying \
these are easily provided. Equation 4.12 is the factor from Ellwood table #6 \
- the payment necessary to amortize a dollar.  To produce this we divide out \
the 12 in our annual debt service equation and make ",
 StyleBox["initln", "Input"],
 " equal to 1."
}], "Text",
 CellChangeTimes->{{3.5285854684329195`*^9, 3.528585470929062*^9}, 
   3.6961851637029653`*^9},ExpressionUUID->"a7d6e6a5-99e4-4425-9c38-\
801ac03238f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{
    RowBox[{"ds", "/", "12"}], "/.", 
    RowBox[{"initln", "->", "1"}]}], "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5285854818296857`*^9, 3.528585487807028*^9}, 
   3.5285855181027603`*^9},
 CellLabel->"In[70]:=",ExpressionUUID->"aded01f7-dc18-49b7-86b2-135f9b0093fb"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{"payment", " ", "factor"}], "=", 
    FractionBox["i", 
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"i", "+", "1"}], ")"}], 
       RowBox[{"-", "t"}]]}]]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5285854965625286`*^9, 
  3.5285855110183554`*^9}},ExpressionUUID->"3d0a77c2-c4a2-4515-a543-\
aa45f96a2dd1"],

Cell[TextData[{
 "For museum curators and those who still own Ellwood tables, inserting \
numeric values for ",
 StyleBox["i", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " and ",
 StyleBox["t", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " produce one of the numbers found in the tables. This same number is more \
usually found with a hand calculator with financial function keys. Using ",
 StyleBox["i", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " = .10/12 and ",
 StyleBox["t", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " = 360, Equation 4.12 returns a monthly payment for a loan of $1."
}], "Text",
 CellChangeTimes->{{3.528585638126625*^9, 3.5285856420288486`*^9}, {
  3.5395252098207316`*^9, 
  3.5395252302749014`*^9}},ExpressionUUID->"147ff282-1525-4cfa-a203-\
3dfb853a043f"],

Cell[TextData[{
 "[Note that the \" % \" symbol refers to the immediately prior input in the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook]."
}], "Text",
 CellChangeTimes->{{3.528585638126625*^9, 3.5285856420288486`*^9}, {
  3.5395252098207316`*^9, 
  3.539525234160124*^9}},ExpressionUUID->"ae80cc33-1d73-43f7-b9c5-\
05ab3d481735"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"i", "\[Rule]", 
     RowBox[{".1", "/", "12"}]}], ",", 
    RowBox[{"t", "\[Rule]", "360"}]}], "}"}]}]], "Input",
 CellLabel->"In[71]:=",ExpressionUUID->"8ff33d7f-08f5-475f-95aa-e9c42993e4cc"],

Cell[BoxData[
 FormBox["0.008775715700887997`", TraditionalForm]], "Output",
 CellChangeTimes->{3.528585575464041*^9, 3.528637347413227*^9, 
  3.529929470711829*^9, 3.533063662735992*^9, 3.533072084350681*^9, 
  3.533681689671875*^9, 3.5337337077374535`*^9, 3.533753402078125*^9, 
  3.539520142998926*^9, 3.5395211425050945`*^9, 3.539521708333458*^9, 
  3.5395224476447444`*^9, 3.539523160185499*^9, 3.540125250995058*^9, 
  3.5409350743979435`*^9, 3.5409353266983743`*^9, 3.5409354231278896`*^9, 
  3.540936032157724*^9, 3.5409376014764843`*^9, 3.540937957787097*^9, 
  3.5410030887113724`*^9, 3.5415996876716537`*^9, 3.5432391470023994`*^9, 
  3.6960758925744944`*^9, 3.6962290340864344`*^9, 3.6962316671764297`*^9, 
  3.696232184993045*^9, 3.7314209517170644`*^9},
 CellLabel->
  "Out[71]//TraditionalForm=",ExpressionUUID->"abdc295d-e8cf-47ae-b46f-\
9a885973e515"]
}, Open  ]],

Cell[TextData[{
 "When contemplating a VIR loan it can be a useful exercise to ask what \
happens to cash flow if interest rates rise.   In Equation 4.13 note the last \
term, the fraction with the \"",
 StyleBox["i", "Input"],
 "\" variables in it. Of course this term is monthly debt service (all the \
other variables sum to ",
 StyleBox["noi", "Input"],
 "). Remembering what a negative exponent in the denominator means, we \
observe this function rising with rising interest rates. The entire term is \
negative so as it gets bigger, ",
 StyleBox["btcf", "Input"],
 " grows smaller."
}], "Text",
 CellChangeTimes->{{3.5285857630527706`*^9, 3.5285857693591313`*^9}, {
   3.5299303948046846`*^9, 3.529930395579729*^9}, 3.539525255207328*^9, {
   3.6961852095249243`*^9, 
   3.6961852105917625`*^9}},ExpressionUUID->"b2a8cb45-fc06-4488-b504-\
259ab27c7760"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", "btcf", "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5285856929607615`*^9, 3.52858569940213*^9}, 
   3.528585734090114*^9},
 CellLabel->"In[72]:=",ExpressionUUID->"1f1613de-7d54-4dde-9bf5-179e8b0b4698"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"btcf", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "exprt"}], " ", 
      RowBox[{"(", 
       RowBox[{"gsi", "-", 
        RowBox[{"gsi", " ", "vacrt"}]}], ")"}]}], "+", 
     RowBox[{"gsi", " ", 
      RowBox[{"(", 
       RowBox[{"-", "vacrt"}], ")"}]}], "+", "gsi", "-", 
     FractionBox[
      RowBox[{"12", " ", "i", " ", "initln"}], 
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], 
        RowBox[{"-", "t"}]]}]]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.528585714628001*^9, 
  3.5285857258466425`*^9}},ExpressionUUID->"7a105a52-6946-45f1-a4a3-\
5e054c1b4a1f"],

Cell["\<\
Some equation decomposition is not helpful. Suppose the vacancy increases.  \
What does this do to after-tax cash flow?  Notice below it affects only part \
of the equation for first year cash flow.  This is not too helpful as that \
term is also multiplied by the tax rate, something that has nothing to do \
with vacancy.\
\>", "Text",
 CellChangeTimes->{{3.5285858344228525`*^9, 3.528585844844449*^9}, {
  3.52858594609024*^9, 3.52858594923442*^9}, {3.5285860085978155`*^9, 
  3.528586029025984*^9}},ExpressionUUID->"32195e73-fbcd-43d0-a273-\
a647c89cc435"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{"cf0", "//", "FullSimplify"}], "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5285858650456047`*^9, 3.5285858959773736`*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"da246784-bdc2-4f5c-bc64-fa7ce3ca44a7"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    SubscriptBox["cf", "0"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "txrt"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"dp", " ", "dprt", " ", 
           RowBox[{"(", 
            RowBox[{"land", "-", "1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"i", "+", "1"}], ")"}], "t"], "-", "1"}], ")"}]}], "+", 
          RowBox[{"initln", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"dprt", " ", 
              RowBox[{"(", 
               RowBox[{"land", "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"i", "+", "1"}], ")"}], "t"], "-", "1"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"12", " ", "i"}], "+", "1"}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"i", "+", "1"}], ")"}], "t"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"i", "+", "1"}], ")"}], "12"]}], ")"}]}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}], "t"], "-", "1"}]], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"exprt", "-", "1"}], ")"}], " ", "gsi", " ", 
         RowBox[{"(", 
          RowBox[{"vacrt", "-", "1"}], ")"}]}], "+", "initln"}], ")"}]}], "+", 
     RowBox[{"exprt", " ", "gsi", " ", 
      RowBox[{"(", 
       RowBox[{"vacrt", "-", "1"}], ")"}]}], "-", 
     RowBox[{"gsi", " ", "vacrt"}], "+", "gsi", "-", 
     FractionBox[
      RowBox[{"12", " ", "i", " ", "initln", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], "t"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], "t"], "-", "1"}]]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5285858827406163`*^9, 
  3.5285859753159113`*^9},ExpressionUUID->"9c62b155-41fa-4453-ad29-\
e797c957e547"],

Cell["\<\
We have covered just a few examples showing how insight into the process can \
be gained by dissecting the equations in component parts and looking at \
dependencies.  Symbolic analysis is rather sterile and too abstract for some. \
Let's combine the approach taken above with the example and see how it may be \
applied in practice.\
\>", "Text",
 CellChangeTimes->{{3.5415998410884285`*^9, 
  3.5415998411044292`*^9}},ExpressionUUID->"2d5a0b19-d42a-4438-8e6f-\
4f4c596630e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". An illustration of bargaining"
}], "Section",
 CellChangeTimes->{3.531447172614333*^9, 
  3.531447329812324*^9},ExpressionUUID->"d849af88-f22f-46f5-8377-\
d48ef974078f"],

Cell[TextData[{
 "Most of the foregoing examples all have to do with isolating one \
deterministic variable.  Does the change in one variable affect another?  \
What about interest rates and capitalization rates? Vacancy and expenses?  \
Are these related? Yes, they are.  How about gross income and vacancy?  What \
happens when two of these change? Let's take a simple example.  When rents \
increase vacancy should also increase. Below we see they both affect net \
operating income.  The key question is: how much of the increase in vacancy \
will neutralize the increase in income.  This is the sort of thing that \
sensitivity testing does. We are interested in knowing how sensitive tenants \
are to rent increases.  Will a small increase cause an exodus of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"tenants", 
    SuperscriptBox["?", 
     ButtonBox["6",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote6"]]}], TraditionalForm]],ExpressionUUID->
  "c4adf563-539e-45b6-81a6-85863f14a0a9"],
 " Assuming we are a potential buyer for the property in our example, and \
using the required rent raise (",
 StyleBox["rrr", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 ") idea introduced in Chapter 3 we will look at how this process enters into \
the negotiations with the seller."
}], "Text",
 CellChangeTimes->{{3.5285860814589825`*^9, 3.528586083322089*^9}, {
  3.528638978748534*^9, 3.5286389833337965`*^9}, {3.528639048532526*^9, 
  3.5286390605892153`*^9}, {3.539525464615305*^9, 
  3.53952546767148*^9}},ExpressionUUID->"24c2529f-0f8f-4164-afa4-\
7e0691231475"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"rrr", ":=", 
  RowBox[{"N", "[", 
   RowBox[{
    FractionBox["grm", "equilibriumgrm"], "-", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data1", "=", 
   RowBox[{"data", "/.", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"gsi", "\[Rule]", "200000"}], ")"}], "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"gsi", "->", 
       StyleBox[
        RowBox[{"200000", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "+", "rrr"}], "/.", "data"}], "/.", 
           RowBox[{"equilibriumgrm", "\[Rule]", "6"}]}], ")"}]}],
        CellFrame->False,
        Background->None]}], 
      StyleBox[")",
       CellFrame->False,
       Background->None]}]}]}]}], 
  StyleBox[";",
   CellFrame->False,
   Background->None]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data2", "=", 
   RowBox[{"data1", "/.", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"g", "\[Rule]", ".03"}], ")"}], "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"g", "\[Rule]", 
       StyleBox[".0325",
        CellFrame->False,
        Background->None]}], 
      StyleBox[")",
       CellFrame->False,
       Background->None]}]}]}]}], 
  StyleBox[";",
   CellFrame->False,
   Background->None]}], "\[IndentingNewLine]", 
 RowBox[{"CellPrint", "[", 
  RowBox[{"Cell", "[", 
   RowBox[{
    RowBox[{"TextData", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<We will assume our building is in a market where the equilibrium \
\>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<grm\>\"", ",", "Italic"}], "]"}], ",", 
       "\"\< is 6.  We know the \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<grm\>\"", ",", "Italic"}], "]"}], ",", 
       RowBox[{"\"\< for our building is \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"N", "[", 
          RowBox[{"grm", "/.", "data"}], "]"}], "]"}], "<>", 
        "\"\<. We see that the building is, not surprisingly, offered for \
sale above the equilibrium \>\""}], ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<grm\>\"", ",", "Italic"}], "]"}], ",", 
       "\"\<. One cannot blame the seller for trying. Recalling the \
Mathematica function from Chapter 3, \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<rrr\>\"", ",", "Italic"}], "]"}], ",", 
       "\"\<, that tells us what rent raise is necessary to bring the \
acquisition to equilibrium and inserting the data for our project and our \
market-based rule for equilibrium \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<grm\>\"", ",", "Italic"}], "]"}], ",", 
       "\"\<, we compute the \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<rrr\>\"", ",", "Italic"}], "]"}], ",", 
       RowBox[{"\"\< and find that our required rent raise is \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"100", " ", "rrr"}], "/.", "data"}], "/.", 
            RowBox[{"equilibriumgrm", "\[Rule]", "6"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
        "\"\<%. After a careful rent survey in the neighborhood, we conclude \
that the tenants will pay the new rent without excessive turnover or \
increased vacancy. We now must modify our data to consider the higher rents \
to see what happens to net present value  We define a new dataset, just like \
the first one. The only change is that \>\""}], ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<gsi\>\"", ",", "Italic"}], "]"}], ",", 
       "\"\< from the original data is increased by the \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<rrr\>\"", ",", "Italic"}], "]"}], ",", 
       "\"\<, given the equilibrium \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<grm\>\"", ",", "Italic"}], "]"}], ",", 
       RowBox[{
       "\"\<. Note that this means the buyer will have to institute an \
immediate rent raise upon the transfer of title to him to raise annual income \
to $\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"AccountingForm", "[", 
          RowBox[{
           StyleBox[
            RowBox[{"200000", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"1", "+", "rrr"}], "/.", "data"}], "/.", 
               RowBox[{"equilibriumgrm", "\[Rule]", "6"}]}], ")"}]}],
            CellFrame->False,
            Background->None], 
           StyleBox[",",
            CellFrame->False,
            Background->None], 
           RowBox[{
            StyleBox["DigitBlock",
             CellFrame->False,
             Background->None], 
            StyleBox["\[Rule]",
             CellFrame->False,
             Background->None], "3"}]}], 
          StyleBox["]",
           CellFrame->False,
           Background->None]}], "]"}], "<>", 
        "\"\< Then we ask for the net present value given this new \
information, which is \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{"npv", "/.", "data1"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "2"}], "}"}], ",", 
           RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}], "<>", 
        "\"\<. Even with this improvement we still do not have a positive \
after-tax net present value. Something has to change.  We believe we have \
extracted the most out of the tenants in the form of increased current rent. \
So we make a second change. We assume a higher annual growth rate, 3.25%, on \
cash flow. This produces a barely positive net present value of $\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{"npv", "/.", "data2"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "0"}], "}"}]}], "]"}], "]"}]}]}], "}"}], "]"}], 
    ",", "\"\<Text\>\""}], "]"}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.533067216373248*^9, 3.53306741552864*^9}, {
   3.5330674490085545`*^9, 3.533067450342631*^9}, {3.5330674869497247`*^9, 
   3.5330675803230653`*^9}, {3.5330676977447815`*^9, 3.533067738401107*^9}, {
   3.533067897751221*^9, 3.5330679715174403`*^9}, {3.533068032758943*^9, 
   3.5330682167794685`*^9}, {3.5330682542256103`*^9, 
   3.5330685853755507`*^9}, {3.5330686286390257`*^9, 3.533068685594283*^9}, {
   3.5330687575734*^9, 3.5330687596275177`*^9}, {3.5330688017309256`*^9, 
   3.533068806561202*^9}, {3.533068859712242*^9, 3.533068860481286*^9}, 
   3.5395227038844004`*^9, {3.5395227671810207`*^9, 3.539522767587044*^9}, {
   3.539525533811263*^9, 3.539525534227287*^9}, {3.541003183580799*^9, 
   3.5410033440079746`*^9}, {3.5410033751207542`*^9, 
   3.5410033987421055`*^9}, {3.5410034518301415`*^9, 3.541003452093157*^9}, 
   3.5410034823528876`*^9},
 CellLabel->"In[74]:=",ExpressionUUID->"6019550c-b34d-4548-8f1e-3bfb0c748dd4"],

Cell[TextData[{
 "We will assume our building is in a market where the equilibrium ",
 StyleBox["grm",
  FontSlant->Italic],
 " is 6.  We know the ",
 StyleBox["grm",
  FontSlant->Italic],
 " for our building is 6.25. We see that the building is, not surprisingly, \
offered for sale above the equilibrium ",
 StyleBox["grm",
  FontSlant->Italic],
 ". One cannot blame the seller for trying. Recalling the Mathematica \
function from Chapter 3, ",
 StyleBox["rrr",
  FontSlant->Italic],
 ", that tells us what rent raise is necessary to bring the acquisition to \
equilibrium and inserting the data for our project and our market-based rule \
for equilibrium ",
 StyleBox["grm",
  FontSlant->Italic],
 ", we compute the ",
 StyleBox["rrr",
  FontSlant->Italic],
 " and find that our required rent raise is 4.17%. After a careful rent \
survey in the neighborhood, we conclude that the tenants will pay the new \
rent without excessive turnover or increased vacancy. We now must modify our \
data to consider the higher rents to see what happens to net present value  \
We define a new dataset, just like the first one. The only change is that ",
 StyleBox["gsi",
  FontSlant->Italic],
 " from the original data is increased by the ",
 StyleBox["rrr",
  FontSlant->Italic],
 ", given the equilibrium ",
 StyleBox["grm",
  FontSlant->Italic],
 ". Note that this means the buyer will have to institute an immediate rent \
raise upon the transfer of title to him to raise annual income to $208,333. \
Then we ask for the net present value given this new information, which is \
-10,353.20. Even with this improvement we still do not have a positive \
after-tax net present value. Something has to change.  We believe we have \
extracted the most out of the tenants in the form of increased current rent. \
So we make a second change. We assume a higher annual growth rate, 3.25%, on \
cash flow. This produces a barely positive net present value of $85."
}], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.7314209550950217`*^9},ExpressionUUID->"67bbc49e-31cc-4cb2-bd3a-\
4b5008005d04"]
}, Open  ]],

Cell[TextData[{
 "With a positive ",
 StyleBox["npv",
  FontSlant->"Italic"],
 " we know that the project has an ",
 StyleBox["irr",
  FontSlant->"Italic"],
 " just above the 13% hurdle rate.  But these modifications to the \
deterministic variables have the buyer taking all the risk.  Why? It is the \
buyer who must raise current rents. It is the buyer who must depend for his \
required return on a higher future rate of growth.  The assumption of a \
higher growth in cash flow means the buyer is required to raise ",
 StyleBox["future",
  FontSlant->"Italic"],
 " ",
 StyleBox["rents faster",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{
  3.528586301392562*^9, {3.5299306885694866`*^9, 3.5299306890675154`*^9}, {
   3.5330689133743114`*^9, 3.5330689138653393`*^9}, {3.5395256272846093`*^9, 
   3.539525634887044*^9}},ExpressionUUID->"f6556d82-94c0-4633-b773-\
e4be76f87c89"],

Cell[TextData[{
 "How might we transfer some of the risk to the seller?  The simple answer is \
to offer a lower price.  A buyer refusing to pay a certain price is \
simultaneously refusing to take a certain level of risk for the reward \
offered.  \"",
 StyleBox["data3", "Input"],
 "\" shows the reduction of down ",
 Cell[BoxData[
  FormBox[
   RowBox[{"payment", 
    SuperscriptBox[",", 
     ButtonBox["7",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote7"]]}], TraditionalForm]],ExpressionUUID->
  "1f0ef23b-6765-455a-b152-948903f58619"],
 " and therefore the reduction in price, necessary to put the project in the \
positive ",
 StyleBox["npv", "Input"],
 " range. For this we modify ",
 StyleBox["data1", "Input"],
 " which has a ",
 StyleBox["gsi", "Input"],
 " of 1.041667 times the ",
 StyleBox["gsi", "Input"],
 " of ",
 StyleBox["data", "Input"],
 " but you will recall retains the original ",
 StyleBox["g", "Input"],
 " = .03 of ",
 StyleBox["data", "Input"],
 "."
}], "Text",
 CellChangeTimes->{{3.528586301392562*^9, 3.5285863035686865`*^9}, {
   3.52863929022535*^9, 3.5286393039451346`*^9}, 
   3.5299304342989435`*^9},ExpressionUUID->"f9e9a5ea-b0b5-4331-afe7-\
9a874b541194"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"data3", "=", 
   RowBox[{"data1", "/.", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dp", "\[Rule]", "375000"}], ")"}], "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"dp", "\[Rule]", "360000"}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"data3", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"data3", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
     "\"\<data3\>\"", ",", "Top"}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.533069290193864*^9, 3.533069322912736*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"a3772b27-3438-4928-9b4d-3810bb1cf039"],

Cell[BoxData[
 StyleBox[
  TemplateBox[{TagBox[
     GridBox[{{"dp", "360000"}, {"gsi", "208333.33333333334`"}, {
       "vacrt", "0.1`"}, {"exprt", "0.35`"}, {"txrt", "0.35`"}, {
       "dprt", "0.03636363636363636`"}, {"land", "0.3`"}, {
       "cro", "0.0936`"}, {"g", "0.03`"}, {"i", "0.009166666666666667`"}, {
       "initln", "875000"}, {"t", "360"}, {"r", "0.13`"}, {"k", "6"}, {
       "scrt", "0.075`"}, {"cgrt", "0.15`"}, {"recaprt", "0.25`"}, {
       "ppmt", "0"}, {"units", "22"}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
    "\"data3\""},
   "Labeled",
   DisplayFunction->(GridBox[{{
       ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
       TagBox[
        ItemBox[
         PaneBox[
          TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
          BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
        "SkipImageSizeLevel"]}}, 
     GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
     AutoDelete -> False, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      BaselinePosition -> {2, 1}]& ),
   InterpretationFunction->(RowBox[{"Labeled", "[", 
      RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.53306929221798*^9, 3.533069324318816*^9, 
  3.533072086068779*^9, 3.53368169278125*^9, 3.5337337104896107`*^9, 
  3.533753407796875*^9, 3.5395201462801137`*^9, 3.5395211462213073`*^9, 
  3.5395224495408525`*^9, 3.53952316177559*^9, 3.5401252539532275`*^9, 
  3.5409350760220366`*^9, 3.540935270547162*^9, 3.540935328321467*^9, 
  3.5409354264310784`*^9, 3.5409360337798166`*^9, 3.540937603299588*^9, 
  3.5409379609392767`*^9, 3.5410030905494776`*^9, 3.5415996911238513`*^9, 
  3.543239150244585*^9, 3.696075893958189*^9, 3.69622903545805*^9, 
  3.696231668702468*^9, 3.696232186450924*^9, 3.7314209551371202`*^9},
 TextAlignment->Center,
 CellLabel->"Out[79]=",ExpressionUUID->"c756cff8-e79f-48d4-955d-bd6e34be7499"]
}, Open  ]],

Cell[TextData[{
 "Note how this change improves first year performance as measured by the \
rules of thumb in Table 4.4. We have left the loan amount the same. This \
increases ",
 StyleBox["ltv", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 ", an indication of increased risk, but at the same time ",
 StyleBox["dcr", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" ", "Input"],
 "has increased, an indication of reduced risk. One wonders if these \
perfectly offset. How we reconcile them to determine if, on balance, the risk \
is more or less than before will be left for later."
}], "Text",
 CellChangeTimes->{{3.528586590391092*^9, 3.5285865958094015`*^9}, {
   3.5286390979523525`*^9, 3.528639101526557*^9}, 3.5299304440545015`*^9, {
   3.529930495678454*^9, 3.5299304983466067`*^9}, {3.5395203054322166`*^9, 
   3.5395203055812254`*^9}},ExpressionUUID->"a60df714-cef2-4b59-b16b-\
75e95a79f464"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{"TableForm", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "cri", ",", "grm", ",", "ppu", ",", "ccRet", ",", "dcr", ",", 
           "ltv"}], "}"}], "/.", "data3"}], ",", 
        RowBox[{"TableHeadings", "->", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Cap Rate\>\"", ",", "\"\<GRM\>\"", ",", "\"\<PPU\>\"", ",", 
            "\"\<After-tax CF\>\"", ",", 
            "\"\<\!\(\*StyleBox[\"dcr\",FontSlant->\"Italic\"]\)\>\"", ",", 
            "\"\<\!\(\*StyleBox[\"ltv\",FontSlant->\"Italic\"]\)\>\""}], 
           "}"}], "}"}]}]}], "]"}], "]"}], ",", "\"\<data3\>\"", ",", "Top"}],
     "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "Times"}], ",", 
   RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.39428364028125*^9, 3.39428369346875*^9, 3.394285247109375*^9, {
   3.5330696556357665`*^9, 3.5330696760149317`*^9}, {3.540935152291399*^9, 
   3.5409351639450655`*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"8414e4ff-1013-4c14-9cca-59d61e4e0885"],

Cell[BoxData[
 StyleBox[
  TemplateBox[{TagBox[
     TagBox[
      GridBox[{{
         TagBox["\"Cap Rate\"", HoldForm], "0.09868421052631579`"}, {
         TagBox["\"GRM\"", HoldForm], "5.928`"}, {
         TagBox["\"PPU\"", HoldForm], "56136.36363636364`"}, {
         TagBox["\"After-tax CF\"", HoldForm], "0.0662413738633255`"}, {
         TagBox[
         "\"\\!\\(\\*StyleBox[\\\"dcr\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
          HoldForm], "1.2188236591582553`"}, {
         TagBox[
         "\"\\!\\(\\*StyleBox[\\\"ltv\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
          HoldForm], "0.708502024291498`"}}, ColumnAlignments -> Left, 
       RowSpacings -> 1, ColumnLines -> {1}, ColumnAlignments -> Left], 
      OutputFormsDump`HeadedColumn], 
     Function[BoxForm`e$, 
      TableForm[
      BoxForm`e$, 
       TableHeadings -> {{
         "Cap Rate", "GRM", "PPU", "After-tax CF", 
          "\!\(\*StyleBox[\"dcr\",FontSlant->\"Italic\"]\)", 
          "\!\(\*StyleBox[\"ltv\",FontSlant->\"Italic\"]\)"}}]]],"\"data3\""},
   "Labeled",
   DisplayFunction->(GridBox[{{
       ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
       TagBox[
        ItemBox[
         PaneBox[
          TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
          BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
        "SkipImageSizeLevel"]}}, 
     GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
     AutoDelete -> False, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      BaselinePosition -> {2, 1}]& ),
   InterpretationFunction->(RowBox[{"Labeled", "[", 
      RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],
  StripOnInput->False,
  FontFamily->Times,
  FontSize->12]], "Output",
 CellChangeTimes->{3.540935342765293*^9, 3.5409354264770813`*^9, 
  3.540936033823819*^9, 3.5409376033525915`*^9, 3.5409379614613066`*^9, 
  3.541003091089508*^9, 3.5415996916548815`*^9, 3.5432391507466135`*^9, 
  3.6960758940283623`*^9, 3.696229035499159*^9, 3.696231668767668*^9, 
  3.696232186511098*^9, 3.7314209551637173`*^9},
 TextAlignment->Center,
 CellLabel->"Out[80]=",ExpressionUUID->"9d365114-25e1-4c51-b7ef-0a963ea94eed"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table ", "TableTitleLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "TableTitleLabel"],
 StyleBox[".", "TableTitleLabel"],
 StyleBox[
 CounterBox["TableTitle"], "TableTitleLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "TableTitleLabel"],
 "Rules of thumb for sample project with revised down payment"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{143.33333333333331`, 10.}, {1., 7.}},
 CellChangeTimes->{
  3.52855262372631*^9, {3.5285864798857713`*^9, 3.5285864961417007`*^9}},
 TextAlignment->Center,ExpressionUUID->"abd1826c-d178-4364-b9ac-1d85f3013f85"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{"TableForm", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"npv", ",", "cri", ",", "cro", ",", "irr"}], "}"}], "/.", 
         "data3"}], ",", 
        RowBox[{"TableHeadings", "->", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\"\<npv\>\"", ",", "\"\<cri\>\"", ",", "\"\<cro\>\"", ",", 
            "\"\<irr\>\""}], "}"}], "}"}]}]}], "]"}], "]"}], ",", 
     "\"\<data3\>\"", ",", "Top"}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "Times"}], ",", 
   RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}]], "Input",
 Editable->False,
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.39428350290625*^9, {3.533069546834543*^9, 3.5330695554590364`*^9}, {
   3.5330696094191227`*^9, 3.533069632523444*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"0ea36a3a-4bae-4657-8306-e93b8f92dc9c"],

Cell[BoxData[
 StyleBox[
  TemplateBox[{TagBox[
     TagBox[
      GridBox[{{
         TagBox["\"npv\"", HoldForm], "3306.967100861337`"}, {
         TagBox["\"cri\"", HoldForm], "0.09868421052631579`"}, {
         TagBox["\"cro\"", HoldForm], "0.0936`"}, {
         TagBox["\"irr\"", HoldForm], "irr"}}, RowSpacings -> 1, 
       ColumnAlignments -> Left, ColumnLines -> {1}, ColumnAlignments -> 
       Left], OutputFormsDump`HeadedColumn], 
     Function[BoxForm`e$, 
      TableForm[
      BoxForm`e$, TableHeadings -> {{"npv", "cri", "cro", "irr"}}]]],
    "\"data3\""},
   "Labeled",
   DisplayFunction->(GridBox[{{
       ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
       TagBox[
        ItemBox[
         PaneBox[
          TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
          BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
        "SkipImageSizeLevel"]}}, 
     GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
     AutoDelete -> False, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      BaselinePosition -> {2, 1}]& ),
   InterpretationFunction->(RowBox[{"Labeled", "[", 
      RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],
  StripOnInput->False,
  FontFamily->Times,
  FontSize->12]], "Output",
 Editable->False,
 CellChangeTimes->{
  3.528586520847114*^9, 3.5286373496773567`*^9, 3.529929475480102*^9, 
   3.533063668314311*^9, 3.5330695561610765`*^9, {3.5330696269801273`*^9, 
   3.5330696331504803`*^9}, 3.5330720861597843`*^9, 3.533681693*^9, 
   3.5337337112556543`*^9, 3.533753409203125*^9, 3.539520147851204*^9, 
   3.5395211466763334`*^9, 3.539522449812868*^9, 3.539523161879596*^9, 
   3.5395257652395*^9, 3.5401252551182942`*^9, 3.540935076120042*^9, 
   3.540935426521084*^9, 3.5409360338668222`*^9, 3.540937603402594*^9, 
   3.5409379619643354`*^9, 3.5410030916135387`*^9, 3.5415996922279143`*^9, 
   3.5432391513786497`*^9, 3.696075894102559*^9, 3.6962290355974197`*^9, 
   3.6962316688689103`*^9, 3.696232186563223*^9, 3.731420955197281*^9},
 TextAlignment->Center,
 CellLabel->"Out[81]=",ExpressionUUID->"901eebf7-a854-4690-8894-d893607267e2"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table ", "TableTitleLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "TableTitleLabel"],
 StyleBox[".", "TableTitleLabel"],
 StyleBox[
 CounterBox["TableTitle"], "TableTitleLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "TableTitleLabel"],
 "Performance measures for sample project with modified inputs"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{150.66666666666666`, 10.}, {1., 7.}},
 CellChangeTimes->{
  3.52855262372631*^9, {3.5285865477756543`*^9, 3.5285865650886445`*^9}},
 TextAlignment->Center,ExpressionUUID->"9de193ab-1479-48a4-a601-1ba2d64f875b"],

Cell[TextData[{
 "Note the ",
 StyleBox["npv", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " is positive in Table 4.5 but for this to be true capitalization rates must \
decline over the holding period. This is another risk factor that we will \
address in a later chapter."
}], "Text",
 CellChangeTimes->{{3.5285866501135073`*^9, 
  3.528586683390411*^9}},ExpressionUUID->"e8d1c71d-c135-4dfa-89bf-\
1aff75f994ab"],

Cell[TextData[{
 "The payoff for undertaking symbolic analysis begins to take shape. The \
positive ",
 StyleBox["npv", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " outcome for ",
 StyleBox["data3", "Input"],
 " says we again have approximately a 13% ",
 StyleBox["irr",
  FontSlant->"Italic"],
 ".  ",
 StyleBox["But is the second 13% irr the same 13%?",
  FontSlant->"Italic"],
 "  By now we should recognize that the two ",
 StyleBox["irr",
  FontSlant->"Italic"],
 "s, though nominally the same, are in fact not equivalent.  It should be \
evident that the risk of the project must be different under ",
 StyleBox["data3", "Input"],
 " than under ",
 StyleBox["data2", "Input"],
 " even though ",
 StyleBox["npv", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " is approximately zero in both cases and the ",
 StyleBox["irr",
  FontSlant->"Italic"],
 " is essentially the same."
}], "Text",
 CellChangeTimes->{{3.5285866501135073`*^9, 3.528586655328806*^9}, {
  3.539525870268507*^9, 
  3.539525920114358*^9}},ExpressionUUID->"b0d568d0-10e1-4757-8a9d-\
6c857bd9f811"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CellPrint", "[", 
  RowBox[{"Cell", "[", 
   RowBox[{
    RowBox[{"TextData", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<The internal rate of return is the number that solves Equation 4.1 \
for \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<r\>\"", ",", "Italic"}], "]"}], ",", "\"\< when \>\"", 
       ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<npv\>\"", ",", "Italic"}], "]"}], ",", 
       "\"\< is set to zero. Mathematicians consider this a problem of \
finding the 'root' of the equation and both reach the same result, an \>\"", 
       ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<irr\>\"", ",", "Italic"}], "]"}], ",", 
       RowBox[{"\"\< of \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"100", " ", "irr"}], "/.", "data3"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
        "\"\<% for the data that produced the \>\""}], ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<npv\>\"", ",", "Italic"}], "]"}], ",", 
       RowBox[{"\"\< of $\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"npv", "/.", "data3"}], "]"}], "<>", "\"\<.\>\""}]}], "}"}], 
     "]"}], ",", "\"\<Text\>\""}], "]"}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.533069734169258*^9, 3.5330697558494983`*^9}, {
  3.5330698126087446`*^9, 3.5330700260619535`*^9}, {3.5410035837046843`*^9, 
  3.541003652579624*^9}, {3.541003688665688*^9, 3.541003715013195*^9}, {
  3.5410037581786637`*^9, 3.5410037692722983`*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"332ffa69-bcb7-4bd6-90fe-4bdda4e07f99"],

Cell[TextData[{
 "The internal rate of return is the number that solves Equation 4.1 for ",
 StyleBox["r",
  FontSlant->Italic],
 " when ",
 StyleBox["npv",
  FontSlant->Italic],
 " is set to zero. Mathematicians consider this a problem of finding the \
'root' of the equation and both reach the same result, an ",
 StyleBox["irr",
  FontSlant->Italic],
 " of 100 irr% for the data that produced the ",
 StyleBox["npv",
  FontSlant->Italic],
 " of $3306.97."
}], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731420955228363*^9},ExpressionUUID->"a6502dcc-e64a-492d-8674-\
e4f9f0453272"]
}, Open  ]],

Cell[TextData[{
 "The focus of this discussion as regards ",
 StyleBox["npv", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " and ",
 StyleBox["irr",
  FontSlant->"Italic"],
 " has been from the standpoint of the negotiation between two parties over a \
specific property, what might be termed a \[OpenCurlyDoubleQuote]micro\
\[CloseCurlyDoubleQuote] approach. There is a larger, \
\[OpenCurlyDoubleQuote]macro\[CloseCurlyDoubleQuote] view that asks the \
broader underlying question: Where do discount rates come from? Entire books \
are written in response to this question and it seems an injustice summarize \
them in a few phrases, but here is a way of thinking about them that fits in \
our context. In general, discount rates are the aggregate of all the \
negotiations that take place every day with all the buyers and sellers in a \
market. They encapsulate the combined expectations of a large number of \
people who compete with one another to acquire business opportunities that \
have uncertain outcomes. During times of positive business conditions \
characterized by solid growth, low inflation, high employment, low interest \
rates, discount rates will be lower than they are during the opposite times \
of negative macroeconomic news when buyers demand more compensation in the \
form of higher discount rates for undertaking risk when the horizon is \
comparatively dark."
}], "Text",
 CellChangeTimes->{
  3.5285874914206276`*^9, {3.5395259769596095`*^9, 3.5395259799447803`*^9}, {
   3.6961852452399435`*^9, 
   3.696185245837533*^9}},ExpressionUUID->"4193c1c7-96a6-41f8-a6af-\
3345a1f6b890"],

Cell[CellGroupData[{

Cell[TextData[{
 "Finally, for those who want to know the precise IRR, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is as good at Excel in finding it.  (In fact there are several ways of \
computing IRR using ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "which are shown in the Appendix to Chapter Five). The method beneath this \
cell employs a matrix approach and provides the most transparent \
demonstration of the process. "
}], "Text",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5285866501135073`*^9, 3.528586660436098*^9}, {
   3.528586905473113*^9, 3.5285869096353517`*^9}, {3.528637373571724*^9, 
   3.528637394942946*^9}, {3.533070113294943*^9, 3.5330701281277914`*^9}, 
   3.53307018912728*^9, 
   3.5395260229442396`*^9},ExpressionUUID->"f4166320-3e0d-4dd8-8890-\
83f3197873ee"],

Cell[TextData[{
 "First we create a list of after-tax cash flows that we name \"",
 StyleBox["cflist", "Input"],
 "\". Note that we start with year #1 cash flow (",
 StyleBox["cf0", "Input"],
 ") and we add the equity reversion to the last year's cash flow, which takes \
some additional manipulation to get ",
 StyleBox["cflist", "Input"],
 " in the right form.  The output below is the list of cash flows the project \
will produce (with it\[CloseCurlyQuote]s equity reversion added to the last \
annual cash flow from operations) given these data."
}], "Text",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5285866501135073`*^9, 3.528586662369209*^9}, {
   3.5299309444521227`*^9, 3.529930982205282*^9}, 3.53307018912728*^9, {
   3.5395228748591795`*^9, 3.539522876104251*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"irrdata", "=", "data3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"partlist", "=", 
   RowBox[{"{", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", "n", "]"}], "/.", "irrdata"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", 
        RowBox[{
         RowBox[{"k", "-", "1"}], "/.", "irrdata"}]}], "}"}]}], "]"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"endcf", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cf", "[", "k", "]"}], "/.", "irrdata"}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{"er", "/.", "irrdata"}], ")"}]}], "}"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cflist", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"partlist", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"endcf", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.394149145375*^9, 3.39414952146875*^9, {3.3941495879375*^9, 
   3.394149614390625*^9}, {3.394149648203125*^9, 3.39414967034375*^9}, 
   3.5330701891282806`*^9, 3.5395260708579803`*^9},
 CellLabel->"In[83]:=",ExpressionUUID->"92502757-7a65-43a0-8971-27555d88b3aa"],

Cell[TextData[{
 "The internal rate of return is the number that solves the following \
equation for",
 StyleBox[" r", "Input"]
}], "Text",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.5330701891282806`*^9}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "k"], 
    FractionBox[
     SubscriptBox["ATCF", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], "n"]]}], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SubscriptBox["ATER", "k"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "r"}], ")"}], "k"]], TraditionalForm]]],
 "- initial investment = 0"
}], "Text",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.5330701891282806`*^9},
 TextAlignment->Center,
 TextJustification->0.],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needs to find the \"root\" of this equation.  We need a polynomial into \
which we insert the ",
 StyleBox["cflist", "Input"],
 ".  We begin by  creating a table, ",
 StyleBox["irrtbl", "Input"],
 ", that will represent a power series.  The variable ",
 StyleBox["v", "Input"],
 " = ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"(", 
     RowBox[{"1", "+", "r"}], ")"}]], TraditionalForm]]],
 " becomes the discounting factor."
}], "Text",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.533070154542302*^9, 3.5330701891282806`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "v", "]"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "necessary", " ", "because", " ", "v", " ", "is", " ", "defined", " ", 
     "above", " ", "as", " ", 
     FractionBox["i", "r"]}], ";", " ", 
    RowBox[{
    "the", " ", "previous", " ", "equations", " ", "using", " ", "v", " ", 
     "are", " ", "no", " ", "longer", " ", "operative"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"irrtbl", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     SuperscriptBox["v", "i"], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "cflist", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"irrpoly", "=", 
   RowBox[{"irrtbl", ".", "cflist"}]}], ";"}]}], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5285871257697134`*^9, 3.5285872040901937`*^9}, 
   3.5330701891282806`*^9, 3.539526085975845*^9},
 CellLabel->"In[87]:=",ExpressionUUID->"b49e1f7b-dfc7-4e0e-a142-ea6936b8e966"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"irrstep2", "=", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"irrpoly", "==", 
      RowBox[{"(", 
       RowBox[{"dp", "/.", "irrdata"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"1", "/", "1.1"}], ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"irr", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["v", 
       RowBox[{"-", "1"}]], "-", "1"}], ")"}], "/.", 
    RowBox[{"irrstep2", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The IRR for these data is: \>\"", ",", "irr"}], "]"}], 
    ";"}], "*)"}]}]}], "Input",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.5330701891282806`*^9, {3.5395229303893557`*^9, 3.5395229327974935`*^9}, 
   3.539526097560508*^9, {3.5409368284852715`*^9, 3.5409368320994782`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"c07ddf77-9dfd-4fd5-b968-8d669cd4a9ec"]
}, Closed]],

Cell[TextData[{
 "The foregoing was but one of many tradeoffs that can occur to keep the \
return constant. ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 " and the Problems Section for this Chapter each provide an omnibus tool \
called ",
 ButtonBox["\"The Price-Terms Tradeoff\"",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/ThePriceTermsTradeoff/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/ThePriceTermsTradeoff/"],
 " which measures how changes in any input or any number of inputs affect \
return"
}], "Text",
 CellChangeTimes->{{3.5285875302358475`*^9, 3.528587616394776*^9}, {
  3.528587951224927*^9, 3.5285879875130024`*^9}, {3.5285880235080614`*^9, 
  3.528588053891799*^9}, {3.528588108595928*^9, 3.5285882189652405`*^9}, {
  3.5330726021572976`*^9, 
  3.533072620936372*^9}},ExpressionUUID->"ae934774-cb73-40c3-8e73-\
0b379c43f585"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Another growth function"
}], "Section",
 CellChangeTimes->{3.531447172614333*^9, 
  3.5314473610831127`*^9},ExpressionUUID->"a14011be-4d18-4f7f-a565-\
dfdb34939aef"],

Cell[TextData[{
 "The above, quite standard ",
 StyleBox["dcf",
  FontSlant->"Italic"],
 " analysis, implies a fixed holding period terminating in a taxable sale. \
This assumption will be relaxed, in part, in future chapters.  The above \
model also depends on the unrealistic assumption that the change in income \
and value over the holding period is constant and positive.  Not only is this \
unlikely because of variable economic conditions, the successful \"add \
labor\" strategy we will discuss in Chapter 8 suggests that, due to the \
owner's active management, the property could undergo a dramatic \
transformation in the early years, resulting in a rapid change in value in \
those years, after which slower, \"normal\", appreciation takes place. To \
represent this we choose a modified logistic growth function, ",
 StyleBox["val[n_]", "Input"],
 ", that exhibits two phases of value change, an early entrepreneurship phase \
with high appreciation, followed by a stabilized \"normal\" appreciation \
phase. Note that the dependent variable, ",
 StyleBox["n",
  FontSlant->"Italic"],
 ", means that value is dependent time. But the specific functional form of ",
 StyleBox["val[n_]", "Input"],
 " is chosen such that the change in early years is different from changes \
occurring in later years."
}], "Text",
 CellChangeTimes->{{3.539526131333439*^9, 3.5395261465663104`*^9}, {
  3.5409368739748735`*^9, 
  3.5409368744098983`*^9}},ExpressionUUID->"712a88ac-b399-465f-a983-\
796c56e7de72"],

Cell[BoxData[
 FormBox[Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002<H0@0006`000000000000006X400030@00
0000000000294000?@@00215CDH0004062<007T0000700000000000000000000`180080H003;0000
2P4000000000000000000<0I0`0[3@@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000G00005000015CDH[8T0400`0000000007T0900`000000000940100`000000000
<4020100000400000020?b501`0<0000000000A0000<0000000001H0000<0000600000X0000@0000
000000000009000040000>H300020@00DP00070100010000Y?ooo`00000000000000090100000000
14008T<0H@1/06T0HP1b06T000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
G;4g0?Bb=`1`RbL2T:lg0?AO[F;d/SL080000>R_=`3ooooof;8g072`=`15n[IRj:lg0?Bb=`0P0000
oooooo`29@:jn[IR0@000000001H0P009@0003L^T040008?1@820P@30PCo0P3Qoj`0@0T000000000
W`40000000130640K01Y0680LP0000000000000000000000000001R`=`2F@k1R2P000?ooommD/3L0
4Vb^HVR`=`20/J9SP;0g0?`29@8P0RD2I7H02000000U000030000040000U000030000040000U0000
30000040000B000030000040000H000030000000009D0000E000000000000000=@0006l000010000
EEF7@=^fQd000000E`000040001<00001000000000000000j0<00001001@0000800003H0000H0000
3000000000960000:00001`00017A4U30P000?ooooooooooiP<000<100000000AP000207000D1`00
ADe6:bY0000T000060000000P3l000200000P000P3l000200000P2501@0<0000000000Q000El1P00
L0H0008@`=/200000P0004P6003GcLJJ0000000000oP0`0900000?5B000100T000<T0`00102`0000
000500000P4100001@000042oooo00D0000^0AT0000500002`8000001@0000`2h0<03a<0000V1Pl0
703ooooo001=01000030oooo^?oool0>002H0`002`0002H63`0<04eQM6QDNG1U003000P0003j0P00
4`00000000840000;@4000D0000D0P02NPD500004`800YD:1@0000T200000PD0000D0^02O0TL0000
n`8Ro`000000090100000002011DJFeULb1>IGLPDVm]HFh0^:CcMl6TlgLP<?Eg81IV@@@0000]0@40
2@00038:00000040000ZNK`11@0001@2H08P0Q`0003k0X3n00000000T0400000008045AYKFEc84iU
Mb1BKfeQKP2hY?=g`JCcMb0`mGLP5VI1100002d10P040000l04100`0000b2P0000030000:2TZIU01
X@T00`D0000D0X`3J0DL0000n`:0oP000000090100000002011DJFeULb1>IGLPDVm]HFh0^:CcMl6T
lgLP<?Eg81IV@@@0000]0@4010000?010P090000<PX000000@00035i00<5000050;P0Q4870000?/2
8_l00000002@0@0000400P0@DgU]HVm/002I5@Y:E=XB0;RTlgO1Y?=g833eMb0FIT440000;@4200@0
003`0@402@00038:00000040000]NK`11@0001@2H09811`0003k0X3n00000000T0400001008045=i
KF9_K0005QH:J5CJ4P2hY?=g`JCcMb0`mGLP5VI1100002d10@040000l04200X0000b2P0000020000
?B^K1P031@0001@2S0=61PT0000b2P0000010000:b/00`D0000D0^02WPPL0000n`8Ro`0000000901
0@000002011DJFeULb1>IGLPDVm]HFh0^:CcMl6TlgLP<?Eg81IV@@@0000]0@8010000?010@0<0000
<PX000000`00065VKVQ_0=h0_0450000509^0GL770000?/2P?h00000002@0@4000000P0@E6U]IG<P
CVEg859_KF5^0;RTlgO1Y?=g833eMb0FIT440000;@4100@0003`0@802P00038:00000080001/Hf`0
00<50000509P0S@070000?/2P?h00000002@0@4000000P0@E6U]IG<PCVEg859_KF5^0;RTlgO1Y?=g
833eMb0FIT440000;@4200@0003`0@404000038:000000H0001fHFa^IfjX0<003P5U2N`100<50000
50:<0eX770000?/2P?h00000002@0@4000000P0@E6U]IG<PCVEg859_KF5^0;RTlgO1Y?=g833eMb0F
IT440000;@4100@0003`0@802@00038:00000040001UH`03/00002H63`1F0DeQM6QDNG1UEEE:0@D1
00D1A5==E3D001=GJFi1K6a2HG=YHd=_I6E@HFMUL`0A1EAYKFEc84iUMb1BKfeQKP0A0e=iKF9_K00A
1D=_MG9YIG8PCVEg0144CE@PAGQdLV404P088Bm5Sd@_@E3d40m7Gd5@lQlN@E3d5@m10?A5m2GdSd9O
@@3d40m3Gd40m8m5m2YOB?B?@@3d40m0m8m1OdSd40m1:Um4GdGdGdGdGd4?30400@010P820P020041
0@03004010002P400P23MP0208=Q0080Pf`00P22:00208=^0080PRT00PB6?@0m0`0;00010080Pf`0
0P23H`000@0208Pa0084QR/0:`80PfD00`0L000;0@410084QQ8R;@80Pf400P23IP02088Z0080Pfh0
000000X218H[02/208=W0080PRX00P23KP0000/0000V1Pl0303ooooo0@00000000080000nP800000
00000000100002d10P0L0000n`8@00L000000;`2000000420R9CNG=dIFd0020FIT4000X08@2:0@00
003oooooY>@B00@0000]0@<010000?010@0300000008@048900001P000024<3K0@0000<000000000
00000000000K@000@00003@0000100000P00000000000000001`A@00N4@30000o_oo?_n_ZSgnOgU4
ojnZ?OkoociC=H538@0000P0001R000030000040000Q000020000680000<00000@000140000<0000
200000X0000@000000000000000900004000000?003P0`003000010000000000000000/0000@0000
iP<00081000Q0000200002D0000<00001`00P2D0000<00000000P1H0000<0000000001P0000<0000
000001T0000<0000oooo01@0000<00003@000580001`0@000P000:Coool0000000000000002@0@00
000000M002930640K01Y0680LP1Y0000000000000000000000000000000000000000000000000000
0000000000000000001ZM0000000000000000000000000000000000000000000ooooo`0000000000
00000000000000000000000000000000000000000000000000000040003ooooo0000000000000000
>4QY1@24P43^6b45402@0@00000003L0n56b1fRoCfALWCL0oki?I9bM=`04000000000000l3l00000
000000000000000000000000l3l00000001i@0000000Q8100000000000000000000006cSlWIL[dhf
00000:@1EP0005H0>4on2=QJ0`T90<80PiN[4FAf00P000009@0000`0000200004P0000`000010000
6@0000`0003oool05P0000`0000I00002P00010000000000000000T0000@000000l00>03000V0000
700000<0000000004`000000000000009@0000`0000300006`000100001j1@00008003H0000@0000
U@X00002000H000030000000000K0000400007`9003P0P00DP000701000400008_ooo`0000000000
00000901000000001`8045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
000000000000000000000000000003L0HSiZM080003^6b456@2`0I`lJW@001T00;Sc1@40001HXSL0
fS6`HPX00000^?<50@0002BL=`200Fid3UaYM>1KJG@TW3L0I040000000000000H6IO00@000000000
JQh:ALbM=`1SG6Ud00000:Coool0000000000000J@D00000kQ/Q1FXN2TD20000Y?ooo`0000000000
00000901000000001d008T<0H@1/06T0HP1b06T00000000000000000000000000000000000000000
000000000000000000000000000006Yd0000000000000000I7H02000000U0000300000@0001D0000
E00007L2002:0000jP800<`000010000]K2<?lL_SCl0000000000040001<00000000000000000000
oooooooooom@0000:P000;`1000K000040000202001P0P00DP00070100050000P?koo`0000000000
00000901000000001`8045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
0000000000000000000000000000000000000000=`1R?VYd0P000>hK8@DI0;01W3aZM0006@00^?<5
0@0005RR=`3J<K1R2P00002hl`D00000i0@00>hK8@D`Tf853P5m1C2CHPD00000:P0006cSlWH/[Thf
000009@1EP0005H0c9dg06=LJG@E05P0O@80000000000000001Y1@00000F05X0O@800080002Toooo
b81F000000040000T04000000028ef45^7eF0<anEP000685B85F0000000@W3L0000004BM=`3=7_Mf
l>2;@?kooom/ho9fd^3bMP0000000Gd500000000JW@00000I7H02000000U0000300000D0000X0000
300000@0001D0000H00008d000140000;0@00;D000010000]K2<?lL_SCl00000000000<0001<0000
0000000000000000oooooooooomD0000:00Y02X0001@0@00X@T00003000K0000400006P5002<0`00
DP00070100040000P?koo`000000000000000901000000001`8045@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^00000000000000000000000000000000000000000000000000000000000000000000
000g068nJW@20000kQ/Q1AT0/06L?6Yd000I002hl`D10000F:8g0=Xa/6800000i0@00>hK8@F@kV85
LP5m1I3^HPD00000:00Y02X0lWH/[Thf000009`1EP0005H0U05F0000EP020200cP000000F01m0P00
00000000000300h0cP0001H0FP1m0P00b81F0000000<0000d9=Q1@00003Xe645^7eF0=1nEP000685
/85F0000HPD@W3L00@0004BM=`3=7_Mfl>2;@?kooom/ho9fd^3bMP00001T0Gd500000000EP000000
I7H02000000U0000300000@0000X0000300000D0001D0000E00006P1002B0000;`8000<100010000
]K2<?lL_SCl0000000000040001<00000000000000000000oooooooooom@0000<@00^P03000K0000
40000148003P0P00DP000701000500008_ooo`000000000000000901000000021`8045<0N@1]0680
K`1/0000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000003L0HSiZM080003^6b456@2`0I`lJW@001T00;Sc1@4000000000
i0@00>hK8@D`Tf85g05m1C2CHPD00000<@1R1FcSlWH/[Thf000009@1EP0005H0W05F0000EP0E05P0
OP800000803>0000001H07d2000F05X0OP8000<03P3>0000b81F000000040000l99Q1@000028ef45
^7eF0<anEP000685B85F0000HPD@W3L00@0004BM=`3=7_Mfl>2;@?kooom/ho9fd^3bMP00003>0Gd5
00000000EP000000I7H02000000U0000300000D0000X0000300000@0001D0000E00001T200250000
S0800</000010000]K2<?lL_SCl0000000000040001<00000000000000000000oooooooooom@0000
;O1Q0;`1000K0000400004P4001P0P00DP00070100040000P?koo`00000000000000090100000002
1`8045<0N@1]0680K`1/000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000=`1R?VYd0P000>hK8@DI0;01
W3aZM0006@000000:P000>hK8@D`Tf85@09m1C2CHPD00000;O1R1FcSlWH/[Thf000009@1EP0005H0
U05F0000EP0E05P0O`800000F01n0P00000P0<h0000F05X0O`8001H0FP1n0P00b81F000000040000
d9=Q1@000028ef45^7eF0<anEP000685B85F0000HPD@W3L00@0004BM=`3=7_Mfl>2;@?kooom/ho9f
d^3bMP00000b0Wd500000000EP000000I7H02000000U0000300000@0000X0000300000D0001D0000
F00001d1000j0000W0<00;<000010000]K2<?lL_SCl0000000000080001<00000000000000000000
oooooooooom@0000?O0[l9/600000`006`00010000161P00S0<005@0001D0000X@4008P0001X0P00
0@400040002e/8`oabn=?`00000000000@0004`00000000000000000003ooooooooooe00000[l0T0
00<001/0000@0000WPP00>02001B0000L04000D0000Roooo0000000000000000T040004000070P0@
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000003L0HSiZM080003^6b45
6@2`0@00000Z0000kQ/Q1C2CHPG20Wd5<9=R1@00000[l2_`K>?bMRb^CSH00000U05F0000EP2D0EH0
001F01D0F0210P00001H07l2000005P0OP8001H0FP210P005P1J07l20038P5H0000000@0003`TV45
000008SGH@FhOEH0c7iF0000HPE8PEH0001R1A2L=`010000A9dg0<dNmgK`h8]0o_ooofcSlWKBh?9f
00000;@2O@D00000001F0000001TMP08000002D0000<00001@0002P0000<0000100005@0001P0000
?@8008/000060`00c0000040002e/8`oabn=?`00000000000`0004`00000000000000000003ooooo
oooooe@0001Q06H0KP0906l0003N0000_04001/0000@0000M`L006h1001B0000L04000@00020o_oo
0000000000000000T040004000070P0@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000=`1R?VYd0P000000003T1000kQ/Q1I3^HPDV0gd5T>iR1@00001Q06H0
KP3bMRb^CSH00000W05F0000EP2D0EH0001F0080803?0000001H0842000005P0O`8000<03P3?0000
5P1J08420038P5H0000000`0003@Tf4500000>SDH@FhOEH0d7iF0000HPF`PEH0001R1A2L=`010000
A9dg0<dNmgK`h8]0o_ooofcSlWKBh?9f000001P3O@D00000001F0000001TMP08000002D0000<0000
100002P0000<00001@0005@0001H0000l@4000D0003D0P00MP000040002e/8`oabn=?`0000000000
0P0004`00000000000000000003ooooooooooe00001/06<0K0000003000K0000400003@0001P0P00
DP00070100050000P?koo`000000000000000901000100001`8045@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000=`000000i0@00>hK8@D`Tf85
T0=m1C2CHPD00000K01S06cSlWH/[Thf000009@1EP0005H0W05F0000EP0E05P0PP800000803?0000
001H0842000F05X0PP8000<03P3?0000b81F000000080000l99Q1@000028ef45^7eF0<anEP000685
B85F0000HPD@W3L00@0004BM=`3=7_Mfl>2;@?kooom/ho9fd^3bMP0000220gd500000000EP000000
I7H02000000U0000300000D0000X0000300000@0001D0000L00000h000140000JP@00;D000010000
]K2<?lL_SCl00000000000H0001<00000000000000000000oooooooooomH0000MP1Q06`0KP1W06h0
Z0000<00000>0@00I@T00>`100000`006`000100001J1`00S0<00580001`0@001000083nool00000
00000000002@0@000@0000L2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000>@4003^6b45d9=Q1OH3O@G@Tf45000007H0H@1/06h0
I`1^0000002T0EH0001F09@1EP0005H01@3Z08ZGZa4005P0PP800000803?00001P3^08ZGZa4F05X0
PP800<R0EP00000060000=2CH@D00000P>1Y1KQmEP3DOUH0001Q1AR2EP00068549`g00400014WCL0
cAkgM_3PRd3nooooK>?bM];PlWH00000j0=m1@00000005H0000006Af00P000009@0000`000040000
:00000`000050000E00005@0003Y0@00TP000;0200030@000@000;F`S3o7;hdo0000000000010000
C00000000000000000000?ooooooooooD00006D000000`009P0001`0000500000000000000000000
000002D0000<00001@000580001`0@001P0001000007000000000000002l0P00000000L20R9C07T0
L`1d06D0K@0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000>@4003^6b45<9=R1FP4O@D`Tf85000006D0H@E/ho9f;:i>=P00002D0EH0001F0:@1EP0005H0
5@1H08<200000>X0RYN[4@00F0220P005P1J08<200060>h0RYN[4LR0EP00000010000?2BH@D00000
R=MQ1KQmEP3<OUH0001R1DR1EP00064549`g00400014WCL0cAkgM_3PRd3nooooK>?bM];PlWH00000
FPAm1@00000005H0000006Af00P000009@0000`000060000:00000`0000400009@0000`000070020
9@0000`000000020<00000`0000?00209@0000`000010000B`000100000000001@0002P0000<0000
0`0002P0000<00001@0002P0000<00001P0002D0000<00000000P2D0000<00001`00P280000<0000
ooooobD0000<00003@00P2P0000<00000P000280000<0000ooooob80000<0000ooooodH0001`0000
I00004E=AR//@000900001P0003ooh@n0000P000081CEHDno_oo?_n_ZSdZ@000900001P00000080o
0000P0000800080o0000P000080Q@0L0300000000004@0003000000000160000500000P00017A4U3
0`0002D0000<00003P00P2D0000<00003P00P4H0000d0000:00004E=AR/Z@000900001P00000080o
0000P0000800080o0000P000080Q000020000680000<00000@0004`0001T000000000000003U0`00
0@40000000000000iP<00081000Y0:X0000000000000080o000000000000080o0000000000000000
000000000000000000000000000R000030000?oooom60000700001000015CDH[0T0000`000000000
3P0001@000000000400001@0
\>"], "Graphics",
   GeneratedCell->False,
   CellAutoOverwrite->False,
   ImageSize->{160, 41},
   ImageMargins->0,ExpressionUUID->"992987d2-c833-4e4a-b41e-3242ed3ab1e8"], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{
  3.5285887053350596`*^9, {3.528589084930771*^9, 3.528589084930771*^9}, {
   3.5330702553390675`*^9, 
   3.533070260683373*^9}},ExpressionUUID->"87c9f80e-b1f5-4b6e-ba38-\
395532f35103"],

Cell[TextData[{
 "It is helpful to examine this function a little closer. Let us focus on the \
first term in Equation (",
 StyleBox["4.15",
  FontFamily->"Times New Roman"],
 "). Note that as ",
 StyleBox["n",
  FontSlant->"Italic"],
 " grows larger the second term in the denominator approaches zero making the \
entire denominator approach unity; hence the entire term approaches the \
numerator as a limit (",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Rule]\[Infinity]).  Thus the value selected for the numerator, which we \
can call the logistic constant (\"",
 StyleBox["lc",
  FontFamily->"Courier New",
  FontWeight->"Bold"],
 "\"), is the answer to the question \"how high is up\" in the near term. It \
is this number that represents the ",
 StyleBox["upper limit",
  FontSlant->"Italic"],
 " of value improvement over the short run due to entrepreneurial effort in \
the early years of the holding period. In the field this is sometimes known \
as \"upside\" or \"value added\" potential. Figure 4.9 illustrates how value \
changes over ten years. ",
 StyleBox["Figure 4.10",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 "displays alternatives using different values for ",
 StyleBox["lc",
  FontFamily->"Courier New",
  FontWeight->"Bold"],
 " keeping the denominator the same."
}], "Text",
 CellChangeTimes->{{3.5285887227090535`*^9, 3.528588723932123*^9}, {
  3.5285887770901637`*^9, 
  3.5285888179344997`*^9}},ExpressionUUID->"99a1f565-465c-472c-8cd7-\
0ebfd7bee664"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"val", "[", "n_", "]"}], ":=", 
  RowBox[{
   FractionBox["1.5", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "n"}]]}]], "+", 
   RowBox[{"0.04", " ", "n"}]}]}], "\n", 
 RowBox[{"fig9", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"val", "[", "n", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Time", ",", "Value"}], "}"}]}]}], "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4023989673125*^9, 3.402398970375*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"292ed697-e1de-44a2-bbf3-18488a612391"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVlXk81XkXx6+IxjITSpHlcpXSatRIqc+3aCEthBoV2S7VbdETUSqTIiKS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       "]]},
     Annotation[#, "Charting`Private`Tag$15828#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["Time", TraditionalForm], 
    FormBox["Value", TraditionalForm]},
  AxesOrigin->{0, 0.7500001612244899},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5285885544344287`*^9, 3.5286373500193768`*^9, 
  3.5299294769541864`*^9, 3.5330636702774234`*^9, 3.5330720866758137`*^9, 
  3.53368169359375*^9, 3.5337337135597863`*^9, 3.533753414453125*^9, 
  3.539520151080388*^9, 3.5395211470143523`*^9, 3.5395224500678825`*^9, 
  3.539523162137611*^9, 3.5401252577794466`*^9, 3.5409350773681135`*^9, 
  3.5409354266480913`*^9, 3.540936033994829*^9, 3.540937604009629*^9, 
  3.540937963650432*^9, 3.54100309303362*^9, 3.541599694560048*^9, 
  3.543239153539774*^9, 3.696075894238922*^9, 3.6962290360195704`*^9, 
  3.696231669263961*^9, 3.6962321868640227`*^9, 3.73142095544547*^9},
 TextAlignment->Center,
 CellLabel->"Out[93]=",ExpressionUUID->"1ada3297-9ddc-4b00-bedd-5f3004c3be80"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Modified logistic growth function"
}], "FigureCaption",
 CellChangeTimes->{{3.528588836802579*^9, 3.528588848583253*^9}, 
   3.5409359767065525`*^9},
 TextAlignment->Center,ExpressionUUID->"5e4fc267-10d2-433d-8bb1-45c9ab5dd76e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig10", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["1.1", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "2"}], " ", "n"}]]}]], "+", 
         RowBox[{"0.04", " ", "n"}]}], ",", 
        RowBox[{
         FractionBox["1.3", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "2"}], " ", "n"}]]}]], "+", 
         RowBox[{"0.04", " ", "n"}]}], ",", 
        RowBox[{
         FractionBox["1.5", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "2"}], " ", "n"}]]}]], "+", 
         RowBox[{"0.04", " ", "n"}]}], ",", 
        RowBox[{
         FractionBox["1.7", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "2"}], " ", "n"}]]}]], "+", 
         RowBox[{"0.04", " ", "n"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", "10"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Time\>\"", ",", "\"\<Value\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".1", "]"}], ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "4"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".3", "]"}], ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"5", ",", "7"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".6", "]"}], ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"7", ",", "5"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".9", "]"}], ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}], ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", ".1", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "4"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", ".3", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"5", ",", "7"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", ".6", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"7", ",", "5"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<lc=1.1\>\"", ",", "\"\<lc=1.3\>\"", ",", "\"\<lc=1.5\>\"", ",", 
        "\"\<lc=1.7\>\""}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.39420730890625*^9, {3.39420746240625*^9, 3.394207477109375*^9}, {
   3.39420750809375*^9, 3.394207530140625*^9}, {3.528588885665374*^9, 
   3.528588885840384*^9}, {3.696229829181471*^9, 3.6962298588313537`*^9}, {
   3.696229893554734*^9, 3.6962299578247433`*^9}, 3.6962300209065504`*^9, {
   3.696230109788017*^9, 3.696230120518565*^9}, {3.6962302592997894`*^9, 
   3.6962303081447396`*^9}, 3.6962303420619764`*^9, {3.696230442377864*^9, 
   3.6962305154973965`*^9}, {3.696230547659963*^9, 3.6962306194589834`*^9}, {
   3.696230683273776*^9, 3.6962307743560824`*^9}, {3.6962308113735666`*^9, 
   3.696230985285259*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"e8c36beb-8316-4878-8b13-f30e2223f156"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.1, 1, 1], 
          AbsoluteDashing[{2, 4}]], 
         LineBox[CompressedData["
1:eJwV1Wk41fsWB/BtrMjJUIrEZtfZkgZxylTfX2lSURkioVIhyakuXUrlSuGg
g9wMhZBKpeSoYwqVhJASpxCKLTab/d/T3+y6L9azns+rtZ61Xnx1PX63Oy7N
YDBuz9T/e+olD3mjY1EbzQ5tbE1O/o7KJuZuJ+YJSNKiHvk++I7pqrIrTGYQ
5q/5cBJ/f0dqRYyOHDMSlrkLAno+f4fvhoBTtE4yzkp11Bso/0DTuHcCXycH
bk6SwuRrPzCr7Qebp1OEZvurtn+c7UZGbfqZAZ0arPba6KJjxcGTp5Ftvqta
kahwOO2MoA9cVW70ziOtmMa+xY7TfWCf27lRP6EVFs/ElkZz+3HHUjGje7QV
+nt/tW1a1o/4mmhPl7dt+OA1r/6lcz/Odf9JbXf9hgBZj9fLXvYjXfH9FZWt
XYiOMItTC+HCCx+TB2f2UPjses+ONwBGpqS4Laob+gd9l47TA0iS1WqvvduN
HNWks7ekB1Fd46md09KNxSaHz79ZOAh9h4nM4+Y90CvcoPls0yD6vNmPO6Q4
iFj6t1gqYRA+8RfLGmN7UcbYzQ5ay4O0OLOzPKcX00ZOLZqWPKQ4VTOevu5F
4tFkx4KtPNRqqVnFiHrBsK+saXDmYcX9B++snX/isk7E04xLPAyWNDW+1ulD
/G+JHRXVPPhxlncXPOnHMabpBeH+IXS5f539qqYf5y37omwOD8H+S8Sq+p5+
bOLesUk7MQTT9z+DOJpcnFQxFbGChyDzLFtZPZyLUlf1zRV3hpAUrLvx34cG
0MUP/Zv0DeGVmkaymTIPl7mz2kNPD8Mkprps6woe2MlrpkoCh3FPPrBn3zYe
NIrf+A2GDCN6tGW1TzAP3gOmdsZxw9jfmVCV0sdDQe2CqgPPhsF9qCwarxiC
j1ti+i/8YSjohrE7Tfn4ybjfl2HMR7Vl3OpLW/nYYNWjMrGOj2vOaeuX2PER
5rW3xs6cD+nYwu0HT/LRL3OfJyZ8jE0Nev2Tysek594DarZ8DLQ7PvggTaGO
wzLI9eKjLom9vKKOgsYCteOnk/j4o8DE6NBXCh8D7r08couPHY2bzKY4FI5k
xk3tSeOjcparteU0BbkI3hbWXT5Kz8WeKDQS4JEcMcl+ykeuw2hO3k0BPoUr
6WlU8XFd+b1BxmEhGLW33Zr5fBStX/Lc1k8I6+XR/neEfPS4/46JC0Ikx/50
9JbwYZGr5uCUKERlvtu1oXE++qxdLyo1CBG57IRMszwFqyu8D0EWIkTpqdxQ
0qIwIp4XYKcuhvfHdM7WLRRYSzymp1li1Fx/aPJsGwXbLQWRuUZinPu8pVzD
mkJ2vHPabBsxfiQ1J/ywoWC3OuNd2RUxLDl5d+ydKOR6r9VcQYlRvNdz1YsT
FDzaHMpl6iQYWt9PEqIpKNz6furMVwnK17/My7pOId/FT6uzV4LAwf7WvFgK
Mq3hQcVSNKR2a/lUJlC4+6XY+Mx6Gra7pKsab1PobWY+6MikMbgqYiLkMQWf
xsHYoqAR2FoZLbWvpaAaGwR2+Ag6LW546cz8pXiP/FBCwgjKS7hl/fUUFD/o
7Dr9dAS7V0z/FfiRwuN6Ozk2ZwRWi94zQr5QGKotDErYO4pvovRj63opnHkb
5vE7ewx5ddLv7BkCaPdsk5cYj2EtUTtYJyXAe+k5D4PJGE7n54VbyQiwjMRQ
kQfGsNptTv5KeQG+Fv835G7UGHwZ0pcpRQE25d1L+zo8BomCWrzpQgFUblW3
WhWOI9q9WtxoKMCz03PtF1lP4v4XB6NwBwHqUtSCcvdP4mFzaE6dowC9lZrp
m49NwnClSKzsJICmxvIB38uTyOwuV715QICwV1uvvHo+CUvjPTHx7gLsV738
l4/eFCI9183Z7y3A2F+U2svxKYROfi5WvSBAxoWT3DVODLLy2vzawlQB1lTM
GQl3Y5AXaxiBT9IEqJB9INd5lEEssrv9s9IF6IrpYcacZpCe3OxDURkz97jj
5tQfySDBDXYL7LMFSKncU5lRyiBZmoUdrx8LEK9kkqaqJ0Uijk1cNygRIDR9
Yp9oUIr868Vuv10tAjCaukjpeRmik5lz1ExeiF/9PQMdDOSIzDzliEsmQvSI
E/crvpQn279teiTvKsROjs/F+DOzyY01KT4WYULY9sSu0NZWIOXbDvQM5AjB
feMRUp2rSOJi8ltk6oRYpdKyxOqQEnFK1Tc25wuhAPGRduEvJND3UEmUigjb
eS60nqMyCbR+eNTmNxG+vD4m5WKoQnKvtE0YOovwPKLSnSlWIQPnjofFB4rg
KRfQ1dCgSnrLWzWTb4lw9OyF53NT1EjcRV+ZDaWimZxZ0bD7yHzyh/nxvrXt
InxQNVQMMFtAztnpp/0zJULJk9BbhjLqxL/S1IitI8YFKYO9dd/USVZXaa7+
ZjEU2s/v8CtYSFQ6nu4JOyYG555uQnrwIqIY6th2PUyMBH0N2SJHDaKwId/A
5r4YsSme744wNYlN9Pi2kndiuCS4Ncz9qUnMz5iHXv0pxsiW7NH0ssWk9nux
vKyCBN2czYGvw7WIup1s+1oDCTI3GC2uP7KEWL55skjdRoLcqwEqXiu1ScGD
25U5pyQIdzy6S0asTcY84vqSYyT4rT0jJ7xeh7g7fb66MU+CpOW3cut3MUnd
HEnWjUYJLlfEJO0qYhL6ti9ShRLYLHbMrl2qS6qKwtxk1Gls8nt3UCVSl7BT
S6Q019FI1/JYWifWJSFvnyzjONNY+ub+TduDeqS5pbfxcBCN2JWvDT6V6ZFZ
MnukzJJpeAplP9YYsEiuOzP/bQkNj2cCZuSfLDIp/50r3U7DN9R+Ymccizik
G3TGzzjAvuCfuTdYpMrEv0nvG40IccD12JssouQ0q3RzB40nZqPjiaksUhS0
Mia0i8boq+mWe49Y5JVF0Gppzsz8T3NjKt+xyOinX/ylhmikZJ3yvlbDIk0L
nb3jZpzl32C14z2LHHDJcNUdpvFCPXbsfQOLBH8x3rqJT6PdRc27qZlF/ixy
Vv+PgAa7W8PqRzeL7FDNLGTQNNYUnNe+y2GRauOBx7EzNr/aNnr8J4sY25tk
MEdo7Gan5vVzWaQlqiqSjNI4e5KpTVEsUtLDdQkZpxFs+Z/RfCGLSMTGe5Qn
aFxV+vHZX8wi6+UuWt2ZcdLTrKiRERbpWDLPsGKSRmaIrFfxGIvsZDsz907R
eLTv+ObgCRapWZUxv2vGBXpVSzZOsYiHCXf26WkaZcJfR2cCgSw0NZ6cnvH/
AHf55HI=
          "]]}, Annotation[#, "Charting`Private`Tag$15955#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.3, 1, 1], 
          AbsoluteDashing[{5, 7}]], 
         LineBox[CompressedData["
1:eJwV1Xs41PkXB/CRS0TrVopchikKJdHaWnp/ConuCKt0oYuQKGMplaiVlbIl
rIqULipUVLKtkFxySdENGzXjbpgx851r8ZvfH+c5z+uP85zznOc8zzENPOi5
ZwqNRrsij//nq8cDVWx3p6x4f2jv7OYmNmra6Ot86fvhnz/fgPGFjcnaikQ6
PRa1xvVTY8fYuFqZaqJMT8a3mlk+c3V6EebEPCAy+RuRn86kRPv2ok0WnM41
KYCTn3qt6GsvpnZ+s+CYPMPFM8Efv1J9yHudGzls0oAYVfoSvZmDKCpO7gxb
1AEvcZDdiiAOhnSGznrs6sCv7GMrPA5xYBHtsWJ+egf+muzOXH+Sg2uO6nks
SQcSnSM0l+dycKHh7F7/V52wXNn+U0EHB9Gs8zy3bf9B1B576+PGUeSqNyZq
u/Zgc0MUi9iNYR/e/j1yiIUSxscbx8O5oF0XlnemsLC82KGsJIqLLCXDrtf5
LOgQIyHrCBf1DXuNCz6wMFpycXhpEhfzvb9f37OcDWHSq3u5uVwMBFvc/6LQ
i+D6aJM/33ARcuFYRWtaH9IDC53LrXiYQl3vflHQh/azrhretjxk+9bTiqv7
EJB+aGLgZx5eG+o6pwr6MHoyPlBpFQ9Wt+/Uufv1w9EzgCj48TDyT1trtckA
OvRdrGYk8hDeu4BVWjSIdWvaQm+/56Fn+2fVqoZB7FH9NDSjkwevT2cWNbMH
ocatGIzr4eGXxv7YXoMhXH9aFOE4zIPiw5taeklDyDr8oD+WNo6sONMVv+8Y
hpmb1gvugnFU6er/vUyLAxsFtua3mHHYp9ZXuFpxYGkT0pZ/bBy3VGLYm1dz
sMn63eHAhHGclXywCYnjYKH2gF9Lyjh8utNrswc4UBMOzNifM46hu1oCWeUo
8oedDhRWj2Oa6SmL7l+4SFy4PyplKh/1jn/ZHHflgmVwbl6IOh9/+OU4GHly
Yfhbao2LJh9T0srctoZykdKp9pmjx4d0YmTfx6tc2PtNPNE052O4a8udN1N4
qLYKnnfJmY+mLIsFlU08TOuOnVFxlI8/S+1td3zm4cFujz76CT7WtK5cNtHL
w6P7CVrxCXzUTN3m7jjJg/jKi6N2yXw8j07bX2Y7DtVlFzUOZvBR6C0peJAx
jomvWdqOD/g4p9VombeTD3pHDdP1Kx/PHIwebwjnIzI+Xz+WzQd7+0F8l/fV
jj4/fqefj18Ldb19M/k4cSnf+weHjwH3bcemt/AR9mrT5lgpH86JnDexvwrA
1DFnV+kIIKY0mZ56FFYlKL57RARgGAVOTjIofBG0OzOdBdjgUppcaEth54Z9
EfarBbh5wS9HdT0FpUmxWsFaATxt8uoqEilsdQsrDvURoDB4iYEVj0L9NgH8
QwUI7PR+odgkRIR552vRBQGmXf56IPKzEC/HTOkbLgnwyD/csLtPiCQDWm1e
pgCKHUmx5QoiYOrv2iuvCJD/qdwu0kEExzJ/1Z03Beh7T7/z5boI8aXXosye
ChDSOpL2LFaMoyYzc1o/CaCTFguLJDHME93TPnYIUL5RZTQ9XYwbC344dnUJ
oP7GZG1EsRgjpZvefekR4H6zp7JFrxhOmyZWNQwIMPq6LDZ9kwQ861b2UrEA
ka9OBR60kOJ7p2p9wkwKxuzVKkI7KZrsR0/On0WhcYra3Tgixehb5YtNsynM
I6m85N+kqJue81LTkMLn8kvx+Sny+rCiywlmFFY+uJXzeUwKrl+8mqENBe3L
9R3OZTLMGCs/bO1G4WGEhtds9x+I8j/4dvFhCk3ZurGFPj9Ajxm2zoqi0Fdj
kLtq9w8EnbUyn2BSMNBfMBx24geSFAOlr2IonKpyTax6/APhffwg1+MUfHRO
lISYTSDpEEdJOZmCtISn+69M7o0vll26SiHvaOjQYl8amTNY3bj9JYXFlWri
pAAa8Xnplry/hkKl0h3l7iAaeR6Qzjz8ikJPKpueGkEjzf4+3afq5Pu4FuA7
mEwjZRu7Zuc0Usiu2ViT95xGnGyyFtxro3Bhun2OjpkCOWUfecWBRSEh9/tm
wYgCKa7uKfeiCUFr6yHPjyiSayzeHhs7Icyj9sZ4WyqTmUaj+plBQrCpTB/1
f1WI8pFnJYfPCuHRG3LsQqQq+ZahEpTzWIgN7DQrY+NpZPmc8V2cTiGGXgbG
1xeqE7c31srBE0Is0v5g5LxjOsnlZtb3mokwDdSuLv5P5OH2ovNBLiK4cfxF
Zlu0iEb5YlXXYBE+Ve9W8LfWJoMVz7SWpYjw+EzNdjqlTap4ZWvu3RNhrzKz
p6VFh9h0Zqj80yJC0KGjjzWydUl+f0DW7jERbPZZtazbNYO4lNMdt2uK8UbH
Wp25bCYZ2Cm+rbxEjH+KEi5bK+oRY/VNgz6e8rtVsNzU9J8eWZh36vJvTDGm
dR1ZE146i2RXn1d6kilG7y3T9Ny42cTvyZh61VMx0ufrKz3bok/KW++WnugQ
Iy17b90uugEZUXJVHZWK4Z8e0KLRb0Dmh5oHlxlIIHa5KcmtmEOq5y6d6uAk
Aat3VUx1kiFJGRaP7AmQ4LqT7ZzmXUZkeVriUvd4CQpPM7X3LTQm8b71A13X
JEjaErRWkTIm/isytZsrJVjalVeQ1GxCum9sexTJkiBrweXC5rV0EiO6+65W
UYoTlalZa5/J3f7wYKu5FOvnbLn5eq4poc9pPPezuxQrw+u2aiebEtWneXbr
90uRaxg4t4kyJWSuqt/ss1LMfXk7Y8NWM1KdmKSYfl+KtIXVlu8qzIjbV2P7
sCYp9vKV3jZYMohaqE6veFSKwIfj9OTzDJLjOmD0s6YMYQle3z3+YpAxyyU6
tXIzvUo/alxkkHaNOBUfLRnOUMxzaRkMElmrOcbUlqFomUSWeVVer+1Q+VhX
BknV5Idb9xikQeN04NLZMqS900itqWOQ+8+Nb9ubypB940DwHw0M4ongyzVy
34hqcV7TyCAOLx6e9zaT4YlemrSxhUE+PXGJiWLI0OWvG9z2nkH4p0PcS+fJ
YMHSd/7GYpCLtx8P21nKsLj0iHF+r3we2mT3S7mXn+6U7OlnkM8+a9q9rGRY
Z3H1weAQg/h+73h+2FqGQ6F0Yx6PQRItaedKFskQ53hS8ojPIOYR7gnONjKc
nv6tPYpiEGbJheg2ubOKb6SIxQwy127eDv5iGa7HK+0rlzLIuYPhXom2Mtzb
vGdV3HcGeVTw1E13iQylZrVGKyYYJOMrzfGG3BV8c4n8IRDM8lhsZyfD/wAF
rN9s
          "]]}, Annotation[#, "Charting`Private`Tag$15955#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.6, 1, 1], 
          AbsoluteDashing[{7, 5}]], 
         LineBox[CompressedData["
1:eJwVlXk81XkXx6+IxjITSpHlcpXSatRIqc+3aCEthBoV2S7VbdETUSqTIiKS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          "]]}, Annotation[#, "Charting`Private`Tag$15955#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.9, 1, 1], 
          AbsoluteDashing[{2, 2}]], 
         LineBox[CompressedData["
1:eJwV1Xk41GsbB/AfooVkTCliDFPHVlR4i6PuBwklspdChtBiqZMiFBGpnOgo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          "]]}, Annotation[#, "Charting`Private`Tag$15955#4"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0.5500001204081634}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"Time\"", TraditionalForm], 
       FormBox["\"Value\"", TraditionalForm]}, 
     AxesOrigin -> {0, 0.5500001204081634}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 450, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"lc=1.1\"", "\"lc=1.3\"", "\"lc=1.5\"", "\"lc=1.7\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.1, 1, 1], 
                    AbsoluteDashing[{2, 4}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.1, 1, 1], 
                    AbsoluteDashing[{2, 4}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.3, 1, 1], 
                    AbsoluteDashing[{5, 7}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.3, 1, 1], 
                    AbsoluteDashing[{5, 7}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.6, 1, 1], 
                    AbsoluteDashing[{7, 5}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.6, 1, 1], 
                    AbsoluteDashing[{7, 5}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    AbsoluteDashing[{2, 2}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    AbsoluteDashing[{2, 2}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    Hue[0.10000000000000002`, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.1`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.1, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.1], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "4"}], "}"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.3], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.3, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.3`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.3, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.3], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "7"}], "}"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.6], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.6, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.6`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.6, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.6], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"7", ",", "5"}], "}"}], "]"}]}], "}"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.6962309877638516`*^9, 3.6962316695006175`*^9, 
  3.6962321870445027`*^9, 3.731420955628427*^9},
 TextAlignment->Center,
 CellLabel->"Out[94]=",ExpressionUUID->"f10e69ef-2df0-4aba-8df4-616f1ad96a26"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Various values of ",
 StyleBox["lc",
  FontWeight->"Bold"],
 " for modified logistic growth function"
}], "FigureCaption",
 CellChangeTimes->{{3.5285889234455347`*^9, 3.528588937439335*^9}, 
   3.5409359788266735`*^9},
 TextAlignment->Center,ExpressionUUID->"ab2ae47e-bf84-48e5-b0c1-718cf1c9b8e5"]
}, Open  ]],

Cell[TextData[{
 "We now focus on the second constant in the first term of (4.15). It appears \
in the denominator operating on ",
 StyleBox["n",
  FontSlant->"Italic"],
 ", the acceleration factor (\"",
 StyleBox["af", "Input"],
 " \").   This answers the question \"how fast\" as it determines how quickly \
the limit is reached.  It may be viewed as the ",
 StyleBox["efficiency",
  FontSlant->"Italic"],
 " of the entrepreneurial effort. Thus, the larger this constant, the more \
rapidly the limit is reached.  Compare the value of the x axis at the sharp \
bend for each of the four alternative plots in Figure 4.11."
}], "Text",
 CellChangeTimes->{{3.528632091226591*^9, 3.5286321191761894`*^9}, {
  3.5286323155174193`*^9, 
  3.528632318662599*^9}},ExpressionUUID->"ed61d4fa-3aaf-485e-9e0d-\
6632c55e3711"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig11", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["1.5", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", "n"}]]}]], "+", 
         RowBox[{"0.04", " ", "n"}]}], ",", 
        RowBox[{
         FractionBox["1.5", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "2"}], " ", "n"}]]}]], "+", 
         RowBox[{"0.04", " ", "n"}]}], ",", 
        RowBox[{
         FractionBox["1.5", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "3"}], " ", "n"}]]}]], "+", 
         RowBox[{"0.04", " ", "n"}]}], ",", 
        RowBox[{
         FractionBox["1.5", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "4"}], " ", "n"}]]}]], "+", 
         RowBox[{"0.04", " ", "n"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", "10"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Time\>\"", ",", "\"\<Value\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".1", "]"}], ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "4"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".3", "]"}], ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"5", ",", "7"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".6", "]"}], ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"7", ",", "5"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".9", "]"}], ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "}"}]}], "}"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", ".1", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "4"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", ".3", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"5", ",", "7"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", ".6", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"7", ",", "5"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<af=1\>\"", ",", "\"\<af=2\>\"", ",", "\"\<af=3\>\"", ",", 
        "\"\<af=4\>\""}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.39420756628125*^9, {3.40239916603125*^9, 3.402399173109375*^9}, {
   3.402399381859375*^9, 3.402399384328125*^9}, {3.6962300575440245`*^9, 
   3.696230093655097*^9}, {3.6962301389475946`*^9, 3.696230151526063*^9}, {
   3.6962301910792904`*^9, 3.696230214312102*^9}, 3.6962311197880955`*^9},
 CellLabel->"In[95]:=",ExpressionUUID->"414e6edf-815d-4fcf-9ec3-c6a04f4703ec"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.1, 1, 1], 
          AbsoluteDashing[{2, 4}]], 
         LineBox[CompressedData["
1:eJwVz30w1Akcx3HPNVJDlqyHtetHWsVpTqU7+X6PUKmu8lCntHbleYlutynU
xXk8kWQ8JCOSVJPKcDcqWySSh1PbqVk6xoblNJfY7MNvf27vj8985vXnm8U7
eShKT0dHZ592/3/1eZ7R5hMF3lNeZ1x1dGTQJWbuPcyMg8wafkKisQyWu0W/
Mpln4Vzu2QYJTQbVzwrtDZn54OQHK1vZMuDvECYu2VeCXoQrOy5IBmJ1bOln
+9swxhaE9jfIYMXIhPMn+zZI9uyyjN83A7WvalL+se+F9tERU17lLDTdzx/h
u0lg88m5tVnhnyAGXlfOnZKCXqjwgFjyLyRNsqUtTTOwIdZITrOcB2NWlvOY
52eICaZoQp8vUGTa51IbsQDt7EdzQTsXgDcS/FS//ytcKa//2dRnEVJeZPFO
OqughSOaZ7Hk8DDZJMhqtwYSVwwr+iVyqE1LmHU/rIMrF2u9Agu/arvJg4tz
uvjUQrf8MHMJdMTj+CRVH+np6ySrry/BekH0mWAXQ1T8wdaNtFbAR3l56Kp2
I0yQX6L5/aKAPZPx50pSVuLur4rG78cVsP9j8UYGwxinI4NsejyUMPucd+Hl
vVU489vb9uo0JbiZDdv5clZjkTSxgdmhBGOQc0cX1mDOhck4H1IJAZ/ClhxC
TNHd4qW+0zYVvO88oRu2yQytBRxODV8FrXldx5lyM2z0fz91qEoF0YbC8cHB
teh0wJxD71NB5Km0VpOr5nj6Tta583IVfBOzcXAvl4a7tlqZhdmp4c+1m1YJ
t1vg6MXORsMANTxuyqzapG+J6X6Xm5v5akjTdTnQ/8ESvSv9kwWlajAeTd2V
1LIOTx9jdlQ8UsNkA6u0Jt0KXTOec3M+qKF0A92gLYSOpERRL9YjofhqdA+X
aY1GdWHHPJxICCsNHzSZtkZaxtiLYn8SFDtvKmtENrjV091NEE+CdNLnTGeu
LWZ3b3vdXEBC3Y7NNgNcO8zpCeDk3CfhXrbQLMaVgT86Nz0eGiIhNyQyUF/O
QJFbgkHwPAlbRmtv5w7YIz0gbymVpoEKdtW9gUAmXrM19v52iwZ+eVZYEdjG
xDWSixGlRzSwzybk5itHFqYGc40wTQM/JPUcNctnoWEH+1pBlQZqbHmO/XIW
dry8cyVbpAHH57fK9h91wFG/t+8cxzRQ7Nrp8kbkgB++NLXSlzUQvWDwuteF
wGH+9NBTFgW8h1+Y+ZcIrB/IjDD1oYCfGUTuuUygV+xA3XWthUEt70yuEGhb
If7o7ktBnlxYVFxGYOYt89iDOylo2q5Ul1cTOL4iLqHEnwJlx/Jww10Cb3td
i6IFUlD8xqSwq4fA6bRWtlUwBVdvJMbm9BJYYiONbNT6hmDQd1cfgVOJ4mrP
EAp+tyxW9Q0SGK2rMf0plILRMPNY8V8ExrWdXaw8QoGzlO47ISUwPjPggU04
Be4tqYz6SQLb6G1Td7X+LntEGTVNoMWdz7ZexynY61z9YGaWwCMZzXnHOBSc
SmAy5ucJnLiUE17NpSDdK0PZvEDgk9OuJa48CrJXT7wVyAmclFV1t2tdcf9G
gUJBIOkx5PZ3JAV1FwxiHqkITE4p4yWdoODuwSifdJJAD8qxjNK6xaHbzpsi
kDBJ7y2KokC0sF65vKzt66siGdEU/Ac9RE3Q
          "]]}, Annotation[#, "Charting`Private`Tag$16092#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.3, 1, 1], 
          AbsoluteDashing[{5, 7}]], 
         LineBox[CompressedData["
1:eJwVlXk81XkXx6+IxjITSpHlcpXSatRIqc+3aCEthBoV2S7VbdETUSqTIiKS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          "]]}, Annotation[#, "Charting`Private`Tag$16092#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.6, 1, 1], 
          AbsoluteDashing[{7, 5}]], 
         LineBox[CompressedData["
1:eJwV1Hk01WsXB3AhdVHXUELmU04dGjSY9f1FlDRHpJlMDaRSCVEIF5EUUbk0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          "]]}, Annotation[#, "Charting`Private`Tag$16092#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.9, 1, 1], 
          AbsoluteDashing[{2, 2}]], 
         LineBox[CompressedData["
1:eJwVlHk0lQsXh4XUrW4dKjcyv6Ii1VfdSvR7L5FMlYhkuGRsIL50U7qUSqQ6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          "]]}, Annotation[#, "Charting`Private`Tag$16092#4"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0.7500000846938775}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"Time\"", TraditionalForm], 
       FormBox["\"Value\"", TraditionalForm]}, 
     AxesOrigin -> {0, 0.7500000846938775}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"af=1\"", "\"af=2\"", "\"af=3\"", "\"af=4\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.1, 1, 1], 
                    AbsoluteDashing[{2, 4}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.1, 1, 1], 
                    AbsoluteDashing[{2, 4}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.3, 1, 1], 
                    AbsoluteDashing[{5, 7}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.3, 1, 1], 
                    AbsoluteDashing[{5, 7}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.6, 1, 1], 
                    AbsoluteDashing[{7, 5}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.6, 1, 1], 
                    AbsoluteDashing[{7, 5}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    AbsoluteDashing[{2, 2}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    AbsoluteDashing[{2, 2}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    Hue[0.10000000000000002`, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.1`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.1, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.1], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "4"}], "}"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.3], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.3, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.3`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.3, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.3], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "7"}], "}"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.6], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.6, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.6`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.6, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.6], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"7", ",", "5"}], "}"}], "]"}]}], "}"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5286321781385617`*^9, 3.5286373559497156`*^9, 
  3.5299294794583297`*^9, 3.5330636729205747`*^9, 3.5330720886669273`*^9, 
  3.533681696515625*^9, 3.533733716136934*^9, 3.533753417875*^9, 
  3.5395201539185505`*^9, 3.5395211488564577`*^9, 3.5395224519709916`*^9, 
  3.539523163957715*^9, 3.540125261704671*^9, 3.540935080318282*^9, 
  3.540935428444194*^9, 3.540936035717928*^9, 3.540937605882736*^9, 
  3.5409379666206017`*^9, 3.541003096846838*^9, 3.541599697451213*^9, 
  3.543239156340934*^9, 3.696075897446456*^9, 3.696229036256173*^9, 
  3.6962302072222376`*^9, 3.6962311215989127`*^9, 3.6962316698625774`*^9, 
  3.6962321872199697`*^9, 3.731420955773312*^9},
 TextAlignment->Center,
 CellLabel->"Out[95]=",ExpressionUUID->"95196c41-b258-4cbb-8ef9-e99ee3e10cb8"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Various values of ",
 StyleBox["af",
  FontWeight->"Bold"],
 " for modified logistic growth function"
}], "FigureCaption",
 CellChangeTimes->{{3.528632285679713*^9, 3.5286322991154814`*^9}, 
   3.540935981002798*^9},
 TextAlignment->Center,ExpressionUUID->"ed441a53-d727-4141-902f-21f0b12d2835"]
}, Open  ]],

Cell[TextData[{
 "The last term in the function involves what might be considered \
\[OpenCurlyDoubleQuote]normal\[CloseCurlyDoubleQuote] growth (\
\[OpenCurlyDoubleQuote]",
 StyleBox["g",
  FontFamily->"Courier New",
  FontWeight->"Bold"],
 "\[CloseCurlyDoubleQuote]), stabilized after the early year \
\[OpenCurlyDoubleQuote]turnaround period\[CloseCurlyDoubleQuote]."
}], "Text",
 CellChangeTimes->{
  3.528632441778641*^9},ExpressionUUID->"0924b498-68b2-40fd-9bdf-\
a301f216a5cc"],

Cell[TextData[{
 "In Figure 4.12 we compare two entrepreneurs, both in possession of \
properties with the same upside potential. One is more efficient, having an \
acceleration factor of 4 contrasted to ",
 StyleBox["af", "Input"],
 " = 1 for the less efficient owner. The filled area represents the \
additional growth reaped in the early years for the more efficient owner. The \
two converge after about six years. But, one might surmise that the more \
efficient party would not hold the original property for the full six years, \
choosing instead to repeat the process once or twice in six years."
}], "Text",
 CellChangeTimes->{{3.528632446156892*^9, 
  3.528632448966052*^9}},ExpressionUUID->"629d8936-c482-4c8a-a673-\
18b49dc544cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig12", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1.5`", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "n"}]]}]], "+", 
       RowBox[{"0.04`", " ", "n"}]}], ",", 
      RowBox[{
       FractionBox["1.5`", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "n"}]]}]], "+", 
       RowBox[{"0.04`", " ", "n"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Time", ",", "Value"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", "0.1`", "]"}], ",", 
       RowBox[{"Hue", "[", "0.9`", "]"}]}], "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", "\[Rule]", 
       RowBox[{"{", "2", "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.394207868359375*^9},
 CellLabel->"In[96]:=",ExpressionUUID->"4a821ec9-12e2-49ae-9973-e1413bf53139"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxN13k8lP3+x3FbdLSNJTeyjyVZ0kk3CZ/rkCVLi2yJZN/XgztLNylkqYbc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    "], {{{}, {}, {}, {}, {}, {}, 
      {Hue[0.1, 1, 1], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
         11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 
         28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
         45, 46, 47, 48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 
         68, 63, 59, 75, 69, 64, 76, 70, 77, 50, 127, 243, 219, 242, 196, 218,
          241, 174, 195, 217, 240, 153, 170, 191, 213, 236, 136, 145, 162, 
         183, 205, 228, 126, 125, 124, 123, 122, 121, 120, 119, 118, 117, 116,
          115, 114, 113, 112, 111, 110, 109, 108, 107, 106, 105, 104, 103, 
         102, 101, 100, 99, 98, 97, 96, 95, 94, 93, 92, 91, 90, 89, 88, 87, 
         86, 135, 144, 161, 182, 204, 227, 85, 152, 169, 190, 212, 235, 134, 
         143, 160, 181, 203, 226, 84, 151, 168, 189, 211, 234, 133, 142, 159, 
         180, 202, 225, 83, 150, 167, 188, 210, 233, 132, 173, 194, 216, 239, 
         141, 158, 179, 201, 224, 82, 149, 166, 187, 209, 232, 131, 172, 193, 
         215, 238, 140, 157, 178, 200, 223, 81, 148, 165, 186, 208, 231, 130, 
         171, 192, 214, 237, 139, 156, 177, 199, 222, 80, 147, 164, 185, 207, 
         230, 129, 138, 155, 176, 198, 221, 79, 146, 163, 184, 206, 229, 128, 
         137, 154, 175, 197, 220, 78}}]]}, {}, {}, {}}, {{}, {}, {}, 
      TagBox[
       {Hue[0.1, 1, 1], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
         12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
         29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
         46, 47, 48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 
         63, 59, 75, 69, 64, 76, 70, 77, 50}]},
       Annotation[#, "Charting`Private`Tag$16168#1"]& ], 
      TagBox[
       {Hue[0.9, 1, 1], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[{78, 220, 197, 175, 154, 137, 128, 229, 206, 184, 163, 146, 
         79, 221, 198, 176, 155, 138, 129, 230, 207, 185, 164, 147, 80, 222, 
         199, 177, 156, 139, 237, 214, 192, 171, 130, 231, 208, 186, 165, 148,
          81, 223, 200, 178, 157, 140, 238, 215, 193, 172, 131, 232, 209, 187,
          166, 149, 82, 224, 201, 179, 158, 141, 239, 216, 194, 173, 132, 233,
          210, 188, 167, 150, 83, 225, 202, 180, 159, 142, 133, 234, 211, 189,
          168, 151, 84, 226, 203, 181, 160, 143, 134, 235, 212, 190, 169, 152,
          85, 227, 204, 182, 161, 144, 135, 86, 87, 88, 89, 90, 91, 92, 93, 
         94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 
         109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122,
          123, 124, 125, 126, 228, 205, 183, 162, 145, 136, 236, 213, 191, 
         170, 153, 240, 217, 195, 174, 241, 218, 196, 242, 219, 243, 127}]},
       Annotation[#, "Charting`Private`Tag$16168#2"]& ]}}], {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["Time", TraditionalForm], 
    FormBox["Value", TraditionalForm]},
  AxesOrigin->{0, 0.7500000846938775},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.528632467495112*^9, 3.5286373560107193`*^9, 
  3.529929479862353*^9, 3.533063673421603*^9, 3.533072088755933*^9, 
  3.533681696765625*^9, 3.5337337166569633`*^9, 3.533753418109375*^9, 
  3.539520154529586*^9, 3.539521148966464*^9, 3.5395224520929985`*^9, 
  3.5395231640657215`*^9, 3.5401252623917103`*^9, 3.5409350809893208`*^9, 
  3.5409354284941964`*^9, 3.5409360357679305`*^9, 3.5409376065217724`*^9, 
  3.5409379673276424`*^9, 3.541003097606881*^9, 3.541599698111251*^9, 
  3.5432391569889708`*^9, 3.6960758975417094`*^9, 3.6962290363263917`*^9, 
  3.6962316700049596`*^9, 3.6962321873353186`*^9, 3.731420955870102*^9},
 TextAlignment->Center,
 CellLabel->"Out[96]=",ExpressionUUID->"751227da-f953-435d-a74b-73ec180698aa"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Different production functions for gain using different owners having \
different efficiency"
}], "FigureCaption",
 CellChangeTimes->{{3.5286325622965345`*^9, 3.5286325964254866`*^9}, 
   3.5395204133333883`*^9, 3.540935982768899*^9},
 TextAlignment->Center,ExpressionUUID->"7ade0da8-94ba-4807-aea1-2e25c24bd2be"]
}, Open  ]],

Cell[TextData[{
 "Suppose the acceleration rate is influenced by institutional factors \
discussed in Chapter 2. We now take one investor as he considers two \
projects, one with an upside ",
 StyleBox["lc", "Input"],
 " of 1.2 in a community that allows him to fully exercise his ",
 StyleBox["entrepreneurial ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 "skills, represented by ",
 StyleBox["af", "Input"],
 " = 4, relatively unfettered by regulatory interference. A second property \
has greater upside of ",
 StyleBox["lc", "Input"],
 " = 1.5 but is located in a community that imposes burdensome regulation \
constraining his entrepreneurial ability to an artificial ",
 StyleBox["af", "Input"],
 " = 2. In Figure 4.13 we see the two growth rates do not converge in twenty \
years.  This has implications for communities interested in attracting the \
real estate equivalent of incubator companies, developers who specialize in \
urban renewal and infill projects in older neighborhoods that benefit the \
community by raising the tax base."
}], "Text",
 CellChangeTimes->{{3.5286326594180894`*^9, 
  3.5286326915749288`*^9}},ExpressionUUID->"fc02f051-be63-4a09-b12b-\
2e5c9e6bb5b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig13", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1.2`", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "n"}]]}]], "+", 
       RowBox[{"0.04`", " ", "n"}]}], ",", 
      RowBox[{
       FractionBox["1.5`", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "n"}]]}]], "+", 
       RowBox[{"0.04`", " ", "n"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "20"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Time", ",", "Value"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", "0.1`", "]"}], ",", 
       RowBox[{"Hue", "[", "0.9`", "]"}]}], "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", "\[Rule]", 
       RowBox[{"{", "2", "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellLabel->"In[97]:=",ExpressionUUID->"59e55f56-0cac-4074-a88e-430ff3358df8"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxF13k01F38B/AxlqdsjciTFktZSkLPlLLkc0sUSZsiLaLQIkWRtSJCSloe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    "], {{{}, {}, {}, {}, {}, {}, 
      {Hue[0.1, 1, 1], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl0necz3UAx/E7XI7O5rrhcNbdGccdsjNDw7qskhJZxR3Zeysjq0HDLCNl
NhAiDVSkIRUySvbe2/P7uD+ej9/r/f0+vn98v79PfKeMtPQsISEhoVQKzfwd
SU+e4TFqBvd4lX50oiUNCJ4dRS/a8zi1qMxr9KczaTQkK6NJ51meoDavM4Tu
tKUKExnAizzFo2RjDBl04EkeYSpD6UE7HmYSA+lCKxoRxlh68xxNqUNVJjOI
rrSmMQ8wjj48TzPqUo3sjOcVOtKcelQnnBzk5EEiyEVu8pCXfOSnAAUpRCQP
EUU0McRSmDiKUJRixFOcEpSkFKVJIJEkylCWcpQnmQpUJIUJ9OUFWlCfGkxh
MN1oQxOmMYyXeJrpDOdlZjCCmaTybUjmeYomNThURJHCcfNW8N66HHv0IS4F
38ouyQ96N/s4G/wPrhXlG72Vr9nCZr5iExvZwJesZx1r+YLP+YxPWcNqVrGS
FSznEz5mGR+xlCUsZhEf8gELWcB85jGXObzPe7zLO8xmBz/zN2cI8w5FmKV/
5yAXyelaCbbr/7gWnBM7kV36L06TzY7jbX2Mm+S3y/KbvhecH12Rf/QFcuji
bNP/cpXcdgI79R0K6WT+1KfIqgvzlv6fG+Szy/CrvkukrsABfZ5wHc/3+ghX
yGWX5id9m4K6PHv1SbLoWN7UR7lOXjuJX/R+zpHdLsZ3+jCXibBL8aP+gxPB
MbNjeEPfB17dhsw=
         "]]]}, {}, {}, {}}, {{}, {}, {}, 
      TagBox[
       {Hue[0.1, 1, 1], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[{1, 127, 108, 90, 73, 59, 51, 135, 116, 98, 81, 67, 2, 128, 
         109, 91, 74, 60, 52, 136, 117, 99, 82, 68, 3, 129, 110, 92, 75, 61, 
         141, 122, 104, 87, 53, 137, 118, 100, 83, 69, 4, 130, 111, 93, 76, 
         62, 142, 123, 105, 88, 54, 138, 119, 101, 84, 70, 5, 131, 112, 94, 
         77, 63, 55, 139, 120, 102, 85, 71, 6, 132, 113, 95, 78, 64, 56, 7, 
         133, 114, 96, 79, 65, 57, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
         36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 134, 115, 97,
          80, 66, 58, 140, 121, 103, 86, 72, 143, 124, 106, 89, 144, 125, 107,
          145, 126, 146, 50}]},
       Annotation[#, "Charting`Private`Tag$16239#1"]& ], 
      TagBox[
       {Hue[0.9, 1, 1], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwt0ukylnEcx+HnUVKWiJJEUVISFWfiEDoAHUwLaSHSQlnSQlEpVJQiS0gL
0qYSyp6uZry4Zj7f37v/3HfqkaN5+cFAIHCeYyQaQb7oPjrYY0cyoz/QSood
xk/9hi4y7Bjm9EeOs90O4avuJ0tvZkk/I11H8VuP0EaqvZ5JPcxBHc9f3c1+
vYl5Pc4Jkuw1fNOvydZbWNbP2as38keP8phd9gZ+6bcc0ltZ0a/I1LEs6E+c
JNley4QeoJN9djSzeown7LbDmdLv6KGAHW6hfNeDvOAphZyiiNOc4SznKKZk
9RuVUsYFyrnIJS5zhQoquco1qqimhlquU8cNbnKL29TTwB3u0kgT97jPA5p5
yCN2esM6fughXtJOmlsE0/o9vRyw41jUnzmsE/7/dOSwjVxanP4BMmddTA==

         "]]},
       Annotation[#, "Charting`Private`Tag$16239#2"]& ]}}], {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["Time", TraditionalForm], 
    FormBox["Value", TraditionalForm]},
  AxesOrigin->{0, 0.6000002612244897},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5286327053647175`*^9, 3.528637356035721*^9, 
  3.5299294801903715`*^9, 3.5330636738486276`*^9, 3.5330720888969407`*^9, 
  3.533681696921875*^9, 3.5337337171299906`*^9, 3.53375341821875*^9, 
  3.539520155168622*^9, 3.5395211490884714`*^9, 3.539522452221006*^9, 
  3.539523164133725*^9, 3.5401252630687485`*^9, 3.540935081747364*^9, 
  3.540935428537199*^9, 3.5409360358099327`*^9, 3.540937607246814*^9, 
  3.540937967880674*^9, 3.5410030982529182`*^9, 3.541599698759288*^9, 
  3.543239157574004*^9, 3.6960758976209393`*^9, 3.696229036471773*^9, 
  3.696231670159374*^9, 3.6962321875287914`*^9, 3.7314209559568357`*^9},
 TextAlignment->Center,
 CellLabel->"Out[97]=",ExpressionUUID->"3f56a5c4-da20-4a31-a228-e596e5048650"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Property in different political jurisdictions, one constraining the owner\
\[CloseCurlyQuote]s productive activities"
}], "FigureCaption",
 CellChangeTimes->{{3.52863273898164*^9, 3.5286327662101974`*^9}, 
   3.540935984523*^9},
 TextAlignment->Center,ExpressionUUID->"2ed4468b-6e6b-47dc-b540-4c0865f5c9bf"]
}, Open  ]],

Cell[TextData[{
 "One can smooth out an irregular growth rate to create an average over the \
holding period. Returning to the original logistic growth function (4.15) \
with fixed values for ",
 StyleBox["lc", "Input"],
 " = 1.5 and ",
 StyleBox["af", "Input"],
 " = 2, value increases just over 60% in the first three years....."
}], "Text",
 CellChangeTimes->{{3.5286328139129257`*^9, 3.528632837323265*^9}, {
  3.5286328908033237`*^9, 3.5286329093523846`*^9}, {3.539526419661931*^9, 
  3.539526420899001*^9}},ExpressionUUID->"a0aa50eb-8e79-4a0d-b2d0-\
7da364e12d0d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"val", "[", "3", "]"}]], "Input",
 CellLabel->"In[98]:=",ExpressionUUID->"b766241b-80ef-476f-968b-120a2d5c7cd4"],

Cell[BoxData["1.616291065265048`"], "Output",
 CellChangeTimes->{3.5286328507140307`*^9, 3.528637356050721*^9, 
  3.5299294805183907`*^9, 3.533063674363657*^9, 3.533072088973945*^9, 
  3.53368169703125*^9, 3.533733717574016*^9, 3.533753418328125*^9, 
  3.5395201558036585`*^9, 3.539521149152475*^9, 3.53952245228401*^9, 
  3.5395231642437315`*^9, 3.5401252639147973`*^9, 3.540935082461405*^9, 
  3.5409354285792017`*^9, 3.5409360358519354`*^9, 3.540937607838848*^9, 
  3.5409379687097216`*^9, 3.5410030991989727`*^9, 3.5415996994733286`*^9, 
  3.5432391582740445`*^9, 3.69607589763596*^9, 3.6962290364887915`*^9, 
  3.696231670188453*^9, 3.696232187578925*^9, 3.731420955979893*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"6962bdc6-d6e0-4962-8ad5-3d1bf0bae2b2"]
}, Open  ]],

Cell["\<\
...but does not quite double in the first ten years, representing the \
flattening of the curve in the later years.\
\>", "Text",
 CellChangeTimes->{{3.5286329459064755`*^9, 
  3.528632957191121*^9}},ExpressionUUID->"dd9d2663-3ae7-4482-9c86-\
6e0936e9440a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"val", "[", "10", "]"}]], "Input",
 CellMargins->{{66, 0}, {5, 10}},
 CellLabel->"In[99]:=",ExpressionUUID->"e4e0313a-0260-4015-8b74-da23eb85dd38"],

Cell[BoxData["1.8999999969082695`"], "Output",
 CellChangeTimes->{3.528632873116312*^9, 3.528637356064722*^9, 
  3.5299294807854056`*^9, 3.5330636747186775`*^9, 3.533072089034949*^9, 
  3.533681697109375*^9, 3.5337337179650383`*^9, 3.53375341840625*^9, 
  3.539520157205739*^9, 3.5395211491994777`*^9, 3.539522452329012*^9, 
  3.5395231642967343`*^9, 3.540125264575835*^9, 3.540935083012436*^9, 
  3.540935428622204*^9, 3.540936035893938*^9, 3.5409376084528832`*^9, 
  3.5409379693997607`*^9, 3.541003099928014*^9, 3.541599700127366*^9, 
  3.5432391589780846`*^9, 3.696075897660024*^9, 3.6962290364988184`*^9, 
  3.696231670248581*^9, 3.6962321876210365`*^9, 3.731420956003456*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"a2b06ade-267d-41d5-8e3a-5fb079a66bb4"]
}, Open  ]],

Cell[TextData[{
 "For the sake of comparison we can look at what sort of continuous return \
would be necessary to produce the same outcome if a constant rate were earned \
over the same ten years. This involves solving for ",
 StyleBox["r",
  FontSlant->"Italic"],
 " in Equation 4.16: "
}], "Text",
 CellChangeTimes->{{3.5286330481543236`*^9, 3.5286330550407176`*^9}, {
  3.53952643119259*^9, 
  3.5395264351128144`*^9}},ExpressionUUID->"71c8f0fc-8bec-4cab-b6a6-\
08707f6aeb0d"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "r10"], "=", "1.9"}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5286330700055733`*^9, 
  3.528633085107437*^9}},ExpressionUUID->"68f6a73a-4ed5-4e02-9f4a-\
b65f4b2bcd25"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sr", "=", 
   RowBox[{"Quiet", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"r", " ", "10"}]], "\[Equal]", 
       RowBox[{"N", "[", 
        RowBox[{"val", "[", "10", "]"}], "]"}]}], ",", "r"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"r", "/.", "sr"}], ",", 
      RowBox[{
       RowBox[{"Positive", "[", "#", "]"}], "&"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"CellPrint", "[", 
  RowBox[{"Cell", "[", 
   RowBox[{
    RowBox[{"TextData", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<The value for \>\"", ",", 
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<r\>\"", ",", "Italic"}], "]"}], ",", 
       RowBox[{
       "\"\< in Equation 4.16, the continuous compounding return, is \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{"rate", "*", "100"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
        "\"\<%.\>\""}]}], "}"}], "]"}], ",", "\"\<Text\>\""}], "]"}], 
  "]"}]}], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.394208832203125*^9, 3.394208841875*^9}, {
  3.52863299983856*^9, 3.5286330312933598`*^9}, {3.528633119850425*^9, 
  3.5286333705087614`*^9}, {3.5330703952080674`*^9, 3.5330705499869204`*^9}, {
  3.541003833032945*^9, 3.541003866526861*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"2be7870c-6b00-4d5a-bffb-8367bf021259"],

Cell[TextData[{
 "The value for ",
 StyleBox["r",
  FontSlant->Italic],
 " in Equation 4.16, the continuous compounding return, is 6.42%."
}], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731420956030528*^9},ExpressionUUID->"091c6efc-6859-4015-aeee-\
ace0a14d600e"]
}, Open  ]],

Cell[TextData[{
 "Figure 4.14 provides an interactive look at the modified logistic growth \
function and how various values of ",
 StyleBox["lc",
  FontWeight->"Bold"],
 " and ",
 StyleBox["af",
  FontWeight->"Bold"],
 " affect the rate at which capital multiplies."
}], "Text",
 CellChangeTimes->{{3.528633532413022*^9, 
  3.528633598759817*^9}},ExpressionUUID->"c4a2f009-6b8b-4fa5-afa7-\
5f77a41ea21f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"firstxintercept", "=", 
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{"0", "\[Equal]", 
              RowBox[{
               RowBox[{"lc", "/", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[ExponentialE]", "^", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "af", " ", "n"}], ")"}]}]}], 
                 ")"}]}], "+", 
               RowBox[{"0.04", " ", "n"}]}]}], ",", 
             RowBox[{"{", 
              RowBox[{"n", ",", "1"}], "}"}]}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
       RowBox[{"secondxintercept", "=", 
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{"0", "\[Equal]", 
              RowBox[{
               RowBox[{"lc", "/", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[ExponentialE]", "^", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "af"}], " ", "n"}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"0.04", " ", "n"}]}]}], ",", 
             RowBox[{"{", 
              RowBox[{"n", ",", "1"}], "}"}]}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}]}], "}"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"lc", "/", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[ExponentialE]", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], " ", "af", " ", "n"}], ")"}]}]}], ")"}]}],
           "+", 
          RowBox[{"0.04", " ", "n"}]}], ",", 
         RowBox[{
          RowBox[{"lc", "/", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[ExponentialE]", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "af"}], " ", "n"}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"0.04", " ", "n"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "13"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<year\>\"", ",", "\"\<value\>\""}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"ColorData", "[", "1", "]"}], "[", "2", "]"}], ",", 
          RowBox[{
           RowBox[{"ColorData", "[", "1", "]"}], "[", "1", "]"}]}], "}"}]}], 
       ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"400", ",", "375"}], "}"}]}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"firstxintercept", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"ColorData", "[", "1", "]"}], "[", "2", "]"}], ",", 
                "Dashed"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"secondxintercept", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"ColorData", "[", "1", "]"}], "[", "1", "]"}], ",", 
                "Dashed"}], "]"}]}], "}"}]}], "}"}], ",", "Automatic"}], 
         "}"}]}], ",", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"TableForm", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"StringJoin", "[", 
               RowBox[{"\"\<initial capital multiplied by \>\"", ",", 
                RowBox[{"ToString", "[", 
                 RowBox[{"SetPrecision", "[", 
                  RowBox[{
                   RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"lc", "/", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[ExponentialE]", "^", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "af", " ", "firstxintercept"}], 
                    ")"}]}]}], ")"}]}], "+", 
                    RowBox[{"0.04", " ", "firstxintercept"}]}], "]"}], ",", 
                   "4"}], "]"}], "]"}], ",", "\"\< in month \>\"", ",", 
                RowBox[{"ToString", "[", 
                 RowBox[{"Round", "[", 
                  RowBox[{"12", " ", "firstxintercept"}], "]"}], "]"}]}], 
               "]"}], ",", 
              RowBox[{
               RowBox[{"ColorData", "[", "1", "]"}], "[", "2", "]"}]}], "]"}],
             ",", 
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"StringJoin", "[", 
               RowBox[{"\"\<initial capital multiplied by \>\"", ",", 
                RowBox[{"ToString", "[", 
                 RowBox[{"SetPrecision", "[", 
                  RowBox[{
                   RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"lc", "/", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[ExponentialE]", "^", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "af"}], " ", "secondxintercept"}], ")"}]}]}],
                     ")"}]}], "+", 
                    RowBox[{"0.04", " ", "secondxintercept"}]}], "]"}], ",", 
                   "4"}], "]"}], "]"}], ",", "\"\< in month \>\"", ",", 
                RowBox[{"ToString", "[", 
                 RowBox[{"Round", "[", 
                  RowBox[{"12", " ", "secondxintercept"}], "]"}], "]"}]}], 
               "]"}], ",", 
              RowBox[{
               RowBox[{"ColorData", "[", "1", "]"}], "[", "1", "]"}]}], 
             "]"}]}], "}"}], ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<scenario 1\>\"", ",", 
                 RowBox[{
                  RowBox[{"ColorData", "[", "1", "]"}], "[", "2", "]"}]}], 
                "]"}], ",", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<scenario 2\>\"", ",", 
                 RowBox[{
                  RowBox[{"ColorData", "[", "1", "]"}], "[", "1", "]"}]}], 
                "]"}]}], "}"}], ",", "None"}], "}"}]}]}], "]"}]}], ",", 
       RowBox[{"ImagePadding", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"25", ",", "35"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"25", ",", "70"}], "}"}]}], "}"}]}]}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lc", ",", "1.6", ",", "\"\<logistic constant\>\""}], "}"}], 
     ",", "1", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"af", ",", ".5", ",", "\"\<acceleration factor\>\""}], "}"}], 
     ",", "0", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Top"}]}], "]"}]], "Input",
 CellOpen->False,
 CellLabel->"In[103]:=",
 CellID->312503371,ExpressionUUID->"05636936-d5ca-4db9-b068-37cd0d28b336"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`af$$ = 0.5, $CellContext`lc$$ = 1.6, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`lc$$], 1.6, "logistic constant"}, 1, 2}, {{
       Hold[$CellContext`af$$], 0.5, "acceleration factor"}, 0, 2}}, 
    Typeset`size$$ = {600., {278., 285.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`lc$16279$$ = 0, $CellContext`af$16284$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`af$$ = 0.5, $CellContext`lc$$ = 1.6}, 
      "ControllerVariables" :> {
        Hold[$CellContext`lc$$, $CellContext`lc$16279$$, 0], 
        Hold[$CellContext`af$$, $CellContext`af$16284$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      With[{$CellContext`firstxintercept$ = -Part[
            Part[
             FindRoot[
             0 == $CellContext`lc$$/(1 + 
                E^((-2) $CellContext`af$$ $CellContext`n)) + 
               0.04 $CellContext`n, {$CellContext`n, 1}], 1], 
            2], $CellContext`secondxintercept$ = -Part[
            Part[
             FindRoot[
             0 == $CellContext`lc$$/(1 + 
                E^((-$CellContext`af$$) $CellContext`n)) + 
               0.04 $CellContext`n, {$CellContext`n, 1}], 1], 2]}, 
        Plot[{$CellContext`lc$$/(1 + 
           E^((-2) $CellContext`af$$ $CellContext`n)) + 
          0.04 $CellContext`n, $CellContext`lc$$/(1 + 
           E^((-$CellContext`af$$) $CellContext`n)) + 
          0.04 $CellContext`n}, {$CellContext`n, 0, 13}, PlotRange -> All, 
         AxesLabel -> {"year", "value"}, PlotRange -> All, PlotStyle -> {
           ColorData[1][2], 
           ColorData[1][1]}, ImageSize -> {400, 375}, 
         GridLines -> {{{$CellContext`firstxintercept$, 
             Directive[
              ColorData[1][2], Dashed]}, {$CellContext`secondxintercept$, 
             Directive[
              ColorData[1][1], Dashed]}}, Automatic}, Filling -> {1 -> {2}}, 
         PlotLabel -> TableForm[{
            Style[
             StringJoin["initial capital multiplied by ", 
              ToString[
               SetPrecision[
                
                N[$CellContext`lc$$/(1 + 
                  E^((-2) $CellContext`af$$ $CellContext`firstxintercept$)) + 
                 0.04 $CellContext`firstxintercept$], 4]], " in month ", 
              ToString[
               Round[12 $CellContext`firstxintercept$]]], 
             ColorData[1][2]], 
            Style[
             StringJoin["initial capital multiplied by ", 
              ToString[
               SetPrecision[
                
                N[$CellContext`lc$$/(1 + 
                  E^((-$CellContext`af$$) $CellContext`secondxintercept$)) + 
                 0.04 $CellContext`secondxintercept$], 4]], " in month ", 
              ToString[
               Round[12 $CellContext`secondxintercept$]]], 
             ColorData[1][1]]}, TableHeadings -> {{
              Style["scenario 1", 
               ColorData[1][2]], 
              Style["scenario 2", 
               ColorData[1][1]]}, None}], 
         ImagePadding -> {{25, 35}, {25, 70}}]], 
      "Specifications" :> {{{$CellContext`lc$$, 1.6, "logistic constant"}, 1, 
         2, Appearance -> 
         "Labeled"}, {{$CellContext`af$$, 0.5, "acceleration factor"}, 0, 2, 
         Appearance -> "Labeled"}}, "Options" :> {ControlPlacement -> Top}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{670., {359., 367.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.528633455647631*^9, 3.5286373561207256`*^9, 
  3.5299294823084927`*^9, 3.5330636756777325`*^9, 3.5330720891719565`*^9, 
  3.533681697359375*^9, 3.533733718831088*^9, 3.53375341865625*^9, 
  3.539520160075903*^9, 3.5395211494334908`*^9, 3.5395224524410186`*^9, 
  3.5395231644147415`*^9, 3.5401252662049284`*^9, 3.540935097898288*^9, 
  3.540935428777213*^9, 3.5409360360439463`*^9, 3.5409376115270586`*^9, 
  3.5409379727159505`*^9, 3.5410031013120933`*^9, 3.5415997024925013`*^9, 
  3.5432391613242188`*^9, 3.6960758977201843`*^9, 3.6962290369129467`*^9, 
  3.6962316706165605`*^9, 3.6962321877975063`*^9, 3.731420956734598*^9},
 TextAlignment->Center,
 CellLabel->
  "Out[103]=",ExpressionUUID->"be43248f-4d9a-4512-a7ea-c7bb4ef027c9"],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "A range of possibilities for the modified logistic growth function"
}], "FigureCaption",
 CellChangeTimes->{{3.5286334866214027`*^9, 3.5286335013412447`*^9}, 
   3.540935987887192*^9},
 TextAlignment->Center,ExpressionUUID->"7a08d463-d3df-4180-b79b-0222c460268e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Data issues"
}], "Section",
 CellChangeTimes->{3.531447172614333*^9, 
  3.531447392971936*^9},ExpressionUUID->"0ff7df0b-ede8-4e7e-ab45-\
668a078ea204"],

Cell[TextData[{
 "In a perfect world (at least for researchers) investors would send in their \
loan payment coupons and income tax returns to some central data collection \
agency at the end of each year to be delivered to academics. Alas, we must \
agree that an imperfect world is a more interesting world.  As we may never \
see after-tax cash flows, we need methods for thinking about how returns are \
generated in the real estate market. Before developing these methods further \
it is useful to think of the investment real estate market in a ",
 StyleBox["hierarchy ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 "composed of three distinct Tiers:"
}], "Text",
 CellChangeTimes->{
  3.528633670243905*^9},ExpressionUUID->"0a23cd7e-d682-4c20-b842-\
a226daf5f013"],

Cell[CellGroupData[{

Cell["\<\
Tier I constitutes the very small property market. For residential we limit \
this to properties having four or less dwelling units.  Sometimes called the \
\[OpenCurlyDoubleQuote]One to Four Market\[CloseCurlyDoubleQuote], this is \
inhabited by small investors, some of whom live on the property. There are a \
host of specialized financing programs for this market intended to promote \
wide distribution of home ownership. The owner-occupancy part of the purchase \
makes this investment also a consumer good.  Indeed, there is some doubt that \
Tier I contains investment property at all. Finally, due to lack of \
sophistication, the participants in this market rarely find themselves using \
anything more advanced than the Rules of Thumb described in Chapter Three. \
Researchers studying Tier I property are primarily interested in the housing \
issues. As our interest is in careful and sophisticated analysis of \
investment property we spend little time dealing with data for Tier I.\
\>", "Item1",
 CellChangeTimes->{{3.5286336826316137`*^9, 
  3.5286336849817486`*^9}},ExpressionUUID->"e75a7c5f-33a6-4d2b-bd9c-\
057a26653c11"],

Cell[TextData[{
 "Tier III is institutional size property. Alternatively known as \
institutional ",
 StyleBox["grade",
  FontSlant->"Italic"],
 " property, this market is subject to a different size limitation. Because \
of the cost of raising money and underwriting acquisitions, the players in \
this market do not acquire small properties. Their interest is in major, \
sometimes \[OpenCurlyDoubleQuote]trophy\[CloseCurlyDoubleQuote] but always ",
 StyleBox["large",
  FontSlant->"Italic"],
 " properties. Although the techniques presented here are applicable to Tier \
III, it is the different sort of data more recently available that interests \
us here. Therefore we will not concentrate on Tier III either."
}], "Item1",
 CellChangeTimes->{{3.5286336857567925`*^9, 
  3.528633697682475*^9}},ExpressionUUID->"56464afe-bcab-4f94-be91-\
70c4b7f95ada"],

Cell["\<\
Tier II property is everything in the middle. For residential, where data are \
most plentiful, the lower bound of Tier II is defined by the upper bound of \
Tier I (four dwelling units). The upper bound of Tier II is not so easily \
found. An informal survey of institutional investors conducted in 1999 \
suggests that for residential property institutional investor interest begins \
at 100 units.  We shall adopt this to define Tier II residential property as \
those properties having between 4 and 100 dwelling units.\
\>", "Item1",
 CellChangeTimes->{
  3.5286337052739086`*^9, {3.5395229667494354`*^9, 
   3.539522967372471*^9}},ExpressionUUID->"84f295a3-e072-4d61-bff9-\
4e1a1dfa950f"]
}, Open  ]],

Cell["\<\
The data challenges for investment property differ between Tier II and Tier \
III. Institutional owners are often public companies. They keep and publish \
detailed records.  Accordingly, operating information is plentiful. Many, \
such as REITs and pension funds, are tax exempt so one may safely ignore the \
after-debt, after-tax outcomes.  The Tier III problem is that sales are \
infrequent so the equity reversion must be estimated by appraisal.  There is \
a large literature on the distortions, called \"smoothing\", this causes.  \
Since a major portion of the return is often in the gain on sale, errors in \
estimating value in mid-holding period can be considerable, leading to errors \
in estimating returns.\
\>", "Text",
 CellChangeTimes->{
  3.5286337305853567`*^9},ExpressionUUID->"269047d2-ddf7-48e2-980d-\
e1166c9a62aa"],

Cell["\<\
Tier II property has the opposite problem. Purchases and sales by investors \
in this market produce many publicly recorded transactions but their \
intra-holding period operational results are out of view.\
\>", "Text",
 CellChangeTimes->{{3.5286337305853567`*^9, 3.5286337353336287`*^9}, {
  3.5409369412847233`*^9, 
  3.5409369477810946`*^9}},ExpressionUUID->"693d9da9-1071-49f1-af10-\
c27018948ce0"],

Cell[TextData[{
 "Such is the imperfect world of real estate investment data. The simple \
reality this leads us to is that ",
 StyleBox["npv",
  FontSlant->"Italic"],
 "s and ",
 StyleBox["irr",
  FontSlant->"Italic"],
 "s are not observable.  Therefore, a proxy is required.  In our primary \
interest, the Tier II market, we observe prices and assume that they are \
driven by income. We further assume, naively, that price is linear in income. \
That is, whatever return outcomes we observe in price changes are both \
brought about and supported by an appropriate proportional change in yearly \
operating income.  In later chapters we will see what that means for risk \
analysis but for now we need only lay the foundation for how price changes \
can be translated into returns."
}], "Text",
 CellChangeTimes->{{3.5286337305853567`*^9, 3.5286337398368855`*^9}, {
  3.5299311555091944`*^9, 3.529931177336443*^9}, {3.5409369650270815`*^9, 
  3.5409369758907022`*^9}},ExpressionUUID->"4dbad269-7a08-4c62-9e51-\
971b72e5563b"],

Cell["\<\
Those familiar with high frequency stock market data know the value and \
usefulness of a time series in which the price of the same asset - a share of \
stock - is observed repeatedly over short, sequential time periods.  As real \
estate ownership is characterized by long holding periods of irregular length \
we must find a way to standardize a unit of return.\
\>", "Text",
 CellChangeTimes->{{3.5286337305853567`*^9, 
  3.5286337442161365`*^9}},ExpressionUUID->"d449666a-4e51-4a09-a003-\
498dba05ffff"],

Cell[TextData[{
 "Consider an investment in a saving account that compounds at an interest \
rate, ",
 StyleBox["r",
  FontSlant->"Italic"],
 ", over time period, ",
 StyleBox["n",
  FontSlant->"Italic"],
 ". Such an investment has a future value, ",
 StyleBox["fv",
  FontSlant->"Italic"],
 ", at any point in time ",
 StyleBox["n",
  FontSlant->"Italic"],
 " of Amount Deposited*",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "r"}], ")"}], "n"], TraditionalForm]],ExpressionUUID->
  "d5327a76-b693-4e0e-88fc-046f9e3a3d4f"],
 ". One can readily see the similarity between the mechanics of this process \
and those described for capitalization rate in Chapter 3. It is unfortunate \
that the limitations of data require us to resort to a return metric of this \
nature for Tier II investment real estate."
}], "Text",
 CellChangeTimes->{{3.5286337305853567`*^9, 3.5286337454742084`*^9}, {
   3.5395264822485104`*^9, 3.5395265159284368`*^9}, 
   3.540936990496538*^9},ExpressionUUID->"851054b4-e0ce-43ea-bf3b-\
e7c38716c476"],

Cell["\<\
What we would like is a real estate equivalent process that can be used for \
analyzing real estate return data. The mathematical tool we use is the \
natural logarithm. The unit of return we are interested in is derived from \
price change.\
\>", "Text",ExpressionUUID->"084f9e0b-73b7-4706-806a-96d09226d539"],

Cell[TextData[{
 "Recall that Log ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    FractionBox[
     SubscriptBox["P", "t"], 
     SubscriptBox["P", 
      RowBox[{"t", "-", "1"}]]], "]"}], TraditionalForm]],ExpressionUUID->
  "31f186b0-f625-4b8c-bc1e-d572e92a39cc"],
 " = Log",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    FractionBox[
     RowBox[{
      RowBox[{"Today", "'"}], "s", " ", "Price"}], 
     RowBox[{
      RowBox[{"Yesterday", "'"}], "s", " ", "Price"}]], "]"}], 
   TraditionalForm]],ExpressionUUID->"331923b3-3b6d-4caf-a4c8-9f18968da5b1"],
 " = Log[Today's Price] - Log[Yesterday's Price] where \"today\" is \"",
 StyleBox["t",
  FontSlant->"Italic"],
 "\" and \"yesterday\" is a metaphor for \"",
 StyleBox["t",
  FontSlant->"Italic"],
 "-1\"."
}], "Text",ExpressionUUID->"081e7157-3096-4f8e-9fba-a0b265bcc544"],

Cell["\<\
If we substitute \"Sale\" for \"Today's\" and \"Purchase\" for \
\"Yesterday's\" we get\
\>", "Text",ExpressionUUID->"71c59c74-4e87-4fc0-b79b-898fbbbba8cd"],

Cell[TextData[{
 "Holding Period Return = Log ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    FractionBox[
     RowBox[{"Sale", " ", "Price"}], 
     RowBox[{"Purchase", " ", "Price"}]], "]"}], TraditionalForm]],
  ExpressionUUID->"ef3aaaef-e6f8-4713-ad4e-e602724ebd8c"],
 "= Log [Sale Price]-Log [Purchase Price] which is in ordered time but not \
specific increments of time. This creates an interval that represents the \
investor's holding period."
}], "Text",ExpressionUUID->"79301ed8-a0de-4138-8f07-3dbd53504eab"],

Cell["\<\
Suppose an asset is purchased for 100 and sold some time later for 200. The \
log return is\
\>", "Text",ExpressionUUID->"405c94db-dd7c-4019-bb1d-ee393b805876"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Log", "[", "200", "]"}], "-", 
   RowBox[{"Log", "[", "100", "]"}]}], "//", "N"}]], "Input",
 CellLabel->
  "In[104]:=",ExpressionUUID->"c03732fa-4903-405b-8fae-7a28248e3384"],

Cell[BoxData["0.6931471805599445`"], "Output",
 CellChangeTimes->{{3.528633873357523*^9, 3.528633899621025*^9}, 
   3.528637356211731*^9, 3.5299294828755255`*^9, 3.533063676406774*^9, 
   3.5330720893059645`*^9, 3.533681697609375*^9, 3.533733719585131*^9, 
   3.533753418890625*^9, 3.539520160915951*^9, 3.5395211496205015`*^9, 
   3.53952245263303*^9, 3.5395231645967517`*^9, 3.540125266991973*^9, 
   3.5409350980632973`*^9, 3.540935428882219*^9, 3.540936036145952*^9, 
   3.540937612334105*^9, 3.5409379735399976`*^9, 3.541003102189143*^9, 
   3.5415997033215485`*^9, 3.5432391621222644`*^9, 3.696075897838499*^9, 
   3.6962290370402718`*^9, 3.6962316708782563`*^9, 3.6962321879438953`*^9, 
   3.731420956915078*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"dc295947-8adc-4e12-8920-abeef40410a1"]
}, Open  ]],

Cell[TextData[{
 "\"Exponenting\" that return means raising the base of the natural log (a \
constant with an approximate value of 2.71828 and shown as \[ExponentialE] in \
most texts",
 StyleBox[") ",
  FontSlant->"Italic"],
 "to the power of the log return. Subtracting 1 and multiplying by 100 \
produces the more familiar percentage return."
}], "Text",ExpressionUUID->"ea7a33cd-f743-4df9-8c3c-289d908cca18"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Log", "[", "200", "]"}], "-", 
        RowBox[{"Log", "[", "100", "]"}]}], "//", "N"}], ")"}]], "-", "1"}], 
   ")"}], "*", "100"}]], "Input",
 CellLabel->
  "In[105]:=",ExpressionUUID->"1667332d-5572-4861-954f-24f9b12730ad"],

Cell[BoxData["99.99999999999984`"], "Output",
 CellChangeTimes->{3.5286339204862185`*^9, 3.528637356222731*^9, 
  3.5299294831445403`*^9, 3.5330636768457994`*^9, 3.533072089359967*^9, 
  3.53368169778125*^9, 3.5337337200651584`*^9, 3.533753418984375*^9, 
  3.5395201614139795`*^9, 3.539521149669504*^9, 3.5395224526800327`*^9, 
  3.5395231646427546`*^9, 3.540125267579007*^9, 3.5409350981042995`*^9, 
  3.540935428926221*^9, 3.5409360361909547`*^9, 3.540937612791131*^9, 
  3.540937973981023*^9, 3.541003102930186*^9, 3.5415997043146057`*^9, 
  3.543239162589291*^9, 3.696075897850531*^9, 3.6962290370653257`*^9, 
  3.6962316709053288`*^9, 3.696232188011074*^9, 3.7314209569401703`*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"f4b28a27-6c18-4aa4-91f8-7e078bd3fa17"]
}, Open  ]],

Cell[TextData[{
 "This is the second time in this chapter we have encountered the \
exponential. When solving for the equivalent continuous compounding return \
matching a certain modified logistic growth we used the exponential. The \
continuous equivalent of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "r"}], ")"}], "n"], TraditionalForm]],ExpressionUUID->
  "c8b51ea7-2121-478d-8339-1fc36157dd6f"],
 " is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"r", " ", "n"}]], TraditionalForm]],ExpressionUUID->
  "351df8f9-c4b0-4cc9-8c3e-b6db0d8968bd"],
 ". Thus if one increases the number of compounding intervals, ",
 StyleBox["n",
  FontSlant->"Italic"],
 ", to infinity while simultaneously reducing the size of the rate, ",
 StyleBox["r",
  FontSlant->"Italic"],
 ", in a similar fashion, in the limit one obtains the continuous compounding \
return for the same rate."
}], "Text",
 CellChangeTimes->{
  3.5286339463146954`*^9, {3.540936998663005*^9, 
   3.5409370044793377`*^9}},ExpressionUUID->"1b11229f-5fed-4ab5-87ef-\
ae71cfda1cdb"],

Cell["\<\
Real estate markets present a unique problem.  For stock market data one can \
parse a holding period return into even increments because sales of \
homogeneous assets occur in a continuous auction market.  Thus since annual, \
monthly, weekly or daily stock prices are all available, returns may be \
expressed over any interval. The example above is slightly less than a 10% \
per annum return if the holding period was ten years, just less than 20% per \
annum if held five years, etc.\
\>", "Text",
 CellChangeTimes->{{3.5286339463146954`*^9, 
  3.5286339511509724`*^9}},ExpressionUUID->"8e364b1f-baa4-4506-894c-\
e8fca38bd023"],

Cell[TextData[{
 "Real estate investors hold properties for varying lengths of time. Each \
return observation comes with its own unique holding period.  To impose some \
order on the process we assume that returns, although ",
 StyleBox["realized",
  FontSlant->"Italic"],
 " at various times separated by differing and often wide intervals, are \
actually earned in equal daily increments over the holding period. This may \
seem artificial and certainly represents another sort of \"smoothing\" \
problem but some standardization of returns is necessary in order to be able \
to compare returns and to think about the market as a whole in some coherent \
way. Patience is recommended at this point. The story is unfolding and later \
chapters offer additional justification for this approach.  We delay until \
later offering a defense. For now we wish to develop the technical aspects of \
the methodology."
}], "Text",
 CellChangeTimes->{{3.5286339463146954`*^9, 
  3.528633956342269*^9}},ExpressionUUID->"188dcea7-1092-4b77-a5ea-\
e45cf2cb5995"],

Cell[CellGroupData[{

Cell["\<\
Our data are 731 repeat sales of buildings between 5 and 100 units covering \
the period from July, 1987 through September, 2001. Prices and dates of \
purchase and sale for each building are shown along with the location and \
number of units. Table 4.6 shows the first five of these.\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5286339463146954`*^9, 3.5286339571513157`*^9}, {
  3.528635558579912*^9, 3.5286355701875763`*^9}, {3.5286356573015585`*^9, 
  3.528635671696382*^9}, {3.5395206532921133`*^9, 
  3.5395206548021994`*^9}},ExpressionUUID->"a6195594-34a1-48be-be12-\
d4169f19a2ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfSaleData", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<Area\>\"", ",", "\"\<Sale1\>\"", ",", "\"\<Date1\>\"", ",", 
       "\"\<Sale2\>\"", ",", "\"\<Date2\>\"", ",", "\"\<Units\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2600000", ",", "\"\<{1993,05,20}\>\"", ",", "1530000", ",", 
       "\"\<{1995,04,28}\>\"", ",", "88"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "3000000", ",", "\"\<{1990,08,10}\>\"", ",", "1770000", ",", 
       "\"\<{1994,07,21}\>\"", ",", "79"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2650000", ",", "\"\<{1990,07,12}\>\"", ",", "1250000", ",", 
       "\"\<{1994,06,30}\>\"", ",", "78"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "12200000", ",", "\"\<{1989,08,02}\>\"", ",", "13800000", 
       ",", "\"\<{1990,03,16}\>\"", ",", "72"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1737500", ",", "\"\<{1994,06,30}\>\"", ",", "2150000", ",", 
       "\"\<{1996,05,15}\>\"", ",", "63"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "2875000", ",", "\"\<{1987,12,15}\>\"", ",", "3620000", ",", 
       "\"\<{1988,09,01}\>\"", ",", "56"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "4200000", ",", "\"\<{1988,09,28}\>\"", ",", "4216346", ",", 
       "\"\<{1991,05,08}\>\"", ",", "55"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "825000", ",", "\"\<{1994,03,29}\>\"", ",", "1850000", ",", 
       "\"\<{1997,12,31}\>\"", ",", "55"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "4475000", ",", "\"\<{1989,08,18}\>\"", ",", "2985000", ",", 
       "\"\<{1994,10,14}\>\"", ",", "54"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "3930000", ",", "\"\<{1995,01,19}\>\"", ",", "6369000", ",", 
       "\"\<{2000,07,06}\>\"", ",", "54"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "3310000", ",", "\"\<{1995,12,19}\>\"", ",", "6250000", ",", 
       "\"\<{1999,02,26}\>\"", ",", "54"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2825000", ",", "\"\<{1989,07,12}\>\"", ",", "3785000", ",", 
       "\"\<{1994,09,07}\>\"", ",", "51"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "2650000", ",", "\"\<{1999,04,13}\>\"", ",", "3425000", ",", 
       "\"\<{2000,01,03}\>\"", ",", "51"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "2045000", ",", "\"\<{1988,01,20}\>\"", ",", "1940000", ",", 
       "\"\<{1994,01,21}\>\"", ",", "51"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "2040000", ",", "\"\<{1990,01,12}\>\"", ",", "885000", ",", 
       "\"\<{1995,11,17}\>\"", ",", "50"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "3150000", ",", "\"\<{1992,12,02}\>\"", ",", "4050000", ",", 
       "\"\<{1996,07,03}\>\"", ",", "48"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1810000", ",", "\"\<{1998,06,12}\>\"", ",", "2650000", ",", 
       "\"\<{1999,08,19}\>\"", ",", "48"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1672000", ",", "\"\<{1996,02,14}\>\"", ",", "2450000", ",", 
       "\"\<{1999,04,20}\>\"", ",", "48"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1150000", ",", "\"\<{1992,02,06}\>\"", ",", "1040000", ",", 
       "\"\<{1996,05,03}\>\"", ",", "48"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2160000", ",", "\"\<{1990,11,21}\>\"", ",", "2325000", ",", 
       "\"\<{1991,03,19}\>\"", ",", "46"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "4300000", ",", "\"\<{1988,12,07}\>\"", ",", "3350000", ",", 
       "\"\<{1993,12,14}\>\"", ",", "44"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1050000", ",", "\"\<{1994,02,25}\>\"", ",", "1560000", ",", 
       "\"\<{1995,12,15}\>\"", ",", "44"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1763000", ",", "\"\<{1997,02,24}\>\"", ",", "3115000", ",", 
       "\"\<{1998,07,23}\>\"", ",", "43"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2200000", ",", "\"\<{1988,06,03}\>\"", ",", "1900000", ",", 
       "\"\<{1991,09,12}\>\"", ",", "41"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1350000", ",", "\"\<{1995,06,16}\>\"", ",", "2080000", ",", 
       "\"\<{1997,06,25}\>\"", ",", "41"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1285000", ",", "\"\<{1997,01,03}\>\"", ",", "1865000", ",", 
       "\"\<{1998,09,29}\>\"", ",", "41"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "5400000", ",", "\"\<{1994,02,15}\>\"", ",", "6200000", ",", 
       "\"\<{1996,09,06}\>\"", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2017500", ",", "\"\<{1992,01,08}\>\"", ",", "2070000", ",", 
       "\"\<{1995,02,01}\>\"", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1750000", ",", "\"\<{1991,05,21}\>\"", ",", "2824601", ",", 
       "\"\<{1998,09,30}\>\"", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1667500", ",", "\"\<{1990,10,19}\>\"", ",", "1683500", ",", 
       "\"\<{1996,05,10}\>\"", ",", "39"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "4600000", ",", "\"\<{1988,08,26}\>\"", ",", "5150000", ",", 
       "\"\<{1991,07,12}\>\"", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "3433500", ",", "\"\<{1998,04,24}\>\"", ",", "4000000", ",", 
       "\"\<{1998,12,15}\>\"", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2600000", ",", "\"\<{1993,05,20}\>\"", ",", "3360000", ",", 
       "\"\<{1996,07,10}\>\"", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "2485000", ",", "\"\<{1995,04,19}\>\"", ",", "4988182", ",", 
       "\"\<{1998,10,09}\>\"", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2125000", ",", "\"\<{1990,12,03}\>\"", ",", "2020000", ",", 
       "\"\<{1993,12,31}\>\"", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1445000", ",", "\"\<{1993,09,30}\>\"", ",", "4200000", ",", 
       "\"\<{2001,02,01}\>\"", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "725000", ",", "\"\<{1992,12,29}\>\"", ",", "1350000", ",", 
       "\"\<{1997,09,10}\>\"", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "2575000", ",", "\"\<{1994,07,29}\>\"", ",", "4950000", ",", 
       "\"\<{2001,01,31}\>\"", ",", "35"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1150000", ",", "\"\<{1988,05,20}\>\"", ",", "1162500", ",", 
       "\"\<{1992,01,29}\>\"", ",", "35"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1320000", ",", "\"\<{1993,04,27}\>\"", ",", "1420000", ",", 
       "\"\<{1994,11,04}\>\"", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "920000", ",", "\"\<{1996,03,13}\>\"", ",", "1475000", ",", 
       "\"\<{1997,03,17}\>\"", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "6390000", ",", "\"\<{1993,01,08}\>\"", ",", "8600000", ",", 
       "\"\<{1996,04,30}\>\"", ",", "32"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1725000", ",", "\"\<{1991,10,17}\>\"", ",", "1800000", ",", 
       "\"\<{1998,03,17}\>\"", ",", "32"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1470000", ",", "\"\<{1996,02,15}\>\"", ",", "2100000", ",", 
       "\"\<{1998,09,30}\>\"", ",", "32"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "855000", ",", "\"\<{1988,11,22}\>\"", ",", "1425000", ",", 
       "\"\<{1998,08,18}\>\"", ",", "32"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "2600000", ",", "\"\<{1988,11,04}\>\"", ",", "3635000", ",", 
       "\"\<{1999,08,13}\>\"", ",", "31"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2529412", ",", "\"\<{1988,05,20}\>\"", ",", "2671000", ",", 
       "\"\<{1989,01,31}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2500000", ",", "\"\<{1992,07,16}\>\"", ",", "2750000", ",", 
       "\"\<{1996,11,01}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "2430000", ",", "\"\<{1990,04,27}\>\"", ",", "3300000", ",", 
       "\"\<{1999,03,18}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "2385000", ",", "\"\<{1987,12,14}\>\"", ",", "4635000", ",", 
       "\"\<{1998,08,11}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "7", ",", "2300000", ",", "\"\<{1997,01,28}\>\"", ",", "4150000", ",", 
       "\"\<{2000,09,15}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2181000", ",", "\"\<{1988,06,29}\>\"", ",", "2452000", ",", 
       "\"\<{1998,05,14}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1795000", ",", "\"\<{1989,07,31}\>\"", ",", "1920000", ",", 
       "\"\<{1995,05,05}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "890000", ",", "\"\<{1997,06,27}\>\"", ",", "1300000", ",", 
       "\"\<{1998,12,31}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "689000", ",", "\"\<{1996,08,14}\>\"", ",", "1250000", ",", 
       "\"\<{1998,10,01}\>\"", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "2650000", ",", "\"\<{1989,01,27}\>\"", ",", "3000000", ",", 
       "\"\<{1993,03,16}\>\"", ",", "29"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2000000", ",", "\"\<{1987,10,23}\>\"", ",", "2300000", ",", 
       "\"\<{1999,10,08}\>\"", ",", "28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1425000", ",", "\"\<{1999,04,16}\>\"", ",", "2550000", ",", 
       "\"\<{2001,04,12}\>\"", ",", "28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1150000", ",", "\"\<{1989,07,20}\>\"", ",", "955000", ",", 
       "\"\<{1995,01,11}\>\"", ",", "28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "2500000", ",", "\"\<{1991,11,18}\>\"", ",", "3300000", ",", 
       "\"\<{1998,09,30}\>\"", ",", "27"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1000033", ",", "\"\<{1992,04,23}\>\"", ",", "1575000", ",", 
       "\"\<{1999,08,20}\>\"", ",", "27"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "910000", ",", "\"\<{1992,03,03}\>\"", ",", "1150000", ",", 
       "\"\<{1997,09,10}\>\"", ",", "27"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1195000", ",", "\"\<{1992,07,27}\>\"", ",", "1990000", ",", 
       "\"\<{1998,10,27}\>\"", ",", "26"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "2200000", ",", "\"\<{1989,07,03}\>\"", ",", "1890000", ",", 
       "\"\<{1996,07,17}\>\"", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1385000", ",", "\"\<{1997,10,01}\>\"", ",", "1825000", ",", 
       "\"\<{1999,02,12}\>\"", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "960000", ",", "\"\<{1997,06,05}\>\"", ",", "1360000", ",", 
       "\"\<{1998,12,23}\>\"", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "911000", ",", "\"\<{1994,05,06}\>\"", ",", "1710000", ",", 
       "\"\<{1999,05,14}\>\"", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "775000", ",", "\"\<{1996,11,19}\>\"", ",", "925000", ",", 
       "\"\<{1998,06,10}\>\"", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "610000", ",", "\"\<{1995,11,16}\>\"", ",", "1100000", ",", 
       "\"\<{1999,04,20}\>\"", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "3000000", ",", "\"\<{1989,12,15}\>\"", ",", "5000000", ",", 
       "\"\<{1998,04,10}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "2981375", ",", "\"\<{1998,11,19}\>\"", ",", "3650000", ",", 
       "\"\<{2001,08,17}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2925000", ",", "\"\<{1997,09,30}\>\"", ",", "2900000", ",", 
       "\"\<{2000,08,09}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2150000", ",", "\"\<{1995,12,12}\>\"", ",", "2450000", ",", 
       "\"\<{1996,12,31}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "2075000", ",", "\"\<{1998,01,16}\>\"", ",", "3240000", ",", 
       "\"\<{2000,05,31}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1975000", ",", "\"\<{1992,02,25}\>\"", ",", "1750000", ",", 
       "\"\<{1993,06,30}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1925000", ",", "\"\<{1989,06,30}\>\"", ",", "1719500", ",", 
       "\"\<{1995,07,28}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1850500", ",", "\"\<{1989,02,28}\>\"", ",", "2075000", ",", 
       "\"\<{1990,12,03}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1608000", ",", "\"\<{1992,09,01}\>\"", ",", "1775000", ",", 
       "\"\<{1995,07,14}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1550000", ",", "\"\<{1999,08,31}\>\"", ",", "2165000", ",", 
       "\"\<{2000,11,01}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1432000", ",", "\"\<{1989,12,29}\>\"", ",", "1596000", ",", 
       "\"\<{1996,09,27}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1170000", ",", "\"\<{1993,04,23}\>\"", ",", "2150000", ",", 
       "\"\<{2000,08,18}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1130000", ",", "\"\<{1990,11,27}\>\"", ",", "2585000", ",", 
       "\"\<{2000,11,17}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "900000", ",", "\"\<{1992,07,24}\>\"", ",", "1290000", ",", 
       "\"\<{1998,06,26}\>\"", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2275000", ",", "\"\<{1998,01,27}\>\"", ",", "3250000", ",", 
       "\"\<{2000,08,15}\>\"", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1875000", ",", "\"\<{1990,03,29}\>\"", ",", "2462500", ",", 
       "\"\<{1999,02,03}\>\"", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1620000", ",", "\"\<{1997,06,23}\>\"", ",", "3000000", ",", 
       "\"\<{2000,10,31}\>\"", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2350000", ",", "\"\<{1999,12,21}\>\"", ",", "2800000", ",", 
       "\"\<{2000,12,08}\>\"", ",", "22"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1200000", ",", "\"\<{1990,06,28}\>\"", ",", "2226000", ",", 
       "\"\<{2000,11,14}\>\"", ",", "22"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "930000", ",", "\"\<{1988,06,14}\>\"", ",", "1300000", ",", 
       "\"\<{2000,03,31}\>\"", ",", "22"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "3200000", ",", "\"\<{1994,04,29}\>\"", ",", "7035779", ",", 
       "\"\<{2000,08,15}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "2375000", ",", "\"\<{1999,01,22}\>\"", ",", "3050000", ",", 
       "\"\<{1999,08,18}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "2250000", ",", "\"\<{1992,01,16}\>\"", ",", "2698000", ",", 
       "\"\<{1995,08,22}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "2140000", ",", "\"\<{1989,01,20}\>\"", ",", "2342000", ",", 
       "\"\<{1997,02,11}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "2100000", ",", "\"\<{1989,10,03}\>\"", ",", "2850000", ",", 
       "\"\<{2000,04,14}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1928000", ",", "\"\<{1996,11,05}\>\"", ",", "2175000", ",", 
       "\"\<{1999,04,09}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1750000", ",", "\"\<{1988,09,08}\>\"", ",", "1850000", ",", 
       "\"\<{1991,04,11}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1665000", ",", "\"\<{1987,09,30}\>\"", ",", "1840000", ",", 
       "\"\<{1997,01,08}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1310000", ",", "\"\<{1997,01,10}\>\"", ",", "2225000", ",", 
       "\"\<{2000,04,28}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1250000", ",", "\"\<{1993,09,30}\>\"", ",", "1900000", ",", 
       "\"\<{1997,09,30}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1133000", ",", "\"\<{1991,11,07}\>\"", ",", "1760000", ",", 
       "\"\<{1999,11,30}\>\"", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1265000", ",", "\"\<{1988,03,25}\>\"", ",", "1780000", ",", 
       "\"\<{1997,09,23}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1250000", ",", "\"\<{1996,03,15}\>\"", ",", "2002000", ",", 
       "\"\<{1999,09,22}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1210000", ",", "\"\<{1989,04,28}\>\"", ",", "1320000", ",", 
       "\"\<{1989,12,08}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1100000", ",", "\"\<{1989,05,26}\>\"", ",", "300000", ",", 
       "\"\<{1994,12,21}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1100000", ",", "\"\<{1988,11,30}\>\"", ",", "1340000", ",", 
       "\"\<{1999,01,25}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1070000", ",", "\"\<{1994,02,17}\>\"", ",", "1217500", ",", 
       "\"\<{1997,01,24}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "830000", ",", "\"\<{1989,01,31}\>\"", ",", "785000", ",", 
       "\"\<{1995,08,24}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "810000", ",", "\"\<{1988,07,13}\>\"", ",", "1405000", ",", 
       "\"\<{1997,12,08}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "730000", ",", "\"\<{1996,01,23}\>\"", ",", "1270000", ",", 
       "\"\<{1998,09,30}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "595000", ",", "\"\<{1998,06,30}\>\"", ",", "1230000", ",", 
       "\"\<{2001,02,02}\>\"", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1320000", ",", "\"\<{1991,11,13}\>\"", ",", "2110500", ",", 
       "\"\<{2000,02,04}\>\"", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1200000", ",", "\"\<{1990,06,29}\>\"", ",", "1385000", ",", 
       "\"\<{1998,07,29}\>\"", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1175000", ",", "\"\<{1989,02,24}\>\"", ",", "1415000", ",", 
       "\"\<{1989,03,30}\>\"", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1100000", ",", "\"\<{1988,08,30}\>\"", ",", "1000000", ",", 
       "\"\<{1999,10,15}\>\"", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1075000", ",", "\"\<{1989,05,31}\>\"", ",", "955000", ",", 
       "\"\<{1997,09,23}\>\"", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1075000", ",", "\"\<{1988,11,04}\>\"", ",", "1200000", ",", 
       "\"\<{1997,10,03}\>\"", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2150000", ",", "\"\<{1993,10,15}\>\"", ",", "2970000", ",", 
       "\"\<{1996,08,09}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1700000", ",", "\"\<{1989,02,10}\>\"", ",", "1750000", ",", 
       "\"\<{1996,05,24}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1375000", ",", "\"\<{1993,10,01}\>\"", ",", "1425000", ",", 
       "\"\<{1995,02,03}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1350000", ",", "\"\<{1995,04,18}\>\"", ",", "3000000", ",", 
       "\"\<{2001,01,31}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1350000", ",", "\"\<{1988,08,01}\>\"", ",", "1550000", ",", 
       "\"\<{1990,03,06}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1212500", ",", "\"\<{1994,11,22}\>\"", ",", "1575000", ",", 
       "\"\<{1996,06,27}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1150000", ",", "\"\<{1992,09,30}\>\"", ",", "1345000", ",", 
       "\"\<{1996,11,13}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "795000", ",", "\"\<{1989,11,16}\>\"", ",", "1325000", ",", 
       "\"\<{2000,01,07}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "700000", ",", "\"\<{1988,11,15}\>\"", ",", "605000", ",", 
       "\"\<{1994,07,27}\>\"", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1600000", ",", "\"\<{1989,04,07}\>\"", ",", "1575000", ",", 
       "\"\<{1993,01,25}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1489000", ",", "\"\<{1990,03,28}\>\"", ",", "1350000", ",", 
       "\"\<{1997,11,21}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1400000", ",", "\"\<{1990,11,06}\>\"", ",", "1375000", ",", 
       "\"\<{1998,06,25}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1334500", ",", "\"\<{1989,04,04}\>\"", ",", "1315000", ",", 
       "\"\<{1998,03,31}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1275000", ",", "\"\<{1989,05,11}\>\"", ",", "1467000", ",", 
       "\"\<{1996,12,12}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1250000", ",", "\"\<{1989,09,01}\>\"", ",", "839000", ",", 
       "\"\<{1991,12,16}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1100000", ",", "\"\<{1988,10,20}\>\"", ",", "1685000", ",", 
       "\"\<{1999,12,22}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1050000", ",", "\"\<{1994,03,18}\>\"", ",", "1700000", ",", 
       "\"\<{1999,09,10}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "815000", ",", "\"\<{1990,01,03}\>\"", ",", "775000", ",", 
       "\"\<{1993,03,03}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "815000", ",", "\"\<{1993,12,16}\>\"", ",", "1310000", ",", 
       "\"\<{1997,08,26}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "565000", ",", "\"\<{1989,06,22}\>\"", ",", "802000", ",", 
       "\"\<{1997,09,29}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "425000", ",", "\"\<{1993,12,14}\>\"", ",", "520000", ",", 
       "\"\<{1997,06,27}\>\"", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1750500", ",", "\"\<{1997,07,18}\>\"", ",", "2195000", ",", 
       "\"\<{1999,05,26}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1525000", ",", "\"\<{1995,02,01}\>\"", ",", "1998000", ",", 
       "\"\<{1997,09,16}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1500000", ",", "\"\<{1997,11,14}\>\"", ",", "1875000", ",", 
       "\"\<{1999,11,24}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1450000", ",", "\"\<{1988,08,26}\>\"", ",", "2000000", ",", 
       "\"\<{1998,03,13}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1410000", ",", "\"\<{1995,05,03}\>\"", ",", "2000000", ",", 
       "\"\<{1997,07,23}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1250000", ",", "\"\<{1991,03,15}\>\"", ",", "1423000", ",", 
       "\"\<{1992,09,30}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "840000", ",", "\"\<{1989,07,28}\>\"", ",", "800000", ",", 
       "\"\<{1997,10,31}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "700000", ",", "\"\<{1996,10,24}\>\"", ",", "995000", ",", 
       "\"\<{1998,07,14}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "395000", ",", "\"\<{1992,12,24}\>\"", ",", "875000", ",", 
       "\"\<{2000,01,14}\>\"", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2000000", ",", "\"\<{1998,04,20}\>\"", ",", "2760000", ",", 
       "\"\<{2000,02,24}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1750000", ",", "\"\<{1989,05,16}\>\"", ",", "1580000", ",", 
       "\"\<{1992,12,01}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1625500", ",", "\"\<{1991,02,08}\>\"", ",", "2000000", ",", 
       "\"\<{1997,05,23}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1600000", ",", "\"\<{1989,08,15}\>\"", ",", "1910000", ",", 
       "\"\<{1990,07,10}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1485000", ",", "\"\<{1989,02,17}\>\"", ",", "1900000", ",", 
       "\"\<{1998,03,03}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1400000", ",", "\"\<{1988,08,23}\>\"", ",", "3600000", ",", 
       "\"\<{2000,10,27}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1365000", ",", "\"\<{1997,10,16}\>\"", ",", "2000000", ",", 
       "\"\<{1999,03,12}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1294500", ",", "\"\<{1998,08,28}\>\"", ",", "1940000", ",", 
       "\"\<{2000,09,25}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1200000", ",", "\"\<{1990,01,17}\>\"", ",", "1290000", ",", 
       "\"\<{1990,06,06}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1175000", ",", "\"\<{1990,05,23}\>\"", ",", "1400000", ",", 
       "\"\<{1999,07,30}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1147500", ",", "\"\<{1989,03,08}\>\"", ",", "1000000", ",", 
       "\"\<{1994,10,28}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1132500", ",", "\"\<{1994,11,04}\>\"", ",", "1350000", ",", 
       "\"\<{1995,12,29}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1129000", ",", "\"\<{1995,12,15}\>\"", ",", "1340000", ",", 
       "\"\<{1997,06,06}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1080500", ",", "\"\<{1987,08,05}\>\"", ",", "1175000", ",", 
       "\"\<{1998,09,09}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1050000", ",", "\"\<{1990,08,14}\>\"", ",", "1900000", ",", 
       "\"\<{1998,04,28}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1006000", ",", "\"\<{1994,11,21}\>\"", ",", "2278000", ",", 
       "\"\<{1999,05,11}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "997500", ",", "\"\<{1990,08,23}\>\"", ",", "2100000", ",", 
       "\"\<{2001,01,24}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "875000", ",", "\"\<{1996,01,26}\>\"", ",", "1125000", ",", 
       "\"\<{1998,08,27}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "875000", ",", "\"\<{1993,06,03}\>\"", ",", "1000000", ",", 
       "\"\<{1995,08,17}\>\"", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "2350000", ",", "\"\<{1999,02,05}\>\"", ",", "2585000", ",", 
       "\"\<{2000,06,15}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2000000", ",", "\"\<{1989,01,06}\>\"", ",", "2277500", ",", 
       "\"\<{1993,09,30}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1950000", ",", "\"\<{1998,12,01}\>\"", ",", "2150000", ",", 
       "\"\<{1999,04,09}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1655000", ",", "\"\<{1991,01,15}\>\"", ",", "1750000", ",", 
       "\"\<{1995,10,10}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1565000", ",", "\"\<{1999,03,30}\>\"", ",", "2190000", ",", 
       "\"\<{2000,03,31}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1460000", ",", "\"\<{1991,12,16}\>\"", ",", "2300000", ",", 
       "\"\<{1997,08,29}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1382500", ",", "\"\<{1994,04,12}\>\"", ",", "1735000", ",", 
       "\"\<{1998,10,09}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1377500", ",", "\"\<{1991,09,06}\>\"", ",", "1600000", ",", 
       "\"\<{1998,05,29}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1260500", ",", "\"\<{1993,09,22}\>\"", ",", "1440000", ",", 
       "\"\<{1997,01,03}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1150000", ",", "\"\<{1996,01,18}\>\"", ",", "1675000", ",", 
       "\"\<{1999,01,26}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1130000", ",", "\"\<{1991,11,22}\>\"", ",", "1225000", ",", 
       "\"\<{1996,07,30}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "1105000", ",", "\"\<{1993,04,05}\>\"", ",", "1428000", ",", 
       "\"\<{1998,09,01}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1090000", ",", "\"\<{1993,09,16}\>\"", ",", "2050000", ",", 
       "\"\<{1997,08,28}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1080000", ",", "\"\<{1987,12,24}\>\"", ",", "1225000", ",", 
       "\"\<{1997,09,23}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1000000", ",", "\"\<{1992,04,13}\>\"", ",", "1005000", ",", 
       "\"\<{1997,01,08}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1000000", ",", "\"\<{1998,03,10}\>\"", ",", "1270000", ",", 
       "\"\<{1999,04,30}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "460000", ",", "\"\<{1993,03,03}\>\"", ",", "600000", ",", 
       "\"\<{1996,05,31}\>\"", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "7350000", ",", "\"\<{2000,05,09}\>\"", ",", "7000000", ",", 
       "\"\<{2001,04,26}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1415000", ",", "\"\<{1991,04,12}\>\"", ",", "1300000", ",", 
       "\"\<{1992,12,01}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1400000", ",", "\"\<{1997,07,23}\>\"", ",", "2600000", ",", 
       "\"\<{2001,07,31}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1295000", ",", "\"\<{1988,07,22}\>\"", ",", "1250000", ",", 
       "\"\<{1994,06,30}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1180000", ",", "\"\<{1989,11,15}\>\"", ",", "1250000", ",", 
       "\"\<{1996,12,31}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1125000", ",", "\"\<{1991,07,05}\>\"", ",", "1350000", ",", 
       "\"\<{1991,12,27}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1100000", ",", "\"\<{1995,11,30}\>\"", ",", "1240000", ",", 
       "\"\<{1998,04,10}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1092500", ",", "\"\<{1996,09,20}\>\"", ",", "1160000", ",", 
       "\"\<{1997,06,20}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "990000", ",", "\"\<{1989,10,27}\>\"", ",", "792000", ",", 
       "\"\<{1995,10,31}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "975000", ",", "\"\<{1987,08,06}\>\"", ",", "1135000", ",", 
       "\"\<{1993,09,17}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "970000", ",", "\"\<{1989,05,08}\>\"", ",", "820000", ",", 
       "\"\<{1995,08,03}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "950000", ",", "\"\<{1988,01,27}\>\"", ",", "750000", ",", 
       "\"\<{1993,06,18}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "922500", ",", "\"\<{1996,12,13}\>\"", ",", "1600000", ",", 
       "\"\<{2000,01,26}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "885000", ",", "\"\<{1992,08,26}\>\"", ",", "1008000", ",", 
       "\"\<{1995,05,24}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "775000", ",", "\"\<{1989,12,01}\>\"", ",", "765000", ",", 
       "\"\<{1997,02,12}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "760000", ",", "\"\<{1988,09,13}\>\"", ",", "750000", ",", 
       "\"\<{1998,03,26}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "740000", ",", "\"\<{1988,02,23}\>\"", ",", "750000", ",", 
       "\"\<{1997,09,05}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "645000", ",", "\"\<{1988,09,02}\>\"", ",", "460000", ",", 
       "\"\<{1995,02,13}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "458000", ",", "\"\<{1989,10,02}\>\"", ",", "675000", ",", 
       "\"\<{1999,06,18}\>\"", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2030000", ",", "\"\<{1988,12,16}\>\"", ",", "2279000", ",", 
       "\"\<{1993,12,21}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2000000", ",", "\"\<{1990,01,17}\>\"", ",", "2681500", ",", 
       "\"\<{1998,01,16}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1743500", ",", "\"\<{1996,08,02}\>\"", ",", "1920000", ",", 
       "\"\<{1997,10,31}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1600000", ",", "\"\<{1994,12,06}\>\"", ",", "1640000", ",", 
       "\"\<{1996,06,28}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1530000", ",", "\"\<{1990,09,28}\>\"", ",", "1065000", ",", 
       "\"\<{1994,03,24}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1485640", ",", "\"\<{1989,04,12}\>\"", ",", "1850000", ",", 
       "\"\<{1991,02,20}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1460000", ",", "\"\<{1999,10,27}\>\"", ",", "1580000", ",", 
       "\"\<{2001,06,29}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1300000", ",", "\"\<{1989,12,21}\>\"", ",", "1200000", ",", 
       "\"\<{1991,12,12}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1300000", ",", "\"\<{1994,10,28}\>\"", ",", "2835000", ",", 
       "\"\<{2000,08,11}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1280000", ",", "\"\<{1996,12,13}\>\"", ",", "2050000", ",", 
       "\"\<{2000,07,20}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1270000", ",", "\"\<{1988,11,01}\>\"", ",", "1500000", ",", 
       "\"\<{1989,11,17}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1175000", ",", "\"\<{1987,10,09}\>\"", ",", "1070000", ",", 
       "\"\<{1994,08,16}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1175000", ",", "\"\<{1988,12,01}\>\"", ",", "1280000", ",", 
       "\"\<{1993,08,13}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1170000", ",", "\"\<{1989,08,10}\>\"", ",", "1090000", ",", 
       "\"\<{1993,11,24}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1100000", ",", "\"\<{1988,08,19}\>\"", ",", "1200000", ",", 
       "\"\<{1989,03,31}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1100000", ",", "\"\<{1999,09,22}\>\"", ",", "1385000", ",", 
       "\"\<{2001,04,03}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1100000", ",", "\"\<{1990,09,20}\>\"", ",", "1360000", ",", 
       "\"\<{1996,10,31}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1095000", ",", "\"\<{1994,07,01}\>\"", ",", "2050000", ",", 
       "\"\<{1998,02,12}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1090000", ",", "\"\<{1992,05,22}\>\"", ",", "1200000", ",", 
       "\"\<{1994,09,08}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1085000", ",", "\"\<{1990,08,31}\>\"", ",", "1391500", ",", 
       "\"\<{1994,02,28}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1060000", ",", "\"\<{1989,09,26}\>\"", ",", "1512000", ",", 
       "\"\<{2000,07,07}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1055000", ",", "\"\<{1992,12,01}\>\"", ",", "1133000", ",", 
       "\"\<{1997,07,18}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1000000", ",", "\"\<{1992,06,26}\>\"", ",", "1129410", ",", 
       "\"\<{1995,05,09}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "980000", ",", "\"\<{1998,06,01}\>\"", ",", "1400000", ",", 
       "\"\<{2000,05,10}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "964500", ",", "\"\<{1988,05,27}\>\"", ",", "1300000", ",", 
       "\"\<{1997,07,16}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "960000", ",", "\"\<{1991,03,01}\>\"", ",", "1065000", ",", 
       "\"\<{1995,04,26}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "947500", ",", "\"\<{1994,09,26}\>\"", ",", "1894500", ",", 
       "\"\<{2000,06,02}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "940000", ",", "\"\<{1990,07,24}\>\"", ",", "1377500", ",", 
       "\"\<{1999,09,21}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "935000", ",", "\"\<{1990,09,19}\>\"", ",", "976000", ",", 
       "\"\<{1997,10,16}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "929000", ",", "\"\<{1989,08,30}\>\"", ",", "770000", ",", 
       "\"\<{1996,12,16}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "915000", ",", "\"\<{1995,10,31}\>\"", ",", "2000000", ",", 
       "\"\<{2001,06,14}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "898950", ",", "\"\<{1988,04,08}\>\"", ",", "1200000", ",", 
       "\"\<{1989,07,25}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "895000", ",", "\"\<{1997,09,11}\>\"", ",", "1925000", ",", 
       "\"\<{2000,04,12}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "885000", ",", "\"\<{1998,12,23}\>\"", ",", "895000", ",", 
       "\"\<{1999,04,30}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "880000", ",", "\"\<{1990,03,20}\>\"", ",", "830000", ",", 
       "\"\<{1995,06,16}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "879000", ",", "\"\<{1996,12,06}\>\"", ",", "999999", ",", 
       "\"\<{1997,06,12}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "875000", ",", "\"\<{1988,05,16}\>\"", ",", "1825000", ",", 
       "\"\<{2001,07,24}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "851000", ",", "\"\<{1988,06,17}\>\"", ",", "980000", ",", 
       "\"\<{1989,02,08}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "850000", ",", "\"\<{1995,06,30}\>\"", ",", "1550000", ",", 
       "\"\<{1998,07,24}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "825000", ",", "\"\<{1988,09,09}\>\"", ",", "940000", ",", 
       "\"\<{1996,05,17}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "805000", ",", "\"\<{1995,01,06}\>\"", ",", "1100000", ",", 
       "\"\<{1997,04,10}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "760000", ",", "\"\<{1997,08,25}\>\"", ",", "955000", ",", 
       "\"\<{1998,12,31}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "750000", ",", "\"\<{1992,12,18}\>\"", ",", "1088000", ",", 
       "\"\<{1993,12,20}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "705000", ",", "\"\<{1990,05,31}\>\"", ",", "870000", ",", 
       "\"\<{1996,07,10}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "700000", ",", "\"\<{1987,08,31}\>\"", ",", "870000", ",", 
       "\"\<{1989,01,13}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "698000", ",", "\"\<{1989,02,08}\>\"", ",", "555000", ",", 
       "\"\<{1996,09,30}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "695000", ",", "\"\<{1996,08,01}\>\"", ",", "1050000", ",", 
       "\"\<{1998,03,13}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "685000", ",", "\"\<{1989,02,28}\>\"", ",", "790000", ",", 
       "\"\<{1996,06,06}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "670000", ",", "\"\<{1998,05,29}\>\"", ",", "870000", ",", 
       "\"\<{1999,09,14}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "640000", ",", "\"\<{1995,04,21}\>\"", ",", "1075000", ",", 
       "\"\<{1998,05,12}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "626000", ",", "\"\<{1988,09,09}\>\"", ",", "650000", ",", 
       "\"\<{1988,10,12}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "620000", ",", "\"\<{1995,07,14}\>\"", ",", "1200000", ",", 
       "\"\<{1999,03,24}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "595000", ",", "\"\<{1989,04,07}\>\"", ",", "895000", ",", 
       "\"\<{1998,11,20}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "595000", ",", "\"\<{1996,08,20}\>\"", ",", "950000", ",", 
       "\"\<{1999,04,09}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "580000", ",", "\"\<{1988,09,01}\>\"", ",", "635000", ",", 
       "\"\<{1997,05,02}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "548500", ",", "\"\<{1993,05,28}\>\"", ",", "585000", ",", 
       "\"\<{1994,04,15}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "515000", ",", "\"\<{1988,06,15}\>\"", ",", "650000", ",", 
       "\"\<{1991,02,15}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "480000", ",", "\"\<{1997,05,30}\>\"", ",", "730000", ",", 
       "\"\<{1999,02,09}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "475000", ",", "\"\<{1992,09,11}\>\"", ",", "900000", ",", 
       "\"\<{1999,09,30}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "440000", ",", "\"\<{1991,08,09}\>\"", ",", "520000", ",", 
       "\"\<{1996,04,17}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "340000", ",", "\"\<{1994,04,19}\>\"", ",", "725000", ",", 
       "\"\<{2000,04,07}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "300000", ",", "\"\<{1988,07,15}\>\"", ",", "375000", ",", 
       "\"\<{1989,03,17}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "186000", ",", "\"\<{1996,03,15}\>\"", ",", "500000", ",", 
       "\"\<{1997,12,05}\>\"", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1800000", ",", "\"\<{2000,05,12}\>\"", ",", "2400000", ",", 
       "\"\<{2001,08,22}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1535000", ",", "\"\<{1990,08,10}\>\"", ",", "1595000", ",", 
       "\"\<{1999,07,27}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1440000", ",", "\"\<{1989,10,27}\>\"", ",", "1180000", ",", 
       "\"\<{1993,06,30}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "1165000", ",", "\"\<{1989,02,09}\>\"", ",", "650000", ",", 
       "\"\<{1997,09,19}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "990000", ",", "\"\<{1999,05,27}\>\"", ",", "1360000", ",", 
       "\"\<{2001,05,01}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "950000", ",", "\"\<{1996,07,11}\>\"", ",", "2000000", ",", 
       "\"\<{2000,03,28}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "950000", ",", "\"\<{1989,07,11}\>\"", ",", "1100000", ",", 
       "\"\<{1997,02,13}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "933000", ",", "\"\<{1993,01,22}\>\"", ",", "1500000", ",", 
       "\"\<{1999,12,29}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "855000", ",", "\"\<{1989,01,06}\>\"", ",", "775000", ",", 
       "\"\<{1994,11,10}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "835000", ",", "\"\<{1989,10,13}\>\"", ",", "868000", ",", 
       "\"\<{1997,02,12}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "816500", ",", "\"\<{1994,09,13}\>\"", ",", "2000000", ",", 
       "\"\<{2001,04,30}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "785000", ",", "\"\<{1996,11,22}\>\"", ",", "1079000", ",", 
       "\"\<{1999,10,01}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "770000", ",", "\"\<{1988,09,23}\>\"", ",", "998000", ",", 
       "\"\<{1989,11,08}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "750000", ",", "\"\<{1991,07,02}\>\"", ",", "1100000", ",", 
       "\"\<{2000,05,10}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "680000", ",", "\"\<{1988,07,15}\>\"", ",", "1250000", ",", 
       "\"\<{2000,03,31}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "610000", ",", "\"\<{1988,04,25}\>\"", ",", "1010000", ",", 
       "\"\<{1989,02,17}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "315000", ",", "\"\<{1995,10,27}\>\"", ",", "530000", ",", 
       "\"\<{1998,06,19}\>\"", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2120000", ",", "\"\<{1997,08,28}\>\"", ",", "3405000", ",", 
       "\"\<{2000,09,29}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1285000", ",", "\"\<{1997,06,10}\>\"", ",", "1600000", ",", 
       "\"\<{2000,10,06}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1225000", ",", "\"\<{1990,09,20}\>\"", ",", "1210000", ",", 
       "\"\<{1993,09,17}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1110000", ",", "\"\<{1998,04,01}\>\"", ",", "1895000", ",", 
       "\"\<{1999,12,17}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1055000", ",", "\"\<{1989,04,18}\>\"", ",", "1127000", ",", 
       "\"\<{1990,08,15}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "995000", ",", "\"\<{1989,11,21}\>\"", ",", "1000000", ",", 
       "\"\<{1994,01,21}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "990000", ",", "\"\<{1989,02,01}\>\"", ",", "820000", ",", 
       "\"\<{1996,08,13}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "978500", ",", "\"\<{1989,03,14}\>\"", ",", "930000", ",", 
       "\"\<{1994,05,12}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "900000", ",", "\"\<{1988,08,22}\>\"", ",", "1010000", ",", 
       "\"\<{1990,11,01}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "805000", ",", "\"\<{1988,12,01}\>\"", ",", "860000", ",", 
       "\"\<{1997,09,10}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "800000", ",", "\"\<{1993,01,29}\>\"", ",", "950000", ",", 
       "\"\<{1994,08,16}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "790000", ",", "\"\<{1992,07,17}\>\"", ",", "1750000", ",", 
       "\"\<{2000,03,09}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "790000", ",", "\"\<{1994,10,19}\>\"", ",", "785000", ",", 
       "\"\<{1996,01,19}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "787000", ",", "\"\<{1987,12,24}\>\"", ",", "965000", ",", 
       "\"\<{1990,07,26}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "765000", ",", "\"\<{1988,11,29}\>\"", ",", "850000", ",", 
       "\"\<{1999,07,26}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "745000", ",", "\"\<{1988,10,27}\>\"", ",", "545000", ",", 
       "\"\<{1994,10,14}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "730000", ",", "\"\<{1992,02,28}\>\"", ",", "1000000", ",", 
       "\"\<{1999,07,30}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "730000", ",", "\"\<{1989,01,19}\>\"", ",", "624000", ",", 
       "\"\<{1993,01,07}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "7", ",", "710000", ",", "\"\<{1996,02,22}\>\"", ",", "980000", ",", 
       "\"\<{1999,08,26}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "674000", ",", "\"\<{1990,03,01}\>\"", ",", "535000", ",", 
       "\"\<{1997,09,15}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "615000", ",", "\"\<{1996,01,18}\>\"", ",", "1090000", ",", 
       "\"\<{2000,03,28}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "605000", ",", "\"\<{1987,11,18}\>\"", ",", "850000", ",", 
       "\"\<{1989,02,01}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "485000", ",", "\"\<{1997,06,11}\>\"", ",", "975000", ",", 
       "\"\<{1999,08,25}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "415000", ",", "\"\<{1989,10,13}\>\"", ",", "305000", ",", 
       "\"\<{1995,06,20}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "383000", ",", "\"\<{1999,04,29}\>\"", ",", "580000", ",", 
       "\"\<{2001,09,24}\>\"", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1675000", ",", "\"\<{1993,04,01}\>\"", ",", "1700000", ",", 
       "\"\<{1996,09,19}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1425000", ",", "\"\<{1990,04,05}\>\"", ",", "1350000", ",", 
       "\"\<{1993,06,25}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1300000", ",", "\"\<{1997,03,06}\>\"", ",", "2600000", ",", 
       "\"\<{2000,11,17}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1100000", ",", "\"\<{1989,04,13}\>\"", ",", "960000", ",", 
       "\"\<{1992,10,07}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "1060000", ",", "\"\<{1989,12,15}\>\"", ",", "1150000", ",", 
       "\"\<{1996,08,06}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "915000", ",", "\"\<{1995,06,16}\>\"", ",", "1450000", ",", 
       "\"\<{1999,06,22}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "885000", ",", "\"\<{1998,12,03}\>\"", ",", "1505000", ",", 
       "\"\<{2001,06,25}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "820000", ",", "\"\<{1988,12,21}\>\"", ",", "740000", ",", 
       "\"\<{1996,02,28}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "812000", ",", "\"\<{1996,12,12}\>\"", ",", "1955000", ",", 
       "\"\<{2001,04,19}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "810000", ",", "\"\<{1997,06,16}\>\"", ",", "1250000", ",", 
       "\"\<{2000,05,08}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "810000", ",", "\"\<{1991,02,28}\>\"", ",", "718000", ",", 
       "\"\<{1997,02,26}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "795000", ",", "\"\<{1989,08,16}\>\"", ",", "823000", ",", 
       "\"\<{1998,06,30}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "785000", ",", "\"\<{1993,04,15}\>\"", ",", "1075000", ",", 
       "\"\<{1999,08,27}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "783000", ",", "\"\<{1989,11,10}\>\"", ",", "821000", ",", 
       "\"\<{1998,07,08}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "781000", ",", "\"\<{1990,03,28}\>\"", ",", "785000", ",", 
       "\"\<{1994,11,22}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "775000", ",", "\"\<{1996,01,09}\>\"", ",", "960000", ",", 
       "\"\<{1997,08,15}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "757000", ",", "\"\<{1998,04,24}\>\"", ",", "908000", ",", 
       "\"\<{1999,01,08}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "745000", ",", "\"\<{1993,08,02}\>\"", ",", "2400000", ",", 
       "\"\<{2000,06,16}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "742000", ",", "\"\<{1988,09,01}\>\"", ",", "705000", ",", 
       "\"\<{1991,11,22}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "720000", ",", "\"\<{1988,06,08}\>\"", ",", "850000", ",", 
       "\"\<{1996,08,02}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "715000", ",", "\"\<{1991,06,21}\>\"", ",", "737500", ",", 
       "\"\<{1996,07,05}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "675000", ",", "\"\<{1992,03,20}\>\"", ",", "625000", ",", 
       "\"\<{1992,11,25}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "650000", ",", "\"\<{1998,11,06}\>\"", ",", "1075000", ",", 
       "\"\<{2001,09,21}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "650000", ",", "\"\<{1991,07,25}\>\"", ",", "1000000", ",", 
       "\"\<{2000,06,30}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "640000", ",", "\"\<{1997,08,22}\>\"", ",", "1071000", ",", 
       "\"\<{2000,04,28}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "625000", ",", "\"\<{1994,11,04}\>\"", ",", "1315000", ",", 
       "\"\<{2000,02,29}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "620000", ",", "\"\<{1992,06,26}\>\"", ",", "839000", ",", 
       "\"\<{1994,07,26}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "575000", ",", "\"\<{1993,09,24}\>\"", ",", "1875000", ",", 
       "\"\<{1999,10,15}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "550000", ",", "\"\<{1997,03,27}\>\"", ",", "776000", ",", 
       "\"\<{1998,12,17}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "550000", ",", "\"\<{1988,05,16}\>\"", ",", "515000", ",", 
       "\"\<{1997,08,20}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "467500", ",", "\"\<{1992,07,17}\>\"", ",", "570000", ",", 
       "\"\<{1998,03,31}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "450000", ",", "\"\<{1999,06,09}\>\"", ",", "880000", ",", 
       "\"\<{2001,06,13}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "430000", ",", "\"\<{1995,02,15}\>\"", ",", "700000", ",", 
       "\"\<{1998,04,30}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "425000", ",", "\"\<{1989,01,19}\>\"", ",", "525000", ",", 
       "\"\<{1992,12,31}\>\"", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1150000", ",", "\"\<{1990,10,31}\>\"", ",", "745000", ",", 
       "\"\<{1995,04,05}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1125000", ",", "\"\<{2001,01,19}\>\"", ",", "1150000", ",", 
       "\"\<{2001,09,07}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1100000", ",", "\"\<{1990,02,21}\>\"", ",", "1130000", ",", 
       "\"\<{1993,06,10}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1100000", ",", "\"\<{1989,11,15}\>\"", ",", "890000", ",", 
       "\"\<{1992,04,24}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "990000", ",", "\"\<{1999,12,23}\>\"", ",", "1350000", ",", 
       "\"\<{2001,03,15}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "887000", ",", "\"\<{1990,01,16}\>\"", ",", "1370000", ",", 
       "\"\<{2000,01,14}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "875000", ",", "\"\<{1990,06,01}\>\"", ",", "969000", ",", 
       "\"\<{1999,05,20}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "870000", ",", "\"\<{1991,05,03}\>\"", ",", "790000", ",", 
       "\"\<{1998,07,09}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "850000", ",", "\"\<{1998,02,27}\>\"", ",", "1663000", ",", 
       "\"\<{2001,04,02}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "850000", ",", "\"\<{1989,09,13}\>\"", ",", "925000", ",", 
       "\"\<{1998,06,25}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "840000", ",", "\"\<{1990,05,02}\>\"", ",", "630000", ",", 
       "\"\<{1995,02,15}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "780000", ",", "\"\<{1990,11,27}\>\"", ",", "625000", ",", 
       "\"\<{1995,06,30}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "765000", ",", "\"\<{1988,08,25}\>\"", ",", "965000", ",", 
       "\"\<{1990,11,30}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "750000", ",", "\"\<{1998,03,26}\>\"", ",", "1175000", ",", 
       "\"\<{2000,03,01}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "743500", ",", "\"\<{1989,01,04}\>\"", ",", "740000", ",", 
       "\"\<{1996,06,07}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "725000", ",", "\"\<{1987,09,28}\>\"", ",", "631000", ",", 
       "\"\<{1995,11,30}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "715000", ",", "\"\<{1999,02,26}\>\"", ",", "944000", ",", 
       "\"\<{2000,04,14}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "700000", ",", "\"\<{1989,10,27}\>\"", ",", "1185000", ",", 
       "\"\<{2000,09,15}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "700000", ",", "\"\<{1993,04,30}\>\"", ",", "1050000", ",", 
       "\"\<{2000,06,30}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "695000", ",", "\"\<{1994,10,07}\>\"", ",", "912500", ",", 
       "\"\<{1998,03,06}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "675000", ",", "\"\<{1987,09,24}\>\"", ",", "653000", ",", 
       "\"\<{1996,02,27}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "675000", ",", "\"\<{2000,08,07}\>\"", ",", "965000", ",", 
       "\"\<{2001,01,03}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "671000", ",", "\"\<{1988,12,02}\>\"", ",", "387000", ",", 
       "\"\<{1997,03,21}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "670000", ",", "\"\<{1989,10,06}\>\"", ",", "1401000", ",", 
       "\"\<{2000,06,15}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "670000", ",", "\"\<{1989,11,10}\>\"", ",", "650000", ",", 
       "\"\<{1993,10,01}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "665000", ",", "\"\<{1996,01,09}\>\"", ",", "850000", ",", 
       "\"\<{1997,08,15}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "656000", ",", "\"\<{1999,02,24}\>\"", ",", "775000", ",", 
       "\"\<{1999,11,23}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "640000", ",", "\"\<{1987,12,10}\>\"", ",", "750000", ",", 
       "\"\<{1999,01,29}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "625500", ",", "\"\<{1988,09,14}\>\"", ",", "568500", ",", 
       "\"\<{1994,09,23}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "625000", ",", "\"\<{1989,09,26}\>\"", ",", "634000", ",", 
       "\"\<{1999,02,11}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "624000", ",", "\"\<{1992,04,14}\>\"", ",", "685000", ",", 
       "\"\<{1996,10,11}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "615000", ",", "\"\<{1993,03,26}\>\"", ",", "715000", ",", 
       "\"\<{1996,09,25}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "608000", ",", "\"\<{1988,09,21}\>\"", ",", "715000", ",", 
       "\"\<{1989,06,30}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "600000", ",", "\"\<{1996,06,28}\>\"", ",", "675000", ",", 
       "\"\<{1998,08,07}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "590000", ",", "\"\<{1998,09,10}\>\"", ",", "702000", ",", 
       "\"\<{1999,09,30}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "575000", ",", "\"\<{1989,11,03}\>\"", ",", "739000", ",", 
       "\"\<{1990,07,11}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "570000", ",", "\"\<{1994,05,19}\>\"", ",", "795000", ",", 
       "\"\<{1999,07,02}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "565000", ",", "\"\<{1996,06,27}\>\"", ",", "900000", ",", 
       "\"\<{1998,06,30}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "550000", ",", "\"\<{1999,03,15}\>\"", ",", "660000", ",", 
       "\"\<{1999,08,31}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "550000", ",", "\"\<{1990,12,03}\>\"", ",", "630000", ",", 
       "\"\<{1997,10,28}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "550000", ",", "\"\<{1989,03,13}\>\"", ",", "415000", ",", 
       "\"\<{1992,11,25}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "550000", ",", "\"\<{1993,04,09}\>\"", ",", "800000", ",", 
       "\"\<{1995,06,01}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "550000", ",", "\"\<{1997,12,30}\>\"", ",", "728000", ",", 
       "\"\<{1999,11,12}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "545000", ",", "\"\<{1989,08,12}\>\"", ",", "475000", ",", 
       "\"\<{1998,09,01}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "539000", ",", "\"\<{1988,04,28}\>\"", ",", "667000", ",", 
       "\"\<{1998,04,15}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "525000", ",", "\"\<{1989,03,31}\>\"", ",", "560000", ",", 
       "\"\<{1995,05,10}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "520000", ",", "\"\<{1990,12,03}\>\"", ",", "515000", ",", 
       "\"\<{1991,05,10}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "498000", ",", "\"\<{1994,05,11}\>\"", ",", "600000", ",", 
       "\"\<{1999,02,04}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "482000", ",", "\"\<{1995,04,27}\>\"", ",", "685000", ",", 
       "\"\<{1997,04,30}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "480000", ",", "\"\<{1996,04,10}\>\"", ",", "995000", ",", 
       "\"\<{2000,05,31}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "466500", ",", "\"\<{1992,09,01}\>\"", ",", "729000", ",", 
       "\"\<{1999,12,01}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "460000", ",", "\"\<{1988,06,13}\>\"", ",", "445000", ",", 
       "\"\<{1992,06,09}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "425000", ",", "\"\<{1996,02,29}\>\"", ",", "750000", ",", 
       "\"\<{2000,02,11}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "420000", ",", "\"\<{1996,12,27}\>\"", ",", "1050000", ",", 
       "\"\<{2000,09,29}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "400000", ",", "\"\<{1993,12,01}\>\"", ",", "750000", ",", 
       "\"\<{2001,03,21}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "310000", ",", "\"\<{1988,05,18}\>\"", ",", "362000", ",", 
       "\"\<{1993,06,29}\>\"", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1450000", ",", "\"\<{1993,06,04}\>\"", ",", "1720000", ",", 
       "\"\<{1998,07,14}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1438000", ",", "\"\<{1990,08,17}\>\"", ",", "1900000", ",", 
       "\"\<{1997,09,25}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "950000", ",", "\"\<{1999,01,20}\>\"", ",", "1420000", ",", 
       "\"\<{1999,04,30}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "875500", ",", "\"\<{2000,03,17}\>\"", ",", "1250000", ",", 
       "\"\<{2000,09,12}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "860000", ",", "\"\<{1987,11,19}\>\"", ",", "2300000", ",", 
       "\"\<{2000,01,11}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "850000", ",", "\"\<{1989,01,13}\>\"", ",", "979000", ",", 
       "\"\<{1998,06,11}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "835000", ",", "\"\<{1991,02,21}\>\"", ",", "1005500", ",", 
       "\"\<{1997,01,14}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "825000", ",", "\"\<{1992,05,27}\>\"", ",", "1300000", ",", 
       "\"\<{2001,04,10}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "776000", ",", "\"\<{1989,02,17}\>\"", ",", "875000", ",", 
       "\"\<{1998,07,06}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "775000", ",", "\"\<{1994,09,09}\>\"", ",", "1050000", ",", 
       "\"\<{2000,08,14}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "765000", ",", "\"\<{1988,04,29}\>\"", ",", "840000", ",", 
       "\"\<{1989,02,10}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "754000", ",", "\"\<{1987,09,17}\>\"", ",", "840000", ",", 
       "\"\<{1992,07,10}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "750000", ",", "\"\<{1988,10,25}\>\"", ",", "1125000", ",", 
       "\"\<{2000,11,30}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "710000", ",", "\"\<{1998,01,07}\>\"", ",", "1313000", ",", 
       "\"\<{2000,04,07}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "700000", ",", "\"\<{1989,12,29}\>\"", ",", "752000", ",", 
       "\"\<{1998,05,21}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "665000", ",", "\"\<{1998,08,28}\>\"", ",", "850000", ",", 
       "\"\<{1999,11,03}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "660000", ",", "\"\<{1993,01,21}\>\"", ",", "685000", ",", 
       "\"\<{1998,03,20}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "650000", ",", "\"\<{1991,12,12}\>\"", ",", "675000", ",", 
       "\"\<{1992,02,28}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "635000", ",", "\"\<{1989,11,16}\>\"", ",", "710000", ",", 
       "\"\<{1998,04,29}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "630000", ",", "\"\<{1990,04,05}\>\"", ",", "930000", ",", 
       "\"\<{2000,09,26}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "628000", ",", "\"\<{1995,01,18}\>\"", ",", "705000", ",", 
       "\"\<{1997,05,13}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "615000", ",", "\"\<{1995,10,11}\>\"", ",", "1025455", ",", 
       "\"\<{1998,12,04}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "610000", ",", "\"\<{1995,10,17}\>\"", ",", "389000", ",", 
       "\"\<{1997,12,31}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "595500", ",", "\"\<{1987,07,31}\>\"", ",", "608000", ",", 
       "\"\<{1992,06,04}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "595000", ",", "\"\<{1994,03,30}\>\"", ",", "532000", ",", 
       "\"\<{1997,05,30}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "585000", ",", "\"\<{1989,06,30}\>\"", ",", "381000", ",", 
       "\"\<{1995,11,17}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "575000", ",", "\"\<{1987,08,13}\>\"", ",", "1295000", ",", 
       "\"\<{2000,11,16}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "556500", ",", "\"\<{1989,02,23}\>\"", ",", "686000", ",", 
       "\"\<{1997,03,14}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "550000", ",", "\"\<{1993,02,04}\>\"", ",", "748000", ",", 
       "\"\<{1997,08,06}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "525000", ",", "\"\<{1998,03,31}\>\"", ",", "700000", ",", 
       "\"\<{1999,05,28}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "512500", ",", "\"\<{1989,12,21}\>\"", ",", "585000", ",", 
       "\"\<{1997,11,14}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "510000", ",", "\"\<{1996,04,26}\>\"", ",", "602000", ",", 
       "\"\<{1997,08,13}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "505000", ",", "\"\<{1989,06,08}\>\"", ",", "725000", ",", 
       "\"\<{2000,05,10}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "500000", ",", "\"\<{1988,04,12}\>\"", ",", "585000", ",", 
       "\"\<{1990,07,31}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "495000", ",", "\"\<{1998,05,29}\>\"", ",", "665000", ",", 
       "\"\<{1999,06,24}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "465000", ",", "\"\<{1987,12,01}\>\"", ",", "650000", ",", 
       "\"\<{1989,08,01}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "440000", ",", "\"\<{1995,01,09}\>\"", ",", "550000", ",", 
       "\"\<{1999,04,30}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "425000", ",", "\"\<{1988,01,25}\>\"", ",", "650000", ",", 
       "\"\<{2000,06,23}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "410000", ",", "\"\<{1988,05,27}\>\"", ",", "490000", ",", 
       "\"\<{1998,04,28}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "405000", ",", "\"\<{1992,11,17}\>\"", ",", "560000", ",", 
       "\"\<{1998,03,31}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "357000", ",", "\"\<{1994,09,08}\>\"", ",", "802500", ",", 
       "\"\<{2001,07,11}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "310000", ",", "\"\<{1995,05,26}\>\"", ",", "520000", ",", 
       "\"\<{1998,06,30}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "300000", ",", "\"\<{1995,03,30}\>\"", ",", "295000", ",", 
       "\"\<{1999,04,21}\>\"", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "2300000", ",", "\"\<{1999,12,30}\>\"", ",", "3400000", ",", 
       "\"\<{2000,05,25}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1755000", ",", "\"\<{2000,07,18}\>\"", ",", "1865000", ",", 
       "\"\<{2001,06,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1425000", ",", "\"\<{1990,08,01}\>\"", ",", "1175000", ",", 
       "\"\<{1994,08,18}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1280000", ",", "\"\<{1998,04,23}\>\"", ",", "1375000", ",", 
       "\"\<{2000,01,06}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1100000", ",", "\"\<{1990,10,22}\>\"", ",", "1255000", ",", 
       "\"\<{1999,06,15}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1050000", ",", "\"\<{2000,05,08}\>\"", ",", "1310000", ",", 
       "\"\<{2000,11,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1020000", ",", "\"\<{1997,10,24}\>\"", ",", "1250000", ",", 
       "\"\<{1999,03,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "1000000", ",", "\"\<{1988,06,01}\>\"", ",", "1650000", ",", 
       "\"\<{2000,05,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "997500", ",", "\"\<{1998,03,27}\>\"", ",", "1500000", ",", 
       "\"\<{2000,11,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "990000", ",", "\"\<{1990,05,30}\>\"", ",", "1750000", ",", 
       "\"\<{1999,08,20}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "975500", ",", "\"\<{1989,03,14}\>\"", ",", "960000", ",", 
       "\"\<{1996,10,10}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "975000", ",", "\"\<{1999,06,24}\>\"", ",", "1195000", ",", 
       "\"\<{2000,04,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "975000", ",", "\"\<{1990,05,25}\>\"", ",", "750000", ",", 
       "\"\<{1993,12,22}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "955000", ",", "\"\<{1989,03,16}\>\"", ",", "1000000", ",", 
       "\"\<{1997,11,05}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "937500", ",", "\"\<{1991,07,26}\>\"", ",", "1500000", ",", 
       "\"\<{2001,04,05}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "936000", ",", "\"\<{1997,05,01}\>\"", ",", "1200000", ",", 
       "\"\<{1999,03,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "900000", ",", "\"\<{1997,01,29}\>\"", ",", "1087500", ",", 
       "\"\<{1997,09,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "900000", ",", "\"\<{1998,07,02}\>\"", ",", "1126000", ",", 
       "\"\<{1998,12,14}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "895000", ",", "\"\<{1989,01,18}\>\"", ",", "965000", ",", 
       "\"\<{1996,12,27}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "880000", ",", "\"\<{1998,04,15}\>\"", ",", "1430000", ",", 
       "\"\<{2000,09,20}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "875000", ",", "\"\<{1989,01,12}\>\"", ",", "940000", ",", 
       "\"\<{1996,12,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "855000", ",", "\"\<{1989,06,23}\>\"", ",", "870500", ",", 
       "\"\<{1995,09,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "850000", ",", "\"\<{1990,01,05}\>\"", ",", "1600000", ",", 
       "\"\<{2000,01,25}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "840000", ",", "\"\<{1989,02,08}\>\"", ",", "725000", ",", 
       "\"\<{1994,06,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "840000", ",", "\"\<{1998,09,11}\>\"", ",", "1110000", ",", 
       "\"\<{2000,05,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "835000", ",", "\"\<{1996,01,31}\>\"", ",", "1690000", ",", 
       "\"\<{1999,02,09}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "825000", ",", "\"\<{1991,11,15}\>\"", ",", "866000", ",", 
       "\"\<{1996,08,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "796500", ",", "\"\<{1996,03,29}\>\"", ",", "1068000", ",", 
       "\"\<{1997,12,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "795000", ",", "\"\<{1989,06,21}\>\"", ",", "825000", ",", 
       "\"\<{1994,03,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "775000", ",", "\"\<{1993,12,14}\>\"", ",", "800000", ",", 
       "\"\<{1994,09,09}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "770000", ",", "\"\<{1989,05,31}\>\"", ",", "762500", ",", 
       "\"\<{1995,05,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "762500", ",", "\"\<{1998,09,15}\>\"", ",", "1400000", ",", 
       "\"\<{2000,05,23}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "760000", ",", "\"\<{1990,02,01}\>\"", ",", "1009000", ",", 
       "\"\<{1993,03,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "755000", ",", "\"\<{1998,02,20}\>\"", ",", "922500", ",", 
       "\"\<{2001,08,20}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "750000", ",", "\"\<{1994,11,18}\>\"", ",", "1000000", ",", 
       "\"\<{1998,07,17}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "750000", ",", "\"\<{1990,01,19}\>\"", ",", "673000", ",", 
       "\"\<{1996,04,17}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "750000", ",", "\"\<{1997,05,16}\>\"", ",", "1350000", ",", 
       "\"\<{2000,07,11}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "748500", ",", "\"\<{1998,06,10}\>\"", ",", "1038000", ",", 
       "\"\<{2000,08,11}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "739000", ",", "\"\<{1989,10,27}\>\"", ",", "1135000", ",", 
       "\"\<{2000,01,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "735000", ",", "\"\<{1991,01,18}\>\"", ",", "750000", ",", 
       "\"\<{1994,07,29}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "735000", ",", "\"\<{1989,01,23}\>\"", ",", "626000", ",", 
       "\"\<{1994,09,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "730000", ",", "\"\<{1998,01,30}\>\"", ",", "815000", ",", 
       "\"\<{1998,09,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "730000", ",", "\"\<{1989,02,09}\>\"", ",", "673000", ",", 
       "\"\<{1991,11,26}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "727000", ",", "\"\<{1989,05,23}\>\"", ",", "590000", ",", 
       "\"\<{1995,11,22}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "725000", ",", "\"\<{1995,06,01}\>\"", ",", "928000", ",", 
       "\"\<{1996,12,20}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "722500", ",", "\"\<{1992,04,10}\>\"", ",", "720000", ",", 
       "\"\<{1997,04,22}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "710000", ",", "\"\<{1989,05,01}\>\"", ",", "1100000", ",", 
       "\"\<{2000,11,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "707000", ",", "\"\<{1988,08,11}\>\"", ",", "756000", ",", 
       "\"\<{1989,04,12}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "705000", ",", "\"\<{1989,01,06}\>\"", ",", "775000", ",", 
       "\"\<{1990,02,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "690000", ",", "\"\<{1990,10,31}\>\"", ",", "940000", ",", 
       "\"\<{1991,07,29}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "690000", ",", "\"\<{1999,03,19}\>\"", ",", "1000000", ",", 
       "\"\<{2000,03,22}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "689500", ",", "\"\<{1988,10,31}\>\"", ",", "1040000", ",", 
       "\"\<{1993,06,15}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "687000", ",", "\"\<{1989,12,01}\>\"", ",", "585000", ",", 
       "\"\<{1997,05,15}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "685500", ",", "\"\<{1989,02,16}\>\"", ",", "850000", ",", 
       "\"\<{1995,05,03}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "685000", ",", "\"\<{1988,09,12}\>\"", ",", "730000", ",", 
       "\"\<{1991,11,20}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "680000", ",", "\"\<{1989,01,18}\>\"", ",", "825000", ",", 
       "\"\<{1999,08,20}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "675000", ",", "\"\<{1988,05,06}\>\"", ",", "900000", ",", 
       "\"\<{2000,04,11}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "675000", ",", "\"\<{1990,03,26}\>\"", ",", "1350000", ",", 
       "\"\<{2001,07,13}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "665000", ",", "\"\<{1992,06,26}\>\"", ",", "715000", ",", 
       "\"\<{1995,10,26}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "665000", ",", "\"\<{1988,06,01}\>\"", ",", "714000", ",", 
       "\"\<{1989,09,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "665000", ",", "\"\<{1998,06,15}\>\"", ",", "950000", ",", 
       "\"\<{2000,06,29}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "660000", ",", "\"\<{1999,03,11}\>\"", ",", "775000", ",", 
       "\"\<{1999,09,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "660000", ",", "\"\<{1990,03,15}\>\"", ",", "883000", ",", 
       "\"\<{2000,03,24}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "650000", ",", "\"\<{1991,04,22}\>\"", ",", "920000", ",", 
       "\"\<{2001,08,02}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "650000", ",", "\"\<{1997,12,05}\>\"", ",", "900000", ",", 
       "\"\<{2000,03,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "640000", ",", "\"\<{1998,03,13}\>\"", ",", "1125000", ",", 
       "\"\<{2001,03,22}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "640000", ",", "\"\<{1997,10,01}\>\"", ",", "1380000", ",", 
       "\"\<{2000,03,10}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "640000", ",", "\"\<{1998,11,19}\>\"", ",", "815000", ",", 
       "\"\<{2000,04,13}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "625000", ",", "\"\<{1999,03,05}\>\"", ",", "700000", ",", 
       "\"\<{2001,07,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "615000", ",", "\"\<{1993,09,03}\>\"", ",", "700000", ",", 
       "\"\<{1998,11,25}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "615000", ",", "\"\<{1988,09,16}\>\"", ",", "617500", ",", 
       "\"\<{1992,02,26}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "605000", ",", "\"\<{1989,08,31}\>\"", ",", "460000", ",", 
       "\"\<{1992,05,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "600000", ",", "\"\<{1992,02,12}\>\"", ",", "795000", ",", 
       "\"\<{2000,05,11}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "600000", ",", "\"\<{1996,05,01}\>\"", ",", "649000", ",", 
       "\"\<{1997,06,18}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "600000", ",", "\"\<{1989,07,14}\>\"", ",", "529500", ",", 
       "\"\<{1997,11,14}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "600000", ",", "\"\<{1997,12,24}\>\"", ",", "710000", ",", 
       "\"\<{1998,09,23}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "600000", ",", "\"\<{1996,03,25}\>\"", ",", "1425000", ",", 
       "\"\<{2001,05,02}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "600000", ",", "\"\<{1990,02,16}\>\"", ",", "701000", ",", 
       "\"\<{1998,03,27}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "600000", ",", "\"\<{1997,12,19}\>\"", ",", "730000", ",", 
       "\"\<{1999,06,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "590000", ",", "\"\<{1988,05,17}\>\"", ",", "509000", ",", 
       "\"\<{1994,10,14}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "590000", ",", "\"\<{1996,10,25}\>\"", ",", "1350000", ",", 
       "\"\<{2000,03,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "590000", ",", "\"\<{1992,07,30}\>\"", ",", "688000", ",", 
       "\"\<{1995,06,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "585000", ",", "\"\<{1989,09,15}\>\"", ",", "749000", ",", 
       "\"\<{1999,12,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "584000", ",", "\"\<{1988,07,19}\>\"", ",", "630000", ",", 
       "\"\<{1998,11,25}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "583000", ",", "\"\<{1989,04,17}\>\"", ",", "690000", ",", 
       "\"\<{1997,12,02}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "7", ",", "580000", ",", "\"\<{1999,10,22}\>\"", ",", "685300", ",", 
       "\"\<{2000,03,10}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "575000", ",", "\"\<{1994,07,19}\>\"", ",", "850000", ",", 
       "\"\<{1997,01,17}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "574000", ",", "\"\<{1989,04,06}\>\"", ",", "820000", ",", 
       "\"\<{1990,01,26}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "570000", ",", "\"\<{1997,03,14}\>\"", ",", "592500", ",", 
       "\"\<{1997,09,25}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "561000", ",", "\"\<{1988,10,07}\>\"", ",", "593500", ",", 
       "\"\<{1997,07,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "560000", ",", "\"\<{1994,10,18}\>\"", ",", "1000000", ",", 
       "\"\<{2000,08,17}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "560000", ",", "\"\<{1995,05,18}\>\"", ",", "845000", ",", 
       "\"\<{2000,04,07}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "559000", ",", "\"\<{1988,07,29}\>\"", ",", "659000", ",", 
       "\"\<{1994,09,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "551500", ",", "\"\<{1989,04,06}\>\"", ",", "820000", ",", 
       "\"\<{1990,01,26}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "550000", ",", "\"\<{1988,10,03}\>\"", ",", "475000", ",", 
       "\"\<{1994,05,10}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "550000", ",", "\"\<{1988,09,20}\>\"", ",", "500000", ",", 
       "\"\<{1997,10,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "545500", ",", "\"\<{1988,10,28}\>\"", ",", "668000", ",", 
       "\"\<{1999,08,13}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "545000", ",", "\"\<{1993,06,30}\>\"", ",", "985000", ",", 
       "\"\<{2000,09,22}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "545000", ",", "\"\<{1988,08,10}\>\"", ",", "625000", ",", 
       "\"\<{1989,01,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "540000", ",", "\"\<{1991,10,11}\>\"", ",", "600000", ",", 
       "\"\<{1999,03,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "538000", ",", "\"\<{1989,04,26}\>\"", ",", "541000", ",", 
       "\"\<{1997,08,29}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "532000", ",", "\"\<{1991,05,01}\>\"", ",", "552500", ",", 
       "\"\<{1993,04,08}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "530000", ",", "\"\<{2000,06,29}\>\"", ",", "750000", ",", 
       "\"\<{2000,11,22}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "525000", ",", "\"\<{1989,01,13}\>\"", ",", "505000", ",", 
       "\"\<{1991,03,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "525000", ",", "\"\<{1989,08,15}\>\"", ",", "545000", ",", 
       "\"\<{1992,08,14}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "517500", ",", "\"\<{1988,12,09}\>\"", ",", "825000", ",", 
       "\"\<{1997,10,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "517500", ",", "\"\<{1988,10,13}\>\"", ",", "492500", ",", 
       "\"\<{1991,06,17}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "510000", ",", "\"\<{1995,01,11}\>\"", ",", "825000", ",", 
       "\"\<{2000,05,11}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "510000", ",", "\"\<{1996,09,25}\>\"", ",", "630000", ",", 
       "\"\<{1998,03,10}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "510000", ",", "\"\<{1998,09,10}\>\"", ",", "920000", ",", 
       "\"\<{2001,09,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "510000", ",", "\"\<{1990,07,31}\>\"", ",", "810000", ",", 
       "\"\<{1999,06,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "509000", ",", "\"\<{1989,12,13}\>\"", ",", "440000", ",", 
       "\"\<{1993,07,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "500000", ",", "\"\<{1989,01,24}\>\"", ",", "518000", ",", 
       "\"\<{1995,12,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "500000", ",", "\"\<{1996,08,29}\>\"", ",", "1175000", ",", 
       "\"\<{1998,08,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "500000", ",", "\"\<{1997,02,28}\>\"", ",", "940000", ",", 
       "\"\<{2001,05,04}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "500000", ",", "\"\<{1996,11,04}\>\"", ",", "765000", ",", 
       "\"\<{1998,10,02}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "499000", ",", "\"\<{1994,10,19}\>\"", ",", "490000", ",", 
       "\"\<{1997,05,15}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "495000", ",", "\"\<{1989,01,25}\>\"", ",", "550000", ",", 
       "\"\<{1998,04,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "495000", ",", "\"\<{1992,06,16}\>\"", ",", "620000", ",", 
       "\"\<{1999,12,07}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "492000", ",", "\"\<{1993,03,09}\>\"", ",", "903000", ",", 
       "\"\<{2000,01,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "490000", ",", "\"\<{1989,04,03}\>\"", ",", "862500", ",", 
       "\"\<{2000,02,17}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "486000", ",", "\"\<{1988,11,29}\>\"", ",", "573000", ",", 
       "\"\<{1999,06,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "485000", ",", "\"\<{1997,10,02}\>\"", ",", "660000", ",", 
       "\"\<{1999,11,03}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "485000", ",", "\"\<{1988,12,22}\>\"", ",", "545500", ",", 
       "\"\<{1994,04,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "485000", ",", "\"\<{1988,10,21}\>\"", ",", "625000", ",", 
       "\"\<{1999,07,23}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "485000", ",", "\"\<{1996,04,30}\>\"", ",", "700000", ",", 
       "\"\<{2000,03,07}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "485000", ",", "\"\<{1989,05,11}\>\"", ",", "862500", ",", 
       "\"\<{2001,06,13}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "483500", ",", "\"\<{1991,07,11}\>\"", ",", "520000", ",", 
       "\"\<{1994,07,06}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "481000", ",", "\"\<{1989,04,14}\>\"", ",", "750000", ",", 
       "\"\<{2001,01,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "480000", ",", "\"\<{1991,06,14}\>\"", ",", "665000", ",", 
       "\"\<{1998,02,24}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "475000", ",", "\"\<{1989,06,30}\>\"", ",", "379500", ",", 
       "\"\<{1994,07,12}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "475000", ",", "\"\<{1990,11,28}\>\"", ",", "665000", ",", 
       "\"\<{1999,04,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "475000", ",", "\"\<{1991,11,01}\>\"", ",", "610000", ",", 
       "\"\<{1998,06,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "470000", ",", "\"\<{1992,10,05}\>\"", ",", "880000", ",", 
       "\"\<{2001,02,07}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "470000", ",", "\"\<{1989,12,22}\>\"", ",", "308000", ",", 
       "\"\<{1996,03,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "467000", ",", "\"\<{1997,10,23}\>\"", ",", "792500", ",", 
       "\"\<{2000,10,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "465000", ",", "\"\<{1989,01,31}\>\"", ",", "838000", ",", 
       "\"\<{2001,07,09}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "460000", ",", "\"\<{1989,05,31}\>\"", ",", "470000", ",", 
       "\"\<{1997,09,12}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "460000", ",", "\"\<{1989,03,23}\>\"", ",", "519950", ",", 
       "\"\<{1994,12,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "460000", ",", "\"\<{1988,04,15}\>\"", ",", "600000", ",", 
       "\"\<{1992,03,04}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "460000", ",", "\"\<{1987,12,22}\>\"", ",", "650000", ",", 
       "\"\<{1990,02,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "457000", ",", "\"\<{1989,07,13}\>\"", ",", "388500", ",", 
       "\"\<{1997,05,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "451000", ",", "\"\<{1989,07,19}\>\"", ",", "311000", ",", 
       "\"\<{1997,11,26}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "445000", ",", "\"\<{1989,03,22}\>\"", ",", "860000", ",", 
       "\"\<{2000,10,13}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "435000", ",", "\"\<{1994,06,10}\>\"", ",", "770000", ",", 
       "\"\<{1999,08,12}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "435000", ",", "\"\<{1988,07,21}\>\"", ",", "730000", ",", 
       "\"\<{1998,10,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "435000", ",", "\"\<{1991,02,07}\>\"", ",", "375000", ",", 
       "\"\<{1994,12,23}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "434000", ",", "\"\<{1987,10,30}\>\"", ",", "415000", ",", 
       "\"\<{1996,08,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "432500", ",", "\"\<{1990,04,10}\>\"", ",", "479000", ",", 
       "\"\<{1992,08,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "430000", ",", "\"\<{1994,03,15}\>\"", ",", "850000", ",", 
       "\"\<{1999,07,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "430000", ",", "\"\<{1988,09,27}\>\"", ",", "550000", ",", 
       "\"\<{2001,08,01}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "425000", ",", "\"\<{1998,09,09}\>\"", ",", "525000", ",", 
       "\"\<{1999,12,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "425000", ",", "\"\<{1995,05,11}\>\"", ",", "450000", ",", 
       "\"\<{1997,09,24}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "425000", ",", "\"\<{1988,03,30}\>\"", ",", "388000", ",", 
       "\"\<{1990,12,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "422000", ",", "\"\<{1988,11,02}\>\"", ",", "470000", ",", 
       "\"\<{1997,11,19}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "416000", ",", "\"\<{1992,06,26}\>\"", ",", "800000", ",", 
       "\"\<{1998,08,26}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "410000", ",", "\"\<{1992,04,08}\>\"", ",", "850000", ",", 
       "\"\<{1998,06,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "410000", ",", "\"\<{1988,05,27}\>\"", ",", "530000", ",", 
       "\"\<{1997,11,06}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "410000", ",", "\"\<{1995,02,03}\>\"", ",", "510000", ",", 
       "\"\<{1996,12,03}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "410000", ",", "\"\<{1989,04,12}\>\"", ",", "473500", ",", 
       "\"\<{1989,12,06}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "405000", ",", "\"\<{1995,03,23}\>\"", ",", "625000", ",", 
       "\"\<{1997,05,27}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "400000", ",", "\"\<{1988,10,20}\>\"", ",", "430000", ",", 
       "\"\<{1996,11,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "7", ",", "400000", ",", "\"\<{1991,05,03}\>\"", ",", "595000", ",", 
       "\"\<{1999,03,09}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "400000", ",", "\"\<{1987,12,04}\>\"", ",", "485000", ",", 
       "\"\<{1999,06,25}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "397500", ",", "\"\<{1989,03,21}\>\"", ",", "595000", ",", 
       "\"\<{1999,09,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "395000", ",", "\"\<{1988,09,02}\>\"", ",", "448000", ",", 
       "\"\<{1998,11,12}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "390000", ",", "\"\<{1989,04,05}\>\"", ",", "272000", ",", 
       "\"\<{1996,10,04}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "385000", ",", "\"\<{1992,06,08}\>\"", ",", "340000", ",", 
       "\"\<{1992,11,12}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "375000", ",", "\"\<{1988,09,07}\>\"", ",", "445000", ",", 
       "\"\<{1997,09,12}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "375000", ",", "\"\<{1989,06,21}\>\"", ",", "276000", ",", 
       "\"\<{1993,12,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "370000", ",", "\"\<{1992,11,12}\>\"", ",", "790000", ",", 
       "\"\<{2001,05,18}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "365000", ",", "\"\<{1989,12,29}\>\"", ",", "450000", ",", 
       "\"\<{1994,05,06}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "360000", ",", "\"\<{1988,07,15}\>\"", ",", "579000", ",", 
       "\"\<{1998,08,07}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "355000", ",", "\"\<{1993,06,15}\>\"", ",", "535000", ",", 
       "\"\<{1998,10,14}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "350000", ",", "\"\<{1994,10,14}\>\"", ",", "560000", ",", 
       "\"\<{1999,12,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "350000", ",", "\"\<{1998,04,29}\>\"", ",", "685000", ",", 
       "\"\<{2000,06,06}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "340000", ",", "\"\<{1996,10,04}\>\"", ",", "659000", ",", 
       "\"\<{2000,04,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "335000", ",", "\"\<{1989,04,11}\>\"", ",", "360000", ",", 
       "\"\<{1993,07,13}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "329000", ",", "\"\<{1996,07,01}\>\"", ",", "545000", ",", 
       "\"\<{1999,02,02}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "325000", ",", "\"\<{1989,12,15}\>\"", ",", "410000", ",", 
       "\"\<{1998,05,29}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "320000", ",", "\"\<{1988,06,01}\>\"", ",", "875000", ",", 
       "\"\<{1988,11,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "310500", ",", "\"\<{1994,03,31}\>\"", ",", "482500", ",", 
       "\"\<{1999,02,24}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "310000", ",", "\"\<{1993,12,30}\>\"", ",", "940000", ",", 
       "\"\<{2001,05,31}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "310000", ",", "\"\<{1994,06,03}\>\"", ",", "485000", ",", 
       "\"\<{1999,11,10}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "306000", ",", "\"\<{1987,08,05}\>\"", ",", "445000", ",", 
       "\"\<{1988,12,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "300000", ",", "\"\<{1992,08,03}\>\"", ",", "462500", ",", 
       "\"\<{1993,05,28}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "290000", ",", "\"\<{1992,11,13}\>\"", ",", "500000", ",", 
       "\"\<{2000,01,14}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "286000", ",", "\"\<{1988,03,09}\>\"", ",", "365000", ",", 
       "\"\<{1998,08,21}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "260000", ",", "\"\<{1996,09,03}\>\"", ",", "320000", ",", 
       "\"\<{1998,11,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "250000", ",", "\"\<{1994,10,19}\>\"", ",", "454000", ",", 
       "\"\<{1997,12,30}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "230000", ",", "\"\<{1991,09,17}\>\"", ",", "310000", ",", 
       "\"\<{1993,06,17}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "185000", ",", "\"\<{1993,02,24}\>\"", ",", "565000", ",", 
       "\"\<{2000,06,16}\>\"", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1320000", ",", "\"\<{1999,03,23}\>\"", ",", "1325000", ",", 
       "\"\<{2000,08,16}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1300000", ",", "\"\<{1988,05,19}\>\"", ",", "1080000", ",", 
       "\"\<{1992,05,28}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1050000", ",", "\"\<{1997,10,03}\>\"", ",", "1425000", ",", 
       "\"\<{1998,12,29}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "915000", ",", "\"\<{1998,05,20}\>\"", ",", "920000", ",", 
       "\"\<{1999,11,08}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "875000", ",", "\"\<{1995,05,01}\>\"", ",", "1550000", ",", 
       "\"\<{1999,05,05}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "785000", ",", "\"\<{1990,08,16}\>\"", ",", "642030", ",", 
       "\"\<{1996,04,17}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "765000", ",", "\"\<{1989,03,15}\>\"", ",", "738000", ",", 
       "\"\<{1997,08,13}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "750000", ",", "\"\<{1990,11,02}\>\"", ",", "976500", ",", 
       "\"\<{1997,08,14}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "735000", ",", "\"\<{2000,11,28}\>\"", ",", "1195000", ",", 
       "\"\<{2001,05,24}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "725000", ",", "\"\<{1990,05,25}\>\"", ",", "750000", ",", 
       "\"\<{1995,07,13}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "716000", ",", "\"\<{1987,08,26}\>\"", ",", "750000", ",", 
       "\"\<{1993,03,17}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "665000", ",", "\"\<{1996,09,24}\>\"", ",", "1040000", ",", 
       "\"\<{2000,06,01}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "650000", ",", "\"\<{1996,07,03}\>\"", ",", "1030000", ",", 
       "\"\<{1998,01,30}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "644500", ",", "\"\<{1988,07,15}\>\"", ",", "770000", ",", 
       "\"\<{1998,06,01}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "642000", ",", "\"\<{1988,07,13}\>\"", ",", "825000", ",", 
       "\"\<{1998,12,21}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "635000", ",", "\"\<{1994,08,02}\>\"", ",", "827000", ",", 
       "\"\<{1997,12,03}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "630000", ",", "\"\<{1989,12,18}\>\"", ",", "430000", ",", 
       "\"\<{1997,11,18}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "630000", ",", "\"\<{1990,01,25}\>\"", ",", "650000", ",", 
       "\"\<{1997,12,18}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "625000", ",", "\"\<{1998,05,29}\>\"", ",", "665000", ",", 
       "\"\<{1998,09,18}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "625000", ",", "\"\<{1990,06,04}\>\"", ",", "530000", ",", 
       "\"\<{1998,06,26}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "615000", ",", "\"\<{2000,05,08}\>\"", ",", "650000", ",", 
       "\"\<{2000,10,20}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "590000", ",", "\"\<{1998,02,26}\>\"", ",", "800000", ",", 
       "\"\<{1999,09,30}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "586000", ",", "\"\<{1989,04,07}\>\"", ",", "540000", ",", 
       "\"\<{1998,01,14}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "585000", ",", "\"\<{1989,02,24}\>\"", ",", "635000", ",", 
       "\"\<{1998,09,23}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "585000", ",", "\"\<{1991,08,01}\>\"", ",", "570000", ",", 
       "\"\<{1995,09,29}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "582000", ",", "\"\<{1995,01,04}\>\"", ",", "850000", ",", 
       "\"\<{1998,10,07}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "575000", ",", "\"\<{1990,04,11}\>\"", ",", "675000", ",", 
       "\"\<{2000,03,08}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "575000", ",", "\"\<{1990,11,30}\>\"", ",", "530000", ",", 
       "\"\<{1996,06,14}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "560000", ",", "\"\<{1989,05,31}\>\"", ",", "515000", ",", 
       "\"\<{1992,01,03}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "558000", ",", "\"\<{1988,11,30}\>\"", ",", "285000", ",", 
       "\"\<{1995,06,14}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "555000", ",", "\"\<{1992,01,07}\>\"", ",", "680000", ",", 
       "\"\<{1999,05,11}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "540000", ",", "\"\<{1989,11,21}\>\"", ",", "535000", ",", 
       "\"\<{1996,09,27}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "537000", ",", "\"\<{1988,12,30}\>\"", ",", "595000", ",", 
       "\"\<{1989,05,19}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "536000", ",", "\"\<{1988,10,05}\>\"", ",", "569500", ",", 
       "\"\<{1997,08,28}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "530000", ",", "\"\<{1989,07,20}\>\"", ",", "590000", ",", 
       "\"\<{1998,06,19}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "525000", ",", "\"\<{1991,07,12}\>\"", ",", "555000", ",", 
       "\"\<{1996,12,06}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "525000", ",", "\"\<{1991,08,09}\>\"", ",", "475000", ",", 
       "\"\<{1998,05,21}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "519000", ",", "\"\<{1994,05,05}\>\"", ",", "530500", ",", 
       "\"\<{1995,12,11}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "518000", ",", "\"\<{1999,04,21}\>\"", ",", "775000", ",", 
       "\"\<{2000,05,15}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "515000", ",", "\"\<{1995,02,22}\>\"", ",", "625000", ",", 
       "\"\<{1997,07,25}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "510000", ",", "\"\<{1991,09,26}\>\"", ",", "955000", ",", 
       "\"\<{2000,06,06}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "503500", ",", "\"\<{1988,08,23}\>\"", ",", "549000", ",", 
       "\"\<{1994,08,17}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "500000", ",", "\"\<{1998,12,21}\>\"", ",", "730000", ",", 
       "\"\<{2000,04,28}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "500000", ",", "\"\<{1998,12,18}\>\"", ",", "690000", ",", 
       "\"\<{1999,12,23}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "500000", ",", "\"\<{1988,08,09}\>\"", ",", "563000", ",", 
       "\"\<{1997,12,31}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "495000", ",", "\"\<{1989,06,16}\>\"", ",", "780000", ",", 
       "\"\<{2001,01,03}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "495000", ",", "\"\<{1989,01,31}\>\"", ",", "501500", ",", 
       "\"\<{1995,09,15}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "495000", ",", "\"\<{1991,03,21}\>\"", ",", "450000", ",", 
       "\"\<{1997,06,27}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "495000", ",", "\"\<{1990,12,21}\>\"", ",", "640000", ",", 
       "\"\<{1992,04,21}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "490000", ",", "\"\<{1990,08,29}\>\"", ",", "515000", ",", 
       "\"\<{1997,07,02}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "490000", ",", "\"\<{1989,04,04}\>\"", ",", "865000", ",", 
       "\"\<{1999,06,01}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "486000", ",", "\"\<{1990,04,16}\>\"", ",", "429500", ",", 
       "\"\<{1995,04,18}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "485000", ",", "\"\<{1994,05,26}\>\"", ",", "540000", ",", 
       "\"\<{1997,05,02}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "480000", ",", "\"\<{1988,11,02}\>\"", ",", "341000", ",", 
       "\"\<{1998,05,21}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "475000", ",", "\"\<{1989,08,31}\>\"", ",", "607000", ",", 
       "\"\<{1998,03,18}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "465000", ",", "\"\<{1992,06,05}\>\"", ",", "466000", ",", 
       "\"\<{1994,04,29}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "460000", ",", "\"\<{1988,08,15}\>\"", ",", "445000", ",", 
       "\"\<{1995,05,09}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "454500", ",", "\"\<{1988,07,28}\>\"", ",", "539000", ",", 
       "\"\<{1988,10,26}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "440000", ",", "\"\<{1988,10,17}\>\"", ",", "420000", ",", 
       "\"\<{1996,11,21}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "435000", ",", "\"\<{1997,10,31}\>\"", ",", "638000", ",", 
       "\"\<{1999,05,21}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "431000", ",", "\"\<{1995,07,03}\>\"", ",", "550000", ",", 
       "\"\<{1997,08,22}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "430000", ",", "\"\<{1993,12,02}\>\"", ",", "510000", ",", 
       "\"\<{1997,06,13}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "430000", ",", "\"\<{1989,08,01}\>\"", ",", "475000", ",", 
       "\"\<{1990,12,20}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "430000", ",", "\"\<{1992,05,29}\>\"", ",", "482500", ",", 
       "\"\<{1998,10,30}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "430000", ",", "\"\<{1989,02,02}\>\"", ",", "533000", ",", 
       "\"\<{1990,05,25}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "430000", ",", "\"\<{1988,08,23}\>\"", ",", "740000", ",", 
       "\"\<{2000,07,13}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "426000", ",", "\"\<{1989,08,25}\>\"", ",", "302000", ",", 
       "\"\<{1995,06,23}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "426000", ",", "\"\<{1990,07,09}\>\"", ",", "328000", ",", 
       "\"\<{1992,08,11}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "425020", ",", "\"\<{1987,10,30}\>\"", ",", "543000", ",", 
       "\"\<{1989,01,13}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "425000", ",", "\"\<{1988,03,04}\>\"", ",", "366000", ",", 
       "\"\<{1994,03,22}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "420000", ",", "\"\<{1987,09,17}\>\"", ",", "469000", ",", 
       "\"\<{1988,07,22}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "417000", ",", "\"\<{1987,08,17}\>\"", ",", "420000", ",", 
       "\"\<{1994,11,10}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "410000", ",", "\"\<{1990,04,27}\>\"", ",", "380000", ",", 
       "\"\<{1999,03,24}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "405000", ",", "\"\<{1995,10,11}\>\"", ",", "575000", ",", 
       "\"\<{1996,08,08}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "400000", ",", "\"\<{1989,07,20}\>\"", ",", "515000", ",", 
       "\"\<{1992,11,13}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "397000", ",", "\"\<{1989,12,05}\>\"", ",", "480000", ",", 
       "\"\<{2000,04,20}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "395000", ",", "\"\<{1999,02,02}\>\"", ",", "645000", ",", 
       "\"\<{2000,03,22}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "390000", ",", "\"\<{1994,11,30}\>\"", ",", "460000", ",", 
       "\"\<{1997,12,31}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "389500", ",", "\"\<{1989,01,05}\>\"", ",", "425000", ",", 
       "\"\<{1993,06,11}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "385000", ",", "\"\<{1990,10,12}\>\"", ",", "535000", ",", 
       "\"\<{1999,11,12}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "385000", ",", "\"\<{1991,07,25}\>\"", ",", "750000", ",", 
       "\"\<{1998,10,09}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "380000", ",", "\"\<{1988,12,29}\>\"", ",", "405000", ",", 
       "\"\<{1998,06,03}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "375000", ",", "\"\<{1990,01,19}\>\"", ",", "320000", ",", 
       "\"\<{1994,12,30}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "372500", ",", "\"\<{1988,06,16}\>\"", ",", "1100000", ",", 
       "\"\<{2000,06,09}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "365000", ",", "\"\<{1999,01,04}\>\"", ",", "645000", ",", 
       "\"\<{2001,05,22}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "360000", ",", "\"\<{1988,06,14}\>\"", ",", "470000", ",", 
       "\"\<{1990,11,14}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "352500", ",", "\"\<{1996,03,15}\>\"", ",", "630000", ",", 
       "\"\<{1999,05,05}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "350000", ",", "\"\<{1988,03,02}\>\"", ",", "430000", ",", 
       "\"\<{1989,01,13}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "350000", ",", "\"\<{1991,04,12}\>\"", ",", "600000", ",", 
       "\"\<{1994,11,29}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "340000", ",", "\"\<{1994,12,12}\>\"", ",", "400000", ",", 
       "\"\<{1995,04,13}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "335000", ",", "\"\<{1996,06,11}\>\"", ",", "535000", ",", 
       "\"\<{1999,11,18}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "330000", ",", "\"\<{1990,05,30}\>\"", ",", "350000", ",", 
       "\"\<{1990,08,10}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "325000", ",", "\"\<{1988,02,05}\>\"", ",", "440000", ",", 
       "\"\<{1989,05,16}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "315000", ",", "\"\<{1998,08,25}\>\"", ",", "415000", ",", 
       "\"\<{1999,05,28}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "313000", ",", "\"\<{1987,08,25}\>\"", ",", "494000", ",", 
       "\"\<{1999,07,08}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "307000", ",", "\"\<{1987,12,31}\>\"", ",", "435000", ",", 
       "\"\<{1990,06,14}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "307000", ",", "\"\<{1994,04,29}\>\"", ",", "645000", ",", 
       "\"\<{1999,05,07}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "268000", ",", "\"\<{1995,09,29}\>\"", ",", "390000", ",", 
       "\"\<{1996,12,27}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "235000", ",", "\"\<{1991,07,12}\>\"", ",", "220000", ",", 
       "\"\<{1996,04,02}\>\"", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "160000", ",", "\"\<{1993,03,31}\>\"", ",", "200000", ",", 
       "\"\<{1996,11,14}\>\"", ",", "5"}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.39422942325*^9, 3.39423004465625*^9, {3.39423014328125*^9, 
   3.3942301821875*^9}, 3.3942302273125*^9, 3.394230326609375*^9, {
   3.394230395515625*^9, 3.39423041378125*^9}, 3.528635236709502*^9, {
   3.5286352734326024`*^9, 3.5286352826251287`*^9}, {3.528635355810314*^9, 
   3.5286353585884733`*^9}, 3.5286355701875763`*^9},
 CellTags->"compatibility-yes",
 CellLabel->
  "In[106]:=",ExpressionUUID->"cd14217d-6556-48b2-a1c9-2557e645541b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{"sfSaleData", ",", "6"}], "]"}], "//", "TableForm"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
   RowBox[{"FontSize", "\[Rule]", "10"}]}], "]"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.39422942325*^9, 3.39423004465625*^9, {3.39423014328125*^9, 
   3.3942301821875*^9}, 3.3942302273125*^9, 3.394230326609375*^9, {
   3.394230395515625*^9, 3.39423041378125*^9}, 3.528635236709502*^9, {
   3.528635434708827*^9, 3.5286355293582406`*^9}},
 CellTags->"compatibility-yes",
 CellLabel->
  "In[107]:=",ExpressionUUID->"4b140db6-5764-4b8c-a180-f335e0bdc301"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"Area\"\>", "\<\"Sale1\"\>", "\<\"Date1\"\>", "\<\"Sale2\"\>", \
"\<\"Date2\"\>", "\<\"Units\"\>"},
     {"2", "2600000", "\<\"{1993,05,20}\"\>", 
      "1530000", "\<\"{1995,04,28}\"\>", "88"},
     {"2", "3000000", "\<\"{1990,08,10}\"\>", 
      "1770000", "\<\"{1994,07,21}\"\>", "79"},
     {"1", "2650000", "\<\"{1990,07,12}\"\>", 
      "1250000", "\<\"{1994,06,30}\"\>", "78"},
     {"2", "12200000", "\<\"{1989,08,02}\"\>", 
      "13800000", "\<\"{1990,03,16}\"\>", "72"},
     {"2", "1737500", "\<\"{1994,06,30}\"\>", 
      "2150000", "\<\"{1996,05,15}\"\>", "63"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]],
  StripOnInput->False,
  FontFamily->"Times",
  FontSize->10]], "Output",
 CellChangeTimes->{{3.528635466373638*^9, 3.528635529598254*^9}, 
   3.5286373563437386`*^9, 3.5299294837035723`*^9, 3.533063677597842*^9, 
   3.5330720895249767`*^9, 3.53368169821875*^9, 3.533733722055272*^9, 
   3.533753419515625*^9, 3.5395201623270316`*^9, 3.5395211498765163`*^9, 
   3.539522452890044*^9, 3.539523164846766*^9, 3.540125269020089*^9, 
   3.540935098238307*^9, 3.540935429041228*^9, 3.540936036304961*^9, 
   3.540937613833191*^9, 3.540937974853073*^9, 3.541003104624283*^9, 
   3.541599705285661*^9, 3.5432391635393457`*^9, 3.6960758980169897`*^9, 
   3.6962290372077045`*^9, 3.6962316710948324`*^9, 3.6962321882787867`*^9, 
   3.7314209571958256`*^9},
 TextAlignment->Center,
 CellTags->"compatibility-yes",
 CellLabel->
  "Out[107]=",ExpressionUUID->"74d5eb41-a398-432d-887c-e460c7ed55eb"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table ", "TableTitleLabel"],
 StyleBox[
 CounterBox["BookChapterNumber"], "TableTitleLabel"],
 StyleBox[".", "TableTitleLabel"],
 StyleBox[
 CounterBox["TableTitle"], "TableTitleLabel"],
 StyleBox[".\[ThickSpace]\[ThickSpace]\[ThickSpace]", "TableTitleLabel"],
 "First five observations of San Francisco repeat sale observations"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{150.66666666666663`, 10.}, {1., 7.}},
 CellChangeTimes->{{3.528635604515539*^9, 3.528635621205494*^9}},
 TextAlignment->Center,ExpressionUUID->"d6608713-c921-415c-9fc2-c58a52b90c7a"],

Cell["\<\
The first question we can ask is what is the average holding period in days.\
\>", "Text",ExpressionUUID->"a473ba07-158e-4c46-b288-6ce7e689928b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"repsData", "=", 
   RowBox[{"Drop", "[", 
    RowBox[{"sfSaleData", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Needs", "[", "\"\<Calendar`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sfReps", "=", 
   RowBox[{"ToExpression", "[", "repsData", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sale1", "=", 
   RowBox[{"sfReps", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date1", "=", 
   RowBox[{"sfReps", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "3"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sale2", "=", 
   RowBox[{"sfReps", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date2", "=", 
   RowBox[{"sfReps", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "5"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"unitCount", "=", 
   RowBox[{"sfReps", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "6"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hp", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"DayCount", "[", 
      RowBox[{
       RowBox[{"date1", "[", 
        RowBox[{"[", "n", "]"}], "]"}], ",", 
       RowBox[{"date2", "[", 
        RowBox[{"[", "n", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", 
       RowBox[{"Length", "[", "date1", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CellPrint", "[", 
  RowBox[{"TextCell", "[", 
   RowBox[{
    RowBox[{"\"\<Average holding period is \>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"N", "[", 
       RowBox[{"Mean", "[", "hp", "]"}], "]"}], "]"}], "<>", 
     "\"\< days.\>\""}], ",", "\"\<Text\>\""}], "]"}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.52863570593834*^9, 3.5286359278260317`*^9}, {
  3.53307065067968*^9, 3.5330707165604477`*^9}, {3.539522361393811*^9, 
  3.5395223624088693`*^9}, {3.696231376704615*^9, 3.6962313811023145`*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"2f7c28e3-eb17-4c08-b16d-afdab86673ae"],

Cell["Average holding period is 1770.76 days.", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731420957625968*^9},ExpressionUUID->"bbd1a0db-1eb6-462c-8901-\
ca9154b5e20a"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Mean daily return over that period is positive, thus the annualized daily \
return is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["positive", 
    ButtonBox["8",
     BaseStyle->"Hyperlink",
     ButtonData->"endnote8"]], TraditionalForm]],ExpressionUUID->
  "6521ff6e-b615-4650-8c29-8fa1d703e28c"]
}], "Text",
 CellChangeTimes->{{3.528639365314645*^9, 3.5286393672107534`*^9}, {
  3.528639478244104*^9, 
  3.528639478244104*^9}},ExpressionUUID->"914cae40-56f3-4a45-82c8-\
1a11000250b7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"returns", "=", 
   RowBox[{
    FractionBox["1", "hp"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"N", "[", 
        RowBox[{"Log", "[", 
         RowBox[{"sale2", "/", "sale1"}], "]"}], "]"}]], "-", "1"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"CellPrint", "[", 
  RowBox[{"TextCell", "[", 
   RowBox[{
    RowBox[{"\"\<The mean daily return is \>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Mean", "[", "returns", "]"}], " ", "100"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "4"}], "}"}]}], "]"}], "]"}], "<>", 
     "\"\<% and the annualized return is \>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Mean", "[", "returns", "]"}], " ", "100", " ", "365"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", "\"\<%\>\""}], 
    ",", "\"\<Text\>\""}], "]"}], "]"}]}], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5286360221964293`*^9, 3.528636205665923*^9}, {
  3.5330707477832336`*^9, 3.533070959410338*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"ca9b8bff-e419-4a9d-9c9f-eb64cd4d77d1"],

Cell["\<\
The mean daily return is 0.0341% and the annualized return is 12.46%\
\>", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.7314209576560493`*^9},ExpressionUUID->"74be60f1-a9e3-4274-8102-\
61b2947097e1"]
}, Open  ]],

Cell["\<\
Granted this number does not have a great deal of meaning at this point. Even \
as an annual return it does not produce a number of the scale needed to \
attract capital. Do not despair, we shall make good use of this measure and \
the data that produced it later.\
\>", "Text",
 CellChangeTimes->{
  3.528636252573606*^9},ExpressionUUID->"6ec0f882-d65e-4acd-ad9d-\
bc4e5bd8c905"],

Cell["\<\
In Chapter 3 we argued, without concluding why, that people may pay higher \
prices on a per unit basis for smaller properties. This begs the question: If \
prices are higher are they justified by greater returns? Preserving our \
convention of considering 10 units or less small and more than 10 units \
large, it appears that one does obtain a slightly higher return with smaller \
properties. An Excel file showing these computations is included with the \
electronic files for this chapter.\
\>", "Text",
 CellChangeTimes->{{3.528636252573606*^9, 3.528636254058691*^9}, {
  3.5286365473904686`*^9, 
  3.5286366130212226`*^9}},ExpressionUUID->"82f253dc-85a6-4528-9ff9-\
f9262de43fd8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"lgSFreps", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"sfReps", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "6", "]"}], "]"}], ">", "10"}], " ", "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Length", "[", "lgSFreps", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"smSFreps", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"sfReps", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "6", "]"}], "]"}], "<", "11"}], " ", "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Length", "[", "smSFreps", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"annretsmall", "=", 
   RowBox[{"365", " ", 
    RowBox[{"Mean", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["E", 
         RowBox[{"N", "[", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Transpose", "[", "smSFreps", "]"}], "[", 
             RowBox[{"[", "4", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Transpose", "[", "smSFreps", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]], "-", "1"}], 
       ")"}], "/", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"DayCount", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Transpose", "[", "smSFreps", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "[", 
           RowBox[{"[", "n", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Transpose", "[", "smSFreps", "]"}], "[", 
            RowBox[{"[", "5", "]"}], "]"}], "[", 
           RowBox[{"[", "n", "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", "smSFreps", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"annretlarge", "=", 
   RowBox[{"365", " ", 
    RowBox[{"Mean", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["E", 
         RowBox[{"N", "[", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Transpose", "[", "lgSFreps", "]"}], "[", 
             RowBox[{"[", "4", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Transpose", "[", "lgSFreps", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]], "-", "1"}], 
       ")"}], "/", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"DayCount", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Transpose", "[", "lgSFreps", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "[", 
           RowBox[{"[", "n", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Transpose", "[", "lgSFreps", "]"}], "[", 
            RowBox[{"[", "5", "]"}], "]"}], "[", 
           RowBox[{"[", "n", "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", "lgSFreps", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
     "]"}]}]}], ";", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"TextCell", "[", 
    RowBox[{
     RowBox[{"\"\<The annualized return for small properties is \>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"annretsmall", " ", "100"}], "]"}], "<>", 
      "\"\<%. and for large properties is \>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"annretlarge", " ", "100"}], "]"}], "<>", "\"\<%.\>\""}], ",", 
     "\"\<Text\>\""}], "]"}], "]"}]}]}], "Input",
 PageWidth->PaperWidth,
 CellOpen->False,
 CellChangeTimes->{{3.528636307593753*^9, 3.528636330469062*^9}, {
   3.528636388952407*^9, 3.5286364280586433`*^9}, {3.528636462682624*^9, 
   3.5286364889541264`*^9}, 3.528636523727115*^9, {3.5330709845447755`*^9, 
   3.5330711131241302`*^9}, {3.696232487521947*^9, 3.6962325004282513`*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"b5933a58-4398-455f-b1a2-1798685108ab"],

Cell["\<\
The annualized return for small properties is 12.7317%. and for large \
properties is 12.0162%.\
\>", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731420958110256*^9},ExpressionUUID->"098d7478-1a8c-440c-a06c-\
46eb6b11e009"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["BookChapterNumber"],
 ".",
 
 CounterBox["Section"],
 ". Conclusion"
}], "Section",
 CellChangeTimes->{3.531447172614333*^9, 
  3.5314474170873156`*^9},ExpressionUUID->"490f5768-1862-4b83-ae93-\
73bc6a6a9365"],

Cell[TextData[{
 "The real-world analysis of a real estate investment involves many complex \
variables. All of these, to some degree, change constantly due to market \
forces. A clear understanding of how deterministic variables affect \
performance standards permits the analyst to grasp the inner workings of the ",
 StyleBox["npv",
  FontSlant->"Italic"],
 " function, the consequences of changes in the value of the variables and to \
place specific prices on those changes as they become bargaining elements in \
the negotiation."
}], "Text",
 CellChangeTimes->{
  3.528636648399246*^9, {3.540937024362475*^9, 
   3.54093702496651*^9}},ExpressionUUID->"24d15e17-c11f-4d74-bf8f-\
274a5a9956b3"],

Cell["\<\
Using more complex but more realistic growth functions allows one to model \
outcomes specialized for different types of owners or properties subject to \
different constraints in different political jurisdictions.\
\>", "Text",
 CellChangeTimes->{{3.528636648399246*^9, 
  3.528636652536483*^9}},ExpressionUUID->"08a96b93-c243-4cf8-b2f7-\
9668ee2bea42"],

Cell["\<\
Data opportunities abound. The large quantity of Tier II data now available \
offers answers to many questions. Here we just scratch the surface, showing \
the analyst a mere glimpse of what is possible.\
\>", "Text",
 CellChangeTimes->{{3.528636648399246*^9, 
  3.528636653590543*^9}},ExpressionUUID->"8ce12a13-f053-4905-8ffa-\
e0c6e3eb0f55"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Endnotes", "EndnoteSection",
 CellChangeTimes->{{3.5286367790957212`*^9, 
  3.528636780701813*^9}},ExpressionUUID->"95b89186-ffff-496e-8458-\
6c7c239594c4"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "1"], TraditionalForm]],ExpressionUUID->
  "340f7c0e-3685-48e6-86c2-2fc24888e140"],
 "Your author has conducted real estate brokerage over four decades and has \
seen many changes in that time. For instance, while interest rates are at \
record lows as the second edition of this book is being edited, in 1982 they \
were at record highs when the US prime rate reached 21.5%. The sample project \
picks middle ground as an illustration. For the reader willing to make the \
adjustments, entering current information as required to bring the project \
current can be a very useful exercise."
}], "Endnote",
 CellChangeTimes->{{3.528637520627135*^9, 3.5286376538337536`*^9}, {
  3.528637699946391*^9, 3.528637792294673*^9}},
 CellTags->"endnote1",ExpressionUUID->"20fd0ab3-e4db-4278-9ab0-36d21f12ce1a"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]],ExpressionUUID->
  "ee20086b-d60f-4e89-a3ef-572e3e26a64b"],
 "A further simplification is the omission of capital gains taxes imposed by \
various states. Some states have none, some states treat capital gains as \
ordinary income. While it is pure madness to try to include all of these \
variations in a book of this nature, these taxes should not be ignored in \
actual practice. The common phrase \[OpenCurlyDoubleQuote]Consult your tax \
professional before making any decisions about the actual tax ramifications \
of a particular strategy\[CloseCurlyDoubleQuote] will send the average \
investor to someone with software specifically tailored to the situation \
under consideration."
}], "Endnote",
 CellChangeTimes->{{3.5286379110764675`*^9, 3.528638105336578*^9}},
 CellTags->"endnote2",ExpressionUUID->"eac18d39-9587-4776-859a-f8426a010dd4"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "3"], TraditionalForm]],ExpressionUUID->
  "a063cfcd-1a4a-4a57-881c-673d9e11752f"],
 "Many of the relationships described in this section are dependent on the \
way our sample project is described. The most general approach would be \
independent of the construction of any particular example. Our purpose here \
is to strike a balance between theory and practice by using a stylized \
example and illuminate its general meaning."
}], "Endnote",
 CellChangeTimes->{{3.528638281706666*^9, 3.52863829681153*^9}, 
   3.529931216546685*^9},
 CellTags->"endnote3",ExpressionUUID->"0044c38a-8916-4621-9c26-e646fe0299ad"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "4"], TraditionalForm]],ExpressionUUID->
  "b1ed98ad-f775-4f08-bdee-8d233447fd14"],
 "Note that some of the constants combine into other numbers not shown in \
Table 4.1 because Equation 4.4 has been simplified."
}], "Endnote",
 CellChangeTimes->{{3.52863868302062*^9, 3.528638734374557*^9}},
 CellTags->"endnote4",ExpressionUUID->"9f291a3a-bd9b-446d-b1eb-485e8e62e57e"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "5"], TraditionalForm]],ExpressionUUID->
  "bf7e8d2a-3862-4062-99e7-e0adb35814f4"],
 "Further analysis, left to the reader as an exercise, will disclose under \
what conditions our definition of positive leverage is a stronger or weaker \
constraint than the alternate definition for positive leverage, \
capitalization rate > interest rate."
}], "Endnote",
 CellChangeTimes->{{3.528638850953225*^9, 3.528638861239813*^9}},
 CellTags->"endnote5",ExpressionUUID->"b8041afa-ac9b-429b-8795-2f8b97fba472"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "6"], TraditionalForm]],ExpressionUUID->
  "a305e53d-c584-41d0-b420-5e9c96d2ced4"],
 "Economists call this price elasticity, something ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can handle also but is beyond the scope of this work."
}], "Endnote",
 CellChangeTimes->{{3.528638992516322*^9, 3.528639010768366*^9}},
 CellTags->"endnote6",ExpressionUUID->"062a0cc2-b700-403a-b850-8906ec5509df"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "7"], TraditionalForm]],ExpressionUUID->
  "9127bae1-c52c-40e2-9d1c-31b3c2dd1225"],
 "In practice it may be that price reduction is shared between loan amount \
and down payment."
}], "Endnote",
 CellChangeTimes->{{3.5286391148333178`*^9, 3.5286391344434395`*^9}},
 CellTags->"endnote7",ExpressionUUID->"ff704dbe-f98e-47e6-aa34-83c41918d6db"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "8"], TraditionalForm]],ExpressionUUID->
  "66f6bdf9-f28a-4c5f-90c9-701e57db6a40"],
 "Assuming 365 days in a year."
}], "Endnote",
 CellChangeTimes->{{3.5286393773953357`*^9, 3.528639396561432*^9}},
 CellTags->"endnote8",ExpressionUUID->"457aac2b-be6c-4e65-93ce-87197ab5bc19"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "ReferenceSection",
 CellChangeTimes->{{3.5286368066102953`*^9, 
  3.5286368098704815`*^9}},ExpressionUUID->"093a5f0d-7d68-4687-8f5d-\
d04d8ac0fb20"],

Cell[CellGroupData[{

Cell[TextData[{
 "Brown, G. R., & Matysiak, G. A. ",
 StyleBox[" Real Estate Investment, A Capital Market Approach",
  FontVariations->{"Underline"->True}],
 ". Essex, UK: Financial Times Prentice Hall."
}], "Reference",
 CellChangeTimes->{{3.5286368354979477`*^9, 
  3.5286368383871126`*^9}},ExpressionUUID->"925051d4-7a45-4f48-a67c-\
fb3ca78d18fe"],

Cell[TextData[{
 "Brown, R. J. (1998). Evaluating Future Input Assumption Risk. ",
 StyleBox["The Appraisal Journal, 66",
  FontVariations->{"Underline"->True}],
 "(2 ), 118-129",
 "."
}], "Reference",
 CellChangeTimes->{
  3.528636860904401*^9},ExpressionUUID->"d16a69c8-98f1-4c4c-8a6c-\
5a484c1e590d"],

Cell[TextData[{
 "Messner, S. D., Schreiber, I., & Lyon, V. L. ",
 StyleBox["Marketing Investment Real Estate",
  FontVariations->{"Underline"->True}],
 ". Chicago, IL: REALTORS National Marketing Institute",
 "."
}], "Reference",
 CellChangeTimes->{
  3.5286368835416956`*^9},ExpressionUUID->"d4f19c51-1175-41d8-ac78-\
f593d64722f0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "ExerciseSection",
 CellChangeTimes->{{3.5286369540217266`*^9, 
  3.5286369557208242`*^9}},ExpressionUUID->"23e94b10-9abf-4f0c-85c0-\
2fce98a2e708"],

Cell["\<\
Below you see an elaborate interactive module that permits a large number of \
permutations to the model this chapter offers. Input as much of the sample \
project in this chapter as practical, paying close attention to how the \
performance measures change with input changes.\
\>", "Item1Exercise",
 CellChangeTimes->{{3.528639512825082*^9, 3.5286395594457483`*^9}, {
  3.5286395984529796`*^9, 3.5286396467377415`*^9}, {3.5330722340812445`*^9, 
  3.5330722705783324`*^9}},ExpressionUUID->"51448b35-c9dd-4963-ab54-\
c57d39c5b1ff"],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 Evaluatable->False,
 CellOpen->False,
 CellChangeTimes->{{3.533072177279996*^9, 
  3.53307217840606*^9}},ExpressionUUID->"53f58ccf-3135-427f-9fe5-\
b919c3de18f8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npvfct", "[", 
   RowBox[{
   "price_", ",", "cr_", ",", "i_", ",", "ltv_", ",", "valgrowth_", ",", 
    "saleyear_", ",", "salecost_", ",", "r_", ",", 
    RowBox[{"prepay_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Quiet", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "debtservice", ",", " ", "endbalance", ",", "saleprice", ",", "ppmt", 
       ",", "npv", ",", "cf", ",", "cflist", ",", "endcf", ",", "irrfct", ",",
        "time", ",", "irr"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"debtservice", "=", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         FractionBox[
          FractionBox["i", "12"], 
          RowBox[{"1", "-", 
           FractionBox["1", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", 
               FractionBox["i", "12"]}], ")"}], "360"]]}]], ")"}], "  ", 
        "price", " ", "ltv"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"endbalance", "=", 
       RowBox[{
        FractionBox["debtservice", "12"], "  ", 
        RowBox[{
         FractionBox["1", 
          FractionBox["i", "12"]], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", 
               FractionBox["i", "12"]}], ")"}], 
             RowBox[{"360", "-", 
              RowBox[{"(", 
               RowBox[{"saleyear", "*", "12"}], ")"}]}]]}]}], ")"}]}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"ppmt", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"prepay", "===", "1"}], ",", 
         RowBox[{".8", " ", "endbalance", " ", 
          FractionBox["i", "2"]}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"saleyear", "<", "6"}], "&&", 
            RowBox[{"prepay", "===", "2"}]}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"5", "-", 
              RowBox[{"(", 
               RowBox[{"saleyear", "-", "1"}], ")"}]}], "100"], " ", 
            "endbalance"}], ",", "0"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"saleprice", "=", 
       RowBox[{"price", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "valgrowth"}], ")"}], "saleyear"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"npv", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"saleprice", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", "salecost"}], ")"}]}], "-", "endbalance", "-", 
           "ppmt"}], ")"}], "/", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], "saleyear"]}], "+", 
        RowBox[{"(", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "saleyear"], 
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"price", " ", "cr", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "+", "valgrowth"}], ")"}], 
                RowBox[{"n", "-", "1"}]]}], "-", "debtservice"}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "r"}], ")"}], "n"]}], "]"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"price", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "ltv"}], ")"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cf", "[", "n_", "]"}], ":=", 
       RowBox[{
        RowBox[{"price", " ", "cr", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "valgrowth"}], ")"}], 
          RowBox[{"n", "-", "1"}]]}], "-", "debtservice"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cflist", "=", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"cf", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", 
            RowBox[{"saleyear", "-", "1"}]}], "}"}]}], "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"endcf", "=", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"cf", "[", "saleyear", "]"}], ")"}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"saleprice", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", "salecost"}], ")"}]}], "-", "endbalance", "-",
             "ppmt"}], ")"}]}], "}"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"cflist", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"cflist", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"endcf", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"irrfct", "[", 
        RowBox[{
        "p_List", ",", "\[IndentingNewLine]", "t_List", ",", "amount_"}], 
        "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", "q", "}"}], ",", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"q", "/.", "\[InvisibleSpace]", 
             RowBox[{"FindRoot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"p", ".", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["q", "#1"], "&"}], ")"}], "/@", "t"}]}], 
                "\[Equal]", "amount"}], ",", 
               RowBox[{"{", 
                RowBox[{"q", ",", "1.*^-6"}], "}"}]}], "]"}]}], ")"}]}], "-", 
          "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"time", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "1", ",", "saleyear"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"irr", "=", 
       RowBox[{"irrfct", "[", 
        RowBox[{"cflist", ",", "time", ",", 
         RowBox[{"price", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "ltv"}], ")"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"npv", ",", "irr"}], "}"}]}]}], "\[IndentingNewLine]", "]"}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npvfct2", "[", 
   RowBox[{
   "price_", ",", "cr_", ",", "i_", ",", "ltv_", ",", "valgrowth_", ",", 
    "incgrowth_", ",", "saleyear_", ",", "salecost_", ",", "r_", ",", 
    RowBox[{"prepay_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Quiet", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "noi", ",", "debtservice", ",", " ", "endbalance", ",", "saleprice", 
       ",", "ppmt", ",", "npv", ",", "cf", ",", "cflist", ",", "endcf", ",", 
       "irrfct", ",", "time", ",", "irr"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"debtservice", "=", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         FractionBox[
          FractionBox["i", "12"], 
          RowBox[{"1", "-", 
           FractionBox["1", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", 
               FractionBox["i", "12"]}], ")"}], "360"]]}]], ")"}], "  ", 
        "price", " ", "ltv"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"endbalance", "=", 
       RowBox[{
        FractionBox["debtservice", "12"], "  ", 
        RowBox[{
         FractionBox["1", 
          FractionBox["i", "12"]], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", 
               FractionBox["i", "12"]}], ")"}], 
             RowBox[{"360", "-", 
              RowBox[{"(", 
               RowBox[{"saleyear", "*", "12"}], ")"}]}]]}]}], ")"}]}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"ppmt", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"prepay", "===", "1"}], ",", 
         RowBox[{".8", " ", "endbalance", " ", 
          FractionBox["i", "2"]}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"saleyear", "<", "6"}], "&&", 
            RowBox[{"prepay", "===", "2"}]}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"5", "-", 
              RowBox[{"(", 
               RowBox[{"saleyear", "-", "1"}], ")"}]}], "100"], " ", 
            "endbalance"}], ",", "0"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cf", "[", "n_", "]"}], ":=", 
       RowBox[{
        RowBox[{"price", " ", "cr", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "incgrowth"}], ")"}], 
          RowBox[{"n", "-", "1"}]]}], "-", "debtservice"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"saleprice", "=", 
       RowBox[{"price", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "valgrowth"}], ")"}], "saleyear"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"npv", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"saleprice", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", "salecost"}], ")"}]}], "-", "endbalance", "-", 
           "ppmt"}], ")"}], "/", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], "saleyear"]}], "+", 
        RowBox[{"(", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "saleyear"], 
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"price", " ", "cr", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "+", "incgrowth"}], ")"}], 
                RowBox[{"n", "-", "1"}]]}], "-", "debtservice"}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "r"}], ")"}], "n"]}], "]"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"price", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "ltv"}], ")"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cflist", "=", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"cf", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", 
            RowBox[{"saleyear", "-", "1"}]}], "}"}]}], "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"endcf", "=", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"cf", "[", "saleyear", "]"}], ")"}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"saleprice", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", "salecost"}], ")"}]}], "-", "endbalance", "-",
             "ppmt"}], ")"}]}], "}"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"cflist", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"cflist", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"endcf", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"irrfct", "[", 
        RowBox[{
        "p_List", ",", "\[IndentingNewLine]", "t_List", ",", "amount_"}], 
        "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", "q", "}"}], ",", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"q", "/.", "\[InvisibleSpace]", 
             RowBox[{"FindRoot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"p", ".", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["q", "#1"], "&"}], ")"}], "/@", "t"}]}], 
                "\[Equal]", "amount"}], ",", 
               RowBox[{"{", 
                RowBox[{"q", ",", "1.*^-6"}], "}"}]}], "]"}]}], ")"}]}], "-", 
          "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"time", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "1", ",", "saleyear"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"irr", "=", 
       RowBox[{"irrfct", "[", 
        RowBox[{"cflist", ",", "time", ",", 
         RowBox[{"price", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "ltv"}], ")"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"npv", ",", "irr"}], "}"}]}]}], "\[IndentingNewLine]", "]"}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 Evaluatable->False,
 CellOpen->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.449181021671875*^9, 3.4491810415*^9}, 
   3.449194266521*^9, {3.4491944161562*^9, 3.4491944175914*^9}, {
   3.4491944704442*^9, 3.449194523453*^9}, 3.4491949394356003`*^9, {
   3.4491952600312*^9, 3.4491953355196*^9}, {3.449195385892*^9, 
   3.449195622778*^9}, {3.4491956799988003`*^9, 3.4491957246772003`*^9}, {
   3.4491957600268*^9, 3.4491958846864*^9}, {3.4491968510058002`*^9, 
   3.4491968540945997`*^9}, {3.44922688825*^9, 3.449226894640625*^9}, {
   3.449236913078125*^9, 3.449236934453125*^9}, {3.449237354453125*^9, 
   3.4492373678125*^9}, {3.44923741484375*^9, 3.44923744284375*^9}, {
   3.449237744140625*^9, 3.449237793765625*^9}, {3.44923783178125*^9, 
   3.44923787684375*^9}, {3.449237911*^9, 3.44923801453125*^9}, {
   3.44923806028125*^9, 3.449238102734375*^9}, {3.4492381548125*^9, 
   3.4492381551875*^9}, {3.449238348015625*^9, 3.449238406546875*^9}, 
   3.44923848334375*^9, {3.449238616765625*^9, 3.4492386498125*^9}, {
   3.449238718875*^9, 3.44923872528125*^9}, {3.449238814078125*^9, 
   3.449238814828125*^9}, 3.449242137765625*^9, {3.449242668625*^9, 
   3.449242684765625*^9}, 3.45028576742*^9, 3.450285824543*^9, {
   3.533071783809491*^9, 3.5330717883647513`*^9}, {3.533071838619626*^9, 
   3.5330718399817038`*^9}, 3.533071891024623*^9},
 CellID->90239728,ExpressionUUID->"98c80ed3-a6da-464d-8de1-bad55186094f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"npvfct", "[", 
     RowBox[{
     "2490000", ",", ".06", ",", ".06", ",", ".65", ",", ".03", ",", "10", 
      ",", ".06", ",", ".06", ",", 
      RowBox[{"prepay_:", "0"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
  RowBox[{"x1", "=", "x"}], ";", 
  RowBox[{"x2", "=", "x"}], ";", 
  RowBox[{"ch", "=", "0"}], ";"}]], "Input",
 Evaluatable->False,
 CellOpen->False,
 CellChangeTimes->{
  3.35696210375764*^9, 3.450481871152483*^9, {3.4504822118625507`*^9, 
   3.450482212373602*^9}, {3.4504823064810114`*^9, 3.4504823776021233`*^9}},
 CellID->149405049,ExpressionUUID->"338da29f-7d46-46a6-9636-038b34f3bb66"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", 
    RowBox[{"nog", ",", " ", 
     RowBox[{"\"\<numeric\>\"", "&&", "\"\<constant CR\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Deploy", "@", 
      RowBox[{"Pane", "[", 
       RowBox[{
        RowBox[{"Grid", "[", 
         RowBox[{
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"Prepend", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"\"\<Price\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{"price", ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}], ",", "\"\<$10,000.00\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    RowBox[{"price", "+", "10000"}], ",", "cr", ",", "i", ",",
                     "ltv", ",", "valgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Cap Rate\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"cr", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.25%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{"price", ",", 
                    RowBox[{"cr", "+", ".0025"}], ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Interest Rate\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"i", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.50%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{"price", ",", "cr", ",", 
                    RowBox[{"i", "+", ".005"}], ",", "ltv", ",", "valgrowth", 
                    ",", "saleyear", ",", "salecost", ",", "r", ",", 
                    "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<LTV\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"ltv", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<05.00%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{"price", ",", "cr", ",", "i", ",", 
                    RowBox[{"ltv", "+", ".05"}], ",", "valgrowth", ",", 
                    "saleyear", ",", "salecost", ",", "r", ",", "prepay"}], 
                    "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Growth Rate\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"valgrowth", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.50%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{"price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    RowBox[{"valgrowth", "+", ".005"}], ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Holding Period\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", "saleyear", "]"}], ",", 
                    "\"\< yr\>\""}], "]"}], ",", "\"\<1 yr\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", 
                    RowBox[{"saleyear", "+", "1"}], ",", "salecost", ",", "r",
                     ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Sale Cost\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"salecost", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.50%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", 
                    RowBox[{"salecost", "+", ".005"}], ",", "r", ",", 
                    "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Discount Rate\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"r", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.50%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", 
                    RowBox[{"r", "+", ".005"}], ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Net Present Value\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"AccountingForm", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}], ",", "\"\<Last \[CapitalDelta] npv = \>\"", ",", 
                  RowBox[{"ch", "=", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x2", "=", "x1"}], ";", 
                    RowBox[{"x1", "=", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"Chop", "@", 
                    RowBox[{"(", 
                    RowBox[{"x1", "-", "x2"}], ")"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}]}], 
                    ")"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Internal Rate of Return\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"100", " ", 
                    RowBox[{
                    RowBox[{"npvfct", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "3"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}], 
                    ",", "\"\<%\>\""}], "]"}], ",", "\"\< \>\"", ",", 
                  "\"\< \>\""}], "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{
                 "\"\<Variable\>\"", ",", "Italic", ",", "Bold", ",", "Red"}],
                  "]"}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                 "\"\<Value\>\"", ",", "Italic", ",", "Bold", ",", "Red"}], 
                 "]"}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                 "\"\<Plus Increment\>\"", ",", "Italic", ",", "Bold", ",", 
                  "Red"}], "]"}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                 "\"\<NPV \[CapitalDelta]\>\"", ",", "Italic", ",", "Bold", 
                  ",", "Red"}], "]"}]}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Prepayment 1 = 6 months interest on 80% of remaining \
balance \\nPrepayment 2 = 5% yr 1; 4% yr 2, etc. declining to zero yr 6\>\"", 
              ",", "SpanFromLeft", ",", "SpanFromLeft", ",", "SpanFromLeft"}],
              "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"ItemStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "10"}],
              "}"}], "]"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "All"}], ",", 
          RowBox[{"Spacings", "\[Rule]", "2"}], ",", 
          RowBox[{"Alignment", "\[Rule]", "\"\<.\>\""}]}], "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"500", ",", "300"}], "}"}]}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"-", "End"}]}]}], " ", "\"\<Constant CR\>\"", " ", 
        "Numeric", " ", 
        RowBox[{
         RowBox[{"Alternative", "--"}], "--"}]}], "-"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<numeric\>\"", "&&", "\"\<variable CR\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Deploy", "@", 
      RowBox[{"Pane", "[", 
       RowBox[{
        RowBox[{"Grid", "[", 
         RowBox[{
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"Prepend", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"\"\<Price\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{"price", ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}], ",", "\"\<$10,000.00\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    RowBox[{"price", "+", "10000"}], ",", "cr", ",", "i", ",",
                     "ltv", ",", "valgrowth", ",", "incgrowth", ",", 
                    "saleyear", ",", "salecost", ",", "r", ",", "prepay"}], 
                    "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Cap Rate\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"cr", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.25%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{"price", ",", 
                    RowBox[{"cr", "+", ".0025"}], ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Interest Rate\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"i", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.50%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{"price", ",", "cr", ",", 
                    RowBox[{"i", "+", ".005"}], ",", "ltv", ",", "valgrowth", 
                    ",", "incgrowth", ",", "saleyear", ",", "salecost", ",", 
                    "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<LTV\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"ltv", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<05.00%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{"price", ",", "cr", ",", "i", ",", 
                    RowBox[{"ltv", "+", ".05"}], ",", "valgrowth", ",", 
                    "incgrowth", ",", "saleyear", ",", "salecost", ",", "r", 
                    ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Growth Rate\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"valgrowth", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.50%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{"price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    RowBox[{"valgrowth", "+", ".005"}], ",", "incgrowth", ",",
                     "saleyear", ",", "salecost", ",", "r", ",", "prepay"}], 
                    "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Holding Period\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", "saleyear", "]"}], ",", 
                    "\"\< yr\>\""}], "]"}], ",", "\"\<1 yr\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", 
                    RowBox[{"saleyear", "+", "1"}], ",", "salecost", ",", "r",
                     ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Sale Cost\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"salecost", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.50%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    RowBox[{"salecost", "+", ".005"}], ",", "r", ",", 
                    "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Discount Rate\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"r", "*", "100"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    "\"\<%\>\""}], "]"}], ",", "\"\<00.50%\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", 
                    RowBox[{"r", "+", ".005"}], ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Net Present Value\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<$\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"AccountingForm", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}]}], 
                   "]"}], ",", "\"\<Last \[CapitalDelta] npv = \>\"", ",", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"x2", "=", "x1"}], ";", 
                    RowBox[{"x1", "=", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"x1", "-", "x2"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "2"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}]}], 
                   ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"\"\<Internal Rate of Return\>\"", ",", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"PaddedForm", "[", 
                    RowBox[{
                    RowBox[{"100", " ", 
                    RowBox[{
                    RowBox[{"npvfct2", "[", 
                    RowBox[{
                    "price", ",", "cr", ",", "i", ",", "ltv", ",", 
                    "valgrowth", ",", "incgrowth", ",", "saleyear", ",", 
                    "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "3"}], "}"}], ",", 
                    RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}], 
                    ",", "\"\<%\>\""}], "]"}], ",", "\"\< \>\"", ",", 
                  "\"\< \>\""}], "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{
                 "\"\<Variable\>\"", ",", "Italic", ",", "Bold", ",", "Red"}],
                  "]"}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                 "\"\<Value\>\"", ",", "Italic", ",", "Bold", ",", "Red"}], 
                 "]"}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                 "\"\<Plus Increment\>\"", ",", "Italic", ",", "Bold", ",", 
                  "Red"}], "]"}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                 "\"\<NPV \[CapitalDelta]\>\"", ",", "Italic", ",", "Bold", 
                  ",", "Red"}], "]"}]}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Prepayment 1 = 6 months interest on 80% of remaining \
balance \\nPrepayment 2 = 5% yr 1; 4% yr 2, etc. declining to zero yr 6\>\"", 
              ",", "SpanFromLeft", ",", "SpanFromLeft", ",", "SpanFromLeft"}],
              "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"ItemStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "10"}],
              "}"}], "]"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "All"}], ",", 
          RowBox[{"Spacings", "\[Rule]", "2"}], ",", 
          RowBox[{"Alignment", "\[Rule]", "\"\<.\>\""}]}], "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"500", ",", "300"}], "}"}]}]}], "]"}]}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"-", "End"}]}]}], " ", "\"\<Variable CR Numeric\>\"", " ", 
        RowBox[{
         RowBox[{"Alternative", "--"}], "--"}]}], "-"}], "*)"}], 
     "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<graphic\>\"", "&&", "\"\<constant CR\>\""}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"npvfct", "[", 
           RowBox[{
           "price", ",", "cr", ",", "i", ",", "ltv", ",", "valgrowth", ",", 
            "sy", ",", "salecost", ",", "r", ",", "prepay"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"sy", ",", "1", ",", "20", ",", "1"}], "}"}]}], "]"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"InterpolationOrder", "\[Rule]", "3"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<sale year\>\"", ",", "\"\<net present value\>\"", ",", "None", 
          ",", "None"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"500", ",", "300"}], "}"}]}], ",", 
       RowBox[{"ImagePadding", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"70", ",", "20"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"40", ",", "10"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<graphic\>\"", "&&", "\"\<variable CR\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"npvfct2", "[", 
           RowBox[{
           "price", ",", "cr", ",", "i", ",", "ltv", ",", "valgrowth", ",", 
            "incgrowth", ",", "sy", ",", "salecost", ",", "r", ",", 
            "prepay"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"sy", ",", "1", ",", "20", ",", "1"}], "}"}]}], "]"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"InterpolationOrder", "\[Rule]", "3"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<sale year\>\"", ",", "\"\<net present value\>\"", ",", "None", 
          ",", "None"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"500", ",", "300"}], "}"}]}], ",", 
       RowBox[{"ImagePadding", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"70", ",", "20"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"40", ",", "10"}], "}"}]}], "}"}]}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"--", 
      RowBox[{"--", "End"}]}], " ", "nog", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Switch", "--"}], "--"}], "--"}], "--"}]}], "*)"}], 
   "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"price", ",", "2490000", ",", "\"\<price\>\""}], "}"}], 
            ",", "100000", ",", "10000000", ",", "10000", ",", "Slider", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"cr", ",", ".06", ",", "\"\<cap rate\>\""}], "}"}], ",", 
            ".04", ",", ".1", ",", ".0025", ",", "Slider", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}]}], "}"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", ".06", ",", "\"\<interest rate\>\""}], "}"}], 
            ",", ".03", ",", ".1", ",", ".005", ",", "Slider", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}], ",", 
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"ltv", ",", ".65", ",", "\"\<LTV\>\""}], "}"}], ",", 
            ".5", ",", ".8", ",", ".05", ",", "Slider", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}]}], "}"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"valgrowth", ",", ".03", ",", "\"\<value growth\>\""}], 
             "}"}], ",", ".02", ",", ".05", ",", ".005", ",", "Slider", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PaneSelector", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"\"\<numeric\>\"", "&&", "\"\<variable CR\>\""}], 
              "\[Rule]", 
              RowBox[{"Control", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                  "incgrowth", ",", ".02", ",", "\"\<income growth\>\""}], 
                  "}"}], ",", ".02", ",", ".05", ",", ".005", ",", "Slider", 
                 ",", 
                 RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
                 RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}]}], 
             ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\"\<graphic\>\"", "&&", "\"\<variable CR\>\""}], 
              "\[Rule]", 
              RowBox[{"Control", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                  "incgrowth", ",", ".02", ",", "\"\<income growth\>\""}], 
                  "}"}], ",", ".02", ",", ".05", ",", ".005", ",", "Slider", 
                 ",", 
                 RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
                 RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}]}], 
             ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\"\<numeric\>\"", "&&", "\"\<constant CR\>\""}], 
              "\[Rule]", "\"\<\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\"\<graphic\>\"", "&&", "\"\<constant CR\>\""}], 
              "\[Rule]", "\"\<\>\""}]}], "}"}], ",", 
           RowBox[{"Dynamic", "[", "nog", "]"}]}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"salecost", ",", ".06", ",", "\"\<sale costs\>\""}], 
             "}"}], ",", "0", ",", ".08", ",", ".005", ",", "Slider", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"r", ",", ".06", ",", "\"\<discount rate\>\""}], "}"}], 
            ",", ".06", ",", ".2", ",", ".005", ",", "Slider", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}]}], "}"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Control", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"saleyear", ",", "10", ",", "\"\<sale year\>\""}], "}"}], 
           ",", "1", ",", "20", ",", "1", ",", "Slider", ",", 
           RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}], "}"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"prepay", ",", "0", ",", "\"\<prepayment\>\""}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", "PopupMenu", ",", 
            RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Button", "[", 
          RowBox[{"\"\<reset\>\"", ",", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"price", "=", "2490000"}], ";", 
             RowBox[{"cr", "=", ".06"}], ";", 
             RowBox[{"i", "=", ".06"}], ";", 
             RowBox[{"ltv", "=", ".65"}], ";", 
             RowBox[{"valgrowth", "=", ".03"}], ";", 
             RowBox[{"incgrowth", "=", ".02"}], ";", 
             RowBox[{"saleyear", "=", "10"}], ";", 
             RowBox[{"salecost", "=", ".06"}], ";", 
             RowBox[{"r", "=", ".06"}], ";", 
             RowBox[{"prepay", "=", "0"}], ";", 
             RowBox[{"nog", "=", 
              RowBox[{"\"\<numeric\>\"", "&&", "\"\<constant CR\>\""}]}], ";", 
             RowBox[{"x", "=", 
              RowBox[{
               RowBox[{"npvfct", "[", 
                RowBox[{
                "2490000", ",", ".06", ",", ".06", ",", ".65", ",", ".03", 
                 ",", "10", ",", ".06", ",", ".06", ",", 
                 RowBox[{"prepay_:", "0"}]}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ";", 
             RowBox[{"x1", "=", "x"}], ";", 
             RowBox[{"x2", "=", "x"}], ";", 
             RowBox[{"ch", "=", "0"}]}], ")"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{".05", ",", ".05"}], "}"}]}]}], "\[IndentingNewLine]", "]"}], 
   ",", "\[IndentingNewLine]", " ", 
   RowBox[{"Control", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"nog", ",", 
        RowBox[{"\"\<numeric\>\"", "&&", "\"\<constant CR\>\""}], ",", 
        "\"\<growth regime \\n & display\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\"\<numeric\>\"", "&&", "\"\<constant CR\>\""}], "\[Rule]", 
         "\"\<constant CR \\n numeric\>\""}], ",", 
        RowBox[{
         RowBox[{"\"\<numeric\>\"", "&&", "\"\<variable CR\>\""}], "\[Rule]", 
         "\"\<variable CR \\n numeric\>\""}], ",", 
        RowBox[{
         RowBox[{"\"\<graphic\>\"", "&&", "\"\<constant CR\>\""}], "\[Rule]", 
         "\"\<constant CR \\n graphic\>\""}], ",", 
        RowBox[{
         RowBox[{"\"\<graphic\>\"", "&&", "\"\<variable CR\>\""}], "\[Rule]", 
         "\"\<variable CR \\n graphic\>\""}]}], "}"}]}], "}"}], "]"}], ",", 
   RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{
     "price", ",", "cr", ",", "i", ",", "ltv", ",", "valgrowth", ",", 
      "incgrowth", ",", "saleyear", ",", "salecost", ",", "r", ",", "prepay", 
      ",", "nog"}], "}"}]}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 Evaluatable->False,
 CellOpen->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.4494217028660316`*^9, 3.4494218189612317`*^9}, 
   3.4494218746064315`*^9, 3.449421954712432*^9, {3.4494221503520317`*^9, 
   3.449422169649232*^9}, {3.4494222368540316`*^9, 3.4494222557612314`*^9}, {
   3.4494223748048315`*^9, 3.4494224242880316`*^9}, {3.4494224599964314`*^9, 
   3.4494225766844316`*^9}, {3.4494227727764316`*^9, 
   3.4494228105440316`*^9}, {3.4494229187768316`*^9, 
   3.4494229963712316`*^9}, {3.4494230346224318`*^9, 3.449423038990432*^9}, {
   3.4494233258432317`*^9, 3.4494233634080315`*^9}, {3.4495340494969997`*^9, 
   3.449534052271*^9}, {3.449534083701*^9, 3.449534091718*^9}, {
   3.449534123134*^9, 3.449534157299*^9}, {3.449534439383*^9, 
   3.4495344506289997`*^9}, {3.4495348186610003`*^9, 3.449534837472*^9}, {
   3.449581584934*^9, 3.449581609965*^9}, {3.449581683153*^9, 
   3.449581689512*^9}, {3.4495891241800003`*^9, 3.4495891284230003`*^9}, 
   3.449589205752*^9, 3.449589954293*^9, {3.4495903973190002`*^9, 
   3.449590431852*^9}, {3.449591087097*^9, 3.449591103609*^9}, {
   3.449591164829*^9, 3.4495912191540003`*^9}, {3.449591334609*^9, 
   3.4495913656619997`*^9}, 3.449591867705*^9, {3.449591942832*^9, 
   3.449591972385*^9}, {3.449592116976*^9, 3.4495921373199997`*^9}, {
   3.449592334472*^9, 3.449592340226*^9}, 3.449592380097*^9, {
   3.449592443205*^9, 3.44959245908*^9}, {3.44959251006*^9, 
   3.449592516428*^9}, {3.449592884632*^9, 3.449592906189*^9}, {
   3.449597693248*^9, 3.4495977159230003`*^9}, {3.4496387271710324`*^9, 
   3.4496387457662325`*^9}, 3.4496387988062325`*^9, {3.4496388425642323`*^9, 
   3.4496388433442326`*^9}, {3.4496388949958324`*^9, 
   3.4496389800002327`*^9}, {3.4496390759870324`*^9, 
   3.4496391749846325`*^9}, {3.4496392097882323`*^9, 
   3.4496392106930323`*^9}, {3.4496394923666325`*^9, 3.4496395100102324`*^9}, 
   3.4496396559170322`*^9, {3.4496397436202326`*^9, 3.4496397444938326`*^9}, {
   3.449639779671832*^9, 3.4496397874094324`*^9}, {3.449640353471032*^9, 
   3.449640363002632*^9}, {3.4496404112846327`*^9, 3.4496404216274323`*^9}, {
   3.4496405708570323`*^9, 3.4496406053174324`*^9}, {3.4496406615866327`*^9, 
   3.4496407152506323`*^9}, 3.4496407697258325`*^9, {3.4496408130002327`*^9, 
   3.4496408178518324`*^9}, 3.4496409562394323`*^9, {3.449642136114232*^9, 
   3.4496422214774323`*^9}, {3.4496422600406322`*^9, 
   3.4496422843766327`*^9}, {3.4496423183690324`*^9, 
   3.4496423191334324`*^9}, {3.4496425205606327`*^9, 3.4496425629770327`*^9}, 
   3.4496426118050327`*^9, {3.4496427348890324`*^9, 3.4496427651998324`*^9}, {
   3.4496430261878324`*^9, 3.4496430304778323`*^9}, {3.4496433637718325`*^9, 
   3.4496435307698326`*^9}, {3.4496436465998325`*^9, 
   3.4496437426958323`*^9}, {3.4496437846598325`*^9, 
   3.4496437904318323`*^9}, {3.4496439513302326`*^9, 
   3.4496439551210327`*^9}, {3.449947981281518*^9, 3.449947981875287*^9}, {
   3.449948037189557*^9, 3.44994807058125*^9}, {3.449948107473056*^9, 
   3.449948136255227*^9}, 3.4499481913976164`*^9, 3.4499482824005284`*^9, {
   3.4499483124327393`*^9, 3.4499484320928183`*^9}, {3.4499484940948024`*^9, 
   3.4499485523154154`*^9}, 3.449948600145071*^9, {3.449952406891883*^9, 
   3.4499524373459826`*^9}, {3.4499525408336687`*^9, 
   3.4499525494433193`*^9}, {3.4499602573019533`*^9, 
   3.4499602627151537`*^9}, {3.4499603239295535`*^9, 
   3.4499603248187532`*^9}, {3.450139736462*^9, 3.450139758635*^9}, {
   3.450139804126*^9, 3.450139851991*^9}, {3.45014010194*^9, 
   3.450140108249*^9}, 3.450140258025*^9, {3.450140305535*^9, 
   3.45014033369*^9}, {3.4501404103199997`*^9, 3.4501404119189997`*^9}, {
   3.450140504132*^9, 3.4501405285109997`*^9}, 3.450140608391*^9, {
   3.450140785539*^9, 3.4501407858599997`*^9}, 3.45014083634*^9, {
   3.450140888369*^9, 3.45014096583*^9}, 3.450141038112*^9, {
   3.450141074047*^9, 3.4501412029639997`*^9}, 3.4501412669639997`*^9, {
   3.4501413700559998`*^9, 3.450141509936*^9}, {3.45014154719*^9, 
   3.450141616551*^9}, {3.4501419610439997`*^9, 3.450142111427*^9}, {
   3.450142149387*^9, 3.450142161211*^9}, {3.450142248291*^9, 
   3.450142257731*^9}, {3.450142291566*^9, 3.450142299981*^9}, {
   3.450142335373*^9, 3.450142344705*^9}, {3.4501423931800003`*^9, 
   3.450142454219*^9}, 3.450142495763*^9, {3.450142532094*^9, 
   3.4501425372539997`*^9}, {3.450142656012*^9, 3.4501426651549997`*^9}, {
   3.4501427937279997`*^9, 3.450142816157*^9}, {3.450142965929*^9, 
   3.450142974645*^9}, {3.450143046921*^9, 3.450143049316*^9}, 
   3.4501432161619997`*^9, 3.450191598704*^9, 3.450191640333*^9, {
   3.4501917013450003`*^9, 3.450191763475*^9}, {3.4501918344560003`*^9, 
   3.450191891745*^9}, 3.4501924290629997`*^9, 3.450192469638*^9, 
   3.450192517133*^9, {3.450192616976*^9, 3.450192632863*^9}, 
   3.4501927707390003`*^9, 3.450193069171*^9, 3.450204751349*^9, {
   3.450204848189*^9, 3.450204895164*^9}, {3.450205007236*^9, 
   3.450205008255*^9}, 3.450205053961*^9, 3.450205385288*^9, {
   3.450205676166*^9, 3.45020570116*^9}, {3.450205752041*^9, 
   3.450205754691*^9}, {3.450206299547*^9, 3.45020633263*^9}, 
   3.450206390099*^9, 3.45020644824*^9, {3.450206543342*^9, 
   3.450206564698*^9}, {3.450206683354*^9, 3.4502066896359997`*^9}, {
   3.450206886424*^9, 3.450206889064*^9}, {3.450206928053*^9, 
   3.450206930158*^9}, {3.450207623737*^9, 3.4502076422209997`*^9}, 
   3.4502077237860003`*^9, 3.450207985999*^9, 3.4502084984519997`*^9, 
   3.4502244633529997`*^9, 3.450224564439*^9, 3.450278904979*^9, {
   3.450279026748*^9, 3.45027903437*^9}, 3.4502797216619997`*^9, 
   3.4502797735480003`*^9, {3.4502798340030003`*^9, 3.4502798406800003`*^9}, {
   3.450287478549*^9, 3.450287510117*^9}, 3.450287776726*^9, {
   3.450288077929*^9, 3.450288087712*^9}, 3.450288384674*^9, {
   3.4502890433310003`*^9, 3.450289053867*^9}, {3.450289096039*^9, 
   3.450289098251*^9}, 3.450289166593*^9, {3.450289226424*^9, 
   3.45028930905*^9}, {3.4502894716949997`*^9, 3.4502894948710003`*^9}, 
   3.450289782638*^9, 3.4503096686540003`*^9, 3.4503097279820004`*^9, {
   3.450309982641*^9, 3.450309989409*^9}, {3.4503100897139997`*^9, 
   3.450310127016*^9}, {3.450310533113*^9, 3.450310560583*^9}, {
   3.4503109974230003`*^9, 3.450311003207*^9}, {3.450311312093*^9, 
   3.450311321645*^9}, 3.450311473685*^9, 3.4503115103129997`*^9, {
   3.450311811862*^9, 3.450311815217*^9}, 3.450312167385*^9, {
   3.4503128713199997`*^9, 3.450312877197*^9}, {3.45046387459375*^9, 
   3.450463896984375*^9}, {3.450464203265625*^9, 3.450464203453125*^9}, {
   3.4504642674375*^9, 3.45046433721875*^9}, {3.450464640609375*^9, 
   3.45046471240625*^9}, {3.45046482421875*^9, 3.450464928359375*^9}, 
   3.45046497628125*^9, {3.45046500890625*^9, 3.45046503565625*^9}, {
   3.450465154859375*^9, 3.450465168515625*^9}, {3.45046520340625*^9, 
   3.450465245953125*^9}, {3.450465279640625*^9, 3.450465284765625*^9}, {
   3.450465441203125*^9, 3.450465442703125*^9}, {3.4504654748125*^9, 
   3.4504654790625*^9}, {3.450465529875*^9, 3.450465628953125*^9}, {
   3.45046569709375*^9, 3.450465698265625*^9}, {3.4504657325*^9, 
   3.450465733390625*^9}, {3.45046584246875*^9, 3.450465842640625*^9}, {
   3.4504660375625*^9, 3.450466058390625*^9}, {3.45046640265625*^9, 
   3.450466436*^9}, {3.45046663796875*^9, 3.450466670234375*^9}, {
   3.450466937171875*^9, 3.45046693759375*^9}, {3.4504677104375*^9, 
   3.450467746171875*^9}, {3.4504686776875*^9, 3.45046871375*^9}, {
   3.450481849430311*^9, 3.450481853370705*^9}, {3.450481890082376*^9, 
   3.4504820478021464`*^9}, {3.450482112224588*^9, 3.450482190572422*^9}, {
   3.450482228485213*^9, 3.4504822293042946`*^9}, {3.450482521426504*^9, 
   3.4504825215605173`*^9}, {3.4504827373510942`*^9, 3.450482757088068*^9}, {
   3.4504827962139797`*^9, 3.4504828290822663`*^9}, {3.450482878655223*^9, 
   3.45048294803016*^9}, {3.45048305063542*^9, 3.4504830531966753`*^9}, 
   3.450483847104551*^9, {3.4505208139375*^9, 3.450520910328125*^9}, {
   3.4505209496875*^9, 3.450521003015625*^9}, {3.45052103434375*^9, 
   3.4505210749375*^9}, {3.450521109875*^9, 3.4505211178125*^9}, {
   3.450521168921875*^9, 3.45052120421875*^9}, {3.4505212550625*^9, 
   3.45052125690625*^9}, {3.450522833*^9, 3.45052285340625*^9}, {
   3.450522891328125*^9, 3.450522914234375*^9}, {3.450522998953125*^9, 
   3.450523010875*^9}, 3.450523042640625*^9, {3.450530921030976*^9, 
   3.4505309263065033`*^9}, {3.4505309593708096`*^9, 3.450531094461317*^9}, {
   3.45053115399827*^9, 3.4505311545843287`*^9}, 3.450555525211361*^9, 
   3.45055560227007*^9, {3.4536410368152637`*^9, 3.4536411421737986`*^9}, {
   3.453641186004181*^9, 3.453641191456726*^9}, {3.4536412875303326`*^9, 
   3.45364131170975*^9}, {3.4537264804443064`*^9, 3.453726528054596*^9}, {
   3.4541529276594067`*^9, 3.4541529381438484`*^9}},
 CellID->422333253,ExpressionUUID->"8f04a9ea-0439-4909-9bcb-886976201b50"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`cr$$ = 0.06, $CellContext`i$$ = 
    0.06, $CellContext`incgrowth$$ = 0.02, $CellContext`ltv$$ = 
    0.65, $CellContext`nog$$ = And[
    "numeric", "constant CR"], $CellContext`prepay$$ = 
    0, $CellContext`price$$ = 2490000, $CellContext`r$$ = 
    0.06, $CellContext`salecost$$ = 0.06, $CellContext`saleyear$$ = 
    10, $CellContext`valgrowth$$ = 0.03, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`price$$], 2490000, "price"}, 100000, 10000000, 
      10000}, {{
       Hold[$CellContext`cr$$], 0.06, "cap rate"}, 0.04, 0.1, 0.0025}, {{
       Hold[$CellContext`i$$], 0.06, "interest rate"}, 0.03, 0.1, 0.005}, {{
       Hold[$CellContext`ltv$$], 0.65, "LTV"}, 0.5, 0.8, 0.05}, {{
       Hold[$CellContext`valgrowth$$], 0.03, "value growth"}, 0.02, 0.05, 
      0.005}, {{
       Hold[$CellContext`incgrowth$$], 0.02, "income growth"}, 0.02, 0.05, 
      0.005}, {{
       Hold[$CellContext`incgrowth$$], 0.02, "income growth"}, 0.02, 0.05, 
      0.005}, {{
       Hold[$CellContext`salecost$$], 0.06, "sale costs"}, 0, 0.08, 0.005}, {{
       Hold[$CellContext`r$$], 0.06, "discount rate"}, 0.06, 0.2, 0.005}, {{
       Hold[$CellContext`saleyear$$], 10, "sale year"}, 1, 20, 1}, {{
       Hold[$CellContext`prepay$$], 0, "prepayment"}, {0, 1, 2}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1], 
          Manipulate`Place[2]}, {
          Manipulate`Place[3], 
          Manipulate`Place[4]}, {
          Manipulate`Place[5], 
          
          PaneSelector[{
           And["numeric", "variable CR"] -> Manipulate`Place[6], 
            And["graphic", "variable CR"] -> Manipulate`Place[7], 
            And["numeric", "constant CR"] -> "", 
            And["graphic", "constant CR"] -> ""}, 
           Dynamic[$CellContext`nog$$]]}, {
          Manipulate`Place[8], 
          Manipulate`Place[9]}, {
          Manipulate`Place[10]}, {
          Manipulate`Place[11], 
          Button[
          "reset", $CellContext`price$$ = 2490000; $CellContext`cr$$ = 
            0.06; $CellContext`i$$ = 0.06; $CellContext`ltv$$ = 
            0.65; $CellContext`valgrowth$$ = 0.03; $CellContext`incgrowth$$ = 
            0.02; $CellContext`saleyear$$ = 10; $CellContext`salecost$$ = 
            0.06; $CellContext`r$$ = 0.06; $CellContext`prepay$$ = 
            0; $CellContext`nog$$ = 
            And["numeric", "constant CR"]; $CellContext`x = Part[
              $CellContext`npvfct[
              2490000, 0.06, 0.06, 0.65, 0.03, 10, 0.06, 0.06, 
               Optional[
                Pattern[$CellContext`prepay$$, 
                 Blank[]], 0]], 
              1]; $CellContext`x1 = $CellContext`x; $CellContext`x2 = \
$CellContext`x; $CellContext`ch = 0, ImageSize -> Small]}}, Alignment -> Left,
         Spacings -> {0.05, 0.05}]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`nog$$], 
       And["numeric", "constant CR"], "growth regime \n & display"}, {
      And["numeric", "constant CR"] -> "constant CR \n numeric", 
       And["numeric", "variable CR"] -> "variable CR \n numeric", 
       And["graphic", "constant CR"] -> "constant CR \n graphic", 
       And["graphic", "variable CR"] -> "variable CR \n graphic"}}}, 
    Typeset`size$$ = {750., {221., 229.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`price$104$$ = 0, $CellContext`cr$109$$ = 
    0, $CellContext`i$110$$ = 0, $CellContext`ltv$111$$ = 
    0, $CellContext`valgrowth$112$$ = 0, $CellContext`incgrowth$113$$ = 
    0, $CellContext`salecost$114$$ = 0, $CellContext`r$115$$ = 
    0, $CellContext`saleyear$116$$ = 0, $CellContext`prepay$117$$ = 
    0, $CellContext`nog$118$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`cr$$ = 0.06, $CellContext`i$$ = 
        0.06, $CellContext`incgrowth$$ = 0.02, $CellContext`ltv$$ = 
        0.65, $CellContext`nog$$ = 
        And["numeric", "constant CR"], $CellContext`prepay$$ = 
        0, $CellContext`price$$ = 2490000, $CellContext`r$$ = 
        0.06, $CellContext`salecost$$ = 0.06, $CellContext`saleyear$$ = 
        10, $CellContext`valgrowth$$ = 0.03}, "ControllerVariables" :> {
        Hold[$CellContext`price$$, $CellContext`price$104$$, 0], 
        Hold[$CellContext`cr$$, $CellContext`cr$109$$, 0], 
        Hold[$CellContext`i$$, $CellContext`i$110$$, 0], 
        Hold[$CellContext`ltv$$, $CellContext`ltv$111$$, 0], 
        Hold[$CellContext`valgrowth$$, $CellContext`valgrowth$112$$, 0], 
        Hold[$CellContext`incgrowth$$, $CellContext`incgrowth$113$$, 0], 
        Hold[$CellContext`salecost$$, $CellContext`salecost$114$$, 0], 
        Hold[$CellContext`r$$, $CellContext`r$115$$, 0], 
        Hold[$CellContext`saleyear$$, $CellContext`saleyear$116$$, 0], 
        Hold[$CellContext`prepay$$, $CellContext`prepay$117$$, 0], 
        Hold[$CellContext`nog$$, $CellContext`nog$118$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Switch[$CellContext`nog$$, 
        And["numeric", "constant CR"], 
        Deploy[
         Pane[
          Grid[
           Append[
            Prepend[{{"Price", 
               StringJoin["$", 
                ToString[
                 PaddedForm[$CellContext`price$$, {4, 2}, DigitBlock -> 3]]], 
               "$10,000.00", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct[$CellContext`price$$ + 
                    10000, $CellContext`cr$$, $CellContext`i$$, \
$CellContext`ltv$$, $CellContext`valgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]]}, {
              "Cap Rate", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`cr$$ 100, {4, 2}]], "%"], "00.25%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$ + 
                    0.0025, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]]}, {
              "Interest Rate", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`i$$ 100, {4, 2}]], "%"], "00.50%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$ + 
                    0.005, $CellContext`ltv$$, $CellContext`valgrowth$$, \
$CellContext`saleyear$$, $CellContext`salecost$$, $CellContext`r$$, \
$CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]]}, {
              "LTV", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`ltv$$ 100, {4, 2}]], "%"], "05.00%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$ + 
                    0.05, $CellContext`valgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]]}, {
              "Growth Rate", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`valgrowth$$ 100, {4, 2}]], "%"], 
               "00.50%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$ + 
                    0.005, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]]}, {
              "Holding Period", 
               StringJoin[
                ToString[$CellContext`saleyear$$], " yr"], "1 yr", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$ + 
                    1, $CellContext`salecost$$, $CellContext`r$$, \
$CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]]}, {
              "Sale Cost", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`salecost$$ 100, {4, 2}]], "%"], 
               "00.50%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$ + 
                    0.005, $CellContext`r$$, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]]}, {
              "Discount Rate", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`r$$ 100, {4, 2}]], "%"], "00.50%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$ + 0.005, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]]}, {
              "Net Present Value", 
               StringJoin["$", 
                ToString[
                 AccountingForm[
                  Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {8, 2}, DigitBlock -> 3]]], 
               "Last \[CapitalDelta] npv = ", $CellContext`ch = \
($CellContext`x2 = $CellContext`x1; $CellContext`x1 = Part[
                   $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1]; PaddedForm[
                  Chop[$CellContext`x1 - $CellContext`x2], {8, 2}, DigitBlock -> 
                  3])}, {"Internal Rate of Return", 
               StringJoin[
                ToString[
                 PaddedForm[100 Part[
                    $CellContext`npvfct[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 2], {5, 3}, DigitBlock -> 3]], "%"],
                " ", " "}}, {
              Style["Variable", Italic, Bold, Red], 
              Style["Value", Italic, Bold, Red], 
              Style["Plus Increment", Italic, Bold, Red], 
              Style["NPV \[CapitalDelta]", Italic, Bold, Red]}], {
            "Prepayment 1 = 6 months interest on 80% of remaining balance \n\
Prepayment 2 = 5% yr 1; 4% yr 2, etc. declining to zero yr 6", SpanFromLeft, 
             SpanFromLeft, SpanFromLeft}], ItemStyle -> 
           Directive[{FontFamily -> "Times", 10}], Frame -> All, Spacings -> 
           2, Alignment -> "."], ImageSize -> {500, 300}]], 
        And["numeric", "variable CR"], 
        Deploy[
         Pane[
          Grid[
           Append[
            Prepend[{{"Price", 
               StringJoin["$", 
                ToString[
                 PaddedForm[$CellContext`price$$, {4, 2}, DigitBlock -> 3]]], 
               "$10,000.00", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct2[$CellContext`price$$ + 
                    10000, $CellContext`cr$$, $CellContext`i$$, \
$CellContext`ltv$$, $CellContext`valgrowth$$, $CellContext`incgrowth$$, \
$CellContext`saleyear$$, $CellContext`salecost$$, $CellContext`r$$, \
$CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]]}, {"Cap Rate", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`cr$$ 100, {4, 2}]], "%"], "00.25%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$ + 
                    0.0025, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]]}, {"Interest Rate", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`i$$ 100, {4, 2}]], "%"], "00.50%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$ + 
                    0.005, $CellContext`ltv$$, $CellContext`valgrowth$$, \
$CellContext`incgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]]}, {"LTV", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`ltv$$ 100, {4, 2}]], "%"], "05.00%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$ + 
                    0.05, $CellContext`valgrowth$$, $CellContext`incgrowth$$, \
$CellContext`saleyear$$, $CellContext`salecost$$, $CellContext`r$$, \
$CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]]}, {"Growth Rate", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`valgrowth$$ 100, {4, 2}]], "%"], 
               "00.50%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$ + 
                    0.005, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]]}, {"Holding Period", 
               StringJoin[
                ToString[$CellContext`saleyear$$], " yr"], "1 yr", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$ + 
                    1, $CellContext`salecost$$, $CellContext`r$$, \
$CellContext`prepay$$], 1] - Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]]}, {"Sale Cost", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`salecost$$ 100, {4, 2}]], "%"], 
               "00.50%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$ + 0.005, $CellContext`r$$, $CellContext`prepay$$], 1] - 
                  Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]]}, {"Discount Rate", 
               StringJoin[
                ToString[
                 NumberForm[$CellContext`r$$ 100, {4, 2}]], "%"], "00.50%", 
               StringJoin["$", 
                ToString[
                 PaddedForm[Part[
                    $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$ + 0.005, $CellContext`prepay$$], 1] - 
                  Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]]}, {"Net Present Value", 
               StringJoin["$", 
                ToString[
                 AccountingForm[
                  Part[
                   $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1], {8, 2},
                   DigitBlock -> 3]]], 
               "Last \[CapitalDelta] npv = ", $CellContext`x2 = \
$CellContext`x1; $CellContext`x1 = Part[
                  $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 1]; 
               PaddedForm[$CellContext`x1 - $CellContext`x2, {8, 2}, 
                 DigitBlock -> 3]}, {"Internal Rate of Return", 
               StringJoin[
                ToString[
                 PaddedForm[100 Part[
                    $CellContext`npvfct2[$CellContext`price$$, \
$CellContext`cr$$, $CellContext`i$$, $CellContext`ltv$$, \
$CellContext`valgrowth$$, $CellContext`incgrowth$$, $CellContext`saleyear$$, \
$CellContext`salecost$$, $CellContext`r$$, $CellContext`prepay$$], 2], {5, 3},
                   DigitBlock -> 3]], "%"], " ", " "}}, {
              Style["Variable", Italic, Bold, Red], 
              Style["Value", Italic, Bold, Red], 
              Style["Plus Increment", Italic, Bold, Red], 
              Style["NPV \[CapitalDelta]", Italic, Bold, Red]}], {
            "Prepayment 1 = 6 months interest on 80% of remaining balance \n\
Prepayment 2 = 5% yr 1; 4% yr 2, etc. declining to zero yr 6", SpanFromLeft, 
             SpanFromLeft, SpanFromLeft}], ItemStyle -> 
           Directive[{FontFamily -> "Times", 10}], Frame -> All, Spacings -> 
           2, Alignment -> "."], ImageSize -> {500, 300}]], 
        And["graphic", "constant CR"], 
        ListPlot[
         Table[
          Part[
           $CellContext`npvfct[$CellContext`price$$, $CellContext`cr$$, \
$CellContext`i$$, $CellContext`ltv$$, $CellContext`valgrowth$$, \
$CellContext`sy, $CellContext`salecost$$, $CellContext`r$$, \
$CellContext`prepay$$], 1], {$CellContext`sy, 1, 20, 1}], Axes -> False, 
         Joined -> True, InterpolationOrder -> 3, Frame -> True, 
         FrameLabel -> {"sale year", "net present value", None, None}, 
         ImageSize -> {500, 300}, ImagePadding -> {{70, 20}, {40, 10}}], 
        And["graphic", "variable CR"], 
        ListPlot[
         Table[
          Part[
           $CellContext`npvfct2[$CellContext`price$$, $CellContext`cr$$, \
$CellContext`i$$, $CellContext`ltv$$, $CellContext`valgrowth$$, \
$CellContext`incgrowth$$, $CellContext`sy, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$], 1], {$CellContext`sy, 1, 20, 1}], 
         Axes -> False, Joined -> True, InterpolationOrder -> 3, Frame -> 
         True, FrameLabel -> {"sale year", "net present value", None, None}, 
         ImageSize -> {500, 300}, ImagePadding -> {{70, 20}, {40, 10}}]], 
      "Specifications" :> {{{$CellContext`price$$, 2490000, "price"}, 100000, 
         10000000, 10000, ControlType -> Slider, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`cr$$, 0.06, "cap rate"}, 0.04, 0.1, 0.0025, 
         ControlType -> Slider, Appearance -> "Labeled", ImageSize -> Tiny, 
         ControlPlacement -> 2}, {{$CellContext`i$$, 0.06, "interest rate"}, 
         0.03, 0.1, 0.005, ControlType -> Slider, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`ltv$$, 0.65, "LTV"}, 0.5, 0.8, 0.05, ControlType -> 
         Slider, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`valgrowth$$, 0.03, "value growth"}, 0.02, 0.05, 
         0.005, ControlType -> Slider, Appearance -> "Labeled", ImageSize -> 
         Tiny, ControlPlacement -> 
         5}, {{$CellContext`incgrowth$$, 0.02, "income growth"}, 0.02, 0.05, 
         0.005, ControlType -> Slider, Appearance -> "Labeled", ImageSize -> 
         Tiny, ControlPlacement -> 
         6}, {{$CellContext`incgrowth$$, 0.02, "income growth"}, 0.02, 0.05, 
         0.005, ControlType -> Slider, Appearance -> "Labeled", ImageSize -> 
         Tiny, ControlPlacement -> 
         7}, {{$CellContext`salecost$$, 0.06, "sale costs"}, 0, 0.08, 0.005, 
         ControlType -> Slider, Appearance -> "Labeled", ImageSize -> Tiny, 
         ControlPlacement -> 8}, {{$CellContext`r$$, 0.06, "discount rate"}, 
         0.06, 0.2, 0.005, ControlType -> Slider, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         9}, {{$CellContext`saleyear$$, 10, "sale year"}, 1, 20, 1, 
         ControlType -> Slider, Appearance -> "Labeled", ImageSize -> Tiny, 
         ControlPlacement -> 10}, {{$CellContext`prepay$$, 0, "prepayment"}, {
         0, 1, 2}, ControlType -> PopupMenu, ImageSize -> Tiny, 
         ControlPlacement -> 11}, 
        Grid[{{
           Manipulate`Place[1], 
           Manipulate`Place[2]}, {
           Manipulate`Place[3], 
           Manipulate`Place[4]}, {
           Manipulate`Place[5], 
           
           PaneSelector[{
            And["numeric", "variable CR"] -> Manipulate`Place[6], 
             And["graphic", "variable CR"] -> Manipulate`Place[7], 
             And["numeric", "constant CR"] -> "", 
             And["graphic", "constant CR"] -> ""}, 
            Dynamic[$CellContext`nog$$]]}, {
           Manipulate`Place[8], 
           Manipulate`Place[9]}, {
           Manipulate`Place[10]}, {
           Manipulate`Place[11], 
           Button[
           "reset", $CellContext`price$$ = 2490000; $CellContext`cr$$ = 
             0.06; $CellContext`i$$ = 0.06; $CellContext`ltv$$ = 
             0.65; $CellContext`valgrowth$$ = 0.03; $CellContext`incgrowth$$ = 
             0.02; $CellContext`saleyear$$ = 10; $CellContext`salecost$$ = 
             0.06; $CellContext`r$$ = 0.06; $CellContext`prepay$$ = 
             0; $CellContext`nog$$ = 
             And["numeric", "constant CR"]; $CellContext`x = Part[
               $CellContext`npvfct[
               2490000, 0.06, 0.06, 0.65, 0.03, 10, 0.06, 0.06, 
                Optional[
                 Pattern[$CellContext`prepay$$, 
                  Blank[]], 0]], 
               1]; $CellContext`x1 = $CellContext`x; $CellContext`x2 = \
$CellContext`x; $CellContext`ch = 0, ImageSize -> Small]}}, Alignment -> Left,
          Spacings -> {0.05, 0.05}], {{$CellContext`nog$$, 
          And["numeric", "constant CR"], "growth regime \n & display"}, {
         And["numeric", "constant CR"] -> "constant CR \n numeric", 
          And["numeric", "variable CR"] -> "variable CR \n numeric", 
          And["graphic", "constant CR"] -> "constant CR \n graphic", 
          And["graphic", "variable CR"] -> "variable CR \n graphic"}}}, 
      "Options" :> {
       TrackedSymbols :> {$CellContext`price$$, $CellContext`cr$$, \
$CellContext`i$$, $CellContext`ltv$$, $CellContext`valgrowth$$, \
$CellContext`incgrowth$$, $CellContext`saleyear$$, $CellContext`salecost$$, \
$CellContext`r$$, $CellContext`prepay$$, $CellContext`nog$$}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{820., {392., 400.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`npvfct[
         Pattern[$CellContext`price, 
          Blank[]], 
         Pattern[$CellContext`cr, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]], 
         Pattern[$CellContext`ltv, 
          Blank[]], 
         Pattern[$CellContext`valgrowth, 
          Blank[]], 
         Pattern[$CellContext`saleyear, 
          Blank[]], 
         Pattern[$CellContext`salecost, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`prepay, 
           Blank[]], 0]] := Quiet[
         Module[{$CellContext`debtservice, $CellContext`endbalance, \
$CellContext`saleprice, $CellContext`ppmt, $CellContext`npv, $CellContext`cf, \
$CellContext`cflist, $CellContext`endcf, $CellContext`irrfct, \
$CellContext`time, $CellContext`irr}, $CellContext`debtservice = ((
              12 ($CellContext`i/(
               12 (1 - 1/(
                 1 + $CellContext`i/
                  12)^360)))) $CellContext`price) $CellContext`ltv; \
$CellContext`endbalance = ($CellContext`debtservice/
             12) ((1/($CellContext`i/12)) (1 - 
              1/(1 + $CellContext`i/12)^(360 - $CellContext`saleyear 
               12))); $CellContext`ppmt = 
           If[$CellContext`prepay === 
             1, (0.8 $CellContext`endbalance) ($CellContext`i/2), 
             If[
              
              And[$CellContext`saleyear < 6, $CellContext`prepay === 
               2], ((5 - ($CellContext`saleyear - 1))/
               100) $CellContext`endbalance, 
              0]]; $CellContext`saleprice = $CellContext`price (
              1 + $CellContext`valgrowth)^$CellContext`saleyear; \
$CellContext`npv = ($CellContext`saleprice (
                1 - $CellContext`salecost) - $CellContext`endbalance - \
$CellContext`ppmt)/(1 + $CellContext`r)^$CellContext`saleyear + Sum[
              
              Evaluate[(($CellContext`price $CellContext`cr) (
                   1 + $CellContext`valgrowth)^($CellContext`n - 
                   1) - $CellContext`debtservice)/(
                1 + $CellContext`r)^$CellContext`n], {$CellContext`n, 
               1, $CellContext`saleyear}] - $CellContext`price (
             1 - $CellContext`ltv); $CellContext`cf[
             Pattern[$CellContext`n, 
              
              Blank[]]] := ($CellContext`price $CellContext`cr) (
               1 + $CellContext`valgrowth)^($CellContext`n - 
               1) - $CellContext`debtservice; $CellContext`cflist = {
             Table[
              $CellContext`cf[$CellContext`n], {$CellContext`n, 
               1, $CellContext`saleyear - 
               1}]}; $CellContext`endcf = \
{{$CellContext`cf[$CellContext`saleyear] + ($CellContext`saleprice (
                 1 - $CellContext`salecost) - $CellContext`endbalance - \
$CellContext`ppmt)}}; $CellContext`cflist = Join[
             Part[$CellContext`cflist, 1], 
             Part[$CellContext`endcf, 1]]; $CellContext`irrfct[
             Pattern[$CellContext`p, 
              Blank[List]], 
             Pattern[$CellContext`t, 
              Blank[List]], 
             Pattern[$CellContext`amount, 
              Blank[]]] := 
           Module[{$CellContext`q}, 1/ReplaceAll[$CellContext`q, 
               FindRoot[Dot[$CellContext`p, 
                  
                  Map[$CellContext`q^#& , $CellContext`t]] == \
$CellContext`amount, {$CellContext`q, 1.*^-6}]] - 1]; $CellContext`time = 
           Table[$CellContext`t, {$CellContext`t, 
              1, $CellContext`saleyear}]; $CellContext`irr = \
$CellContext`irrfct[$CellContext`cflist, $CellContext`time, \
$CellContext`price (
              1 - $CellContext`ltv)]; {$CellContext`npv, $CellContext`irr}]], \
$CellContext`npv := $CellContext`er/(1 + FE`r$$435)^$CellContext`k + Sum[
          
          Evaluate[$CellContext`cf[$CellContext`n]/(1 + 
            FE`r$$435)^$CellContext`n], {$CellContext`n, 
           1, $CellContext`k}] - $CellContext`dp, $CellContext`er = \
-843381.1350420993 - $CellContext`ppmt + ((
            1 + $CellContext`g)^$CellContext`k ($CellContext`gsi - \
$CellContext`gsi $CellContext`vacrt - $CellContext`exprt ($CellContext`gsi - \
$CellContext`gsi $CellContext`vacrt)))/$CellContext`cro - (((
            1 + $CellContext`g)^$CellContext`k $CellContext`scrt) \
($CellContext`gsi - $CellContext`gsi $CellContext`vacrt - $CellContext`exprt \
($CellContext`gsi - $CellContext`gsi $CellContext`vacrt)))/$CellContext`cro - \
$CellContext`cgrt (-$CellContext`dp - $CellContext`initln + ((
             1 + $CellContext`g)^$CellContext`k ($CellContext`gsi - \
$CellContext`gsi $CellContext`vacrt - $CellContext`exprt ($CellContext`gsi - \
$CellContext`gsi $CellContext`vacrt)))/$CellContext`cro - (((
             1 + $CellContext`g)^$CellContext`k $CellContext`scrt) \
($CellContext`gsi - $CellContext`gsi $CellContext`vacrt - $CellContext`exprt \
($CellContext`gsi - $CellContext`gsi $CellContext`vacrt)))/$CellContext`cro) - \
$CellContext`recaprt $CellContext`accdp[$CellContext`k], $CellContext`accdp[
         Pattern[$CellContext`n, 
          
          Blank[]]] := $CellContext`depn $CellContext`n, $CellContext`depn = \
$CellContext`dprt ($CellContext`dp + $CellContext`initln - ($CellContext`dp + \
$CellContext`initln) $CellContext`land), FE`r$$435 = 0.06, $CellContext`cf[
         Pattern[$CellContext`n, 
          
          Blank[]]] := $CellContext`noi (1 + $CellContext`g)^($CellContext`n - 
           1) - $CellContext`ds - $CellContext`yrtx[$CellContext`n], \
$CellContext`noi = $CellContext`gsi - $CellContext`gsi $CellContext`vacrt - \
$CellContext`exprt ($CellContext`gsi - $CellContext`gsi $CellContext`vacrt), \
$CellContext`ds = (0.72 $CellContext`initln)/(1 - 
        1.06^(-$CellContext`t)), $CellContext`yrtx[
         Pattern[$CellContext`n, 
          
          Blank[]]] := ($CellContext`noi (1 + $CellContext`g)^($CellContext`n - 
            
            1) - $CellContext`int[$CellContext`n] - $CellContext`depn) \
$CellContext`txrt, $CellContext`int[
         Pattern[$CellContext`n, 
          Blank[]]] := 
       ReplaceAll[$CellContext`ds, $CellContext`data] - \
($CellContext`bal[$CellContext`n - 
          1] - $CellContext`bal[$CellContext`n]), $CellContext`data = \
{$CellContext`dp -> 375000, $CellContext`gsi -> 200000, $CellContext`vacrt -> 
         0.1, $CellContext`exprt -> 0.35, $CellContext`txrt -> 
         0.35, $CellContext`dprt -> 0.03636363636363636, $CellContext`land -> 
         0.3, $CellContext`cro -> 0.0936, $CellContext`g -> 0.03, 0.06 -> 
         0.009166666666666667, $CellContext`initln -> 875000, $CellContext`t -> 
         360, 0.06 -> 0.13, $CellContext`k -> 6, $CellContext`scrt -> 
         0.075, $CellContext`cgrt -> 0.15, $CellContext`recaprt -> 
         0.25, $CellContext`ppmt -> 0, $CellContext`units -> 
         22}, $CellContext`units = CompressedData["
1:eJxTTMoPSmJkYGC4zcTAEOHv52FvYW5uZmZmbGxsZAAEejo62pqamhoaGuoq
EKCsrKioAATycjAgKyMjIy0tLSUJBhIoQFxcXExMTBQBROBAGAyEYEAQCQjA
AD8m4EMHvJiAhzLAjQ64cAFOgoCDTMBOPGAb4oCVDgAAXnAldg==
        "], $CellContext`bal[
         Pattern[$CellContext`n$, 
          Blank[]]] := ($CellContext`ds/
         12) ((1 - 1/(1 + FE`i$$435)^($CellContext`t - $CellContext`n$ 12))/
         FE`i$$435), FE`i$$435 = 
       0.06, $CellContext`cflist = {23846.894590797136`, 26063.93740995337, 
        28333.81767229216, 30656.538180096646`, 33031.91871537268, 
        552600.4749914816}, $CellContext`endcf = {{
        552600.4749914816}}, $CellContext`irr = 
       0.1320012717855661, $CellContext`ch = 0, $CellContext`x2 = 
       514436.6327411528, $CellContext`x1 = 
       514436.6327411528, $CellContext`npvfct2[
         Pattern[$CellContext`price, 
          Blank[]], 
         Pattern[$CellContext`cr, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]], 
         Pattern[$CellContext`ltv, 
          Blank[]], 
         Pattern[$CellContext`valgrowth, 
          Blank[]], 
         Pattern[$CellContext`incgrowth, 
          Blank[]], 
         Pattern[$CellContext`saleyear, 
          Blank[]], 
         Pattern[$CellContext`salecost, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`prepay, 
           Blank[]], 0]] := Quiet[
         Module[{$CellContext`noi, $CellContext`debtservice, \
$CellContext`endbalance, $CellContext`saleprice, $CellContext`ppmt, \
$CellContext`npv, $CellContext`cf, $CellContext`cflist, $CellContext`endcf, \
$CellContext`irrfct, $CellContext`time, $CellContext`irr}, \
$CellContext`debtservice = ((
              12 ($CellContext`i/(
               12 (1 - 1/(
                 1 + $CellContext`i/
                  12)^360)))) $CellContext`price) $CellContext`ltv; \
$CellContext`endbalance = ($CellContext`debtservice/
             12) ((1/($CellContext`i/12)) (1 - 
              1/(1 + $CellContext`i/12)^(360 - $CellContext`saleyear 
               12))); $CellContext`ppmt = 
           If[$CellContext`prepay === 
             1, (0.8 $CellContext`endbalance) ($CellContext`i/2), 
             If[
              
              And[$CellContext`saleyear < 6, $CellContext`prepay === 
               2], ((5 - ($CellContext`saleyear - 1))/
               100) $CellContext`endbalance, 0]]; $CellContext`cf[
             Pattern[$CellContext`n, 
              
              Blank[]]] := ($CellContext`price $CellContext`cr) (
               1 + $CellContext`incgrowth)^($CellContext`n - 
               1) - $CellContext`debtservice; $CellContext`saleprice = \
$CellContext`price (
              1 + $CellContext`valgrowth)^$CellContext`saleyear; \
$CellContext`npv = ($CellContext`saleprice (
                1 - $CellContext`salecost) - $CellContext`endbalance - \
$CellContext`ppmt)/(1 + $CellContext`r)^$CellContext`saleyear + Sum[
              
              Evaluate[(($CellContext`price $CellContext`cr) (
                   1 + $CellContext`incgrowth)^($CellContext`n - 
                   1) - $CellContext`debtservice)/(
                1 + $CellContext`r)^$CellContext`n], {$CellContext`n, 
               1, $CellContext`saleyear}] - $CellContext`price (
             1 - $CellContext`ltv); $CellContext`cflist = {
             Table[
              $CellContext`cf[$CellContext`n], {$CellContext`n, 
               1, $CellContext`saleyear - 
               1}]}; $CellContext`endcf = \
{{$CellContext`cf[$CellContext`saleyear] + ($CellContext`saleprice (
                 1 - $CellContext`salecost) - $CellContext`endbalance - \
$CellContext`ppmt)}}; $CellContext`cflist = Join[
             Part[$CellContext`cflist, 1], 
             Part[$CellContext`endcf, 1]]; $CellContext`irrfct[
             Pattern[$CellContext`p, 
              Blank[List]], 
             Pattern[$CellContext`t, 
              Blank[List]], 
             Pattern[$CellContext`amount, 
              Blank[]]] := 
           Module[{$CellContext`q}, 1/ReplaceAll[$CellContext`q, 
               FindRoot[Dot[$CellContext`p, 
                  
                  Map[$CellContext`q^#& , $CellContext`t]] == \
$CellContext`amount, {$CellContext`q, 1.*^-6}]] - 1]; $CellContext`time = 
           Table[$CellContext`t, {$CellContext`t, 
              1, $CellContext`saleyear}]; $CellContext`irr = \
$CellContext`irrfct[$CellContext`cflist, $CellContext`time, \
$CellContext`price (
              1 - $CellContext`ltv)]; {$CellContext`npv, $CellContext`irr}]], \
$CellContext`x = 514436.6327411528}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.533071942171549*^9, 3.5330720904430294`*^9, 
  3.5330721904457493`*^9},
 TextAlignment->Center,ExpressionUUID->"588b7adb-69fb-4f17-a4fd-7b24277533dd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Using Figure 4.14, change the sliders until capital in both scenarios is 1.5 \
times the original. Note the difference in time.\
\>", "Item1Exercise",
 CellChangeTimes->{{3.5286397506666856`*^9, 
  3.5286397881588297`*^9}},ExpressionUUID->"1fa044e5-080b-4853-865d-\
d1d246dca911"],

Cell["\<\
Table 4.3 describes the effect positive or negative leverage has on cash \
flow. Locate the equation or equations among Equations 4.2 through Equations \
4.14 that causes this.\
\>", "Item1Exercise",
 CellChangeTimes->{{3.5286398474572215`*^9, 
  3.528639933583148*^9}},ExpressionUUID->"45a2fcd7-5b8c-4e42-ad59-\
8843a1ba0a79"],

Cell["\<\
Data for San Francisco described in Table 4.6 leads us to believe that the \
average holding period is just less than five years. What would your \
expectation of total return be if holding period averaged ten years? Do you \
think your conclusion would change if you picked a different ten year period? \
How would it change?\
\>", "Item1Exercise",
 CellChangeTimes->{{3.528639942260644*^9, 3.5286400373430824`*^9}, {
  3.5330723698520107`*^9, 
  3.533072376436387*^9}},ExpressionUUID->"e7cbdbff-5c15-4283-9ddd-\
511ef1b68bbd"],

Cell["\<\
As suggested in Endnote 1, find an apartment building presently for sale and \
substitute the marketing information you see into the Excel worksheets \
provided for this chapter. Make equivalent inputs into the module under \
Problem #1 above. The results should be identical. What differences between \
the text illustration and the current market conditions can you identify?\
\>", "Item1Exercise",
 CellChangeTimes->{{3.528639942260644*^9, 3.5286401391789074`*^9}, {
  3.529931238212925*^9, 3.5299312527747574`*^9}, {3.5330724232260637`*^9, 
  3.5330724486915197`*^9}, {3.5395204833743944`*^9, 
  3.539520483712414*^9}},ExpressionUUID->"f8664aa9-36e5-4f3b-8a2c-\
9c8043c12ab7"]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{1280, 637},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{32000, 32000},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{576, 720}},
ShowSelection->True,
ShowCellLabel->False,
CounterAssignments->{{"BookChapterNumber", 4}},
Magnification:>1.5 Inherited,
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Book"}, "Textbook.nb", CharacterEncoding -> 
       "WindowsANSI"]]], 
   Cell[
    StyleData["BookChapterTitle"], FontColor -> GrayLevel[0.5]], 
   Cell[
    StyleData["Section"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["Subsection"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["TableTitle"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["PageBreak"], Editable -> True, CellMargins -> {{0, 0}, {1, 1}},
     CellBracketOptions -> {
     "Color" -> RGBColor[0.500008, 0.500008, 1], "Margins" -> {Inherited, 3}, 
      "Thickness" -> 1, "Widths" -> {5, 5}}, 
    CellElementSpacings -> {"CellMinHeight" -> 1}, 
    ConversionRules :> {"TeX" -> {"\n\n\\pagebreak", 
        $CellContext`NoOutput[], ""}, "HTML" -> {"<br class=\"PageBreak\">", 
        $CellContext`NoOutput[], ""}}, PageBreakAbove -> Automatic, 
    CellSize -> {Automatic, 9.120000000000005}, TabFilling -> "- ", 
    TabSpacings -> 1000, FontSize -> 6, FontColor -> GrayLevel[0.700008]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Hyperlink", StyleDefinitions -> StyleData["Link"]], 
       ContextMenu -> FEPrivate`FrontEndResource["ContextMenus", "Hyperlink"],
        FontVariations -> {"Underline" -> True}, FontColor -> 
       RGBColor[0, 0, 1], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["Hyperlink", "Condensed"], FontSize -> 11], 
      Cell[
       StyleData[
       "Hyperlink", "Printout", StyleDefinitions -> StyleData["Link"]], 
       ContextMenu -> FEPrivate`FrontEndResource["ContextMenus", "Hyperlink"],
        FontVariations -> {"Underline" -> True}, FontColor -> 
       RGBColor[0, 0, 1], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ReferenceSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["ReferenceSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["EndnoteSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["EndnoteSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ExerciseSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["ExerciseSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    StyleData["BookChapterNumber"], Background -> 
    RGBColor[0.9333333333333333, 0.1803921568627451, 0.1411764705882353]], 
   Cell[
    StyleData["EquationNumbered"], CellFrame -> True, CellFrameColor -> 
    RGBColor[0.501961, 0, 0], FontColor -> 
    RGBColor[0.5019607843137255, 0., 0.]], 
   Cell[
    CellGroupData[{
      Cell[
      "Figure", "Subsubsection", FontFamily -> "Times New Roman", FontSize -> 
       12, FontColor -> RGBColor[0, 0, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Figure"], Editable -> False, 
          CellMargins -> {{12, Inherited}, {8, 6}}, CellGroupingRules -> 
          "InputGrouping", ConversionRules :> {"TeX" -> {"\n\\begin{center}", 
              $CellContext`ExtractFigure[], "\n\\end{center}"}}, 
          TaggingRules :> {
           "CounterSettings" -> {"CounterTarget" -> "Style:FigureCaption"}, 
            "ExtraConversionRules" -> {
             "General" -> {
               "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, 
              "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}}, 
          PageBreakAbove -> False, Hyphenation -> True, CounterIncrements -> 
          "Figure", FontFamily -> "Times New Roman", FontSize -> 12, 
          FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["Figure", "Printout"], 
          CellMargins -> {{2, Inherited}, {6, 4}}, Magnification -> 0.8], 
         Cell[
          StyleData["Figure", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, Inherited}, {6, 4}}, Magnification -> 0.8]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FigureCaption"], CellMargins -> {{12, 10}, {6, 2}}, 
          CellGroupingRules -> "OutputGrouping", 
          ConversionRules :> {"TeX" -> {"\n\\caption{", "}"}}, 
          TaggingRules :> {
           "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "Figure"}, 
              "CounterTarget" -> "Cell", "XRefPrefix" -> "Figure"}, 
            "ExtraConversionRules" -> {
             "General" -> {"NestingLevel" -> 90}, 
              "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}}, 
          PageBreakAbove -> False, Hyphenation -> True, CounterIncrements -> 
          "FigureCaption", CounterAssignments -> {{"Nil", 0}}, FontFamily -> 
          "Times New Roman", FontSize -> 12, FontWeight -> "Plain", FontSlant -> 
          "Plain", 
          FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}, 
          FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["FigureCaption", "Printout"], 
          CellMargins -> {{2, 2}, {4, 1}}], 
         Cell[
          StyleData["FigureCaption", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 2}, {4, 1}}, LineSpacing -> {2, 1}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FigureCaptionLabel"], Editable -> False, 
          ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, FontFamily -> "Times New Roman", 
          FontSize -> 12, FontWeight -> "Bold", FontColor -> 
          RGBColor[0, 0, 1]], 
         Cell[
          StyleData["FigureCaptionLabel", "Printout"]], 
         Cell[
          StyleData["FigureCaptionLabel", "DoubleSpacedPrintout"]]}, Open]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell[
      "Tables", "Subsubsection", FontFamily -> "Times New Roman", FontColor -> 
       RGBColor[0, 0, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableTitle"], PageWidth -> 530, 
          CellMargins -> {{12, 10}, {1, 7}}, CellGroupingRules -> 
          "InputGrouping", 
          ConversionRules :> {"TeX" -> {"\n\\caption{", Automatic, "} "}}, 
          TaggingRules :> {
           "ExtraConversionRules" -> {
             "General" -> {
               "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, 
              "TeX" -> {"CellGroupEnvironment" -> "table"}}, 
            "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "TableTitle"}, 
              "CounterTarget" -> "Cell", "XRefPrefix" -> "Table"}}, 
          LineSpacing -> {1, 2}, CounterIncrements -> "TableTitle", 
          FontFamily -> "Times New Roman", FontWeight -> "Plain", FontColor -> 
          RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{40}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableTitle", "Printout"], 
          CellMargins -> {{2, 10}, {1, 5}}, FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["TableTitle", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 10}, {1, 5}}, FontFamily -> "Times New Roman", 
          FontSize -> 10]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableTitleLabel"], Editable -> True, 
          ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, LineSpacing -> {1, 2}, 
          CounterIncrements -> "TableTitleLabel", 
          CounterAssignments -> {{"Nil", 0}}, FontFamily -> "Times New Roman",
           FontWeight -> "Bold", FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{40}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableTitleLabel", "Printout"]], 
         Cell[
          StyleData["TableTitleLabel", "DoubleSpacedPrintout"], FontSize -> 
          10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Table"], Editable -> True, PageWidth -> WindowWidth, 
          CellMargins -> {{12, 10}, {4, 1}}, CellGroupingRules -> 
          "OutputGrouping", 
          ConversionRules :> {
           "TeX" -> {"\n\\begin{tabular}\n", Automatic, "\n\\end{tabular}"}, 
            "HTML" -> {{"", Automatic, ""}, {"", Automatic, ""}}}, 
          TaggingRules :> {
           "ExtraConversionRules" -> {
             "General" -> {"NestingLevel" -> 90}, 
              "TeX" -> {"CellGroupEnvironment" -> "table"}}, 
            "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "TableTitle"}, 
              "CounterTarget" -> "CellGroup"}}, CellHorizontalScrolling -> 
          True, CounterIncrements -> "Table", 
          CounterAssignments -> {{"TableNote", 0}}, FontFamily -> 
          "Times New Roman", FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}}, 
            GridBoxDividers -> {
             "Columns" -> {False, {False}, False}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                AbsoluteThickness[2], {False}, 
                AbsoluteThickness[0.5]}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {"Columns" -> {{
                 Scaled[0.503]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}, GridDefaultElement :> 
            Cell["Data", "TableText"]}], 
         Cell[
          StyleData["Table", "Printout"], PageWidth -> PaperWidth, 
          CellMargins -> {{2, 10}, {3, 1}}], 
         Cell[
          StyleData["Table", "DoubleSpacedPrintout"], PageWidth -> PaperWidth,
           CellMargins -> {{2, 10}, {3, 1}}, FontSize -> 10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableNote"], Editable -> True, 
          CellMargins -> {{12, 10}, {7, -3}}, CellGroupingRules -> 
          "OutputGrouping", ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, 
          TaggingRules :> {
           "CounterSettings" -> {
             "CounterFormat" -> {"Table"}, "CounterTarget" -> "CellGroup"}}, 
          LineSpacing -> {1, 1}, ParagraphSpacing -> {0.3, 0}, 
          CounterIncrements -> "TableNote", FontFamily -> "Times New Roman", 
          FontSize -> 10, FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["TableNote", "Printout"], 
          CellMargins -> {{2, 10}, {5, -2}}], 
         Cell[
          StyleData["TableNote", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 10}, {5, -2}}, LineSpacing -> {2, 1}, FontSize -> 
          9]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Inline Table Styles", "Subsubsubsection", FontFamily -> 
          "Times New Roman", FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableColumnHead"], Editable -> True, 
             ConversionRules :> {
              "TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic, ""}}}, 
             FontFamily -> "Times New Roman", FontSlant -> "Italic", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableColumnHead", "Printout"]], 
            Cell[
             StyleData["TableColumnHead", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableSpanHead"], Editable -> True, 
             ConversionRules :> {
              "TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic, ""}}}, 
             TextAlignment -> Center, FontFamily -> "Times New Roman", 
             FontSlant -> "Italic", FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableSpanHead", "Printout"]], 
            Cell[
             StyleData["TableSpanHead", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableText"], Editable -> True, TextAlignment -> Left, 
             LineSpacing -> {1, 1}, FontFamily -> "Times New Roman", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableText", "Printout"]], 
            Cell[
             StyleData["TableText", "DoubleSpacedPrintout"], 
             LineSpacing -> {2, 1}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableSpanText"], Editable -> True, TextAlignment -> 
             Center, LineSpacing -> {1, 1}, FontFamily -> "Times New Roman", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["TableSpanText", "Printout"]], 
            Cell[
             StyleData["TableSpanText", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          StyleData["TableSubGrid"], FontFamily -> "Times New Roman", 
          FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {{0.1}}, 
              "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.27999999999999997`]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
            Cell["Data", "TableText"]}], 
         Cell[
          StyleData["TableMasterGrid"], FontFamily -> "Times New Roman", 
          FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                 Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.004]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableLineElement"], Editable -> False, 
          CellFrame -> {{0, 0}, {0.5, 0}}, 
          CellElementSpacings -> {"CellMinHeight" -> 1}, 
          ConversionRules :> {"HTML" -> {{"&nbsp;", 
               $CellContext`NoOutput[], ""}, {"", Automatic, ""}}}, 
          CellSize -> {Inherited, 1.25}, TabFilling -> " ", TabSpacings -> 
          1000, FontFamily -> "Times New Roman", FontSize -> 1, FontColor -> 
          RGBColor[0, 0, 1]], 
         Cell[
          StyleData["TableBlankElement"], Editable -> False, 
          CellElementSpacings -> {"CellMinHeight" -> 1}, 
          CellSize -> {Inherited, 1.25}, FontFamily -> "Times New Roman", 
          FontSize -> 1, FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanLeft"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanLeft", "Printout"]], 
            Cell[
             StyleData["SpanLeft", "DoubleSpacedPrintout"], FontSize -> 14]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanCenter"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanCenter", "Printout"]], 
            Cell[
             StyleData["SpanCenter", "DoubleSpacedPrintout"], FontSize -> 
             14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanRight"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanRight", "Printout"]], 
            Cell[
             StyleData["SpanRight", "DoubleSpacedPrintout"], FontSize -> 14]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AppendixSection"], 
             CellMargins -> {{12, 12}, {24, 48}}, FontColor -> 
             GrayLevel[0.5]], 
            Cell[
             StyleData["AppendixSection", "Printout"], 
             CellMargins -> {{12, 12}, {24, 48}}, FontColor -> 
             GrayLevel[0.5]]}, Open]]}, Open]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> "11.3 for Microsoft Windows (64-bit) (March 6, 2018)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"],
PrivateNotebookOptions -> {"NotebookAuthor" -> ""}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "compatibility-yes"->{
  Cell[501507, 10048, 123050, 2945, 28, "Input",ExpressionUUID->"cd14217d-6556-48b2-a1c9-2557e645541b",
   CellOpen->False,
   CellGroupingRules->{GroupTogetherGrouping, 10000.},
   CellTags->"compatibility-yes"],
  Cell[624594, 12998, 712, 17, 28, "Input",ExpressionUUID->"4b140db6-5764-4b8c-a180-f335e0bdc301",
   CellOpen->False,
   CellTags->"compatibility-yes"],
  Cell[625309, 13017, 1989, 44, 139, "Output",ExpressionUUID->"74d5eb41-a398-432d-887c-e460c7ed55eb",
   CellTags->"compatibility-yes"]},
 "endnote1"->{
  Cell[640283, 13441, 864, 15, 97, "Endnote",ExpressionUUID->"20fd0ab3-e4db-4278-9ab0-36d21f12ce1a",
   CellTags->"endnote1"]},
 "endnote2"->{
  Cell[641150, 13458, 939, 16, 97, "Endnote",ExpressionUUID->"eac18d39-9587-4776-859a-f8426a010dd4",
   CellTags->"endnote2"]},
 "endnote3"->{
  Cell[642092, 13476, 678, 13, 74, "Endnote",ExpressionUUID->"0044c38a-8916-4621-9c26-e646fe0299ad",
   CellTags->"endnote3"]},
 "endnote4"->{
  Cell[642773, 13491, 434, 9, 28, "Endnote",ExpressionUUID->"9f291a3a-bd9b-446d-b1eb-485e8e62e57e",
   CellTags->"endnote4"]},
 "endnote5"->{
  Cell[643210, 13502, 565, 11, 51, "Endnote",ExpressionUUID->"b8041afa-ac9b-429b-8795-2f8b97fba472",
   CellTags->"endnote5"]},
 "endnote6"->{
  Cell[643778, 13515, 467, 11, 28, "Endnote",ExpressionUUID->"062a0cc2-b700-403a-b850-8906ec5509df",
   CellTags->"endnote6"]},
 "endnote7"->{
  Cell[644248, 13528, 406, 9, 28, "Endnote",ExpressionUUID->"ff704dbe-f98e-47e6-aa34-83c41918d6db",
   CellTags->"endnote7"]},
 "endnote8"->{
  Cell[644657, 13539, 340, 8, 28, "Endnote",ExpressionUUID->"457aac2b-be6c-4e65-93ce-87197ab5bc19",
   CellTags->"endnote8"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"compatibility-yes", 788340, 16586},
 {"endnote1", 788861, 16596},
 {"endnote2", 789004, 16599},
 {"endnote3", 789147, 16602},
 {"endnote4", 789290, 16605},
 {"endnote5", 789432, 16608},
 {"endnote6", 789575, 16611},
 {"endnote7", 789718, 16614},
 {"endnote8", 789860, 16617}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1510, 35, 312, 5, 232, "BookChapterNumber",ExpressionUUID->"d084675e-1f48-4c27-9aa3-74335a81c878"],
Cell[1825, 42, 183, 2, 194, "BookChapterTitle",ExpressionUUID->"d3362101-4e6d-4195-bf54-4419e2da7fd2"],
Cell[CellGroupData[{
Cell[2033, 48, 299, 4, 56, "Epigraph",ExpressionUUID->"e3cd5e66-09d9-45a2-b054-a1ae1df2e71d"],
Cell[2335, 54, 403, 11, 75, "EpigraphAuthor",ExpressionUUID->"f60ce0ab-7ff3-404e-9901-222e0cfbc57c"]
}, Open  ]],
Cell[2753, 68, 400, 9, 28, "Input",ExpressionUUID->"13c991fd-09dd-4341-8668-ada36b7443a6",
 CellOpen->False],
Cell[CellGroupData[{
Cell[3178, 81, 218, 10, 87, "Section",ExpressionUUID->"501c19dd-a6be-4de3-9eee-0e150f8ad538"],
Cell[3399, 93, 843, 16, 107, "Text",ExpressionUUID->"a767a825-305c-4635-996e-17f7e6211dac"],
Cell[CellGroupData[{
Cell[4267, 113, 288, 6, 27, "Item1",ExpressionUUID->"51242407-7869-4fa3-af21-4843224b0fba"],
Cell[4558, 121, 276, 6, 27, "Item1",ExpressionUUID->"caa0a88d-d4d7-41cc-9a26-fa1d4fde0b76"],
Cell[4837, 129, 201, 3, 27, "Item1",ExpressionUUID->"a9eaccee-4009-439d-a087-9aac08378104"],
Cell[5041, 134, 262, 6, 27, "Item1",ExpressionUUID->"f2adb2dd-d39f-432f-a317-22921dcee4eb"],
Cell[5306, 142, 228, 5, 27, "Item1",ExpressionUUID->"8267b4dc-c169-4fcb-9490-58222f62729e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5571, 152, 293, 12, 51, "Subsection",ExpressionUUID->"c2882114-d9be-4e9f-8be1-3c6ede104d09"],
Cell[5867, 166, 1342, 31, 156, "Text",ExpressionUUID->"caa99c8b-d50e-4bd6-8b55-79a878182ad1"],
Cell[7212, 199, 150, 2, 33, "Text",ExpressionUUID->"07320564-30bc-40d9-ad26-bd73fae49f49"],
Cell[CellGroupData[{
Cell[7387, 205, 693, 16, 70, "Item1",ExpressionUUID->"df6de716-b81a-4ead-a95e-ce326e550e18"],
Cell[8083, 223, 574, 10, 70, "Item1",ExpressionUUID->"f51e2ac0-6197-4d70-9c1c-1e97da5ea34f"],
Cell[8660, 235, 619, 10, 70, "Item1",ExpressionUUID->"e6a2a547-589a-441a-aa58-d5d6d73e86ea"],
Cell[9282, 247, 712, 12, 92, "Item1",ExpressionUUID->"5a064ab7-3b2a-468a-b1d6-f2b9f2910834"]
}, Open  ]],
Cell[10009, 262, 1082, 26, 131, "Text",ExpressionUUID->"ba5d15b0-96b9-408e-b093-cad78018684f"],
Cell[11094, 290, 1014, 20, 107, "Text",ExpressionUUID->"8ae747fa-6a16-4492-b534-43fbf3dd3f60"]
}, Open  ]]
}, Open  ]],
Cell[12135, 314, 1041, 30, 107, "Text",ExpressionUUID->"158c13c7-06d5-476c-b74a-84d4ddb177db"],
Cell[CellGroupData[{
Cell[13201, 348, 342, 12, 87, "Section",ExpressionUUID->"f934f5f0-6b0e-44cd-85ef-501d0795a71e"],
Cell[13546, 362, 178, 3, 33, "Text",ExpressionUUID->"c1df8cd1-7950-4aad-8702-399ae929d640"],
Cell[CellGroupData[{
Cell[13749, 369, 3137, 60, 28, "Input",ExpressionUUID->"3742a61a-2086-4bd6-95c2-68f5481b0609",
 CellOpen->False],
Cell[16889, 431, 3594, 63, 356, "Output",ExpressionUUID->"981521c9-bd72-46c7-bd81-172c4989cb9c"]
}, Open  ]],
Cell[20498, 497, 106, 0, 33, "Text",ExpressionUUID->"8f11489f-264d-48e2-ae1d-0bf88e0be307"],
Cell[CellGroupData[{
Cell[20629, 501, 1721, 34, 28, "Input",ExpressionUUID->"12035555-cf5d-402b-8069-ca3b54680384",
 CellOpen->False],
Cell[22353, 537, 2061, 36, 210, "Output",ExpressionUUID->"b4d5e9b0-1a7d-420b-8fa1-aa0a2480f790"]
}, Open  ]],
Cell[24429, 576, 106, 0, 33, "Text",ExpressionUUID->"9eb85e29-6558-49b1-9d60-b97c0324d8c7"],
Cell[CellGroupData[{
Cell[24560, 580, 2554, 49, 28, "Input",ExpressionUUID->"b916afe2-bb15-45d1-b3b2-e70c3f8d658b",
 CellOpen->False],
Cell[27117, 631, 2672, 47, 210, "Output",ExpressionUUID->"cf90ee9d-6aa2-4e93-85c1-07fb0f8f0eb6"]
}, Open  ]],
Cell[29804, 681, 107, 0, 33, "Text",ExpressionUUID->"7c7b4fbe-453a-4b67-a1f9-346b24b36275"],
Cell[CellGroupData[{
Cell[29936, 685, 2069, 40, 28, "Input",ExpressionUUID->"bae7ae4f-8557-468a-9754-29ac0b406eed",
 CellOpen->False],
Cell[32008, 727, 2146, 38, 186, "Output",ExpressionUUID->"9010f483-4c58-4186-879a-45e3e18ff4fe"]
}, Open  ]],
Cell[34169, 768, 151, 2, 33, "Text",ExpressionUUID->"80664b60-e85e-403b-a51b-c421e72a841c"],
Cell[CellGroupData[{
Cell[34345, 774, 3079, 58, 28, "Input",ExpressionUUID->"c5758b8c-e4e2-4550-a078-ff23152305b6",
 CellOpen->False],
Cell[37427, 834, 3468, 59, 304, "Output",ExpressionUUID->"1113a6eb-01d4-4d11-a2ca-dd8b524cc4cb"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40944, 899, 325, 11, 87, "Section",ExpressionUUID->"aaf1dc06-7e0b-4c7c-b2ed-f23b22deebb8"],
Cell[41272, 912, 204, 5, 33, "Text",ExpressionUUID->"d14d56ac-f9f4-4342-8d32-8ccc64ded481"],
Cell[CellGroupData[{
Cell[41501, 921, 2761, 97, 558, "Input",ExpressionUUID->"173e8461-e5f2-44fc-af02-8e0bd59a6506"],
Cell[44265, 1020, 552, 12, 32, "FigureCaption",ExpressionUUID->"80b30629-ef8b-4f2c-9472-813a44fe734e"]
}, Open  ]],
Cell[44832, 1035, 614, 17, 39, "Text",ExpressionUUID->"647e302b-4a8c-4bc2-ad38-ddc9cae63ef5"],
Cell[CellGroupData[{
Cell[45471, 1056, 3635, 84, 28, "Input",ExpressionUUID->"a972a0b9-dad1-4f32-b51a-c661ae13ee98",
 CellOpen->False],
Cell[49109, 1142, 2756, 52, 259, "Output",ExpressionUUID->"6676e7ec-50da-4453-a941-4a0d9d410e7d"]
}, Open  ]],
Cell[51880, 1197, 561, 13, 33, "TableTitle",ExpressionUUID->"b67f97b7-3715-4a7e-9e0a-19535e9ef2f6"],
Cell[52444, 1212, 768, 19, 83, "Text",ExpressionUUID->"6d6ae692-7bf6-49c0-925d-22be9556b287"],
Cell[53215, 1233, 96, 0, 33, "Text",ExpressionUUID->"8568345f-52b5-4207-9fc1-3da3d2928e94"],
Cell[53314, 1235, 311, 10, 45, "Input",ExpressionUUID->"c16342b1-6496-4c32-b370-05b60b08f4b5",
 Evaluatable->False],
Cell[53628, 1247, 836, 26, 60, "Text",ExpressionUUID->"b904c31f-dc02-4201-95b1-69fd4b4a2bbf"],
Cell[54467, 1275, 87, 0, 33, "Text",ExpressionUUID->"0eb3e066-71aa-4bac-ad4b-ac2f5c48f57d"],
Cell[54557, 1277, 276, 7, 45, "Input",ExpressionUUID->"e795df80-a921-4b60-949d-f47108079e97",
 Evaluatable->False],
Cell[54836, 1286, 271, 7, 35, "Text",ExpressionUUID->"2901b0ff-120a-4879-a49d-4c6323804c41"],
Cell[55110, 1295, 365, 8, 33, "Text",ExpressionUUID->"dd0585c1-d776-4785-bf9c-021ab78c3d18"],
Cell[CellGroupData[{
Cell[55500, 1307, 1076, 26, 28, "Input",ExpressionUUID->"834f2267-b6fd-45ca-bb8b-40e28e39bf4e",
 CellOpen->False],
Cell[56579, 1335, 2463, 62, 162, "Output",ExpressionUUID->"419dbcab-1ab2-45a5-a5e9-8a1122bf04e9"]
}, Open  ]],
Cell[59057, 1400, 571, 13, 33, "TableTitle",ExpressionUUID->"5344b4b2-588e-4441-ac43-4239bd1dd1f2"],
Cell[59631, 1415, 393, 10, 58, "Text",ExpressionUUID->"312b7c98-4490-4e25-9c79-7294faa4e898"],
Cell[CellGroupData[{
Cell[60049, 1429, 906, 22, 28, "Input",ExpressionUUID->"64833465-9531-4b5a-9f3a-d9aacaf1c3df",
 CellOpen->False],
Cell[60958, 1453, 1329, 26, 34, "Print",ExpressionUUID->"eebd1088-1943-4da5-a4cf-7c4a1a367163"],
Cell[62290, 1481, 1368, 27, 34, "Print",ExpressionUUID->"b3751944-c5c8-4def-8fc2-30c93fd55ff9"]
}, Open  ]],
Cell[63673, 1511, 275, 6, 33, "Text",ExpressionUUID->"a3fa0d13-7ed4-4bf1-ae64-222a23f83bc1"],
Cell[63951, 1519, 71, 0, 33, "Text",ExpressionUUID->"5f873c5c-51c3-4cad-8d22-fe984ad6ec3d"],
Cell[64025, 1521, 56801, 705, 497, "Graphics",ExpressionUUID->"5c0f47ed-ee26-4ef6-b65a-7a7a00e869b1"],
Cell[120829, 2228, 552, 12, 32, "FigureCaption",ExpressionUUID->"78e50677-7997-4e11-bc3d-6ebaa2820682"],
Cell[121384, 2242, 13853, 174, 350, "Graphics",ExpressionUUID->"f267ac96-fe35-4a53-a189-853d7ba54d60"],
Cell[135240, 2418, 556, 12, 32, "FigureCaption",ExpressionUUID->"81d29c6f-b0c3-4ecb-b86a-bd7d21d572ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[135833, 2435, 304, 11, 87, "Section",ExpressionUUID->"84aeb17e-b80f-43ee-b81e-f6b28d02a6eb"],
Cell[136140, 2448, 171, 3, 33, "Text",ExpressionUUID->"34fe0024-65e9-46e7-93a6-5cbf7d2137dd"],
Cell[136314, 2453, 328, 7, 33, "Text",ExpressionUUID->"68c785ea-d1f1-46f5-88d9-303cf571c4db"],
Cell[CellGroupData[{
Cell[136667, 2464, 1755, 59, 214, "Input",ExpressionUUID->"a84575d8-7215-4473-89f2-7d6fce540706"],
Cell[138425, 2525, 550, 12, 32, "FigureCaption",ExpressionUUID->"79db8417-6cf7-4410-a5ca-571af17b71dc"]
}, Open  ]],
Cell[138990, 2540, 237, 6, 33, "Text",ExpressionUUID->"835d7a33-2fe7-4734-bb3d-afe20912061b"],
Cell[CellGroupData[{
Cell[139252, 2550, 2432, 62, 28, "Input",ExpressionUUID->"58f08c9f-69c7-4670-a73a-edc24e24470e",
 CellOpen->False],
Cell[141687, 2614, 2728, 55, 330, "Output",ExpressionUUID->"8e64274b-be2e-4d1a-9050-a6a252b1b084"]
}, Open  ]],
Cell[144430, 2672, 236, 5, 35, "Text",ExpressionUUID->"f8cd2ee7-ddad-4546-80c3-d39dea0992a1"],
Cell[CellGroupData[{
Cell[144691, 2681, 230, 5, 45, "Input",ExpressionUUID->"2a7dd540-50a7-41e9-9869-83bc18801339"],
Cell[144924, 2688, 845, 11, 45, "Output",ExpressionUUID->"33987c5d-f497-4a3f-bc09-bdac3fe59bd8"]
}, Open  ]],
Cell[145784, 2702, 396, 7, 60, "Text",ExpressionUUID->"b831eb13-9b0d-4051-a9e2-3335f3008c18"],
Cell[CellGroupData[{
Cell[146205, 2713, 636, 15, 74, "Input",ExpressionUUID->"c5a70aef-f4ec-4cfe-a657-ad58ed7e610b"],
Cell[146844, 2730, 1534, 36, 162, "Output",ExpressionUUID->"f84011aa-30d6-4bef-bb07-cc5ec1eca147"]
}, Open  ]],
Cell[148393, 2769, 179, 3, 33, "Text",ExpressionUUID->"daf01f6a-0db0-4736-8785-bb5527983bea"],
Cell[CellGroupData[{
Cell[148597, 2776, 184, 4, 45, "Input",ExpressionUUID->"ac0ee380-17e5-4446-a581-69f54532e936"],
Cell[148784, 2782, 862, 12, 45, "Output",ExpressionUUID->"990b6772-bbc1-4b13-bee7-e579147c0bea"]
}, Open  ]],
Cell[149661, 2797, 1014, 26, 113, "Text",ExpressionUUID->"9d92a758-8c0c-41e7-9c2f-2c8ae90ebe24"],
Cell[CellGroupData[{
Cell[150700, 2827, 285, 5, 45, "Input",ExpressionUUID->"b8c07901-cde4-47c3-b33c-873e7536cc8e"],
Cell[150988, 2834, 837, 11, 45, "Output",ExpressionUUID->"b6253fe5-fbe7-4ce3-b8b3-4f31e0fc0f8b"]
}, Open  ]],
Cell[151840, 2848, 2146, 50, 232, "Text",ExpressionUUID->"1488cbf9-8c65-487d-8672-7b1fd0e48ab1"],
Cell[153989, 2900, 36085, 449, 503, "Graphics",ExpressionUUID->"afe76573-9407-4e6b-a5b1-2c93f3e7bf2a"],
Cell[190077, 3351, 547, 12, 32, "FigureCaption",ExpressionUUID->"9f0bc178-6fae-411c-833a-e0d109ce405e"],
Cell[190627, 3365, 529, 9, 58, "Text",ExpressionUUID->"9f05bb1b-e6ee-49bb-aeef-106616187109"],
Cell[CellGroupData[{
Cell[191181, 3378, 303, 6, 45, "Input",ExpressionUUID->"79e3b415-7ed3-40b7-b8fb-0cbd4c01a3dd"],
Cell[191487, 3386, 827, 11, 45, "Output",ExpressionUUID->"f192e523-8f79-448b-bf21-978baba875c7"]
}, Open  ]],
Cell[192329, 3400, 921, 17, 131, "Text",ExpressionUUID->"4922c5be-fcfe-4a53-ac3e-cd985337dae6"],
Cell[CellGroupData[{
Cell[193275, 3421, 624, 13, 45, "Input",ExpressionUUID->"5bbd8293-f2e1-44cd-9aa8-26d6d120dbc2"],
Cell[193902, 3436, 1211, 24, 45, "Output",ExpressionUUID->"16ff2924-243a-44d5-8098-c473cc5f6fc9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[195162, 3466, 306, 11, 87, "Section",ExpressionUUID->"039b09af-de90-4794-b425-df1e4d74d61a"],
Cell[195471, 3479, 308, 7, 33, "Text",ExpressionUUID->"5f0fedf1-6812-4540-8110-b25d4384d6ec"],
Cell[CellGroupData[{
Cell[195804, 3490, 982, 31, 169, "Input",ExpressionUUID->"b4ed6779-ef9b-4084-831a-3623261a0d5f"],
Cell[196789, 3523, 552, 12, 32, "FigureCaption",ExpressionUUID->"dfd5b5f3-6a82-48c5-8797-f773f913e548"]
}, Open  ]],
Cell[197356, 3538, 505, 11, 84, "Text",ExpressionUUID->"7939cd26-53e7-49ef-a8f0-b5bebd001e2a"],
Cell[CellGroupData[{
Cell[197886, 3553, 294, 7, 74, "Input",ExpressionUUID->"7ace3c26-b6fa-4232-b176-c729806df117"],
Cell[198183, 3562, 829, 11, 45, "Output",ExpressionUUID->"6b22a398-2d3d-40c3-85e8-cc9be0df0c54"]
}, Open  ]],
Cell[199027, 3576, 1267, 25, 136, "Text",ExpressionUUID->"9d098fcc-b232-4f95-a1ce-495d78bb2538"],
Cell[200297, 3603, 671, 11, 82, "Text",ExpressionUUID->"fbf83167-a184-442d-8721-a042dd5389fb"],
Cell[200971, 3616, 41171, 512, 662, "Graphics",ExpressionUUID->"2dbdc4ff-6cff-40a2-9264-6f598d7e55e0"],
Cell[242145, 4130, 544, 12, 32, "FigureCaption",ExpressionUUID->"69df0030-c5c2-490d-80c3-82ea414da7fc"],
Cell[242692, 4144, 456, 11, 35, "Text",ExpressionUUID->"a3303430-81ed-419e-aa0d-3237e9c83de6"],
Cell[CellGroupData[{
Cell[243173, 4159, 133, 2, 45, "Input",ExpressionUUID->"00c60968-a4f9-4962-ad4c-617dbc4619bb"],
Cell[243309, 4163, 817, 11, 45, "Output",ExpressionUUID->"0a5148c2-30e0-4393-8ac8-98464423ef91"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[244175, 4180, 303, 11, 87, "Section",ExpressionUUID->"c45a02c1-050a-4857-a212-22692180be17"],
Cell[244481, 4193, 588, 14, 60, "Text",ExpressionUUID->"868fbcce-93af-4630-8176-8d4654ef0965"],
Cell[245072, 4209, 635, 21, 105, "EquationNumbered",ExpressionUUID->"0b021aae-4ba5-427a-8bd3-1164bdabd1b4"],
Cell[245710, 4232, 654, 21, 28, "Input",ExpressionUUID->"2732839e-3362-4b57-b006-c6c8a24c78dd",
 CellOpen->False],
Cell[246367, 4255, 327, 9, 33, "Text",ExpressionUUID->"fc509b19-59c2-4fbd-a616-fa745f7412b2"],
Cell[CellGroupData[{
Cell[246719, 4268, 134, 2, 45, "Input",ExpressionUUID->"7f8a9778-4ad9-4f3e-b2ca-1c6e06f3ca6e"],
Cell[246856, 4272, 859, 13, 45, "Output",ExpressionUUID->"734d778f-d759-4dc9-98f8-a5fedf94894d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[247752, 4290, 12098, 204, 194, "Text",ExpressionUUID->"bbd4abea-dc25-41d1-a90d-c77022568533"],
Cell[259853, 4496, 581, 13, 32, "FigureCaption",ExpressionUUID->"1a943f47-9d6e-4562-84dc-5d49a8b94b2a"]
}, Open  ]],
Cell[260449, 4512, 582, 12, 82, "Text",ExpressionUUID->"d6a9ca38-59a9-4bc4-919a-9f979a183714"]
}, Open  ]],
Cell[CellGroupData[{
Cell[261068, 4529, 333, 12, 87, "Section",ExpressionUUID->"648ab817-ebe3-40fd-a5cb-8e8a1334f172"],
Cell[261404, 4543, 1359, 35, 112, "Text",ExpressionUUID->"0e4fbc87-070d-44b4-af1f-11b84399e7c3"],
Cell[262766, 4580, 247, 4, 33, "Text",ExpressionUUID->"36ba7315-e84f-4531-ba3b-604486fbcb85"],
Cell[263016, 4586, 313, 9, 103, "EquationNumbered",ExpressionUUID->"0200d7fe-3daf-4cee-99ea-72c5d4471f12"],
Cell[263332, 4597, 696, 17, 86, "Text",ExpressionUUID->"62ff39e9-69e0-42ec-9c53-4cd2f0f567ca"],
Cell[CellGroupData[{
Cell[264053, 4618, 108, 1, 45, "Input",ExpressionUUID->"0640e802-6cbb-4288-b619-af6c7a17a101"],
Cell[264164, 4621, 849, 13, 77, "Output",ExpressionUUID->"3e7ae65a-f573-4fac-a61f-3a6c2b66e4bf"]
}, Open  ]],
Cell[265028, 4637, 240, 5, 35, "Text",ExpressionUUID->"9e71b58f-587d-4ba0-97bf-b12940068e77"],
Cell[265271, 4644, 778, 21, 62, "Text",ExpressionUUID->"5f09a23c-731d-4535-8b18-1a89238305dc"],
Cell[266052, 4667, 259, 7, 28, "Input",ExpressionUUID->"2ca4c316-401b-453d-8f55-d96021329449",
 Evaluatable->False,
 CellOpen->False],
Cell[266314, 4676, 2059, 63, 180, "EquationNumbered",ExpressionUUID->"5ce14eba-0ee4-4cf2-9cae-cc5b33545fa5"],
Cell[268376, 4741, 422, 8, 58, "Text",ExpressionUUID->"44296690-1903-4d2d-a3a4-bf06b2ece7ba"],
Cell[268801, 4751, 1369, 28, 161, "Text",ExpressionUUID->"b6700f23-8c0b-4c37-91f8-fea30f11e780"],
Cell[270173, 4781, 536, 17, 28, "Input",ExpressionUUID->"471e8dd7-1680-4f09-a745-92e99426563b",
 Evaluatable->False,
 CellOpen->False],
Cell[270712, 4800, 1900, 55, 183, "EquationNumbered",ExpressionUUID->"2484f377-05e0-4ffe-b868-ec8d3fc5c526"],
Cell[272615, 4857, 1544, 28, 161, "Text",ExpressionUUID->"06e6504d-5759-458d-99cf-ac6156494778"],
Cell[274162, 4887, 832, 22, 28, "Input",ExpressionUUID->"b42ec447-f68e-4d6a-92f3-1ebb55ffc610",
 CellOpen->False],
Cell[274997, 4911, 1325, 41, 146, "EquationNumbered",ExpressionUUID->"a884f9f7-6d40-4cd4-b5a6-1d8dc429e3c1"],
Cell[CellGroupData[{
Cell[276347, 4956, 795, 17, 58, "Text",ExpressionUUID->"2dfb1c42-c0e1-4713-9c11-df5cb26a887e",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[277145, 4975, 1735, 48, 28, "Input",ExpressionUUID->"6c19997f-aeba-4bf5-acdb-19a1de265856",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[278917, 5028, 1658, 41, 28, "Input",ExpressionUUID->"f93c0cb0-ed50-487d-8fc8-31f40fc1447c",
 CellOpen->False],
Cell[280578, 5071, 1668, 28, 110, "Output",ExpressionUUID->"60a1f667-f8a9-4f21-87f0-568b6884e867"]
}, Open  ]],
Cell[282261, 5102, 618, 14, 33, "TableTitle",ExpressionUUID->"84c53da2-6901-44d8-b3c1-f3eb1ad007b6"],
Cell[282882, 5118, 583, 11, 82, "Text",ExpressionUUID->"9f9dbfa6-55c6-4190-8ef5-69b3487d5ecf"],
Cell[283468, 5131, 311, 7, 28, "Input",ExpressionUUID->"247b6c0a-115e-4288-9f65-970962c3b209",
 CellOpen->False],
Cell[283782, 5140, 1941, 54, 160, "EquationNumbered",ExpressionUUID->"61fc64e5-6cee-4116-8051-4bdbfebb6e78"],
Cell[285726, 5196, 222, 3, 33, "Text",ExpressionUUID->"fc866776-17bf-4a21-bf89-44b704896e83"],
Cell[285951, 5201, 314, 7, 28, "Input",ExpressionUUID->"3a3337ae-09be-4c35-b7ca-e7a4873cbd80",
 CellOpen->False],
Cell[286268, 5210, 970, 29, 103, "EquationNumbered",ExpressionUUID->"4d63d33b-d7a2-4493-94c7-928565a4477b"],
Cell[287241, 5241, 314, 7, 33, "Text",ExpressionUUID->"13720a1f-62f9-4a02-9ca2-fd66f875ddce"],
Cell[287558, 5250, 314, 7, 28, "Input",ExpressionUUID->"db67d451-c89c-45e7-b51a-7a18c645f1d7",
 CellOpen->False],
Cell[287875, 5259, 747, 23, 105, "EquationNumbered",ExpressionUUID->"a3d4c865-4941-4ab4-87ea-51199ec91720"],
Cell[CellGroupData[{
Cell[288647, 5286, 969, 18, 111, "Text",ExpressionUUID->"facfc1be-c68c-41ca-9a14-98eb35fe19b4",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[289619, 5306, 741, 19, 28, "Text",ExpressionUUID->"d428b7af-8d7e-4a99-953b-9be74d4a4a3d",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[290363, 5327, 478, 10, 28, "Input",ExpressionUUID->"e9c1a347-f93e-40f1-987e-278148b8ca24",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[290856, 5340, 354, 7, 28, "Input",ExpressionUUID->"18a5dff0-dffa-45d3-af94-15d300b78f5a",
 CellOpen->False],
Cell[291213, 5349, 1440, 46, 114, "EquationNumbered",ExpressionUUID->"41e2c703-65d1-4d13-abfd-42629c55a426"],
Cell[292656, 5397, 421, 9, 59, "Text",ExpressionUUID->"91566bda-f5ef-4539-a262-7a79509f81a1"],
Cell[293080, 5408, 293, 6, 28, "Input",ExpressionUUID->"ecac4f3f-1cf9-480a-b431-746a58c895ca",
 CellOpen->False],
Cell[293376, 5416, 406, 12, 68, "EquationNumbered",ExpressionUUID->"0aace123-1097-44e9-aa40-654b4d4848a3"],
Cell[293785, 5430, 542, 12, 62, "Text",ExpressionUUID->"21474f37-354f-4348-af36-46bdc42f1d12"],
Cell[294330, 5444, 278, 6, 28, "Input",ExpressionUUID->"b2a2d50b-28f8-43e4-b34d-ff22af6fadb8",
 CellOpen->False],
Cell[294611, 5452, 453, 14, 102, "EquationNumbered",ExpressionUUID->"4daeab5b-d217-43ff-afbc-cfe61b097328"],
Cell[295067, 5468, 514, 10, 60, "Text",ExpressionUUID->"a7d6e6a5-99e4-4425-9c38-801ac03238f6"],
Cell[295584, 5480, 386, 10, 28, "Input",ExpressionUUID->"aded01f7-dc18-49b7-86b2-135f9b0093fb",
 CellOpen->False],
Cell[295973, 5492, 450, 14, 100, "EquationNumbered",ExpressionUUID->"3d0a77c2-c4a2-4515-a543-aa45f96a2dd1"],
Cell[296426, 5508, 972, 28, 58, "Text",ExpressionUUID->"147ff282-1525-4cfa-a203-3dfb853a043f"],
Cell[297401, 5538, 350, 9, 33, "Text",ExpressionUUID->"ae80cc33-1d73-43f7-b9c5-05ab3d481735"],
Cell[CellGroupData[{
Cell[297776, 5551, 268, 7, 45, "Input",ExpressionUUID->"8ff33d7f-08f5-475f-95aa-e9c42993e4cc"],
Cell[298047, 5560, 868, 14, 43, "Output",ExpressionUUID->"abdc295d-e8cf-47ae-b46f-9a885973e515"]
}, Open  ]],
Cell[298930, 5577, 860, 18, 86, "Text",ExpressionUUID->"b2a8cb45-fc06-4488-b504-259ab27c7760"],
Cell[299793, 5597, 303, 7, 28, "Input",ExpressionUUID->"1f1613de-7d54-4dde-9bf5-179e8b0b4698",
 CellOpen->False],
Cell[300099, 5606, 737, 23, 102, "EquationNumbered",ExpressionUUID->"7a105a52-6946-45f1-a4a3-5e054c1b4a1f"],
Cell[300839, 5631, 570, 10, 58, "Text",ExpressionUUID->"32195e73-fbcd-43d0-a273-a647c89cc435"],
Cell[301412, 5643, 315, 7, 28, "Input",ExpressionUUID->"da246784-bdc2-4f5c-bc64-fa7ce3ca44a7",
 CellOpen->False],
Cell[301730, 5652, 2311, 67, 183, "EquationNumbered",ExpressionUUID->"9c62b155-41fa-4453-ad29-e797c957e547"],
Cell[304044, 5721, 487, 9, 58, "Text",ExpressionUUID->"2d5a0b19-d42a-4438-8e6f-4f4c596630e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304568, 5735, 257, 10, 87, "Section",ExpressionUUID->"d849af88-f22f-46f5-8377-d48ef974078f"],
Cell[304828, 5747, 1621, 32, 161, "Text",ExpressionUUID->"24c2529f-0f8f-4164-afa4-7e0691231475"],
Cell[CellGroupData[{
Cell[306474, 5783, 7018, 166, 28, "Input",ExpressionUUID->"6019550c-b34d-4548-8f1e-3bfb0c748dd4",
 CellOpen->False],
Cell[313495, 5951, 2114, 49, 254, "Text",ExpressionUUID->"67bbc49e-31cc-4cb2-bd3a-4b5008005d04"]
}, Open  ]],
Cell[315624, 6003, 897, 23, 82, "Text",ExpressionUUID->"f6556d82-94c0-4633-b773-e4be76f87c89"],
Cell[316524, 6028, 1206, 35, 117, "Text",ExpressionUUID->"f9e9a5ea-b0b5-4331-afe7-9a874b541194"],
Cell[CellGroupData[{
Cell[317755, 6067, 1072, 30, 28, "Input",ExpressionUUID->"a3772b27-3438-4928-9b4d-3810bb1cf039",
 CellOpen->False],
Cell[318830, 6099, 2145, 41, 499, "Output",ExpressionUUID->"c756cff8-e79f-48d4-955d-bd6e34be7499"]
}, Open  ]],
Cell[320990, 6143, 1000, 22, 84, "Text",ExpressionUUID->"a60df714-cef2-4b59-b16b-75e95a79f464"],
Cell[CellGroupData[{
Cell[322015, 6169, 1222, 30, 28, "Input",ExpressionUUID->"8414e4ff-1013-4c14-9cca-59d61e4e0885",
 CellOpen->False],
Cell[323240, 6201, 2205, 48, 187, "Output",ExpressionUUID->"9d365114-25e1-4c51-b7ef-0a963ea94eed"]
}, Open  ]],
Cell[325460, 6252, 620, 14, 33, "TableTitle",ExpressionUUID->"abd1826c-d178-4364-b9ac-1d85f3013f85"],
Cell[CellGroupData[{
Cell[326105, 6270, 997, 27, 28, "Input",ExpressionUUID->"0ea36a3a-4bae-4657-8306-e93b8f92dc9c",
 CellOpen->False],
Cell[327105, 6299, 2174, 46, 139, "Output",ExpressionUUID->"901eebf7-a854-4690-8894-d893607267e2"]
}, Open  ]],
Cell[329294, 6348, 621, 14, 33, "TableTitle",ExpressionUUID->"9de193ab-1479-48a4-a601-1ba2d64f875b"],
Cell[329918, 6364, 460, 12, 58, "Text",ExpressionUUID->"e8d1c71d-c135-4dfa-89bf-1aff75f994ab"],
Cell[330381, 6378, 1162, 36, 86, "Text",ExpressionUUID->"b0d568d0-10e1-4757-8a9d-6c857bd9f811"],
Cell[CellGroupData[{
Cell[331568, 6418, 1751, 39, 28, "Input",ExpressionUUID->"332ffa69-bcb7-4bd6-90fe-4bdda4e07f99",
 CellOpen->False],
Cell[333322, 6459, 620, 20, 58, "Text",ExpressionUUID->"a6502dcc-e64a-492d-8674-e4f9f0453272"]
}, Open  ]],
Cell[333957, 6482, 1657, 31, 205, "Text",ExpressionUUID->"4193c1c7-96a6-41f8-a6af-3345a1f6b890"],
Cell[CellGroupData[{
Cell[335639, 6517, 859, 19, 28, "Text",ExpressionUUID->"f4166320-3e0d-4dd8-8890-83f3197873ee",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[336501, 6538, 827, 16, 141, "Text",ExpressionUUID->"3c8726cb-ec8b-4a55-b1de-f56d1fb08361",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[337331, 6556, 1391, 41, 141, "Input",ExpressionUUID->"92502757-7a65-43a0-8971-27555d88b3aa",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[338725, 6599, 254, 7, 141, "Text",ExpressionUUID->"d9d350bc-dbe3-4b2e-a563-1373d6a09986",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[338982, 6608, 670, 25, 141, "Text",ExpressionUUID->"07b312d6-fbee-4b05-9867-35c7475696c3",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[339655, 6635, 663, 20, 141, "Text",ExpressionUUID->"21c3e8d1-6c28-4570-8587-36c3ef330c5d",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[340321, 6657, 1094, 30, 141, "Input",ExpressionUUID->"b49e1f7b-dfc7-4e0e-a142-ea6936b8e966",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[341418, 6689, 1107, 32, 141, "Input",ExpressionUUID->"c07ddf77-9dfd-4fd5-b968-8d669cd4a9ec",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[342540, 6724, 1055, 23, 54, "Text",ExpressionUUID->"ae934774-cb73-40c3-8e73-0b379c43f585"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343632, 6752, 253, 10, 87, "Section",ExpressionUUID->"a14011be-4d18-4f7f-a565-dfdb34939aef"],
Cell[343888, 6764, 1504, 28, 184, "Text",ExpressionUUID->"712a88ac-b399-465f-a983-796c56e7de72"],
Cell[345395, 6794, 12653, 163, 115, "EquationNumbered",ExpressionUUID->"87c9f80e-b1f5-4b6e-ba38-395532f35103"],
Cell[358051, 6959, 1547, 40, 158, "Text",ExpressionUUID->"99a1f565-465c-472c-8cd7-0ebfd7bee664"],
Cell[CellGroupData[{
Cell[359623, 7003, 776, 22, 28, "Input",ExpressionUUID->"292ed697-e1de-44a2-bbf3-18488a612391",
 CellOpen->False],
Cell[360402, 7027, 5591, 109, 356, "Output",ExpressionUUID->"1ada3297-9ddc-4b00-bedd-5f3004c3be80"],
Cell[365996, 7138, 537, 12, 32, "FigureCaption",ExpressionUUID->"5e4fc267-10d2-433d-8bb1-45c9ab5dd76e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[366570, 7155, 4358, 113, 28, "Input",ExpressionUUID->"e8c36beb-8316-4878-8b13-f30e2223f156",
 CellOpen->False],
Cell[370931, 7270, 32041, 616, 439, "Output",ExpressionUUID->"f10e69ef-2df0-4aba-8df4-616f1ad96a26"],
Cell[402975, 7888, 606, 15, 32, "FigureCaption",ExpressionUUID->"ab2ae47e-bf84-48e5-b0c1-718cf1c9b8e5"]
}, Open  ]],
Cell[403596, 7906, 814, 18, 84, "Text",ExpressionUUID->"ed61d4fa-3aaf-485e-9e0d-6632c55e3711"],
Cell[CellGroupData[{
Cell[404435, 7928, 3963, 107, 28, "Input",ExpressionUUID->"414e6edf-815d-4fcf-9ec3-c6a04f4703ec",
 CellOpen->False],
Cell[408401, 8037, 31229, 601, 358, "Output",ExpressionUUID->"95196c41-b258-4cbb-8ef9-e99ee3e10cb8"],
Cell[439633, 8640, 604, 15, 32, "FigureCaption",ExpressionUUID->"ed441a53-d727-4141-902f-21f0b12d2835"]
}, Open  ]],
Cell[440252, 8658, 484, 12, 34, "Text",ExpressionUUID->"0924b498-68b2-40fd-9bdf-a301f216a5cc"],
Cell[440739, 8672, 742, 13, 109, "Text",ExpressionUUID->"629d8936-c482-4c8a-a673-18b49dc544cd"],
Cell[CellGroupData[{
Cell[441506, 8689, 1240, 36, 28, "Input",ExpressionUUID->"4a821ec9-12e2-49ae-9973-e1413bf53139",
 CellOpen->False],
Cell[442749, 8727, 9497, 164, 356, "Output",ExpressionUUID->"751227da-f953-435d-a74b-73ec180698aa"],
Cell[452249, 8893, 622, 13, 32, "FigureCaption",ExpressionUUID->"7ade0da8-94ba-4807-aea1-2e25c24bd2be"]
}, Open  ]],
Cell[452886, 8909, 1212, 25, 135, "Text",ExpressionUUID->"fc02f051-be63-4a09-b12b-2e5c9e6bb5b3"],
Cell[CellGroupData[{
Cell[454123, 8938, 1230, 36, 28, "Input",ExpressionUUID->"59e55f56-0cac-4074-a88e-430ff3358df8",
 CellOpen->False],
Cell[455356, 8976, 9897, 181, 356, "Output",ExpressionUUID->"3f56a5c4-da20-4a31-a228-e596e5048650"],
Cell[465256, 9159, 616, 13, 32, "FigureCaption",ExpressionUUID->"2ed4468b-6e6b-47dc-b540-4c0865f5c9bf"]
}, Open  ]],
Cell[465887, 9175, 570, 12, 60, "Text",ExpressionUUID->"a0aa50eb-8e79-4a0d-b2d0-7da364e12d0d"],
Cell[CellGroupData[{
Cell[466482, 9191, 135, 2, 45, "Input",ExpressionUUID->"b766241b-80ef-476f-968b-120a2d5c7cd4"],
Cell[466620, 9195, 761, 10, 45, "Output",ExpressionUUID->"6962bdc6-d6e0-4962-8ad5-3d1bf0bae2b2"]
}, Open  ]],
Cell[467396, 9208, 267, 6, 33, "Text",ExpressionUUID->"dd9d2663-3ae7-4482-9c86-6e0936e9440a"],
Cell[CellGroupData[{
Cell[467688, 9218, 170, 3, 45, "Input",ExpressionUUID->"e4e0313a-0260-4015-8b74-da23eb85dd38"],
Cell[467861, 9223, 760, 10, 45, "Output",ExpressionUUID->"a2b06ade-267d-41d5-8e3a-5fb079a66bb4"]
}, Open  ]],
Cell[468636, 9236, 480, 11, 58, "Text",ExpressionUUID->"71c8f0fc-8bec-4cab-b6a6-08707f6aeb0d"],
Cell[469119, 9249, 299, 8, 71, "EquationNumbered",ExpressionUUID->"68f6a73a-4ed5-4e02-9f4a-b65f4b2bcd25"],
Cell[CellGroupData[{
Cell[469443, 9261, 1691, 46, 28, "Input",ExpressionUUID->"2be7870c-6b00-4d5a-bffb-8367bf021259",
 CellOpen->False],
Cell[471137, 9309, 300, 10, 33, "Text",ExpressionUUID->"091c6efc-6859-4015-aeee-ace0a14d600e"]
}, Open  ]],
Cell[471452, 9322, 405, 12, 33, "Text",ExpressionUUID->"c4a2f009-6b8b-4fa5-afa7-5f77a41ea21f"],
Cell[CellGroupData[{
Cell[471882, 9338, 8046, 207, 28, "Input",ExpressionUUID->"05636936-d5ca-4db9-b068-37cd0d28b336",
 CellOpen->False,
 CellID->312503371],
Cell[479931, 9547, 5084, 103, 751, "Output",ExpressionUUID->"be43248f-4d9a-4512-a7ea-c7bb4ef027c9"],
Cell[485018, 9652, 572, 12, 32, "FigureCaption",ExpressionUUID->"7a08d463-d3df-4180-b79b-0222c460268e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[485639, 9670, 239, 10, 87, "Section",ExpressionUUID->"0ff7df0b-ede8-4e7e-ab45-668a078ea204"],
Cell[485881, 9682, 793, 15, 107, "Text",ExpressionUUID->"0a23cd7e-d682-4c20-b842-a226daf5f013"],
Cell[CellGroupData[{
Cell[486699, 9701, 1150, 17, 135, "Item1",ExpressionUUID->"e75a7c5f-33a6-4d2b-bd9c-057a26653c11"],
Cell[487852, 9720, 857, 17, 92, "Item1",ExpressionUUID->"56464afe-bcab-4f94-be91-70c4b7f95ada"],
Cell[488712, 9739, 704, 12, 92, "Item1",ExpressionUUID->"84f295a3-e072-4d61-bff9-4e1a1dfa950f"]
}, Open  ]],
Cell[489431, 9754, 849, 14, 131, "Text",ExpressionUUID->"269047d2-ddf7-48e2-980d-e1166c9a62aa"],
Cell[490283, 9770, 413, 8, 58, "Text",ExpressionUUID->"693d9da9-1071-49f1-af10-c27018948ce0"],
Cell[490699, 9780, 1029, 20, 131, "Text",ExpressionUUID->"4dbad269-7a08-4c62-9e51-971b72e5563b"],
Cell[491731, 9802, 518, 9, 82, "Text",ExpressionUUID->"d449666a-4e51-4a09-a003-498dba05ffff"],
Cell[492252, 9813, 1066, 29, 82, "Text",ExpressionUUID->"851054b4-e0ce-43ea-bf3b-e7c38716c476"],
Cell[493321, 9844, 320, 5, 58, "Text",ExpressionUUID->"084f9e0b-73b7-4706-806a-96d09226d539"],
Cell[493644, 9851, 834, 27, 55, "Text",ExpressionUUID->"081e7157-3096-4f8e-9fba-a0b265bcc544"],
Cell[494481, 9880, 166, 3, 33, "Text",ExpressionUUID->"71c59c74-4e87-4fc0-b79b-898fbbbba8cd"],
Cell[494650, 9885, 521, 12, 75, "Text",ExpressionUUID->"79301ed8-a0de-4138-8f07-3dbd53504eab"],
Cell[495174, 9899, 170, 3, 33, "Text",ExpressionUUID->"405c94db-dd7c-4019-bb1d-ee393b805876"],
Cell[CellGroupData[{
Cell[495369, 9906, 222, 6, 45, "Input",ExpressionUUID->"c03732fa-4903-405b-8fae-7a28248e3384"],
Cell[495594, 9914, 802, 12, 45, "Output",ExpressionUUID->"dc295947-8adc-4e12-8920-abeef40410a1"]
}, Open  ]],
Cell[496411, 9929, 412, 8, 58, "Text",ExpressionUUID->"ea7a33cd-f743-4df9-8c3c-289d908cca18"],
Cell[CellGroupData[{
Cell[496848, 9941, 383, 12, 55, "Input",ExpressionUUID->"1667332d-5572-4861-954f-24f9b12730ad"],
Cell[497234, 9955, 769, 11, 45, "Output",ExpressionUUID->"f4b28a27-6c18-4aa4-91f8-7e078bd3fa17"]
}, Open  ]],
Cell[498018, 9969, 1118, 29, 82, "Text",ExpressionUUID->"1b11229f-5fed-4ab5-87ef-ae71cfda1cdb"],
Cell[499139, 10000, 642, 11, 82, "Text",ExpressionUUID->"8e364b1f-baa4-4506-894c-e8fca38bd023"],
Cell[499784, 10013, 1051, 18, 131, "Text",ExpressionUUID->"188dcea7-1092-4b77-a5ea-e45cf2cb5995"],
Cell[CellGroupData[{
Cell[500860, 10035, 644, 11, 58, "Text",ExpressionUUID->"a6195594-34a1-48be-be12-d4169f19a2ac",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[501507, 10048, 123050, 2945, 28, "Input",ExpressionUUID->"cd14217d-6556-48b2-a1c9-2557e645541b",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellTags->"compatibility-yes"]
}, Open  ]],
Cell[CellGroupData[{
Cell[624594, 12998, 712, 17, 28, "Input",ExpressionUUID->"4b140db6-5764-4b8c-a180-f335e0bdc301",
 CellOpen->False,
 CellTags->"compatibility-yes"],
Cell[625309, 13017, 1989, 44, 139, "Output",ExpressionUUID->"74d5eb41-a398-432d-887c-e460c7ed55eb",
 CellTags->"compatibility-yes"]
}, Open  ]],
Cell[627313, 13064, 598, 13, 33, "TableTitle",ExpressionUUID->"d6608713-c921-415c-9fc2-c58a52b90c7a"],
Cell[627914, 13079, 155, 2, 33, "Text",ExpressionUUID->"a473ba07-158e-4c46-b288-6ce7e689928b"],
Cell[CellGroupData[{
Cell[628094, 13085, 2217, 62, 28, "Input",ExpressionUUID->"2f7c28e3-eb17-4c08-b16d-afdab86673ae",
 CellOpen->False],
Cell[630314, 13149, 205, 5, 33, "Text",ExpressionUUID->"bbd1a0db-1eb6-462c-8901-ca9154b5e20a"]
}, Open  ]]
}, Open  ]],
Cell[630546, 13158, 508, 14, 38, "Text",ExpressionUUID->"914cae40-56f3-4a45-82c8-1a11000250b7"],
Cell[CellGroupData[{
Cell[631079, 13176, 1329, 37, 28, "Input",ExpressionUUID->"ca9b8bff-e419-4a9d-9c9f-eb64cd4d77d1",
 CellOpen->False],
Cell[632411, 13215, 244, 7, 33, "Text",ExpressionUUID->"74be60f1-a9e3-4274-8102-61b2947097e1"]
}, Open  ]],
Cell[632670, 13225, 390, 8, 58, "Text",ExpressionUUID->"6ec0f882-d65e-4acd-ad9d-bc4e5bd8c905"],
Cell[633063, 13235, 697, 12, 82, "Text",ExpressionUUID->"82f253dc-85a6-4528-9ff9-f9262de43fd8"],
Cell[CellGroupData[{
Cell[633785, 13251, 4288, 118, 28, "Input",ExpressionUUID->"b5933a58-4398-455f-b1a2-1798685108ab",
 CellOpen->False],
Cell[638076, 13371, 269, 8, 33, "Text",ExpressionUUID->"098d7478-1a8c-440c-a06c-46eb6b11e009"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[638394, 13385, 240, 10, 87, "Section",ExpressionUUID->"490f5768-1862-4b83-ae93-73bc6a6a9365"],
Cell[638637, 13397, 699, 14, 82, "Text",ExpressionUUID->"24d15e17-c11f-4d74-bf8f-274a5a9956b3"],
Cell[639339, 13413, 364, 7, 58, "Text",ExpressionUUID->"08a96b93-c243-4cf8-b2f7-9668ee2bea42"],
Cell[639706, 13422, 353, 7, 58, "Text",ExpressionUUID->"8ce12a13-f053-4905-8ffa-e0c6e3eb0f55"]
}, Open  ]],
Cell[CellGroupData[{
Cell[640096, 13434, 162, 3, 155, "EndnoteSection",ExpressionUUID->"95b89186-ffff-496e-8458-6c7c239594c4"],
Cell[CellGroupData[{
Cell[640283, 13441, 864, 15, 97, "Endnote",ExpressionUUID->"20fd0ab3-e4db-4278-9ab0-36d21f12ce1a",
 CellTags->"endnote1"],
Cell[641150, 13458, 939, 16, 97, "Endnote",ExpressionUUID->"eac18d39-9587-4776-859a-f8426a010dd4",
 CellTags->"endnote2"],
Cell[642092, 13476, 678, 13, 74, "Endnote",ExpressionUUID->"0044c38a-8916-4621-9c26-e646fe0299ad",
 CellTags->"endnote3"],
Cell[642773, 13491, 434, 9, 28, "Endnote",ExpressionUUID->"9f291a3a-bd9b-446d-b1eb-485e8e62e57e",
 CellTags->"endnote4"],
Cell[643210, 13502, 565, 11, 51, "Endnote",ExpressionUUID->"b8041afa-ac9b-429b-8795-2f8b97fba472",
 CellTags->"endnote5"],
Cell[643778, 13515, 467, 11, 28, "Endnote",ExpressionUUID->"062a0cc2-b700-403a-b850-8906ec5509df",
 CellTags->"endnote6"],
Cell[644248, 13528, 406, 9, 28, "Endnote",ExpressionUUID->"ff704dbe-f98e-47e6-aa34-83c41918d6db",
 CellTags->"endnote7"],
Cell[644657, 13539, 340, 8, 28, "Endnote",ExpressionUUID->"457aac2b-be6c-4e65-93ce-87197ab5bc19",
 CellTags->"endnote8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[645046, 13553, 168, 3, 155, "ReferenceSection",ExpressionUUID->"093a5f0d-7d68-4687-8f5d-d04d8ac0fb20"],
Cell[CellGroupData[{
Cell[645239, 13560, 350, 8, 26, "Reference",ExpressionUUID->"925051d4-7a45-4f48-a67c-fb3ca78d18fe"],
Cell[645592, 13570, 303, 9, 26, "Reference",ExpressionUUID->"d16a69c8-98f1-4c4c-8a6c-5a484c1e590d"],
Cell[645898, 13581, 334, 9, 26, "Reference",ExpressionUUID->"d4f19c51-1175-41d8-ac78-f593d64722f0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[646281, 13596, 165, 3, 155, "ExerciseSection",ExpressionUUID->"23e94b10-9abf-4f0c-85c0-2fce98a2e708"],
Cell[646449, 13601, 541, 9, 49, "Item1Exercise",ExpressionUUID->"51448b35-c9dd-4963-ab54-c57d39c5b1ff"],
Cell[646993, 13612, 216, 6, 28, "Input",ExpressionUUID->"53f58ccf-3135-427f-9fe5-b919c3de18f8",
 Evaluatable->False,
 CellOpen->False],
Cell[647212, 13620, 14335, 381, 28, "Input",ExpressionUUID->"98c80ed3-a6da-464d-8de1-bad55186094f",
 Evaluatable->False,
 CellOpen->False,
 CellID->90239728],
Cell[661550, 14003, 697, 18, 28, "Input",ExpressionUUID->"338da29f-7d46-46a6-9636-038b34f3bb66",
 Evaluatable->False,
 CellOpen->False,
 CellID->149405049],
Cell[CellGroupData[{
Cell[662272, 14025, 60001, 1219, 28, "Input",ExpressionUUID->"8f04a9ea-0439-4909-9bcb-886976201b50",
 Evaluatable->False,
 CellOpen->False,
 CellID->422333253],
Cell[722276, 15246, 40642, 776, 817, "Output",ExpressionUUID->"588b7adb-69fb-4f17-a4fd-7b24277533dd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[762955, 16027, 290, 6, 27, "Item1Exercise",ExpressionUUID->"1fa044e5-080b-4853-865d-d1d246dca911"],
Cell[763248, 16035, 337, 7, 49, "Item1Exercise",ExpressionUUID->"45a2fcd7-5b8c-4e42-ad59-8843a1ba0a79"],
Cell[763588, 16044, 538, 10, 49, "Item1Exercise",ExpressionUUID->"e7cbdbff-5c15-4283-9ddd-511ef1b68bbd"],
Cell[764129, 16056, 690, 11, 70, "Item1Exercise",ExpressionUUID->"f8664aa9-36e5-4f3b-8a2c-9c8043c12ab7"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature pxDjtZ0G2Zu1nAgY7kkF1L7@ *)
