(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.3' *)

(***************************************************************************)
(*                                                                         *)
(*                                                                         *)
(*  Under the Wolfram FreeCDF terms of use, this file and its content are  *)
(*  bound by the Creative Commons BY-SA Attribution-ShareAlike license.    *)
(*                                                                         *)
(*        For additional information concerning CDF licensing, see:        *)
(*                                                                         *)
(*         www.wolfram.com/cdf/adopting-cdf/licensing-options.html         *)
(*                                                                         *)
(*                                                                         *)
(***************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1088,         20]
NotebookDataLength[    861017,      18476]
NotebookOptionsPosition[    803812,      17391]
NotebookOutlinePosition[    831163,      18011]
CellTagsIndexPosition[    830849,      17998]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["6", "BookChapterNumber",
 CellChangeTimes->{3.5396072906784883`*^9},
 Background->RGBColor[
  0.9333333333333333, 0.1803921568627451, 
   0.1411764705882353],ExpressionUUID->"0b48d162-3a49-4c9d-b22a-7f1a35a4dcc9"],

Cell["Chance: Risk in general", "BookChapterTitle",
 CellMargins->{{12., 4.625}, {98., 0.}},
 CellChangeTimes->{3.5386855197721586`*^9, 3.539607637123304*^9},
 TextAlignment->Center,ExpressionUUID->"bf3a545f-732e-4f0a-be24-a62a427e24b1"],

Cell["\<\
\[OpenCurlyDoubleQuote]Scientific knowledge is a body of statements of \
varying degrees of certainty - some most unsure, some nearly sure, none \
absolutely certain.\[CloseCurlyDoubleQuote]\
\>", "Epigraph",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5294378102459755`*^9, 3.5386855197721586`*^9},
 TextAlignment->Center,ExpressionUUID->"faa8c295-14af-4c30-ad1b-e63706d77548"],

Cell[TextData[{
 StyleBox["Richard P. Feynman",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" \[OpenCurlyDoubleQuote]",
  FontSlant->"Plain"],
 "The Value of Science\[CloseCurlyDoubleQuote]",
 StyleBox[" published in ",
  FontSlant->"Plain"],
 StyleBox["The Pleasure of Finding Things Out",
  FontSlant->"Plain",
  FontVariations->{"Underline"->True}],
 StyleBox[", Perseus Publishing, Cambridge, MA, 2000, p. 146.",
  FontSlant->"Plain"]
}], "EpigraphAuthor",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5294378395196505`*^9, 3.5386855197721586`*^9, {3.5396073392732677`*^9, 
   3.5396073427344656`*^9}},
 TextAlignment->Center,ExpressionUUID->"0fcc0e09-797b-483a-b6a6-8cbc1cf9befe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Rasterize", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "350"}]}], "]"}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.402658393265625*^9, 3.402658406765625*^9}, {
   3.402658512625*^9, 3.40265851428125*^9}, 3.402699468766625*^9, 
   3.5331346696703568`*^9, {3.5386851658549156`*^9, 3.5386851826948786`*^9}, 
   3.5386855197721586`*^9, {3.6963384255581594`*^9, 
   3.696338425717583*^9}},ExpressionUUID->"b9058593-caf2-44ca-b7ab-\
1318967df2c6"],

Cell[CellGroupData[{

Cell["6.1. Introduction", "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531447172614333*^9, 3.5314479503188148`*^9, 
  3.5386855197721586`*^9},ExpressionUUID->"06937bd4-b053-4a9d-8b9e-\
1ce2847b4363"],

Cell[TextData[{
 "Perhaps one of the most complex notions of the interconnectedness of modern \
society is the relationship between risk and reward.  Each day we take risks \
of varying kinds.  Presumably we evaluate prospects rationally prior to \
taking risks and decide which risks are \"worth it\".  When we embark on any \
endeavor with an uncertain outcome we are saying, however casually or \
informally, that the risk is worth the reward. In so doing we put a ",
 StyleBox["price or value on risk bearing",
  FontSlant->"Italic"],
 ".  We see the price of a shirt in a department store and compare it with \
the value we place on it before purchasing it. We do the same with investment \
opportunities.  The color, texture, cut, weight, fit and style right down to \
the buttons of the shirt all play a part in reaching our conclusion that the \
shirt is or is not worth the price.  Likewise, we go through a calculus for \
accepting or rejecting risky propositions based on a list of criteria we have \
developed in our minds about what is an appropriate return for the risk \
involved. This list and the way we process it creates an interesting thought \
experiment about what part of this calculus is objective, making it truly \
like a calculus, and what part is subjective making it more like a \
\"feeling\" or emotion. The former has properties of known laws of \
mathematics and physics; the latter is intuition. With only mathematics we \
can ",
 StyleBox["understand risk",
  FontSlant->"Italic"],
 ".  More is required to ",
 StyleBox["undertake risk",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{12., 18.666666666666742`}, {3., 5.}},
 CellChangeTimes->{3.5386855197721586`*^9, 
  3.541012643202694*^9},ExpressionUUID->"6fc66632-139d-4c62-8e78-\
ca0cbf5e6460"],

Cell["\<\
This section begins in earnest our investigation of risk. In this chapter we \
will: \
\>", "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -359.375}, {Inherited, Inherited}},
 CellChangeTimes->{
  3.5386855197721586`*^9},ExpressionUUID->"83058c91-592f-4a43-854c-\
fade824723d7"],

Cell["Address risk more formally than we have thus far;", "Item1",
 PageWidth->WindowWidth,
 CellMargins->{{36, 0}, {1, 3}},
 CellChangeTimes->{
  3.5294402119633465`*^9, {3.529935177760254*^9, 3.5299351849896674`*^9}, 
   3.5386855197721586`*^9, {3.541012611790897*^9, 
   3.5410126126459455`*^9}},ExpressionUUID->"be369688-88a6-46cf-bc26-\
5a86d16c7505"],

Cell["Explore the origins of risk as seen through games of chance;", "Item1",
 PageWidth->WindowWidth,
 CellMargins->{{36, 0}, {1, 3}},
 CellChangeTimes->{{3.52944021360044*^9, 3.529440214433488*^9}, 
   3.5386855197721586`*^9, {3.5410126169451914`*^9, 
   3.5410126185052805`*^9}},ExpressionUUID->"d73f1057-5b48-467f-b9e0-\
ca810f4d03f0"],

Cell["\<\
Re-introduce the utility function, in fact several of them, to illustrate how \
risk is \"priced\"; and\
\>", "Item1",
 PageWidth->WindowWidth,
 CellMargins->{{36, 0}, {1, 3}},
 CellChangeTimes->{
  3.529440216691617*^9, 3.5386855197721586`*^9, {3.5410126223274994`*^9, 
   3.541012623054541*^9}},ExpressionUUID->"c14bf3b6-20a2-4b49-a172-\
39814344ca5f"],

Cell["\<\
Work through the mathematics of probability and utility for binary outcomes \
(two results), then multiple discrete outcomes (a few results), concluding \
with probability in a continuous setting (lots of results).\
\>", "Item1",
 PageWidth->WindowWidth,
 CellMargins->{{36, 0}, {1, 3}},
 CellChangeTimes->{3.5294402183907137`*^9, 
  3.5386855197721586`*^9},ExpressionUUID->"9b33e9fe-2308-4584-8ac2-\
8a38324570bd"],

Cell[CellGroupData[{

Cell["6.1.1. Objective and subjective risk", "Subsection",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531446664268257*^9, 3.531447970844989*^9, 
  3.5386855197721586`*^9},ExpressionUUID->"e4304088-20e9-4aec-852c-\
54ee4fd61e83"],

Cell[TextData[{
 "The ",
 StyleBox["overarching ",
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, -359.375}, {Inherited, Inherited}},
  CharacterEncoding -> "WindowsANSI"],
 "goal of this chapter is to provide context in which to think about \
investment risk. Embedded in this is the notion of objective and subjective \
evaluation. It would be nice to clearly separate these. This goal is elusive. \
If you watch as I flip a fair coin into the air, catch it covered with my \
hand and then ask you whether it landed heads or tails up, your response is \
subjective. Whatever you respond must be based on what you \"feel\" was the \
outcome. On the other hand, if I flip a coin into the air 1000 times and ask \
you ",
 StyleBox["over the telephone ",
  FontSlant->"Italic"],
 "approximately how many times it came up heads you could answer without \
having seen me, the coin, any of the flips or their outcomes. You don't have \
to \"feel\" anything about approximately how 1000 trials ended. Elementary \
understanding of probability tells you ",
 StyleBox["objectively",
  FontSlant->"Italic"],
 " that in a large number of flips, heads will come up about 50% of the time."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529440423105423*^9, 3.5294404356491404`*^9}, 
   3.5386855197721586`*^9, 
   3.538686885773289*^9},ExpressionUUID->"c27a9b20-bed3-4c8d-9339-\
a24413d24c94"],

Cell[TextData[{
 "Probability theory, the laws of large numbers and statistics are powerful \
tools and we shall discuss them briefly here for their applicability to real \
estate investments.  But we must never lose sight of the fact that just as it \
is impossible to flip a building in the air even once, much less 1000 times, \
it is impossible to capture all of real estate risk with mathematics.  \
Despite improving our data and the tools we use to analyze it, there will \
always be a subjective aspect of risk evaluation in privately owned real \
estate investments. Does this mean that we ignore mathematics when thinking \
about real estate investment? No, knowledge of mathematical technicalities \
enhances one's ",
 StyleBox["understanding",
  FontSlant->"Italic"],
 " of risk bearing. A street-wise appreciation of subjective risk evaluation \
enhances the ",
 StyleBox["undertaking",
  FontSlant->"Italic"],
 " of risk. This is an excellent example of the difference between academia \
and the real world: Understanding risk and profitably taking risk involve \
very different skills. The challenge we face is combining the two in some \
useful way. A complicating issue that specifically bears on privately owned \
real estate investments is the impact of owner management. By this we mean \
the addition of entrepreneurial skill to the process, not the day-to-day \
renting, maintaining and accounting functions all of which can be acquired \
for the payment of wages or commissions to managers.  Public financial \
markets are organized in a way that separates ownership from control. Private \
real estate investment combines them. The effect of this on the investment \
result should not be ignored."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529440476303466*^9, 3.5294404770545087`*^9}, 
   3.529611438779989*^9, 
   3.5386855197721586`*^9},ExpressionUUID->"6dd6d9cc-f043-48c2-a1c1-\
b2a9286a9783"]
}, Open  ]],

Cell["\<\
Before we take up the thorny issues of risk in real estate we must build a \
foundation for it from classical risk models that date back centuries. These \
involve the St. Petersburg Paradox, expected utility theory and the theory of \
consumer choice under conditions of uncertainty.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855197721586`*^9},ExpressionUUID->"fc89fcd8-45d2-428a-9f28-\
4aea00e87adc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2. Games of chance and risk bearing", "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531447172614333*^9, 3.5314479910911465`*^9, 
  3.5386855197721586`*^9},ExpressionUUID->"08d33cfb-39e2-45c7-8def-\
9f0ecebd6fde"],

Cell["\<\
We are interested in learning how people make decisions in the presence of \
uncertainty.  One way to do this is to think about having to choose between \
certain and uncertain options and how one might put a price on the difference.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5296115028406525`*^9, 
  3.5386855197721586`*^9},ExpressionUUID->"edcb91f1-c9f8-4354-90ba-\
10b8e61bceb5"],

Cell["\<\
The St. Petersburg Paradox (attributed to Daniel Bernoulli in the 1700s) \
concerns the value of participating in a \"fair game\". The simplest of these \
is flipping a coin that has an equal probability of coming down either heads \
or tails.  The game is \"fair\" in the long run if, each time, one pays a $1 \
to play and wins $1 plus the return of his bet if he bets tails and the coin \
comes up tails.  In the long run (defined as a series of a large number of \
equivalent bets) the investor playing this game neither gains nor loses on \
average. Sometimes we will be ahead, sometimes behind. Some players will win \
(sometimes a lot), some players will lose. \
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296115028406525`*^9, 3.529611508836996*^9}, 
   3.5386855197721586`*^9, {3.6965439789441338`*^9, 
   3.6965439797963924`*^9}},ExpressionUUID->"039649d5-e5e4-4d40-a270-\
220b37141c81"],

Cell["\<\
Let us imagine a different version of the coin flipping game. In this game \
the prize is paid when the first head appears and the amount of the prize is \
dependent on the number of flips prior to the appearance of the first head. \
Stated differently, the prize depends on the number of tails that appear in a \
row. The prize is $2 raised to the power of the number of tails appearing \
before the first head.   Suppose the participant has to pay a fee each round \
to play. How much should one be willing to pay to enter this game?  When one \
buys an investment with an uncertain outcome (offering different prospective \
net present values or internal rates of return) we can view the purchase \
price as a fee to enter the \"game\" which that investment represents.  In \
Chapter 5 we said that investments are a gamble even if they do not appear on \
the surface to be games of chance.  The mere presence of uncertain prospects \
makes investments eligible for evaluation in a probabilistic framework.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296115028406525`*^9, 3.529611515150357*^9}, 
   3.5386855197721586`*^9, {3.6965440242677045`*^9, 
   3.6965440247068944`*^9}},ExpressionUUID->"fab53c44-2a3d-4c5e-94be-\
eb94eed51398"],

Cell[CellGroupData[{

Cell[TextData[{
 "Table 6.1 demonstrates, for our coin flipping game, how the probability \
falls as the number of tails before a head appears grows. But at the same \
time the value of the prize increases.  The expected value of the game is the \
sum of the probability of an outcome times its payoff over all the possible \
outcomes.  The Paradox arises from the fact that, taking ",
 StyleBox["n",
  FontSlant->"Italic"],
 " to infinity, the expected payoff is infinite.  Thus, one should be willing \
to pay an infinite amount to play. Yet we observe that people are actually \
only willing to pay a nominal amount.  What explains this?"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296115028406525`*^9, 3.529611516661443*^9}, {
   3.5296138363221207`*^9, 3.5296138392282867`*^9}, 
   3.5386855197721586`*^9},ExpressionUUID->"1bddd1e7-7bcc-43ed-8fa2-\
be8055e7fd78"],

Cell[TextData[{
 "Here in mathematical symbols using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " syntax as input and its related output, is what we just said in words \
(\"Sum does not converge\" is ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s way of saying that the sum of the terms cannot be expressed as a finite \
number)."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855197721586`*^9, {3.541012665771984*^9, 3.5410126892153254`*^9}, {
   3.54101272321027*^9, 
   3.5410127413563075`*^9}},ExpressionUUID->"b906da55-b60f-4d3e-8963-\
9c0a580db46f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"n", "=", "1"}], "\[Infinity]"], 
  RowBox[{"N", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", "2"], ")"}], "n"], " ", 
    SuperscriptBox["2", 
     RowBox[{"n", "-", "1"}]]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519773158*^9},ExpressionUUID->"6c5ae1b1-0d64-43ec-b526-\
149c6e121dbb"],

Cell[BoxData[
 TemplateBox[{
  "Sum","div","\"Sum does not converge.\"",2,2,1,22143457674635830915,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.529611815817554*^9, 3.529615470221574*^9, 
  3.5296155625088525`*^9, 3.5296985542057056`*^9, 3.529789997155944*^9, 
  3.529793109178357*^9, 3.529935113566582*^9, 3.529937320945837*^9, 
  3.530016396009672*^9, 3.5300167162909913`*^9, 3.530017178637436*^9, 
  3.530193683702219*^9, 3.530194221310969*^9, 3.5314482236344476`*^9, 
  3.5315006204783754`*^9, 3.5331346847842207`*^9, 3.5331358766263905`*^9, 
  3.533682243859375*^9, 3.5337345676126356`*^9, 3.5337541354375*^9, 
  3.533755408015625*^9, 3.5386852032130523`*^9, 3.538685519773158*^9, 
  3.5396359520018225`*^9, 3.5401267844857693`*^9, 3.54101260922375*^9, 
  3.541015079887064*^9, 3.541015542860544*^9, 3.54160042418778*^9, 
  3.5433421711080413`*^9, 3.696338456239787*^9, 3.6963423712558546`*^9, 
  3.6965443561463504`*^9, 
  3.7314211823789387`*^9},ExpressionUUID->"e19a7dd4-c9f4-48f8-9207-\
ba771c38e82e"],

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"n", "=", "1"}], "\[Infinity]"], "0.5`"}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.4026586385625*^9, 3.402699566079125*^9, 
  3.5296118158195543`*^9, 3.5296154702405753`*^9, 3.5296155625098524`*^9, 
  3.5296985542557087`*^9, 3.5297899972069464`*^9, 3.529793109248361*^9, 
  3.529935113599584*^9, 3.5299373209868393`*^9, 3.5300163960686755`*^9, 
  3.530016716343994*^9, 3.5300171786964393`*^9, 3.530193683733221*^9, 
  3.5301942213399706`*^9, 3.531448223664449*^9, 3.531500620499377*^9, 
  3.533134684805222*^9, 3.533135876672393*^9, 3.533682243890625*^9, 
  3.533734567660638*^9, 3.533754135484375*^9, 3.533755408046875*^9, 
  3.5386852032710557`*^9, 3.5386855197741585`*^9, 3.539635952051825*^9, 
  3.540126784551773*^9, 3.5410126092437515`*^9, 3.5410150799130654`*^9, 
  3.5410155428775454`*^9, 3.5416004241997805`*^9, 3.543342171123042*^9, 
  3.696338456273878*^9, 3.696342371293968*^9, 3.6965443561894336`*^9, 
  3.7314211824371076`*^9},ExpressionUUID->"275df707-dc6b-4ab1-9676-\
54bf29b90ed3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   TagBox[
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"N", "[", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "2"], ")"}], "n"], "]"}], ",", 
        SuperscriptBox["2", 
         RowBox[{"n", "-", "1"}]], ",", 
        RowBox[{
         RowBox[{"N", "[", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox["1", "2"], ")"}], "n"], "]"}], " ", 
         SuperscriptBox["2", 
          RowBox[{"n", "-", "1"}]]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "11"}], "}"}]}], "]"}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, 
      TableHeadings -> {None, {"n", "p(n)", "payoff", "p(n) x payoff"}}]]], 
   ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<n\>\"", ",", "\"\<p(n)\>\"", ",", "\"\<payoff\>\"", ",", 
        "\"\<p(n) payoff\>\""}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.40265871384375*^9, 3.40265884690625*^9}, {
   3.529611759234318*^9, 3.5296117739601603`*^9}, {3.5296118632092648`*^9, 
   3.529611902628519*^9}, {3.5296121347297945`*^9, 3.5296121397460814`*^9}, {
   3.5296122043837786`*^9, 3.529612242917983*^9}, {3.529612313744034*^9, 
   3.5296123294509325`*^9}, {3.5296124153328447`*^9, 3.529612511117323*^9}, {
   3.5296986429997845`*^9, 3.5296987538001223`*^9}, 
   3.5386855197741585`*^9},ExpressionUUID->"f6005a76-ba18-4c57-bd45-\
3537555c4b49"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"n\"\>",
       HoldForm], 
      TagBox["\<\"p(n)\"\>",
       HoldForm], 
      TagBox["\<\"payoff\"\>",
       HoldForm], 
      TagBox["\<\"p(n) payoff\"\>",
       HoldForm]},
     {"1", "0.5`", "1", "0.5`"},
     {"2", "0.25`", "2", "0.5`"},
     {"3", "0.125`", "4", "0.5`"},
     {"4", "0.0625`", "8", "0.5`"},
     {"5", "0.03125`", "16", "0.5`"},
     {"6", "0.015625`", "32", "0.5`"},
     {"7", "0.0078125`", "64", "0.5`"},
     {"8", "0.00390625`", "128", "0.5`"},
     {"9", "0.001953125`", "256", "0.5`"},
     {"10", "0.0009765625`", "512", "0.5`"},
     {"11", "0.00048828125`", "1024", "0.5`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"n", "p(n)", "payoff", "p(n) payoff"}}]]]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.40265884240625*^9, 3.402658847578125*^9}, 
   3.4026995658135*^9, 3.5296117507248306`*^9, 3.52961186959363*^9, 
   3.529611917007342*^9, {3.5296122282111416`*^9, 3.529612243500016*^9}, {
   3.529612322806552*^9, 3.5296123303959866`*^9}, {3.5296124206361475`*^9, 
   3.5296124381121473`*^9}, {3.5296124759613123`*^9, 3.5296125118683662`*^9}, 
   3.529613802173167*^9, 3.5296154702795773`*^9, 3.5296155625498548`*^9, 
   3.529698554331713*^9, {3.5296986873383207`*^9, 3.5296987539591312`*^9}, 
   3.529789997285951*^9, 3.5297931095543785`*^9, 3.5299351137885947`*^9, 
   3.5299373210468426`*^9, 3.5300163961646805`*^9, 3.5300167164299994`*^9, 
   3.530017178791445*^9, 3.5301936837952247`*^9, 3.5301942213989735`*^9, 
   3.531448223708452*^9, 3.531500620541379*^9, 3.533134685034235*^9, 
   3.5331358767333965`*^9, 3.53368224396875*^9, 3.5337345678876514`*^9, 
   3.53375413565625*^9, 3.533755408125*^9, 3.538685203490068*^9, 
   3.5386855197741585`*^9, 3.5396359521148286`*^9, 3.5401267849517956`*^9, 
   3.541012609795783*^9, 3.5410150802260833`*^9, 3.541015543201564*^9, 
   3.5416004245067987`*^9, 3.543342171521065*^9, 3.696338456310977*^9, 
   3.6963423713480854`*^9, 3.6965443562124944`*^9, 3.731421182457145*^9},
 TextAlignment->Center,ExpressionUUID->"124e7a33-0d1f-4dc6-b489-d849822134cf"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table 6.1.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "TableTitleLabel"],
 "Probabilities and payoffs in the St. Petersburg Paradox coin flipping game"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5314998749897366`*^9, 3.5386855197741585`*^9},
 TextAlignment->Center,ExpressionUUID->"5b8e047a-82d9-4442-861c-018bf51a7688"],

Cell["\<\
In addition to the intuitive reasons, here are some graphical illustrations \
of why rational risk takers would not bet a significant amount of wealth on \
this game.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.529613050418169*^9, {3.529693197266307*^9, 3.5296931978683414`*^9}, 
   3.5386855197741585`*^9},ExpressionUUID->"9c1bcdcd-59c5-4a0e-85ea-\
fbc64a676098"],

Cell[TextData[{
 "First, we show the probability of recovering at least the cost of playing \
the game assuming one paid ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["$2", "k"], TraditionalForm]],ExpressionUUID->
  "c49c7630-6649-4add-9db9-5a259e29b397"],
 ", where ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is the number of rounds prior to a success (heads). Below we plot the \
intersection of the realization of two functions, the payoff = entry cost on \
the x axis and the payoff probability for each round on the y axis. Recall \
that the probability that payoff occurs at or after ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is",
 StyleBox[" ", "MLHText",
  FontColor->GrayLevel[0]],
 StyleBox[Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "k"}], "\[Infinity]"], 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox["1", "2."], ")"}], "n"]}]], "MLHText",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],ExpressionUUID->
  "b0416ccd-6721-4eb4-8362-b33c7c550e29"], "MLHText"],
 StyleBox[", or 1 - the", "MLHText",
  FontSize->12,
  FontColor->GrayLevel[0]],
 StyleBox[" ", "MLHText",
  FontColor->GrayLevel[0]],
 "probability that payoff occurs before ",
 StyleBox["k",
  FontSlant->"Italic"],
 ". As we see in Figure 6.1, the more you play (and pay), the lower your \
chances of recovering your entry fee. This is an unappealing prospect, to say \
the least."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529613050418169*^9, 3.5296130526252956`*^9}, {
  3.5296141113758526`*^9, 3.5296141162731323`*^9}, {3.5386855197741585`*^9, 
  3.5386855197761583`*^9}, {3.5410127799065123`*^9, 3.541012783087694*^9}, {
  3.541012835160673*^9, 
  3.541012839882943*^9}},ExpressionUUID->"452c4e11-1258-453b-9dc1-\
20822fef4355"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2k", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", "2", ")"}], 
       RowBox[{"k", "-", "1"}]], ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "k"}], "\[Infinity]"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", "2."], ")"}], "n"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "5"}], "}"}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", "0.9", "]"}], ",", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.02", ",", "0.04"}], "}"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", 
     RowBox[{"1", "/", "2"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Entry fee\>\"", ",", "\"\<Pr(recovery)\>\""}], "}"}]}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.40265886646875*^9, 3.4026588694375*^9}, {
   3.402658908390625*^9, 3.402658980609375*^9}, {3.4026997311885*^9, 
   3.402699842579125*^9}, 3.402699936876*^9, {3.402699972485375*^9, 
   3.40270000040725*^9}, {3.402700059860375*^9, 3.402700074329125*^9}, {
   3.40270055715725*^9, 3.402700685391625*^9}, {3.402700926110375*^9, 
   3.402700940172875*^9}, {3.402701999204125*^9, 3.402702022766625*^9}, {
   3.402702111172875*^9, 3.402702112141625*^9}, {3.402702359829125*^9, 
   3.402702364704125*^9}, {3.40270256284475*^9, 3.40270265003225*^9}, {
   3.40270269153225*^9, 3.402702703204125*^9}, {3.40270274584475*^9, 
   3.402702767297875*^9}, {3.402702814422875*^9, 3.40270282371975*^9}, {
   3.4027029036885*^9, 3.40270292978225*^9}, {3.402703066876*^9, 
   3.40270311328225*^9}, {3.402703583672875*^9, 3.402703590860375*^9}, {
   3.402703627047875*^9, 3.402703628001*^9}, {3.40270367134475*^9, 
   3.402703694610375*^9}, 
   3.5386855197771587`*^9},ExpressionUUID->"e251e7da-c394-4735-b7c1-\
8316da38e65a"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   TagBox[
    {Hue[0.9, 1, 1], AbsoluteThickness[1.6], Opacity[1.], 
     Dashing[{0.02, 0.04}], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw1lHs0lAkchofJZVwiqplMm+uOqdF8ESu6/H6rLbqwyaY2sRLtVpio6LYq
kW5bTVYR0+6ElrJ8lUuYCRUirBGhkmnMOCRmTBSWVKfd95z3PP8857z/vZZB
vPUhmhQKxfNTP/NLVPA/D4tm6x6mqqDL4N89tFElHNWIaRrRVsET1tNd09VK
SNpRlDtkqIJDY88UXLkSYpOyTg0zVUCL6Bnd90gJOxqLB5iLVJBqm7JpLV8J
Vgc4wvHdKjjS8G0W3UYJplyRFV3xaYe/5sxMrwHgJ5Tlq/sGYX7/Pd4V/huQ
rP/ZqVaphhfXQz9cpvWBeY3+o8bxt2C+/2bJ34JesGbzes/aD4OrJyUint0D
F/w7VFFB7yBJ49LuyM5uuFY/qPYofw91B2hj588poHBVpF6M3Sg4288fy/WV
w76Q71JeJI5BdJ7wds7yLhC3TWa6LhiH4cevNj6fK4OIVb8vLK6egGaSw/O2
fwVvWnv5CWGTwPPISuCvlkKXDzenMYuCprKZ70tLX8LguPOKmssamBqxTLDC
rANavB1gJFsTy3vtjcXhz8E9r60poJqKarH2CYWsHWIMLYJeSaegY2QdpyO+
Dfgdb7P7rbUxzudxgKFFKzAFC2wNtulgRdBR/WPyFuhwX8djSXQxJVrw4rSw
GQ4e31ro56WH8jSD/ItRT0C///s/k6r0cZP48JTB8CbYG19XtzLKELcNCMva
AiXA8Es4NmxhhFqznnhmRDZCcmNV7cYwY4wO7dKjcP4B8/KH2LhzGpaJayQ7
Q+rhx+Vu5l+FmKAnPeVkaMtjeOnHKvWIM0VHzeJ06eJaaF5Bu780bzomao71
FpY/AjEnaJh4OgPttuSEb42shlMbthSks+loa71+sohZBRluG+wMohkoEjv7
nOh/CK1nj+nZSWahy6RM/23zA+jOTK8ODWCi7OaEC6PgPihEdK+L3bNxZsYN
hltRBeS+c5p3PGsO7tHWTHa7Uw4sW6E828ECIzsGbXpTy4C6xuLcIMMSkxX2
lfPVYrizOCfJydIK2Sam6TlLRbDSjP3ahWWN22WBlaWiEnhqqa+V622DTgKO
4S2HYmhYy2+KOvU1To2a49FTWQTmwvY+SzELF9+Ou7YsrhB+vefH5sxh41/G
0J7pWgAhwTtKjA7NRf/gCK8Rej68KUrpc5HPwzT5u3gzvTtgV29DK461Q+rV
UnfP4VsgG1IPjDG5WPnMQO2ocQu6ApLPeltzMUy3ZdR4ggR5ltlQ9jwu+joX
UAdGSDDz3WsV6MLFnzzuz76pImGDX5GuzJeLTZsX+ttLSfihLc9/yUUuum59
KA0rIyFt4AZ66RFIC/HFzBgSZpxxHHo5jcC7+bEmwoMkNHAeHImYReDqYFqn
IIqEkIpSizQ2gRNMh+1Xwkl47VN4ScedwKqSVaw/Aj77U+86xxGoJTy5qHUZ
CYxME6vuMwTylvQkylxJCKZu3nUpkcDw+nbFwDckjFfGCcavEWh7NzZUjyAh
j8L4rbOCwAaXgA9rzUnw2k/5kFZDoCSjTCeQSULFLy3eWyQEpq5r1tpLJ+G8
gJkhlRJ42mZu51UjEnyu7k/P7CFw1FNdXKBPQu2FlIRQFYGikqMn63VImJo6
tM5phMDrRimru6nkf7+1AL+QhI+7tkCX
      "]]},
    Annotation[#, "Charting`Private`Tag$1135#1"]& ]},
  AspectRatio->NCache[
    Rational[1, 2], 0.5],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Entry fee\"", TraditionalForm], 
    FormBox["\"Pr(recovery)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->Automatic,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{0., 16.}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.4027006879385*^9, 3.402700945922875*^9, 3.402702028876*^9, 
   3.4027021186885*^9, 3.4027023703135*^9, 3.402702569329125*^9, {
   3.40270260221975*^9, 3.402702622641625*^9}, 3.402702655610375*^9, 
   3.402702709891625*^9, 3.40270283303225*^9, 3.40270293403225*^9, 
   3.40270312615725*^9, 3.402703598141625*^9, 3.40270363365725*^9, 
   3.40270369834475*^9, 3.5296130792018156`*^9, 3.5296132234580665`*^9, 
   3.5296154705175905`*^9, 3.5296155627848682`*^9, 3.5296985547027345`*^9, 
   3.5297899976619725`*^9, 3.529793110664442*^9, 3.5299351143606277`*^9, 
   3.5299373213068576`*^9, 3.530016396555703*^9, 3.530016716740017*^9, 
   3.5300171790734606`*^9, 3.5301936841632457`*^9, 3.5301942216539884`*^9, 
   3.531448224059472*^9, 3.5315006209084005`*^9, 3.533134685694273*^9, 
   3.533135876988411*^9, 3.5336822445*^9, 3.533734568589691*^9, 
   3.53375413615625*^9, 3.533755408609375*^9, 3.538685204313115*^9, 
   3.5386855197791586`*^9, 3.539635952535853*^9, 3.5401267883109875`*^9, 
   3.541012610934848*^9, 3.541015081195139*^9, 3.5410155441336174`*^9, 
   3.541600425457853*^9, 3.5433421724901204`*^9, 3.696338456616791*^9, 
   3.6963423717812386`*^9, 3.69654435655641*^9, 3.731421182843173*^9},
 TextAlignment->Center,ExpressionUUID->"6a1bab21-10bb-4cb7-928a-e9fe91ad7d52"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.1.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Probability of recovery as entry fee increases."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5315001553967743`*^9, 3.5386855197791586`*^9},
 TextAlignment->Center,ExpressionUUID->"db06071c-0db4-4770-81a9-a877d81c5a46"],

Cell[TextData[{
 "Second, since doubling the payoff of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "k"], TraditionalForm]],ExpressionUUID->
  "717f039d-2cb6-44d3-9273-6be6d3dc1a55"],
 " is 2 x ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "k"], TraditionalForm]],ExpressionUUID->
  "136b3235-a064-4d15-a879-65f86fa05c36"],
 "= ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    RowBox[{"k", "+", "1"}]], TraditionalForm]],ExpressionUUID->
  "9cd19f03-c339-4383-bab5-c7799bee8f0a"],
 ", we can add to the above graph the chance of doubling your money. In \
Figure 6.2 the probabilities are even lower over the same number of rounds."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529614884859093*^9, 3.5296148933285775`*^9}, 
   3.529935620237562*^9, {3.5386855197791586`*^9, 3.538685519780159*^9}, 
   3.5410128963681736`*^9},ExpressionUUID->"c6bf02df-43cc-489d-8fa7-\
346abb9372f6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p2ka", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", "2", ")"}], 
        RowBox[{"k", "-", "1"}]], ",", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", 
          RowBox[{"k", "+", "1"}]}], "\[Infinity]"], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "2."], ")"}], "n"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Hue", "[", ".5", "]"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"probshow", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"p2k", ",", "p2ka", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Entry fee\>\"", ",", "\"\<Probability\>\""}], "}"}]}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"fig1", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{"probshow", ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", "0.9`", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "]"}], ",", 
        RowBox[{"Hue", "[", "0.5", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Pr(Recovery)\>\"", ",", "\"\<Pr(Entry Fee x 2)\>\""}], 
       "}"}]}], "]"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.402658892546875*^9, 3.402658894640625*^9}, 
   3.40270317290725*^9, 3.40270321821975*^9, {3.402703726516625*^9, 
   3.40270377346975*^9}, {3.5296133970789967`*^9, 3.52961340168026*^9}, 
   3.538685519780159*^9, {3.696544452481616*^9, 
   3.6965445688111076`*^9}},ExpressionUUID->"3d6fbace-c4eb-4c43-a3a4-\
7928646945d6"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          Hue[0.9, 1, 1], 
          Dashing[{0.02, 0.04}]], 
         LineBox[CompressedData["
1:eJw1lHs0lAkchofJZVwiqplMm+uOqdF8ESu6/H6rLbqwyaY2sRLtVpio6LYq
kW5bTVYR0+6ElrJ8lUuYCRUirBGhkmnMOCRmTBSWVKfd95z3PP8857z/vZZB
vPUhmhQKxfNTP/NLVPA/D4tm6x6mqqDL4N89tFElHNWIaRrRVsET1tNd09VK
SNpRlDtkqIJDY88UXLkSYpOyTg0zVUCL6Bnd90gJOxqLB5iLVJBqm7JpLV8J
Vgc4wvHdKjjS8G0W3UYJplyRFV3xaYe/5sxMrwHgJ5Tlq/sGYX7/Pd4V/huQ
rP/ZqVaphhfXQz9cpvWBeY3+o8bxt2C+/2bJ34JesGbzes/aD4OrJyUint0D
F/w7VFFB7yBJ49LuyM5uuFY/qPYofw91B2hj588poHBVpF6M3Sg4288fy/WV
w76Q71JeJI5BdJ7wds7yLhC3TWa6LhiH4cevNj6fK4OIVb8vLK6egGaSw/O2
fwVvWnv5CWGTwPPISuCvlkKXDzenMYuCprKZ70tLX8LguPOKmssamBqxTLDC
rANavB1gJFsTy3vtjcXhz8E9r60poJqKarH2CYWsHWIMLYJeSaegY2QdpyO+
Dfgdb7P7rbUxzudxgKFFKzAFC2wNtulgRdBR/WPyFuhwX8djSXQxJVrw4rSw
GQ4e31ro56WH8jSD/ItRT0C///s/k6r0cZP48JTB8CbYG19XtzLKELcNCMva
AiXA8Es4NmxhhFqznnhmRDZCcmNV7cYwY4wO7dKjcP4B8/KH2LhzGpaJayQ7
Q+rhx+Vu5l+FmKAnPeVkaMtjeOnHKvWIM0VHzeJ06eJaaF5Bu780bzomao71
FpY/AjEnaJh4OgPttuSEb42shlMbthSks+loa71+sohZBRluG+wMohkoEjv7
nOh/CK1nj+nZSWahy6RM/23zA+jOTK8ODWCi7OaEC6PgPihEdK+L3bNxZsYN
hltRBeS+c5p3PGsO7tHWTHa7Uw4sW6E828ECIzsGbXpTy4C6xuLcIMMSkxX2
lfPVYrizOCfJydIK2Sam6TlLRbDSjP3ahWWN22WBlaWiEnhqqa+V622DTgKO
4S2HYmhYy2+KOvU1To2a49FTWQTmwvY+SzELF9+Ou7YsrhB+vefH5sxh41/G
0J7pWgAhwTtKjA7NRf/gCK8Rej68KUrpc5HPwzT5u3gzvTtgV29DK461Q+rV
UnfP4VsgG1IPjDG5WPnMQO2ocQu6ApLPeltzMUy3ZdR4ggR5ltlQ9jwu+joX
UAdGSDDz3WsV6MLFnzzuz76pImGDX5GuzJeLTZsX+ttLSfihLc9/yUUuum59
KA0rIyFt4AZ66RFIC/HFzBgSZpxxHHo5jcC7+bEmwoMkNHAeHImYReDqYFqn
IIqEkIpSizQ2gRNMh+1Xwkl47VN4ScedwKqSVaw/Aj77U+86xxGoJTy5qHUZ
CYxME6vuMwTylvQkylxJCKZu3nUpkcDw+nbFwDckjFfGCcavEWh7NzZUjyAh
j8L4rbOCwAaXgA9rzUnw2k/5kFZDoCSjTCeQSULFLy3eWyQEpq5r1tpLJ+G8
gJkhlRJ42mZu51UjEnyu7k/P7CFw1FNdXKBPQu2FlIRQFYGikqMn63VImJo6
tM5phMDrRimru6nkf7+1AL+QhI+7tkCX
          "]]}, Annotation[#, "Charting`Private`Tag$1135#1"]& ]}}, {{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          Hue[0.5, 1, 1]], 
         LineBox[CompressedData["
1:eJwt1H080wkcB/CxPG1EVJZ1mYebadqvKSd0fb+nK3rgkktd4iTrrvIQJ3o6
lUhPV61OWaz7LVaU6MHzLFSSxMuEqNhaeFFxsygcuevVfV6vz+v9z+fvj01o
1FqBLoVC8fmvn/0SDXxRBfvLZxvup2pAbfzPb0ajSjiok9A0oq+Bp+zWHdO1
SkjdVpw3ZKKBfWPPu3ldSkhMzT42zNSAYXTv6K5HStjWWDrAXKSBdAfRhtVC
Jdju4UrGd2rgQMN32Zb2SrDgldtadmtgr3DViZm+nSBMqSjQvh2Eef13oy4K
X4Ji7S8uj//WQueV8E8XjF6AdS39UeP4e2Dtvl52Q9wOdpyovpP8YXD3oUQn
c9rgTFCHJi70A6TqnN8Zo2yFy/WDWu/Kj1C3x2js9KkWKFoRQ0twGgVX/ryx
vIBm2CX4XvTy3BjE50tu5y59CvK2San7/HEYqnu1/oVjE0Sv+HNBac0EtNzk
RvnxFfDuWZ8wJWISdnpnpwhXNsJrf15uYzYFLdQzP8pkDTA47rqs9oIOpkcv
ES+zqocWP2cYydHFyj6+mTyyDrzy25qCa6iolesf6VbXQoIJK/SVagoujHnC
7Uh+BMKO9zn9dvqY5F8XbMKqAaZ4voPxFgOsCj1IP9RVDR1ea6LYCkMUxYtf
Hpc8gL2HNxcF+tKwK8O44GzcfaD3/0CmPqTjBvn+KYOR9yA2+cmT5XEmuGVA
UtEWUgWMwJRDwyxT1Jv11CcrphLSGh8+Xh9hhvHhr2kUbgVYVz7Axu3TUC6v
VWwXyOGnpZ7WXwnM0cdSdDS8RQadgWyZd5IF8nVLM1UeZdC8zOjet/nTUag7
1ldUWQJybugw0ToDeZtyIzfHFMOxdZsKMzmW6Gi3drKYWQRZnuucjOMZWCZ3
9T/SXwDPTh6iOSlmocekmv6++Q70SDNrwoOZqL4+4cYovA3d5Za+Z3tm48ys
awzP4luQ98Fl7uHsORirr5vmeecmsB0kXTnOLIzpGLTvS88H6irWqUGGDaZ1
86vnaW/AHY/cVBcbW+SYW2TmfpsLy604b9zYdrhVHVItK78GrTZ0vTw/e3QR
c01uOedAw2phU9yxr3Fq3Bzv3uqrYC1pf2sjZ6PH7aTLS5KuwO93AzncORy8
agbtUncpCMK2lZnuc8SgsGjfEcsseFcseuvWNRczuj4kW9Eywane3qg00Qmp
l2RePsMSUA9pB8aYPKx+bqxdqCOB18FpJ/3seBhh2DJqNkFCV7bVUM5cHga4
FlIHRkiwCoi1DXHj4c/e92Zf15CwLrDYUB3Aw6aNC4L4KhJ+bMsPWnyWh+6b
H6giKkjIGLiGvjQCjQQBKE0gYcaJhUOd0wgsKUg0l+wloYF7/0D0LAJXhhkp
xXEkCKpkrAwOgRNM560XI0l441903sCLwIdlK9h/BX/eTy1xTSJQT3J00bMl
JDCk5rY9JwiMWtx7Tu1OQhh1447z5wiMrG/vHviGhPHqJPH4ZQIdShLDaQQJ
+RTGH8oqAhvcgj+ttibBdzflU0YtgYqsCoMQJglVv7b4bVIQmL6mWS/WkoTT
YmaWSkXgcXtH5SVTEvwv7c6U9hI46qMtLaST8PiMKCVcQ2B52cGj9QYkTE0f
WuMyQuAVU9HKHir5/2/Nxy+S8C83CTvE
          "]]}, Annotation[#, "Charting`Private`Tag$2471#1"]& ]}}}, {
    AxesLabel -> {
       FormBox["\"Entry fee\"", TraditionalForm], 
       FormBox["\"Probability\"", TraditionalForm]}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], Axes -> {True, True}, AxesLabel -> {
       FormBox["\"Entry fee\"", TraditionalForm], 
       FormBox["\"Pr(recovery)\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> Automatic, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 400, 
     Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {{0., 16.}, {0., 1.}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"Pr(Recovery)\"", "\"Pr(Entry Fee x 2)\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.9, 1, 1], 
                    AbsoluteDashing[{2, 2}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.9, 1, 1], 
                    AbsoluteDashing[{2, 2}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.5, 1, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.5, 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.9, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.9`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.9], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "]"}], ",", 
               InterpretationBox[
                ButtonBox[
                 TooltipBox[
                  GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                   "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                   FrameStyle -> Hue[0.5, 1., 0.6666666666666667], FrameTicks -> 
                   None, PlotRangePadding -> None, ImageSize -> 
                   Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  StyleBox[
                   RowBox[{"Hue", "[", "0.5`", "]"}], NumberMarks -> False]], 
                 Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                 Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                 With[{Typeset`box$ = EvaluationBox[]}, 
                   If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.5, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                 Automatic, Method -> "Preemptive"], 
                Hue[0.5], Editable -> False, Selectable -> False]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& ), Editable -> True], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.4027505376885*^9, 3.402750583766625*^9, {3.4027508175635*^9, 
   3.402750840610375*^9}, 3.402750920704125*^9, 3.402751321829125*^9, 
   3.40275135665725*^9, 3.5296133571027107`*^9, 3.529613403136344*^9, 
   3.52961547137364*^9, 3.5296155636399174`*^9, 3.529698555903803*^9, 
   3.5297899989500465`*^9, 3.529793112967574*^9, 3.5299351156877036`*^9, 
   3.5299373222119093`*^9, 3.530016398357806*^9, 3.5300167183261075`*^9, 
   3.530017180719555*^9, 3.53019368546432*^9, 3.5301942229110603`*^9, 
   3.5314482250455284`*^9, 3.5315006219314585`*^9, 3.533134687055351*^9, 
   3.5331358779444656`*^9, 3.533682246140625*^9, 3.533734570098778*^9, 
   3.53375413778125*^9, 3.533755410390625*^9, 3.538685205816201*^9, 
   3.5386855197881594`*^9, 3.539635953552911*^9, 3.540126789958082*^9, 
   3.541012612575942*^9, 3.541015082826232*^9, 3.5410155456707053`*^9, 
   3.541600426951938*^9, 3.5433421741552153`*^9, 3.696338458158893*^9, 
   3.6963423720790358`*^9, 3.696544356756958*^9, 3.6965445450899997`*^9, 
   3.731421183899007*^9},
 TextAlignment->Center,ExpressionUUID->"43edc92e-92c6-4e5b-85cd-4990c09eee9e"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.2.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Probabilities of recovery and doubling one\[CloseCurlyQuote]s money as \
entry fee increases."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500176435978*^9}, 
   3.5386855197881594`*^9},
 TextAlignment->Center,ExpressionUUID->"e39077c7-5b64-40cb-868d-e9cdf99a7327"],

Cell[TextData[{
 "There is another problem with this game. We are concerned that the bank \
offering this bet cannot take the loss (will go bankrupt) if the payoff \
becomes too high.  To avoid this we limit the number of rounds that may take \
place.  Taking the expected value of a series of different ",
 StyleBox["k",
  FontSlant->"Italic"],
 ", each acting as a cap, and ",
 StyleBox["comparing it with the expected value of the payoff shows a drastic \
reduction in expectations, even for a very large bank",
  FontColor->GrayLevel[0]],
 ". This may be seen best in two illustrations.  First, all is well if only \
three rounds are permitted.  The maximum Payoff is $8 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["2", "3"], ")"}], TraditionalForm]],ExpressionUUID->
  "16bafdb8-97ce-4469-8305-14266331fe35"],
 " and the expected value of that payoff is $2. But dramatic things happen \
with even a modest number of extra rounds.  On the right side of Figure 6.3 \
we see that a game of 30 rounds still has a small expected value but exposes \
the bank to a loss of over $1 Trillion."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296149627535486`*^9, 3.5296149672898083`*^9}, {
  3.53375460865625*^9, 3.533754608875*^9}, {3.5386855197881594`*^9, 
  3.5386855197891593`*^9}, {3.5410129094089193`*^9, 
  3.541012912826115*^9}},ExpressionUUID->"c5d27fa6-56b6-4d47-8519-\
076fd2772c6f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"epk", "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], 
      RowBox[{"k", "+", "1"}]], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "n"], " ", 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}], "+", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       RowBox[{"k", "+", "2"}]}], "\[Infinity]"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", "2"], ")"}], "n"]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pp1", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["2", "k"], ",", "epk"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
     RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Max Payoff (3 rounds)\>\"", ",", 
        "\"\<Expected Value of payoff\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pp2", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["2", "k"], ",", "epk"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "30"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["10", "8"]}], ",", 
          RowBox[{"6", " ", 
           SuperscriptBox["10", "8"]}], ",", 
          SuperscriptBox["10", "9"]}], "}"}], ",", "Automatic"}], "}"}]}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Max Payoff (30 rounds)\>\"", ",", 
        "\"\<Expected Value of payoff\>\""}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["10", "8"]}], ",", "\"\<200 Bil\>\""}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox["10", "8"]}], ",", "\"\<600 Bil\>\""}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox["10", "9"], ",", "\"\<1,000 Bil\>\""}], "}"}]}], 
         "}"}], ",", "Automatic"}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"fig2", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"GraphicsRow", "[", 
     RowBox[{"{", 
      RowBox[{"pp1", ",", "pp2"}], "}"}], "]"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", ".5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.402751912704125*^9, 3.402751916141625*^9}, {
   3.402752014251*^9, 3.4027520429385*^9}, {3.5296135212931013`*^9, 
   3.529613527225441*^9}, {3.533134796129589*^9, 3.533134850305688*^9}, {
   3.5337545528125*^9, 3.53375457309375*^9}, 
   3.538685519790159*^9},ExpressionUUID->"d88a3520-b6e2-41f2-b657-\
3bfd055a3707"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw1lH0w1Hkcx79rLdYiz9n18JMejuOuK1Kuh8/nJJRE8lS59DB1tAo3yZIW
zTa6U7voKHmKMBFJVxRS7hi2cOVUlzoZ40LFdvntAxbnprvPzHte85r33+/P
ov3RAQc1CCG+8/mX/x1+Ag3NsR3v7jEILuNWOfTMe1KTlU4Sk2CSSBBeyqAh
hSHsUWkRzNU9IvNm0pAdWX+d1ifY9bbocpYWDaeyr/4gtyRovVTLy16fhsjH
d8ct1xB8G1B2KYxHw6IEx2J1DMHmbCfTURcati5+6ktkBLu96u7xoml44nxW
YhTBwA0+Pm+cy2mIqYmY1B1kYLDJH0Ojr2jYnHHRye6wBuop9Tw0uXL4jZ+k
//C9Bg70e3h2bpfDxlpGa4KQicGbqj43zJCDb461bauRJi5/uthutEsOicl7
e42LNJHlHiJ001FAU6db9M11LAzt6d1s462Ao7nZaQt7WUjfSS3bI1JAVpas
IDdKC/fxr/ip7yuguWhLRYe5NlafCM32YChBXsWPt23QRo3M7sSGDUow6f7u
5OYYHWyPPHZ3LFUJFmfz3x6xZ6N8qH6FoFUJxVkTepwXbJyz/ujCYqqg8Wsb
B9NCXSyMkToc8FLBknsyteduDi5RjEiq01SwUsql13yph0KW2PFFlwpKKw2e
pTL10fvbQvf1JpMw4WlV4fBYH+Vafo4RgZMwk1mWc+SWAZopijaezpuEkk2p
TbclC5Ctm/Q6qH8Skr0y6/1cDdEsIdlrje0UbFgyMSKuNUTPQIWzVcQUCPI+
fOz/zAhdY6M6zl+bgtg9vzt1XTPChPK+51z5FEjCBnK/WGGMNQvHv69ePw0h
uwsuU7XGuC7M+3ld6jTwnqlLX4AJptfZub96NA3u3KC17ztM0HNw9eIIIzVI
et4x5gJM8UJjXd9gkBrOjaxoMB0zxfgtwt7Tl9XwjYZsjE4xw5tlxcq4N2oo
jYpMH1hqjkOm0T9fXDkD6BHvH9Rqjs7sv5ymE2Zg/2A/TB9YiM+vcPaufTAD
Wp5+Z7nmFigKz3l0R28WOkxWXbVusUDptbrH4YGz8FJ6StKZzEXmoRpd35JZ
6MvSiclBHvpPVDLNZLOQly6+IJ7kYRvV1fu36xzAQcvDA+2W6IXD62xOz0Hb
/bxQA7EVVu2UPQvsnoOM9xz1zSBr1CpJibLnEAwu/7ggwcUGx9pvxwWsJPjT
eCVu06XQTa7XrQom2OdzPNzcgMIMzUfV+SEEOekudL8RheUsoQRDCbY6/poc
y6XQeLQl9MxOgrtaGm3z7Sm8/mODhkUYwdc76nK0vSjcP+d2a/U+glJHgzur
RRQaHpKmC/gEi0KW1xqcoTCec6PCKoqgWZmx3Zt0Cl8aiqQP5j2cuYufc57C
HT4TBuyjBNVtogJ1CYVp48M3cud3WUMszr1uoTDglNy/MY6gQNuV3dxG4bB+
zrnw4wS3CshsvpTCS2ttO5nxBFsinm4Pe0LhiPjDtvkOJQWWpQMDFB7KTOT/
mUhwmrgN/zJE4YLKffWpJwj6FwqulI1QWHzmK9ayJIIPM3LToj5QqKwQlR89
SfBY9MUaf5pC5nH2lLGQoGEe7b9KRaGYF+dXP+9Dr5r4PDWFvmHt5buT//9b
tp+YQvAfs0IY4w==
          "]]},
        Annotation[#, "Charting`Private`Tag$3772#1"]& ]},
      AspectRatio->NCache[
        Rational[1, 2], 0.5],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{2., 1.25},
      DisplayFunction->Identity,
      Frame->{{True, False}, {True, False}},
      FrameLabel->{{
         FormBox["\"Expected Value of payoff\"", TraditionalForm], None}, {
         FormBox["\"Max Payoff (3 rounds)\"", TraditionalForm], None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->Automatic,
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{"ScalingFunctions" -> None},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {192., -94.5}, 
     ImageScaled[{0.5, 0.5}], {360., 180.}], InsetBox[
     GraphicsBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwtWnk0FVy0vzJmnufhXlxcwzWH8N19yEyRscg8JIQyVIbI7CNDqEyZCilz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          "]]},
        Annotation[#, "Charting`Private`Tag$3795#1"]& ]},
      AspectRatio->NCache[
        Rational[1, 2], 0.5],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 1.25},
      DisplayFunction->Identity,
      Frame->{{True, False}, {True, False}},
      FrameLabel->{{
         FormBox["\"Expected Value of payoff\"", TraditionalForm], None}, {
         FormBox["\"Max Payoff (30 rounds)\"", TraditionalForm], None}},
      FrameTicks->{{Automatic, Automatic}, {{{200000000, 
           FormBox["\"200 Bil\"", TraditionalForm]}, {600000000, 
           FormBox["\"600 Bil\"", TraditionalForm]}, {1000000000, 
           FormBox["\"1,000 Bil\"", TraditionalForm]}}, {{200000000, 
           FormBox["\"200 Bil\"", TraditionalForm]}, {600000000, 
           FormBox["\"600 Bil\"", TraditionalForm]}, {1000000000, 
           FormBox["\"1,000 Bil\"", TraditionalForm]}}}},
      GridLines->{{200000000, 600000000, 1000000000}, Automatic},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{"ScalingFunctions" -> None},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {576., -94.5}, 
     ImageScaled[{0.5, 0.5}], {360., 180.}]}, {}},
  AspectRatio->0.5,
  ContentSelectable->True,
  ImageSize->600,
  PlotRangePadding->{6, 5}]], "Output",
 PageWidth->WindowWidth,
 CellMargins->{{22, 10}, {10, 5}},
 CellChangeTimes->{
  3.402658641875*^9, 3.40265900496875*^9, 3.402699570735375*^9, 
   3.402751869204125*^9, 3.402752050172875*^9, 3.5296134919024205`*^9, {
   3.5296135228911934`*^9, 3.5296135275074573`*^9}, 3.5296154715226483`*^9, 
   3.529615563790926*^9, 3.529698556236822*^9, 3.529789999414073*^9, 
   3.5297931139206285`*^9, 3.529935116199733*^9, 3.5299373223999205`*^9, 
   3.5300163987528286`*^9, 3.530016718682128*^9, 3.5300171809765697`*^9, 
   3.5301936858033395`*^9, 3.530194223096071*^9, 3.531448225284542*^9, 
   3.5315006222594776`*^9, 3.533134687613383*^9, {3.5331348102123947`*^9, 
   3.5331348508787208`*^9}, 3.533135878146477*^9, 3.533682246546875*^9, 
   3.533734570629808*^9, 3.533754138171875*^9, 3.53375457409375*^9, 
   3.533755410734375*^9, 3.538685206553243*^9, 3.5386855198071604`*^9, 
   3.539635954013937*^9, 3.5401267907641277`*^9, 3.5410126134629927`*^9, 
   3.541015083652279*^9, 3.541015547251796*^9, 3.541600427711982*^9, 
   3.543342174895258*^9, 3.696338458367469*^9, 3.6963423722836018`*^9, 
   3.6965443569414606`*^9, 3.7314211904032793`*^9},
 TextAlignment->Center,ExpressionUUID->"61921493-1f37-40d1-996c-e8969b645ab1"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.3.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Risk of the St. Petersburg Paradox coin flipping game to the sponsor."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315001967321386`*^9}, 
   3.5386855198071604`*^9},
 TextAlignment->Center,ExpressionUUID->"ac3c9775-c959-4440-91b6-95695b851a5e"],

Cell[TextData[{
 "So Bernoulli's coin flipping game is hard to justify. Later we question \
whether real estate investors can ",
 StyleBox["ever",
  FontSlant->"Italic"],
 " justify a game in which the risk is based on flipping coins."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198071604`*^9},ExpressionUUID->"84e9c4f4-b544-4385-9a06-\
55f004a9c81b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3. The utility function revisited", "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531447172614333*^9, 3.5314480177156696`*^9, 
  3.5386855198071604`*^9},ExpressionUUID->"0e4e25b3-167f-4ef2-a941-\
261e37be21ba"],

Cell["\<\
We first encountered the idea of utility in Chapter Two, using it to indicate \
conditions under which a community was \"better off\" depending on how they \
made choices.  There is a natural extension to the individual (some would \
argue that individual utility is the starting point and the extension is to \
the community but we won't quibble with such things here).  People make \
choices. Some are good, some are bad. Very often, in fact usually, it is not \
possible to know in advance whether a choice will turn out to be a good one \
or not.  Models that involve choice under conditions of uncertainty need a \
way to measure outcome. Utility serves in that capacity, going up or down \
depending on the success achieved following a given choice. \
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5296135762432446`*^9, 
  3.5386855198071604`*^9},ExpressionUUID->"7589ede0-8842-49d2-8d46-\
125b54bd075b"],

Cell["\<\
From a mathematical standpoint there is a practical aspect of utility that \
involves the illustration of results graphically. Each of the two choices \
requires an axis. We need a third axis to scale and measure the benefit or \
cost of any outcome arising from making choices or choosing different \
combinations of the two choices.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296135762432446`*^9, 3.5296135809115114`*^9}, 
   3.5386855198071604`*^9},ExpressionUUID->"641bcb4c-c982-4f55-bbcf-\
75dda17a02fd"],

Cell[TextData[{
 StyleBox["Despite the fact that we grapple with multiple-dimensional \
problems daily (ask the parent of two children!), the display on a 3D graph \
can be confusing. In ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["Figure 6.4 ",
  FontFamily->"Times New Roman",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["one should focus on any point on the vertical axis labeled \
\"Utility\". Recall that utility is ordinal, meaning that higher on that axis \
is better. At any given point on that vertical axis there is a corresponding \
point on the plane where the combination of two choices intersect to create \
the value on the vertical axis. For example, on the left of ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["Figure 6.4 a line connects the utility value of 30 with the values \
5 and 6 for Choice A and B respectively. Here utility is a function of the \
product of these two choice values. The rendering on the right of Figure 6.4 \
is the same plot with a flat plane at utility value = 30 intersecting the \
utility function at all the points where the two choices may be combined in \
different ways to produce utility of ",
  FontFamily->"Times New Roman",
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["30.", 
    ButtonBox["1",
     BaseStyle->"Hyperlink",
     ButtonData->"endnote1"]], TraditionalForm]],ExpressionUUID->
  "7c016157-aa6c-4473-a07d-e01390314ca9"]
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296135762432446`*^9, 3.5296135816225524`*^9}, {
  3.5296150588700457`*^9, 3.5296150593290725`*^9}, {3.5296151495712337`*^9, 
  3.52961515002726*^9}, {3.529615609085517*^9, 3.5296156123387027`*^9}, {
  3.5296994034762816`*^9, 3.529699407768527*^9}, {3.5297094167550087`*^9, 
  3.5297094331049433`*^9}, {3.5297095161186914`*^9, 3.5297095161186914`*^9}, {
  3.5386855198071604`*^9, 
  3.53868551980916*^9}},ExpressionUUID->"6d93a378-1a73-48a5-aec3-\
4d760c5b2872"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"shplot1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Plot3D", "[", 
      RowBox[{
       RowBox[{"x", " ", "y"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "10"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "5", "}"}], ",", 
          RowBox[{"{", "6", "}"}], ",", 
          RowBox[{"{", "30", "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\\nChoice A\>\"", ",", "\"\<\\nChoice B\>\"", ",", 
          "\"\<Utility   \>\""}], "}"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "10"}]}], "]"}], ",", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"AbsoluteThickness", "[", "3", "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "30"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "6", ",", "30"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"shplot2", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Plot3D", "[", 
      RowBox[{"30", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "10"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "5", "}"}], ",", 
          RowBox[{"{", "6", "}"}], ",", 
          RowBox[{"{", "30", "}"}]}], "}"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\\nChoice A\>\"", ",", "\"\<\\nChoice B\>\"", ",", 
          "\"\<Utility   \>\""}], "}"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "10"}]}], "]"}], ",", 
     RowBox[{"Plot3D", "[", 
      RowBox[{
       RowBox[{"x", " ", "y"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "10"}], "}"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "5", "}"}], ",", 
          RowBox[{"{", "6", "}"}], ",", 
          RowBox[{"{", "30", "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\\nChoice A\>\"", ",", "\"\<\\nChoice B\>\"", ",", 
          "\"\<Utility   \>\""}], "}"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "10"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "}"}], ",", 
        RowBox[{"{", "}"}], ",", 
        RowBox[{"{", "30", "}"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"fig3", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"GraphicsRow", "[", 
     RowBox[{"{", 
      RowBox[{"shplot1", ",", "shplot2"}], "}"}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "550"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.40265904884375*^9, 3.402659066265625*^9}, 
   3.529615276327484*^9, {3.5296153241402187`*^9, 3.5296153281964507`*^9}, {
   3.529615398935497*^9, 3.5296154124292684`*^9}, {3.529615507586711*^9, 
   3.5296155420546827`*^9}, 
   3.53868551980916*^9},ExpressionUUID->"00ed8709-05c8-47ae-bc5d-\
f488a0d8a936"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxlnAdYVMfXxik2LKgoorKKqIgSorHhGmD3iqjYAAuIJcaaWGLBEmuMJsQe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        "], {{
          {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
            GrayLevel[1], 3], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[{Polygon3DBox[CompressedData["
1:eJwtmHfgl9Mex8+IaySJlAjdyOZmhFtEVinjJrNFFImIknUbaNAuUUlbSXbI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                "]], Polygon3DBox[CompressedData["
1:eJwtmXccV9Mbx+89J7LJlp2MjCRChOwKERVlpEhlZSaRUWSPZP1syciOX3Z2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                "]], Polygon3DBox[CompressedData["
1:eJwtlmW4VkUUhb9zDiEpKR2XkG4F6ZLubi5cOi9wEZDmAj50gyAgSiog3R3S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                "]], 
               Polygon3DBox[{{735, 317, 193, 192, 438, 682}, {509, 508, 806, 
                439, 441, 807}, {647, 328, 445, 810, 526, 527}, {730, 308, 
                169, 168, 429, 678}, {731, 309, 173, 172, 432, 679}, {694, 
                454, 205, 206, 455, 695}, {652, 339, 453, 814, 542, 543}, {
                643, 319, 442, 808, 512, 513}, {646, 327, 443, 809, 522, 
                523}, {696, 457, 207, 208, 458, 697}, {756, 352, 236, 235, 
                465, 699}, {529, 528, 812, 450, 452, 813}}]},
              Annotation[#, "Charting`Private`Tag$3880#1"]& ]],
            Lighting->{{"Ambient", 
               RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
              "Directional", 
               RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
               ImageScaled[{0, 2, 2}]}, {"Directional", 
               RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
               ImageScaled[{2, 2, 2}]}, {"Directional", 
               RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
               ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
          {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0TdLA2EAx+Gzx7bpZsuiiTXJjbZNN0vc7CaimxkEAy46iWXVQewgCgqi
oKDg6Ozg4hfwAwhuTj4Bh4ff/4WD946LZnLplaIgCFY5oLD3WefHoVo/i4Pg
SH+d67XGuZZmu0WjxO1QQx3QQfrttE4wbC/pMuP2u27pOVOcsEurO6a1TWPM
2HFtZ9bu0E7m7C6d127tYcFOaJKMndKQrP2l23rBIqfssek9JjWva4zZWc0w
ZI/qCH12r6Y0qQlidqM20GRXaoQ6+0039IwqjtnhtfAcLzwT4YlHKnjgnnLu
KOOWG0q55ooSvn3ToV7iuuDDOf//H/8AnhYs2A==
            "]]}, 
          {GrayLevel[0.2], 
           Line3DBox[{499, 725, 676, 701, 485, 720, 700, 1020, 677, 704, 818, 
            1002, 721, 703, 1021, 678, 730, 1003, 706, 1022, 679, 731, 1004, 
            500, 819, 641, 501, 820, 732, 911, 502, 821, 733, 912, 503, 822, 
            734, 913, 504, 1023, 707, 642, 708}], 
           Line3DBox[{506, 680, 710, 1027, 722, 723, 709, 1024, 681, 713, 491,
             724, 712, 1025, 682, 735, 1005, 509, 807, 823, 736, 1007, 511, 
            685, 824, 643, 513, 826, 827, 644, 515, 828, 739, 923, 517, 829, 
            741, 926, 519, 830, 645, 521}], 
           Line3DBox[{520, 927, 742, 518, 925, 924, 740, 516, 922, 921, 738, 
            514, 920, 737, 825, 512, 808, 919, 684, 510, 1006, 683, 918, 806, 
            508, 805, 917, 916, 804, 507, 803, 915, 705, 726, 494, 505, 802, 
            914, 702, 729, 728, 727}], 
           Line3DBox[{525, 687, 715, 1026, 646, 523, 1009, 689, 831, 647, 527,
             811, 832, 329, 529, 813, 833, 743, 1012, 531, 834, 648, 533, 836,
             837, 649, 535, 839, 840, 650, 537, 841, 748, 936, 539, 842, 651, 
            541}], Line3DBox[{540, 937, 749, 538, 935, 934, 747, 536, 933, 
            746, 838, 534, 932, 745, 835, 532, 931, 744, 530, 1011, 691, 930, 
            812, 528, 1010, 690, 447, 526, 810, 929, 714, 688, 1008, 522, 809,
             928, 711, 686, 524}], 
           Line3DBox[{545, 693, 843, 652, 543, 815, 844, 845, 653, 547, 816, 
            846, 847, 654, 549, 817, 848, 342, 551, 849, 655, 553, 851, 852, 
            656, 555, 854, 855, 657, 557, 857, 858, 658, 559, 859, 659, 561}],
            Line3DBox[{560, 943, 754, 558, 942, 753, 856, 556, 941, 752, 853, 
            554, 940, 751, 850, 552, 939, 750, 550, 1017, 698, 460, 548, 1015,
             697, 696, 1016, 546, 1013, 695, 694, 1014, 542, 814, 938, 716, 
            692, 544}], 
           Line3DBox[{563, 755, 944, 562, 1019, 699, 756, 1018, 564, 860, 757,
             945, 565, 861, 758, 946, 566, 357, 567, 862, 759, 947, 568, 863, 
            760, 948, 569, 864, 761, 949, 570, 865, 660, 571}], 
           Line3DBox[{575, 866, 661, 573, 867, 764, 953, 577, 868, 766, 956, 
            579, 869, 768, 959, 581, 870, 662, 583, 871, 374, 585, 872, 771, 
            964, 587, 873, 773, 967, 589, 874, 663, 591}], 
           Line3DBox[{590, 968, 774, 588, 966, 965, 772, 586, 963, 962, 770, 
            584, 961, 373, 582, 960, 769, 580, 958, 957, 767, 578, 955, 954, 
            765, 576, 952, 951, 763, 572, 950, 762, 574}], 
           Line3DBox[{595, 875, 664, 593, 877, 878, 665, 597, 879, 778, 973, 
            599, 880, 780, 976, 601, 881, 666, 603, 883, 884, 667, 605, 885, 
            391, 607, 886, 784, 982, 609, 887, 668, 611}], 
           Line3DBox[{610, 983, 785, 608, 981, 980, 783, 606, 979, 390, 604, 
            978, 782, 882, 602, 977, 781, 600, 975, 974, 779, 598, 972, 971, 
            777, 596, 970, 776, 876, 592, 969, 775, 594}], 
           Line3DBox[{615, 888, 669, 613, 890, 891, 670, 617, 893, 894, 671, 
            619, 895, 790, 989, 621, 896, 672, 623, 898, 899, 673, 625, 901, 
            902, 674, 627, 903, 408, 629, 904, 675, 631}], 
           Line3DBox[{630, 994, 794, 628, 993, 407, 626, 992, 793, 900, 624, 
            991, 792, 897, 622, 990, 791, 620, 988, 987, 789, 618, 986, 788, 
            892, 616, 985, 787, 889, 612, 984, 786, 614}], 
           Line3DBox[{640, 719, 482, 639, 1001, 801, 910, 638, 1000, 800, 909,
             637, 999, 799, 908, 636, 998, 798, 635, 997, 797, 907, 634, 996, 
            796, 906, 633, 995, 795, 905, 632, 481, 717, 718}]}, 
          {GrayLevel[0.2], 
           Line3DBox[{164, 497, 498, 468, 1020, 426, 471, 494, 495, 477, 1024,
             435, 480, 444, 1008, 1009, 446, 205, 454, 1014, 456, 844, 220, 
            463, 1019, 465, 235, 951, 366, 867, 250, 381, 876, 877, 265, 396, 
            889, 890, 280, 411, 905, 295}], 
           Line3DBox[{166, 427, 470, 1021, 429, 168, 916, 436, 479, 1025, 438,
             192, 447, 449, 832, 207, 457, 1016, 459, 846, 222, 353, 860, 237,
             954, 368, 868, 252, 971, 383, 879, 267, 398, 892, 893, 282, 413, 
            906, 297}], 
           Line3DBox[{170, 430, 473, 1022, 432, 172, 918, 439, 441, 823, 194, 
            930, 450, 452, 833, 209, 460, 462, 848, 224, 355, 861, 239, 957, 
            370, 869, 254, 974, 385, 880, 269, 987, 400, 895, 284, 415, 907, 
            299}], Line3DBox[{174, 310, 819, 175, 919, 442, 319, 824, 196, 
            931, 331, 834, 211, 939, 343, 849, 226, 357, 241, 960, 372, 870, 
            256, 977, 387, 881, 271, 990, 402, 896, 286, 998, 417, 301}], 
           Line3DBox[{176, 311, 820, 178, 320, 825, 826, 197, 332, 835, 836, 
            212, 344, 850, 851, 227, 358, 862, 242, 373, 871, 257, 388, 882, 
            883, 272, 403, 897, 898, 287, 418, 908, 302}], 
           Line3DBox[{180, 313, 821, 182, 921, 322, 828, 199, 334, 838, 839, 
            214, 346, 853, 854, 229, 360, 863, 244, 962, 375, 872, 259, 390, 
            885, 274, 405, 900, 901, 289, 420, 909, 304}], 
           Line3DBox[{184, 315, 822, 186, 924, 324, 829, 201, 934, 336, 841, 
            216, 348, 856, 857, 231, 362, 864, 246, 965, 377, 873, 261, 980, 
            392, 886, 276, 407, 903, 291, 422, 910, 306}], 
           Line3DBox[{188, 474, 1023, 475, 189, 927, 326, 830, 203, 937, 338, 
            842, 218, 943, 350, 859, 233, 364, 865, 248, 968, 379, 874, 263, 
            983, 394, 887, 278, 994, 409, 904, 293, 482, 483, 484}], 
           Line3DBox[{294, 410, 481, 279, 888, 395, 984, 264, 875, 380, 969, 
            249, 866, 365, 950, 234, 351, 944, 219, 843, 339, 453, 938, 204, 
            1026, 327, 443, 928, 190, 490, 1027, 489, 476, 433, 914, 163, 486,
             485, 467, 424, 493, 466}], 
           Line3DBox[{296, 412, 995, 281, 891, 397, 985, 266, 878, 382, 970, 
            251, 367, 953, 952, 236, 352, 1018, 464, 221, 845, 340, 1013, 455,
             206, 831, 328, 445, 929, 191, 492, 491, 478, 434, 915, 165, 488, 
            487, 1002, 469, 425, 496}], 
           Line3DBox[{298, 414, 996, 283, 894, 399, 986, 268, 384, 973, 972, 
            253, 369, 956, 955, 238, 354, 945, 223, 847, 341, 1015, 458, 208, 
            329, 1010, 448, 193, 317, 1005, 437, 917, 169, 308, 1003, 472, 
            428, 167}], 
           Line3DBox[{300, 416, 997, 285, 401, 989, 988, 270, 386, 976, 975, 
            255, 371, 959, 958, 240, 356, 946, 225, 342, 1017, 461, 210, 330, 
            1012, 1011, 451, 195, 318, 1007, 1006, 440, 173, 309, 1004, 431, 
            171}], Line3DBox[{303, 419, 999, 288, 899, 404, 991, 273, 884, 
            389, 978, 258, 374, 961, 243, 359, 947, 228, 852, 345, 940, 213, 
            837, 333, 932, 198, 827, 321, 920, 179, 312, 911, 177}], 
           Line3DBox[{305, 421, 1000, 290, 902, 406, 992, 275, 391, 979, 260, 
            376, 964, 963, 245, 361, 948, 230, 855, 347, 941, 215, 840, 335, 
            933, 200, 323, 923, 922, 183, 314, 912, 181}], 
           Line3DBox[{307, 423, 1001, 292, 408, 993, 277, 393, 982, 981, 262, 
            378, 967, 966, 247, 363, 949, 232, 858, 349, 942, 217, 337, 936, 
            935, 202, 325, 926, 925, 187, 316, 913, 185}]}, {}, {}}},
        VertexNormals->CompressedData["
1:eJx0m3k0lV3Y/5UUSioJEQqVKCQp05YiSYNoLkpCaC5pQqhEZU6UJhpMiczT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         "]], 
       {AbsoluteThickness[3], Line3DBox[{{0, 0, 30}, {5, 6, 30}}]}},
      Axes->True,
      AxesLabel->{
        FormBox["\"\\nChoice A\"", TraditionalForm], 
        FormBox["\"\\nChoice B\"", TraditionalForm], 
        FormBox["\"Utility   \"", TraditionalForm]},
      AxesOrigin->{Automatic, Automatic, Automatic},
      BoxRatios->{1, 1, 0.4},
      DisplayFunction->Identity,
      FaceGrids->None,
      FaceGridsStyle->Automatic,
      Method->{"DefaultBoundaryStyle" -> Directive[
          GrayLevel[0.3]], "RotationControl" -> "Globe"},
      PlotRange->{{0, 10}, {0, 10}, {0., 99.99997777777902}},
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{5, 
          FormBox["5", TraditionalForm]}}, {{6, 
          FormBox["6", TraditionalForm]}}, {{30, 
          FormBox["30", TraditionalForm]}}}], {192., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.},
     ContentSelectable->True], InsetBox[
     Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJx1mwusVNUVhgfEB8hDUURlgHtRtEVqtVIdqpUbH8ViqkQdImrUiqYSa2VA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        "], {{
          {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
            GrayLevel[1], 3], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[{Polygon3DBox[CompressedData["
1:eJwtmHcUVsURxfftCggiTXrviqIiVXoTpAmCVKWL9CK9VwUFEVBQQAWNJRgF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                "]], Polygon3DBox[CompressedData["
1:eJw1mHn8l1MWx597v2mZ0KISiV/IUpEsyVIiIlLaVdYsWcYyhrHOxMsY2TK2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                "]], Polygon3DBox[CompressedData["
1:eJwtl2WYFUcQRefNY3F3d9cE1+DuCwS3DW6LBXd316DB3UNwd3d3EpLgEiB4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                "]]},
              Annotation[#, "Charting`Private`Tag$3950#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}}, {
          {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0c0qhFEAx+GDGWOMr0KsyMpYYsuWLVbybUgSMyx8i6IoURRlQdbcAcUd
UNwBWSrugOfE4un3n5rTnPedllxhIF8UQlhinbiXmeHah4ze6C319oM+0my/
6Ctt9od26pd+022XFIeQoNdu0Eb67SGd002GWaUQv+/ciCY0yahdqinG7DJN
M26X64RmtIJJu1KryNnVWsOUfanzusU0ayzS7h5DmtVW+uw6raXHDvrjbJf5
qR36rm9k7Wd9osm+1zvq7EHnZnUj3pMV8lyQ5pyz+DycckKKY47iM3NIkgP2
4zthj934nthh+++K4crvLvz/f79yvCqE
            "],
            VertexColors->None]}, 
          {GrayLevel[0.2], 
           Line3DBox[{415, 598, 273, 414, 687, 604, 791, 416, 688, 605, 792, 
            417, 689, 606, 793, 418, 690, 562, 419, 691, 607, 794, 420, 692, 
            608, 795, 421, 693, 609, 796, 422, 895, 599, 563, 600},
            VertexColors->None], 
           Line3DBox[{426, 694, 564, 424, 695, 289, 428, 696, 612, 801, 430, 
            697, 614, 804, 432, 698, 565, 434, 700, 701, 566, 436, 702, 618, 
            809, 438, 703, 620, 812, 440, 704, 567, 442},
            VertexColors->None], 
           Line3DBox[{441, 813, 621, 439, 811, 810, 619, 437, 808, 807, 617, 
            435, 806, 616, 699, 433, 805, 615, 431, 803, 802, 613, 429, 800, 
            799, 611, 427, 798, 288, 423, 797, 610, 425},
            VertexColors->None], 
           Line3DBox[{446, 705, 568, 444, 707, 708, 569, 448, 709, 306, 450, 
            710, 625, 819, 452, 711, 570, 454, 713, 714, 571, 456, 716, 717, 
            572, 458, 718, 630, 825, 460, 719, 573, 462},
            VertexColors->None], 
           Line3DBox[{461, 826, 631, 459, 824, 823, 629, 457, 822, 628, 715, 
            455, 821, 627, 712, 453, 820, 626, 451, 818, 817, 624, 449, 816, 
            305, 447, 815, 623, 706, 443, 814, 622, 445},
            VertexColors->None], 
           Line3DBox[{466, 720, 574, 464, 722, 723, 575, 468, 725, 726, 576, 
            470, 727, 323, 472, 728, 577, 474, 730, 731, 578, 476, 733, 734, 
            579, 478, 736, 737, 580, 480, 738, 581, 482},
            VertexColors->None], 
           Line3DBox[{481, 835, 639, 479, 834, 638, 735, 477, 833, 637, 732, 
            475, 832, 636, 729, 473, 831, 635, 471, 830, 322, 469, 829, 634, 
            724, 467, 828, 633, 721, 463, 827, 632, 465},
            VertexColors->None], 
           Line3DBox[{484, 640, 836, 483, 739, 641, 837, 485, 740, 642, 838, 
            486, 741, 643, 839, 487, 339, 488, 742, 644, 840, 489, 743, 645, 
            841, 490, 744, 646, 842, 491, 745, 582, 492},
            VertexColors->None], 
           Line3DBox[{496, 746, 583, 494, 747, 649, 846, 498, 748, 651, 849, 
            500, 749, 653, 852, 502, 750, 584, 504, 751, 356, 506, 752, 656, 
            857, 508, 753, 658, 860, 510, 754, 585, 512},
            VertexColors->None], 
           Line3DBox[{511, 861, 659, 509, 859, 858, 657, 507, 856, 855, 655, 
            505, 854, 355, 503, 853, 654, 501, 851, 850, 652, 499, 848, 847, 
            650, 497, 845, 844, 648, 493, 843, 647, 495},
            VertexColors->None], 
           Line3DBox[{516, 755, 586, 514, 757, 758, 587, 518, 759, 663, 866, 
            520, 760, 665, 869, 522, 761, 588, 524, 763, 764, 589, 526, 765, 
            373, 528, 766, 669, 875, 530, 767, 590, 532},
            VertexColors->None], 
           Line3DBox[{531, 876, 670, 529, 874, 873, 668, 527, 872, 372, 525, 
            871, 667, 762, 523, 870, 666, 521, 868, 867, 664, 519, 865, 864, 
            662, 517, 863, 661, 756, 513, 862, 660, 515},
            VertexColors->None], 
           Line3DBox[{536, 768, 591, 534, 770, 771, 592, 538, 773, 774, 593, 
            540, 775, 675, 882, 542, 776, 594, 544, 778, 779, 595, 546, 781, 
            782, 596, 548, 783, 390, 550, 784, 597, 552},
            VertexColors->None], 
           Line3DBox[{551, 887, 679, 549, 886, 389, 547, 885, 678, 780, 545, 
            884, 677, 777, 543, 883, 676, 541, 881, 880, 674, 539, 879, 673, 
            772, 537, 878, 672, 769, 533, 877, 671, 535},
            VertexColors->None], 
           Line3DBox[{561, 603, 410, 560, 894, 686, 790, 559, 893, 685, 789, 
            558, 892, 684, 788, 557, 891, 683, 556, 890, 682, 787, 555, 889, 
            681, 786, 554, 888, 680, 785, 553, 409, 601, 602},
            VertexColors->None]}, 
          {GrayLevel[0.2], 
           Line3DBox[{126, 274, 687, 128, 288, 695, 155, 303, 706, 707, 170, 
            318, 721, 722, 185, 333, 739, 200, 844, 348, 747, 215, 363, 756, 
            757, 230, 378, 769, 770, 245, 393, 785, 260},
            VertexColors->None], 
           Line3DBox[{130, 276, 688, 132, 799, 290, 696, 157, 305, 709, 172, 
            320, 724, 725, 187, 335, 740, 202, 847, 350, 748, 217, 864, 365, 
            759, 232, 380, 772, 773, 247, 395, 786, 262},
            VertexColors->None], 
           Line3DBox[{134, 278, 689, 136, 802, 292, 697, 159, 817, 307, 710, 
            174, 322, 727, 189, 337, 741, 204, 850, 352, 749, 219, 867, 367, 
            760, 234, 880, 382, 775, 249, 397, 787, 264},
            VertexColors->None], 
           Line3DBox[{138, 280, 690, 139, 805, 294, 698, 161, 820, 309, 711, 
            176, 831, 324, 728, 191, 339, 206, 853, 354, 750, 221, 870, 369, 
            761, 236, 883, 384, 776, 251, 891, 399, 266},
            VertexColors->None], 
           Line3DBox[{140, 281, 691, 142, 295, 699, 700, 162, 310, 712, 713, 
            177, 325, 729, 730, 192, 340, 742, 207, 355, 751, 222, 370, 762, 
            763, 237, 385, 777, 778, 252, 400, 788, 267},
            VertexColors->None], 
           Line3DBox[{144, 283, 692, 146, 807, 297, 702, 164, 312, 715, 716, 
            179, 327, 732, 733, 194, 342, 743, 209, 855, 357, 752, 224, 372, 
            765, 239, 387, 780, 781, 254, 402, 789, 269},
            VertexColors->None], 
           Line3DBox[{148, 285, 693, 150, 810, 299, 703, 166, 823, 314, 718, 
            181, 329, 735, 736, 196, 344, 744, 211, 858, 359, 753, 226, 873, 
            374, 766, 241, 389, 783, 256, 404, 790, 271},
            VertexColors->None], 
           Line3DBox[{152, 407, 895, 408, 153, 813, 301, 704, 168, 826, 316, 
            719, 183, 835, 331, 738, 198, 346, 745, 213, 861, 361, 754, 228, 
            876, 376, 767, 243, 887, 391, 784, 258, 410, 411, 412},
            VertexColors->None], 
           Line3DBox[{259, 392, 409, 244, 768, 377, 877, 229, 755, 362, 862, 
            214, 746, 347, 843, 199, 332, 836, 184, 720, 317, 827, 169, 705, 
            302, 814, 154, 694, 287, 797, 125, 273, 406, 413},
            VertexColors->None], 
           Line3DBox[{261, 394, 888, 246, 771, 379, 878, 231, 758, 364, 863, 
            216, 349, 846, 845, 201, 334, 837, 186, 723, 319, 828, 171, 708, 
            304, 815, 156, 289, 798, 129, 275, 791, 127},
            VertexColors->None], 
           Line3DBox[{263, 396, 889, 248, 774, 381, 879, 233, 366, 866, 865, 
            218, 351, 849, 848, 203, 336, 838, 188, 726, 321, 829, 173, 306, 
            816, 158, 291, 801, 800, 133, 277, 792, 131},
            VertexColors->None], 
           Line3DBox[{265, 398, 890, 250, 383, 882, 881, 235, 368, 869, 868, 
            220, 353, 852, 851, 205, 338, 839, 190, 323, 830, 175, 308, 819, 
            818, 160, 293, 804, 803, 137, 279, 793, 135},
            VertexColors->None], 
           Line3DBox[{268, 401, 892, 253, 779, 386, 884, 238, 764, 371, 871, 
            223, 356, 854, 208, 341, 840, 193, 731, 326, 832, 178, 714, 311, 
            821, 163, 701, 296, 806, 143, 282, 794, 141},
            VertexColors->None], 
           Line3DBox[{270, 403, 893, 255, 782, 388, 885, 240, 373, 872, 225, 
            358, 857, 856, 210, 343, 841, 195, 734, 328, 833, 180, 717, 313, 
            822, 165, 298, 809, 808, 147, 284, 795, 145},
            VertexColors->None], 
           Line3DBox[{272, 405, 894, 257, 390, 886, 242, 375, 875, 874, 227, 
            360, 860, 859, 212, 345, 842, 197, 737, 330, 834, 182, 315, 825, 
            824, 167, 300, 812, 811, 151, 286, 796, 149},
            VertexColors->None]}, {}, {}}},
        VertexColors->{
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.], 
          Hue[0.]},
        VertexNormals->CompressedData["
1:eJztyMEJgDAABMFDK7GS9GAJgm9LMCVbgvnkoQ2EwCwHB7Md134uSe41aevV
7z+Fc84555xzPsx/cc4555xzzjnnnHPOOeecc84555xzzjnnnHPOOeecc845
55xzzjnnnHPOOed8Bn8B6Uuhvg==
         "]], GraphicsComplex3DBox[CompressedData["
1:eJxlnAdYVMfXxik2LKgoorKKqIgSorHhGmD3iqjYAAuIJcaaWGLBEmuMJsQe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        "], {{
          {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
            GrayLevel[1], 3], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[{Polygon3DBox[CompressedData["
1:eJwtmHfgl9Mex8+IaySJlAjdyOZmhFtEVinjJrNFFImIknUbaNAuUUlbSXbI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                "]], Polygon3DBox[CompressedData["
1:eJwtmXccV9Mbx+89J7LJlp2MjCRChOwKERVlpEhlZSaRUWSPZP1syciOX3Z2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                "]], Polygon3DBox[CompressedData["
1:eJwtlmW4VkUUhb9zDiEpKR2XkG4F6ZLubi5cOi9wEZDmAj50gyAgSiog3R3S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                "]], 
               Polygon3DBox[{{735, 317, 193, 192, 438, 682}, {509, 508, 806, 
                439, 441, 807}, {647, 328, 445, 810, 526, 527}, {730, 308, 
                169, 168, 429, 678}, {731, 309, 173, 172, 432, 679}, {694, 
                454, 205, 206, 455, 695}, {652, 339, 453, 814, 542, 543}, {
                643, 319, 442, 808, 512, 513}, {646, 327, 443, 809, 522, 
                523}, {696, 457, 207, 208, 458, 697}, {756, 352, 236, 235, 
                465, 699}, {529, 528, 812, 450, 452, 813}}]},
              Annotation[#, "Charting`Private`Tag$3985#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}}, {
          {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0TdLA2EAx+Gzx7bpZsuiiTXJjbZNN0vc7CaimxkEAy46iWXVQewgCgqi
oKDg6Ozg4hfwAwhuTj4Bh4ff/4WD946LZnLplaIgCFY5oLD3WefHoVo/i4Pg
SH+d67XGuZZmu0WjxO1QQx3QQfrttE4wbC/pMuP2u27pOVOcsEurO6a1TWPM
2HFtZ9bu0E7m7C6d127tYcFOaJKMndKQrP2l23rBIqfssek9JjWva4zZWc0w
ZI/qCH12r6Y0qQlidqM20GRXaoQ6+0039IwqjtnhtfAcLzwT4YlHKnjgnnLu
KOOWG0q55ooSvn3ToV7iuuDDOf//H/8AnhYs2A==
            "],
            VertexColors->None]}, 
          {GrayLevel[0.2], 
           Line3DBox[{499, 725, 676, 701, 485, 720, 700, 1020, 677, 704, 818, 
            1002, 721, 703, 1021, 678, 730, 1003, 706, 1022, 679, 731, 1004, 
            500, 819, 641, 501, 820, 732, 911, 502, 821, 733, 912, 503, 822, 
            734, 913, 504, 1023, 707, 642, 708},
            VertexColors->None], 
           Line3DBox[{506, 680, 710, 1027, 722, 723, 709, 1024, 681, 713, 491,
             724, 712, 1025, 682, 735, 1005, 509, 807, 823, 736, 1007, 511, 
            685, 824, 643, 513, 826, 827, 644, 515, 828, 739, 923, 517, 829, 
            741, 926, 519, 830, 645, 521},
            VertexColors->None], 
           Line3DBox[{520, 927, 742, 518, 925, 924, 740, 516, 922, 921, 738, 
            514, 920, 737, 825, 512, 808, 919, 684, 510, 1006, 683, 918, 806, 
            508, 805, 917, 916, 804, 507, 803, 915, 705, 726, 494, 505, 802, 
            914, 702, 729, 728, 727},
            VertexColors->None], 
           Line3DBox[{525, 687, 715, 1026, 646, 523, 1009, 689, 831, 647, 527,
             811, 832, 329, 529, 813, 833, 743, 1012, 531, 834, 648, 533, 836,
             837, 649, 535, 839, 840, 650, 537, 841, 748, 936, 539, 842, 651, 
            541},
            VertexColors->None], 
           Line3DBox[{540, 937, 749, 538, 935, 934, 747, 536, 933, 746, 838, 
            534, 932, 745, 835, 532, 931, 744, 530, 1011, 691, 930, 812, 528, 
            1010, 690, 447, 526, 810, 929, 714, 688, 1008, 522, 809, 928, 711,
             686, 524},
            VertexColors->None], 
           Line3DBox[{545, 693, 843, 652, 543, 815, 844, 845, 653, 547, 816, 
            846, 847, 654, 549, 817, 848, 342, 551, 849, 655, 553, 851, 852, 
            656, 555, 854, 855, 657, 557, 857, 858, 658, 559, 859, 659, 561},
            VertexColors->None], 
           Line3DBox[{560, 943, 754, 558, 942, 753, 856, 556, 941, 752, 853, 
            554, 940, 751, 850, 552, 939, 750, 550, 1017, 698, 460, 548, 1015,
             697, 696, 1016, 546, 1013, 695, 694, 1014, 542, 814, 938, 716, 
            692, 544},
            VertexColors->None], 
           Line3DBox[{563, 755, 944, 562, 1019, 699, 756, 1018, 564, 860, 757,
             945, 565, 861, 758, 946, 566, 357, 567, 862, 759, 947, 568, 863, 
            760, 948, 569, 864, 761, 949, 570, 865, 660, 571},
            VertexColors->None], 
           Line3DBox[{575, 866, 661, 573, 867, 764, 953, 577, 868, 766, 956, 
            579, 869, 768, 959, 581, 870, 662, 583, 871, 374, 585, 872, 771, 
            964, 587, 873, 773, 967, 589, 874, 663, 591},
            VertexColors->None], 
           Line3DBox[{590, 968, 774, 588, 966, 965, 772, 586, 963, 962, 770, 
            584, 961, 373, 582, 960, 769, 580, 958, 957, 767, 578, 955, 954, 
            765, 576, 952, 951, 763, 572, 950, 762, 574},
            VertexColors->None], 
           Line3DBox[{595, 875, 664, 593, 877, 878, 665, 597, 879, 778, 973, 
            599, 880, 780, 976, 601, 881, 666, 603, 883, 884, 667, 605, 885, 
            391, 607, 886, 784, 982, 609, 887, 668, 611},
            VertexColors->None], 
           Line3DBox[{610, 983, 785, 608, 981, 980, 783, 606, 979, 390, 604, 
            978, 782, 882, 602, 977, 781, 600, 975, 974, 779, 598, 972, 971, 
            777, 596, 970, 776, 876, 592, 969, 775, 594},
            VertexColors->None], 
           Line3DBox[{615, 888, 669, 613, 890, 891, 670, 617, 893, 894, 671, 
            619, 895, 790, 989, 621, 896, 672, 623, 898, 899, 673, 625, 901, 
            902, 674, 627, 903, 408, 629, 904, 675, 631},
            VertexColors->None], 
           Line3DBox[{630, 994, 794, 628, 993, 407, 626, 992, 793, 900, 624, 
            991, 792, 897, 622, 990, 791, 620, 988, 987, 789, 618, 986, 788, 
            892, 616, 985, 787, 889, 612, 984, 786, 614},
            VertexColors->None], 
           Line3DBox[{640, 719, 482, 639, 1001, 801, 910, 638, 1000, 800, 909,
             637, 999, 799, 908, 636, 998, 798, 635, 997, 797, 907, 634, 996, 
            796, 906, 633, 995, 795, 905, 632, 481, 717, 718},
            VertexColors->None]}, 
          {GrayLevel[0.2], 
           Line3DBox[{164, 497, 498, 468, 1020, 426, 471, 494, 495, 477, 1024,
             435, 480, 444, 1008, 1009, 446, 205, 454, 1014, 456, 844, 220, 
            463, 1019, 465, 235, 951, 366, 867, 250, 381, 876, 877, 265, 396, 
            889, 890, 280, 411, 905, 295},
            VertexColors->None], 
           Line3DBox[{166, 427, 470, 1021, 429, 168, 916, 436, 479, 1025, 438,
             192, 447, 449, 832, 207, 457, 1016, 459, 846, 222, 353, 860, 237,
             954, 368, 868, 252, 971, 383, 879, 267, 398, 892, 893, 282, 413, 
            906, 297},
            VertexColors->None], 
           Line3DBox[{170, 430, 473, 1022, 432, 172, 918, 439, 441, 823, 194, 
            930, 450, 452, 833, 209, 460, 462, 848, 224, 355, 861, 239, 957, 
            370, 869, 254, 974, 385, 880, 269, 987, 400, 895, 284, 415, 907, 
            299},
            VertexColors->None], 
           Line3DBox[{174, 310, 819, 175, 919, 442, 319, 824, 196, 931, 331, 
            834, 211, 939, 343, 849, 226, 357, 241, 960, 372, 870, 256, 977, 
            387, 881, 271, 990, 402, 896, 286, 998, 417, 301},
            VertexColors->None], 
           Line3DBox[{176, 311, 820, 178, 320, 825, 826, 197, 332, 835, 836, 
            212, 344, 850, 851, 227, 358, 862, 242, 373, 871, 257, 388, 882, 
            883, 272, 403, 897, 898, 287, 418, 908, 302},
            VertexColors->None], 
           Line3DBox[{180, 313, 821, 182, 921, 322, 828, 199, 334, 838, 839, 
            214, 346, 853, 854, 229, 360, 863, 244, 962, 375, 872, 259, 390, 
            885, 274, 405, 900, 901, 289, 420, 909, 304},
            VertexColors->None], 
           Line3DBox[{184, 315, 822, 186, 924, 324, 829, 201, 934, 336, 841, 
            216, 348, 856, 857, 231, 362, 864, 246, 965, 377, 873, 261, 980, 
            392, 886, 276, 407, 903, 291, 422, 910, 306},
            VertexColors->None], 
           Line3DBox[{188, 474, 1023, 475, 189, 927, 326, 830, 203, 937, 338, 
            842, 218, 943, 350, 859, 233, 364, 865, 248, 968, 379, 874, 263, 
            983, 394, 887, 278, 994, 409, 904, 293, 482, 483, 484},
            VertexColors->None], 
           Line3DBox[{294, 410, 481, 279, 888, 395, 984, 264, 875, 380, 969, 
            249, 866, 365, 950, 234, 351, 944, 219, 843, 339, 453, 938, 204, 
            1026, 327, 443, 928, 190, 490, 1027, 489, 476, 433, 914, 163, 486,
             485, 467, 424, 493, 466},
            VertexColors->None], 
           Line3DBox[{296, 412, 995, 281, 891, 397, 985, 266, 878, 382, 970, 
            251, 367, 953, 952, 236, 352, 1018, 464, 221, 845, 340, 1013, 455,
             206, 831, 328, 445, 929, 191, 492, 491, 478, 434, 915, 165, 488, 
            487, 1002, 469, 425, 496},
            VertexColors->None], 
           Line3DBox[{298, 414, 996, 283, 894, 399, 986, 268, 384, 973, 972, 
            253, 369, 956, 955, 238, 354, 945, 223, 847, 341, 1015, 458, 208, 
            329, 1010, 448, 193, 317, 1005, 437, 917, 169, 308, 1003, 472, 
            428, 167},
            VertexColors->None], 
           Line3DBox[{300, 416, 997, 285, 401, 989, 988, 270, 386, 976, 975, 
            255, 371, 959, 958, 240, 356, 946, 225, 342, 1017, 461, 210, 330, 
            1012, 1011, 451, 195, 318, 1007, 1006, 440, 173, 309, 1004, 431, 
            171},
            VertexColors->None], 
           Line3DBox[{303, 419, 999, 288, 899, 404, 991, 273, 884, 389, 978, 
            258, 374, 961, 243, 359, 947, 228, 852, 345, 940, 213, 837, 333, 
            932, 198, 827, 321, 920, 179, 312, 911, 177},
            VertexColors->None], 
           Line3DBox[{305, 421, 1000, 290, 902, 406, 992, 275, 391, 979, 260, 
            376, 964, 963, 245, 361, 948, 230, 855, 347, 941, 215, 840, 335, 
            933, 200, 323, 923, 922, 183, 314, 912, 181},
            VertexColors->None], 
           Line3DBox[{307, 423, 1001, 292, 408, 993, 277, 393, 982, 981, 262, 
            378, 967, 966, 247, 363, 949, 232, 858, 349, 942, 217, 337, 936, 
            935, 202, 325, 926, 925, 187, 316, 913, 185},
            VertexColors->None]}, {}, {}}},
        VertexColors->{
          Hue[0.], 
          Hue[1.2345679012345676`*^-8], 
          Hue[2.4691358024691355`*^-8], 
          Hue[3.7037037037037036`*^-8], 
          Hue[4.938271604938271*^-8], 
          Hue[6.172839506172839*^-8], 
          Hue[7.407407407407406*^-8], 
          Hue[8.641975308641975*^-8], 
          Hue[9.876543209876542*^-8], 
          Hue[1.111111111111111*^-7], 
          Hue[1.2345679012345676`*^-8], 
          Hue[0.01234570096021948], 
          Hue[0.024691389574759946`], 
          Hue[0.03703707818930041], 
          Hue[0.04938276680384088], 
          Hue[0.061728455418381345`], 
          Hue[0.07407414403292181], 
          Hue[0.08641983264746228], 
          Hue[0.09876552126200275], 
          Hue[0.1111112098765432], 
          Hue[2.4691358024691355`*^-8], 
          Hue[0.024691389574759946`], 
          Hue[0.049382754458161864`], 
          Hue[0.07407411934156378], 
          Hue[0.09876548422496569], 
          Hue[0.12345684910836761`], 
          Hue[0.14814821399176956`], 
          Hue[0.17283957887517148`], 
          Hue[0.1975309437585734], 
          Hue[0.22222230864197529`], 
          Hue[3.7037037037037036`*^-8], 
          Hue[0.03703707818930041], 
          Hue[0.07407411934156378], 
          Hue[0.11111116049382716`], 
          Hue[0.14814820164609052`], 
          Hue[0.18518524279835388`], 
          Hue[0.2222222839506173], 
          Hue[0.2592593251028807], 
          Hue[0.2962963662551441], 
          Hue[0.3333334074074074], 
          Hue[4.938271604938271*^-8], 
          Hue[0.04938276680384088], 
          Hue[0.09876548422496569], 
          Hue[0.14814820164609052`], 
          Hue[0.19753091906721532`], 
          Hue[0.24691363648834017`], 
          Hue[0.296296353909465], 
          Hue[0.3456790713305899], 
          Hue[0.3950617887517147], 
          Hue[0.4444445061728395], 
          Hue[6.172839506172839*^-8], 
          Hue[0.061728455418381345`], 
          Hue[0.12345684910836761`], 
          Hue[0.18518524279835388`], 
          Hue[0.24691363648834017`], 
          Hue[0.3086420301783265], 
          Hue[0.3703704238683128], 
          Hue[0.4320988175582991], 
          Hue[0.49382721124828544`], 
          Hue[0.5555556049382716], 
          Hue[7.407407407407406*^-8], 
          Hue[0.07407414403292181], 
          Hue[0.14814821399176956`], 
          Hue[0.2222222839506173], 
          Hue[0.296296353909465], 
          Hue[0.3703704238683128], 
          Hue[0.44444449382716056`], 
          Hue[0.5185185637860084], 
          Hue[0.592592633744856], 
          Hue[0.6666667037037037], 
          Hue[8.641975308641975*^-8], 
          Hue[0.08641983264746228], 
          Hue[0.17283957887517148`], 
          Hue[0.2592593251028807], 
          Hue[0.3456790713305899], 
          Hue[0.4320988175582991], 
          Hue[0.5185185637860084], 
          Hue[0.6049383100137176], 
          Hue[0.6913580562414269], 
          Hue[0.7777778024691359], 
          Hue[9.876543209876542*^-8], 
          Hue[0.09876552126200275], 
          Hue[0.1975309437585734], 
          Hue[0.2962963662551441], 
          Hue[0.3950617887517147], 
          Hue[0.49382721124828544`], 
          Hue[0.592592633744856], 
          Hue[0.6913580562414269], 
          Hue[0.7901234787379975], 
          Hue[0.888888901234568], 
          Hue[1.111111111111111*^-7], 
          Hue[0.1111112098765432], 
          Hue[0.22222230864197529`], 
          Hue[0.3333334074074074], 
          Hue[0.4444445061728395], 
          Hue[0.5555556049382716], 
          Hue[0.6666667037037037], 
          Hue[0.7777778024691359], 
          Hue[0.888888901234568], 
          Hue[1.], 
          Hue[0.0030864314128943755`], 
          Hue[0.009259281893004115], 
          Hue[0.015432132373113852`], 
          Hue[0.021604982853223594`], 
          Hue[0.009259281893004115], 
          Hue[0.027777808641975307`], 
          Hue[0.0462963353909465], 
          Hue[0.06481486213991769], 
          Hue[0.08333338888888887], 
          Hue[0.015432132373113852`], 
          Hue[0.0462963353909465], 
          Hue[0.07716053840877914], 
          Hue[0.10802474142661178`], 
          Hue[0.021604982853223594`], 
          Hue[0.06481486213991769], 
          Hue[0.10802474142661178`], 
          Hue[0.15123462071330587`], 
          Hue[0.08333338888888887], 
          Hue[6.172839506172839*^-9], 
          Hue[0.006172856652949245], 
          Hue[0.006172856652949245], 
          Hue[6.172839506172839*^-9], 
          Hue[0.012345707133058985`], 
          Hue[0.018518545267489715`], 
          Hue[0.018518557613168726`], 
          Hue[0.052469235253772305`], 
          Hue[0.055555660493827166`], 
          Hue[0.018518545267489715`], 
          Hue[0.012345707133058985`], 
          Hue[0.037037072016460906`], 
          Hue[0.037037072016460906`], 
          Hue[0.018518557613168726`], 
          Hue[0.052469235253772305`], 
          Hue[1.0493827160493827`*^-7], 
          Hue[0.8919753203017836], 
          Hue[0.9444444506172842], 
          Hue[1.0493827160493827`*^-7], 
          Hue[0.055555660493827166`], 
          Hue[0.9444444506172842], 
          Hue[0.006944461419753086], 
          Hue[0.016203730967078188`], 
          Hue[0.016203730967078188`], 
          Hue[0.037808676783264744`], 
          Hue[0.000771610939643347], 
          Hue[0.002314826646090535], 
          Hue[0.002314826646090535], 
          Hue[0.019290150034293557`], 
          Hue[3.086419753086419*^-9], 
          Hue[3.086419753086419*^-9], 
          Hue[0.02700627794924555], 
          Hue[0.02700627794924555], 
          Hue[0.9452160553840879], 
          Hue[1.8518518518518515`*^-8], 
          Hue[0.0038580423525377233`], 
          Hue[1.8518518518518515`*^-8], 
          Hue[1.0802469135802469`*^-7], 
          Hue[0.02777788580246914], 
          Hue[0.9722222253086421], 
          Hue[0.02777788580246914], 
          Hue[1.0802469135802469`*^-7], 
          Hue[0.9722222253086421], 
          Hue[0.0038580423525377233`], 
          Hue[0.006944462191358024], 
          Hue[1.3888888888888887`*^-8], 
          Hue[0.02083336188271605], 
          Hue[2.7777777777777777`*^-8], 
          Hue[3.4722222222222227`*^-8], 
          Hue[0.027777811728395062`], 
          Hue[0.03472226157407408], 
          Hue[4.166666666666667*^-8], 
          Hue[4.861111111111112*^-8], 
          Hue[0.04166671141975309], 
          Hue[0.048611161265432114`], 
          Hue[5.555555555555556*^-8], 
          Hue[0.05555561111111112], 
          Hue[6.25*^-8], 
          Hue[6.944444444444444*^-8], 
          Hue[0.06250006095679013], 
          Hue[0.06944451080246913], 
          Hue[7.638888888888888*^-8], 
          Hue[8.333333333333333*^-8], 
          Hue[0.07638896064814815], 
          Hue[0.08333341049382716], 
          Hue[9.027777777777777*^-8], 
          Hue[9.722222222222222*^-8], 
          Hue[0.09027786033950619], 
          Hue[0.0972223101851852], 
          Hue[1.0416666666666665`*^-7], 
          Hue[0.1041667600308642], 
          Hue[0.013888917438271605`], 
          Hue[0.041666702932098766`], 
          Hue[0.055555595679012346`], 
          Hue[0.06944448842592592], 
          Hue[0.0833333811728395], 
          Hue[0.09722227391975308], 
          Hue[0.11111116666666668`], 
          Hue[0.12500005941358025`], 
          Hue[0.13888895216049385`], 
          Hue[0.15277784490740742`], 
          Hue[0.166666737654321], 
          Hue[0.18055563040123457`], 
          Hue[0.19444452314814817`], 
          Hue[0.20833341589506174`], 
          Hue[0.020833372685185186`], 
          Hue[0.04166670833333334], 
          Hue[0.06250004398148147], 
          Hue[0.08333337962962963], 
          Hue[0.10416671527777777`], 
          Hue[0.12500005092592592`], 
          Hue[0.14583338657407408`], 
          Hue[0.16666672222222223`], 
          Hue[0.18750005787037036`], 
          Hue[0.20833339351851854`], 
          Hue[0.2291667291666667], 
          Hue[0.25000006481481485`], 
          Hue[0.270833400462963], 
          Hue[0.2916667361111112], 
          Hue[0.3125000717592593], 
          Hue[0.027777827932098768`], 
          Hue[0.05555560648148148], 
          Hue[0.08333338503086418], 
          Hue[0.11111116358024689`], 
          Hue[0.1388889421296296], 
          Hue[0.16666672067901234`], 
          Hue[0.19444449922839507`], 
          Hue[0.22222227777777778`], 
          Hue[0.2500000563271605], 
          Hue[0.27777783487654323`], 
          Hue[0.30555561342592596`], 
          Hue[0.3333333919753087], 
          Hue[0.3611111705246914], 
          Hue[0.3888889490740742], 
          Hue[0.4166667276234568], 
          Hue[0.03472228317901234], 
          Hue[0.06944450462962963], 
          Hue[0.10416672608024691`], 
          Hue[0.1388889475308642], 
          Hue[0.17361116898148146`], 
          Hue[0.20833339043209875`], 
          Hue[0.24305561188271607`], 
          Hue[0.2777778333333334], 
          Hue[0.31250005478395065`], 
          Hue[0.347222276234568], 
          Hue[0.38194449768518524`], 
          Hue[0.41666671913580255`], 
          Hue[0.4513889405864199], 
          Hue[0.4861111620370372], 
          Hue[0.5208333834876544], 
          Hue[0.041666738425925935`], 
          Hue[0.08333340277777779], 
          Hue[0.12500006712962966`], 
          Hue[0.1666667314814815], 
          Hue[0.20833339583333338`], 
          Hue[0.2500000601851852], 
          Hue[0.2916667245370371], 
          Hue[0.333333388888889], 
          Hue[0.37500005324074087`], 
          Hue[0.4166667175925927], 
          Hue[0.45833338194444456`], 
          Hue[0.5000000462962964], 
          Hue[0.5416667106481482], 
          Hue[0.5833333750000002], 
          Hue[0.625000039351852], 
          Hue[0.04861119367283952], 
          Hue[0.09722230092592593], 
          Hue[0.14583340817901236`], 
          Hue[0.19444451543209876`], 
          Hue[0.2430556226851852], 
          Hue[0.2916667299382717], 
          Hue[0.3402778371913582], 
          Hue[0.38888894444444455`], 
          Hue[0.437500051697531], 
          Hue[0.4861111589506174], 
          Hue[0.5347222662037039], 
          Hue[0.5833333734567903], 
          Hue[0.6319444807098767], 
          Hue[0.6805555879629633], 
          Hue[0.7291666952160496], 
          Hue[0.055555648919753106`], 
          Hue[0.11111119907407409`], 
          Hue[0.16666674922839508`], 
          Hue[0.2222222993827161], 
          Hue[0.27777784953703716`], 
          Hue[0.3333333996913581], 
          Hue[0.3888889498456791], 
          Hue[0.44444450000000013`], 
          Hue[0.5000000501543211], 
          Hue[0.5555556003086422], 
          Hue[0.611111150462963], 
          Hue[0.6666667006172842], 
          Hue[0.7222222507716052], 
          Hue[0.7777778009259261], 
          Hue[0.8333333510802471], 
          Hue[0.06250010416666667], 
          Hue[0.12500009722222222`], 
          Hue[0.18750009027777778`], 
          Hue[0.25000008333333334`], 
          Hue[0.3125000763888889], 
          Hue[0.3750000694444445], 
          Hue[0.43750006250000006`], 
          Hue[0.5000000555555556], 
          Hue[0.5625000486111111], 
          Hue[0.6250000416666667], 
          Hue[0.6875000347222223], 
          Hue[0.7500000277777779], 
          Hue[0.8125000208333335], 
          Hue[0.875000013888889], 
          Hue[0.02893522350823046], 
          Hue[0.04591054381001377], 
          Hue[0.03086425240054875], 
          Hue[0.004629691872428027], 
          Hue[0.04629636316872431], 
          Hue[0.01620377880658438], 
          Hue[0.06481489300411522], 
          Hue[0.030864284807956086`], 
          Hue[0.08641984190672158], 
          Hue[0.0636574503600823], 
          Hue[0.09452165646433475], 
          Hue[0.08333338888888894], 
          Hue[0.06712969032921816], 
          Hue[0.11574080452674901`], 
          Hue[0.09259266306584364], 
          Hue[0.14814822016460907`], 
          Hue[0.12114205486968448`], 
          Hue[0.18364205486968455`], 
          Hue[0.15277786574074076`], 
          Hue[0.018132750600137176`], 
          Hue[0.05671300437242798], 
          Hue[0.09837967721193415], 
          Hue[0.14313276911865574`], 
          Hue[0.14197536351165985`], 
          Hue[0.12962968878600828`], 
          Hue[0.18518524588477372`], 
          Hue[0.16898154732510293`], 
          Hue[0.2314815473251029], 
          Hue[0.2114198249314129], 
          Hue[0.28086426783264756`], 
          Hue[0.2569445216049383], 
          Hue[0.025077205847050758`], 
          Hue[0.0775463454218107], 
          Hue[0.133101904063786], 
          Hue[0.19174388177297672`], 
          Hue[0.1975309190672154], 
          Hue[0.1921296872427984], 
          Hue[0.2546296872427984], 
          Hue[0.24537043158436217`], 
          Hue[0.31481487448559675`], 
          Hue[0.3016975949931413], 
          Hue[0.3780864807956105], 
          Hue[0.36111117746913585`], 
          Hue[0.034722277777777776`], 
          Hue[0.09837968647119341], 
          Hue[0.12037042386831275`], 
          Hue[0.16898153806584362`], 
          Hue[0.18518523971193415`], 
          Hue[0.24074079681069965`], 
          Hue[0.253086474622771], 
          Hue[0.25462968569958855`], 
          Hue[0.32407412860082313`], 
          Hue[0.3217593158436215], 
          Hue[0.39814820164609055`], 
          Hue[0.39197536505486974`], 
          Hue[0.47530869375857354`], 
          Hue[0.4652778333333334], 
          Hue[0.04166673302469136], 
          Hue[0.07253092524005486], 
          Hue[0.12114203943758575`], 
          Hue[0.14814820781893007`], 
          Hue[0.20370376491769548`], 
          Hue[0.22685190946502057`], 
          Hue[0.2893519094650207], 
          Hue[0.3086420301783266], 
          Hue[0.3171296841563787], 
          Hue[0.3935185699588479], 
          Hue[0.3981482001028807], 
          Hue[0.48148152880658446`], 
          Hue[0.4822531351165981], 
          Hue[0.5725309067215365], 
          Hue[0.569444489197531], 
          Hue[0.04861118827160495], 
          Hue[0.08641982338820303], 
          Hue[0.14197538048696848`], 
          Hue[0.17592599176954737`], 
          Hue[0.23842599176954735`], 
          Hue[0.26851857921810707`], 
          Hue[0.3379630221193417], 
          Hue[0.36419758573388217`], 
          Hue[0.3796296826131689], 
          Hue[0.46296301131687256`], 
          Hue[0.47453708436214004`], 
          Hue[0.5648148559670784], 
          Hue[0.5725309051783266], 
          Hue[0.6697531196844996], 
          Hue[0.6736111450617285], 
          Hue[0.055555643518518535`], 
          Hue[0.10030872153635119`], 
          Hue[0.16280872153635118`], 
          Hue[0.20370377572016463`], 
          Hue[0.27314821862139926`], 
          Hue[0.3101852489711935], 
          Hue[0.3865741347736627], 
          Hue[0.41975314128943775`], 
          Hue[0.44212968106995904`], 
          Hue[0.5324074526748973], 
          Hue[0.5509259686213993], 
          Hue[0.6481481831275723], 
          Hue[0.662808675240055], 
          Hue[0.7669753326474625], 
          Hue[0.7777778009259261], 
          Hue[0.05979948208161867], 
          Hue[0.11419761968449933`], 
          Hue[0.18364206258573387`], 
          Hue[0.2314815596707819], 
          Hue[0.3078704454732511], 
          Hue[0.3518519187242799], 
          Hue[0.4351852474279837], 
          Hue[0.47530869684499333`], 
          Hue[0.5046296795267492], 
          Hue[0.6018518940329219], 
          Hue[0.6273148528806586], 
          Hue[0.731481510288066], 
          Hue[0.7530864453017835], 
          Hue[0.8641975456104255], 
          Hue[0.0028935302211934156`], 
          Hue[0.0057870604423868295`], 
          Hue[0.011574096193415638`], 
          Hue[0.007716078532235945], 
          Hue[0.0057870727880658356`], 
          Hue[0.020061760973936894`], 
          Hue[0.016203746399176964`], 
          Hue[0.0027006660665294525`], 
          Hue[0.025463006687242787`], 
          Hue[0.009645084276406035], 
          Hue[0.026620401491769547`], 
          Hue[0.025462994341563787`], 
          Hue[0.03549386248285323], 
          Hue[0.04050929963991769], 
          Hue[0.04783954492455418], 
          Hue[0.0578704161522634], 
          Hue[0.05131177872085045], 
          Hue[0.0671296764403292], 
          Hue[0.08333338888888883], 
          Hue[0.016589539523319617`], 
          Hue[0.030092626028806586`], 
          Hue[0.04745374254115226], 
          Hue[0.03935189248971194], 
          Hue[0.06327164643347051], 
          Hue[0.07523152649176953], 
          Hue[0.07561732887517146], 
          Hue[0.09953708590534979], 
          Hue[0.09992289137517144], 
          Hue[0.10879634619341563`], 
          Hue[0.023533994770233192`], 
          Hue[0.04398152417695474], 
          Hue[0.06828708359053498], 
          Hue[0.05324079063786008], 
          Hue[0.09104943038408779], 
          Hue[0.10995375334362138`], 
          Hue[0.10339511282578873`], 
          Hue[0.1412037556584362], 
          Hue[0.1485340040294924], 
          Hue[0.15046301594650205`], 
          Hue[0.05787042232510288], 
          Hue[0.08912042463991768], 
          Hue[0.06712968878600822], 
          Hue[6.944444444444444*^-9], 
          Hue[0.0034722345679012345`], 
          Hue[0.006944462962962962], 
          Hue[0.01041669135802469], 
          Hue[0.01388891975308642], 
          Hue[0.013888912037037038`], 
          Hue[0.01736114814814815], 
          Hue[0.020833376543209877`], 
          Hue[0.045910593192729714`], 
          Hue[0.05825627100480117], 
          Hue[0.010416689814814814`], 
          Hue[0.02083336111111111], 
          Hue[0.03125003240740741], 
          Hue[0.041666703703703706`], 
          Hue[0.027777810185185187`], 
          Hue[0.058256271004801116`], 
          Hue[0.8792438401063102], 
          Hue[0.8915895179183816], 
          Hue[0.9375000069444446], 
          Hue[0.004050938914609053], 
          Hue[0.006365757844650206], 
          Hue[0.014467618698559673`], 
          Hue[0.01678243454218107], 
          Hue[0.010995394161522634`], 
          Hue[0.013310213091563786`], 
          Hue[0.03530095974794239], 
          Hue[0.03761577559156379], 
          Hue[0.0005787112911522636], 
          Hue[0.01581792549725652], 
          Hue[0.018904347650891634`], 
          Hue[2.083333333333333*^-8], 
          Hue[0.0019290273491083677`], 
          Hue[0.005015449502743484], 
          Hue[6.944444444444444*^-9], 
          Hue[0.027777827932098768`], 
          Hue[0.03472228317901234], 
          Hue[0.041666738425925935`], 
          Hue[0.04861119367283952], 
          Hue[0.055555648919753106`], 
          Hue[0.013888912037037038`], 
          Hue[2.083333333333333*^-8], 
          Hue[0.027777810185185187`], 
          Hue[0.04166670833333334], 
          Hue[0.06250004398148147], 
          Hue[0.05555560648148148], 
          Hue[0.08333338503086418], 
          Hue[0.06944450462962963], 
          Hue[0.10416672608024691`], 
          Hue[0.08333340277777779], 
          Hue[0.12500006712962966`], 
          Hue[0.09722230092592593], 
          Hue[0.14583340817901236`], 
          Hue[0.11111119907407409`], 
          Hue[0.16666674922839508`], 
          Hue[0.12500009722222222`], 
          Hue[0.18750009027777778`], 
          Hue[0.027777811728395062`], 
          Hue[0.03472226157407408], 
          Hue[2.7777777777777777`*^-8], 
          Hue[3.4722222222222227`*^-8], 
          Hue[0.055555595679012346`], 
          Hue[0.06944448842592592], 
          Hue[0.08333337962962963], 
          Hue[0.10416671527777777`], 
          Hue[0.11111116358024689`], 
          Hue[0.1388889421296296], 
          Hue[0.1388889475308642], 
          Hue[0.17361116898148146`], 
          Hue[0.1666667314814815], 
          Hue[0.20833339583333338`], 
          Hue[0.19444451543209876`], 
          Hue[0.2430556226851852], 
          Hue[0.2222222993827161], 
          Hue[0.27777784953703716`], 
          Hue[0.25000008333333334`], 
          Hue[0.3125000763888889], 
          Hue[0.04166671141975309], 
          Hue[0.048611161265432114`], 
          Hue[4.166666666666667*^-8], 
          Hue[4.861111111111112*^-8], 
          Hue[0.0833333811728395], 
          Hue[0.09722227391975308], 
          Hue[0.12500005092592592`], 
          Hue[0.14583338657407408`], 
          Hue[0.16666672067901234`], 
          Hue[0.19444449922839507`], 
          Hue[0.20833339043209875`], 
          Hue[0.24305561188271607`], 
          Hue[0.2500000601851852], 
          Hue[0.2916667245370371], 
          Hue[0.2916667299382717], 
          Hue[0.3402778371913582], 
          Hue[0.3333333996913581], 
          Hue[0.3888889498456791], 
          Hue[0.3750000694444445], 
          Hue[0.43750006250000006`], 
          Hue[0.05555561111111112], 
          Hue[5.555555555555556*^-8], 
          Hue[0.11111116666666668`], 
          Hue[0.16666672222222223`], 
          Hue[0.22222227777777778`], 
          Hue[0.2777778333333334], 
          Hue[0.333333388888889], 
          Hue[0.38888894444444455`], 
          Hue[0.44444450000000013`], 
          Hue[0.5000000555555556], 
          Hue[0.06250006095679013], 
          Hue[0.06944451080246913], 
          Hue[6.25*^-8], 
          Hue[6.944444444444444*^-8], 
          Hue[0.12500005941358025`], 
          Hue[0.13888895216049385`], 
          Hue[0.18750005787037036`], 
          Hue[0.20833339351851854`], 
          Hue[0.2500000563271605], 
          Hue[0.27777783487654323`], 
          Hue[0.31250005478395065`], 
          Hue[0.347222276234568], 
          Hue[0.37500005324074087`], 
          Hue[0.4166667175925927], 
          Hue[0.437500051697531], 
          Hue[0.4861111589506174], 
          Hue[0.5000000501543211], 
          Hue[0.5555556003086422], 
          Hue[0.5625000486111111], 
          Hue[0.6250000416666667], 
          Hue[0.07638896064814815], 
          Hue[0.08333341049382716], 
          Hue[7.638888888888888*^-8], 
          Hue[8.333333333333333*^-8], 
          Hue[0.15277784490740742`], 
          Hue[0.166666737654321], 
          Hue[0.2291667291666667], 
          Hue[0.25000006481481485`], 
          Hue[0.30555561342592596`], 
          Hue[0.3333333919753087], 
          Hue[0.38194449768518524`], 
          Hue[0.41666671913580255`], 
          Hue[0.45833338194444456`], 
          Hue[0.5000000462962964], 
          Hue[0.5347222662037039], 
          Hue[0.5833333734567903], 
          Hue[0.611111150462963], 
          Hue[0.6666667006172842], 
          Hue[0.6875000347222223], 
          Hue[0.7500000277777779], 
          Hue[0.09027786033950619], 
          Hue[0.0972223101851852], 
          Hue[9.027777777777777*^-8], 
          Hue[9.722222222222222*^-8], 
          Hue[0.18055563040123457`], 
          Hue[0.19444452314814817`], 
          Hue[0.270833400462963], 
          Hue[0.2916667361111112], 
          Hue[0.3611111705246914], 
          Hue[0.3888889490740742], 
          Hue[0.4513889405864199], 
          Hue[0.4861111620370372], 
          Hue[0.5416667106481482], 
          Hue[0.5833333750000002], 
          Hue[0.6319444807098767], 
          Hue[0.6805555879629633], 
          Hue[0.7222222507716052], 
          Hue[0.7777778009259261], 
          Hue[0.8125000208333335], 
          Hue[0.875000013888889], 
          Hue[0.1041667600308642], 
          Hue[0.20833341589506174`], 
          Hue[0.3125000717592593], 
          Hue[0.4166667276234568], 
          Hue[0.5208333834876544], 
          Hue[0.625000039351852], 
          Hue[0.7291666952160496], 
          Hue[0.8333333510802471], 
          Hue[0.9375000069444446], 
          Hue[0.03472227777777778], 
          Hue[0.05979948208161867], 
          Hue[0.09837968647119341], 
          Hue[0.12114203943758574`], 
          Hue[0.18364206258573387`], 
          Hue[0.028935223508230457`], 
          Hue[0.0636574503600823], 
          Hue[0.16898153806584362`], 
          Hue[0.2037037649176955], 
          Hue[0.23842599176954737`], 
          Hue[0.3078704454732511], 
          Hue[0.04591054381001377], 
          Hue[0.09452165646433475], 
          Hue[0.14313276911865574`], 
          Hue[0.24074079681069965`], 
          Hue[0.2893519094650207], 
          Hue[0.3379630221193417], 
          Hue[0.3865741347736627], 
          Hue[0.4351852474279837], 
          Hue[0.47530869684499333`], 
          Hue[0.04629636316872432], 
          Hue[0.32407412860082313`], 
          Hue[0.6018518940329219], 
          Hue[0.06481489300411525], 
          Hue[0.14814822016460907`], 
          Hue[0.39814820164609055`], 
          Hue[0.48148152880658446`], 
          Hue[0.731481510288066], 
          Hue[0.08641984190672156], 
          Hue[0.18364205486968455`], 
          Hue[0.2808642678326476], 
          Hue[0.47530869375857354`], 
          Hue[0.5725309067215365], 
          Hue[0.6697531196844997], 
          Hue[0.8641975456104255], 
          Hue[0.0028935302211934156`], 
          Hue[0.009645084276406035], 
          Hue[0.016589539523319617`], 
          Hue[0.023533994770233192`], 
          Hue[0.0057870604423868295`], 
          Hue[0.026620401491769547`], 
          Hue[0.04745374254115226], 
          Hue[0.05324079063786009], 
          Hue[0.05787042232510288], 
          Hue[0.08912042463991768], 
          Hue[0.007716078532235945], 
          Hue[0.0057870727880658356`], 
          Hue[0.03549386248285323], 
          Hue[0.04050929963991769], 
          Hue[0.07561732887517146], 
          Hue[0.10339511282578873`], 
          Hue[0.016203746399176964`], 
          Hue[0.0027006660665294525`], 
          Hue[0.0578704161522634], 
          Hue[0.0671296764403292], 
          Hue[0.09953708590534979], 
          Hue[0.1087963461934156], 
          Hue[0.15046301594650202`], 
          Hue[0.08333338888888883], 
          Hue[0.006944462191358024], 
          Hue[0.0034722345679012345`], 
          Hue[0.006944462962962962], 
          Hue[0.013888917438271605`], 
          Hue[0.010416689814814814`], 
          Hue[0.02083336111111111], 
          Hue[0.020833372685185186`], 
          Hue[0.058256271004801116`], 
          Hue[0.06250010416666667], 
          Hue[0.02083336188271605], 
          Hue[0.01041669135802469], 
          Hue[0.01388891975308642], 
          Hue[0.041666702932098766`], 
          Hue[0.03125003240740741], 
          Hue[0.041666703703703706`], 
          Hue[0.01736114814814815], 
          Hue[0.020833376543209877`], 
          Hue[0.045910593192729714`], 
          Hue[1.0416666666666665`*^-7], 
          Hue[0.8915895179183816], 
          Hue[0.006365757844650206], 
          Hue[0.013310213091563786`], 
          Hue[0.014467618698559673`], 
          Hue[0.01678243454218107], 
          Hue[0.03761577559156379], 
          Hue[0.0005787112911522636], 
          Hue[0.018904347650891634`], 
          Hue[1.3888888888888887`*^-8], 
          Hue[0.0019290273491083677`], 
          Hue[0.005015449502743484], 
          Hue[0.018132750600137176`], 
          Hue[0.025077205847050758`], 
          Hue[0.04166673302469136], 
          Hue[0.04861118827160495], 
          Hue[0.05555564351851852], 
          Hue[0.05671300437242798], 
          Hue[0.07754634542181069], 
          Hue[0.07253092524005486], 
          Hue[0.086419823388203], 
          Hue[0.14197538048696848`], 
          Hue[0.10030872153635119`], 
          Hue[0.16280872153635118`], 
          Hue[0.11419761968449932`], 
          Hue[0.133101904063786], 
          Hue[0.12037042386831275`], 
          Hue[0.14814820781893007`], 
          Hue[0.17592599176954737`], 
          Hue[0.20370377572016463`], 
          Hue[0.27314821862139926`], 
          Hue[0.2314815596707819], 
          Hue[0.18518523971193415`], 
          Hue[0.22685190946502062`], 
          Hue[0.26851857921810707`], 
          Hue[0.3101852489711935], 
          Hue[0.3518519187242799], 
          Hue[0.030864252400548756`], 
          Hue[0.08333338888888894], 
          Hue[0.14197536351165987`], 
          Hue[0.1975309190672154], 
          Hue[0.30864203017832664`], 
          Hue[0.36419758573388217`], 
          Hue[0.41975314128943775`], 
          Hue[0.004629691872428028], 
          Hue[0.06712969032921813], 
          Hue[0.11574080452674901`], 
          Hue[0.12962968878600828`], 
          Hue[0.18518524588477372`], 
          Hue[0.1921296872427984], 
          Hue[0.2546296872427984], 
          Hue[0.25462968569958855`], 
          Hue[0.3796296826131688], 
          Hue[0.46296301131687256`], 
          Hue[0.44212968106995904`], 
          Hue[0.5324074526748973], 
          Hue[0.5046296795267492], 
          Hue[0.016203778806584388`], 
          Hue[0.09259266306584363], 
          Hue[0.16898154732510293`], 
          Hue[0.23148154732510293`], 
          Hue[0.24537043158436217`], 
          Hue[0.31481487448559675`], 
          Hue[0.3217593158436214], 
          Hue[0.39814820010288077`], 
          Hue[0.5509259686213993], 
          Hue[0.6481481831275722], 
          Hue[0.6273148528806586], 
          Hue[0.030864284807956055`], 
          Hue[0.12114205486968446`], 
          Hue[0.21141982493141281`], 
          Hue[0.3016975949931413], 
          Hue[0.3780864807956105], 
          Hue[0.3919753650548698], 
          Hue[0.48225313511659806`], 
          Hue[0.5725309051783266], 
          Hue[0.7530864453017836], 
          Hue[0.1527778657407408], 
          Hue[0.2569445216049384], 
          Hue[0.36111117746913574`], 
          Hue[0.4652778333333334], 
          Hue[0.569444489197531], 
          Hue[0.6736111450617285], 
          Hue[0.7777778009259261], 
          Hue[0.011574096193415638`], 
          Hue[0.025462994341563783`], 
          Hue[0.030092626028806586`], 
          Hue[0.03935189248971193], 
          Hue[0.04398152417695474], 
          Hue[0.06828708359053498], 
          Hue[0.06712968878600822], 
          Hue[0.020061760973936898`], 
          Hue[0.04783954492455419], 
          Hue[0.07523152649176953], 
          Hue[0.09104943038408779], 
          Hue[0.1099537533436214], 
          Hue[0.02546300668724279], 
          Hue[0.05131177872085045], 
          Hue[0.09992289137517142], 
          Hue[0.1485340040294924], 
          Hue[0.010995394161522634`], 
          Hue[0.03395067223936901], 
          Hue[0.03549388871742114], 
          Hue[0.043981555041152275`], 
          Hue[0.052469221364883405`], 
          Hue[0.0698302938957476], 
          Hue[0.09375005555555557], 
          Hue[0.07098771493484227], 
          Hue[0.10570993638545956`], 
          Hue[0.11959882913237313`], 
          Hue[0.1296296980452675], 
          Hue[0.15354945970507547`], 
          Hue[0.17746922136488344`], 
          Hue[0.05902782021604939], 
          Hue[0.07754634156378601], 
          Hue[0.11689819855967079`], 
          Hue[0.15740746270576134`], 
          Hue[0.14120376260288067`], 
          Hue[0.17592598405349794`], 
          Hue[0.19675931970164615`], 
          Hue[0.1736111766975309], 
          Hue[0.21527784104938277`], 
          Hue[0.2361111766975309], 
          Hue[0.2546296980452675], 
          Hue[0.29398155504115236`], 
          Hue[0.027392024777091916`], 
          Hue[0.05439819855967079], 
          Hue[0.0821759771090535], 
          Hue[0.10918215089163238`], 
          Hue[0.1369599294410151], 
          Hue[0.163966103223594], 
          Hue[0.21913585793895754`], 
          Hue[0.21141981027091908`], 
          Hue[0.2461420317215364], 
          Hue[0.27391981027091916`], 
          Hue[0.2592593197016462], 
          Hue[0.300925984053498], 
          Hue[0.3287037626028808], 
          Hue[0.3070988291323732], 
          Hue[0.35570993638545967`], 
          Hue[0.38348771493484235`], 
          Hue[0.4104938887174212], 
          Hue[0.12654326508916325`], 
          Hue[0.1898148698559671], 
          Hue[0.28163585793895757`], 
          Hue[0.34490746270576145`], 
          Hue[0.40817906747256527`], 
          Hue[0.47145067223936915`], 
          Hue[0.041666733796296304`], 
          Hue[0.07870376954732511], 
          Hue[0.1574074696502058], 
          Hue[0.23611116975308644`], 
          Hue[0.3148148698559672], 
          Hue[0.35185190560699603`], 
          Hue[0.4305556057098766], 
          Hue[0.5092593058127572], 
          Hue[0.587963005915638], 
          Hue[0.048611190586419765`], 
          Hue[0.0871914289266118], 
          Hue[0.0941358787722908], 
          Hue[0.14274698602537725`], 
          Hue[0.1882716742112483], 
          Hue[0.28240746965020586`], 
          Hue[0.37654326508916336`], 
          Hue[0.38734573182441717`], 
          Hue[0.4220679532750344], 
          Hue[0.47067906052812086`], 
          Hue[0.5162037487139919], 
          Hue[0.6103395441529494], 
          Hue[0.7044753395919069], 
          Hue[0.05555564737654323], 
          Hue[0.10262353815157753`], 
          Hue[0.10956798799725655`], 
          Hue[0.16512353815157754`], 
          Hue[0.20524698602537722`], 
          Hue[0.21913587877229085`], 
          Hue[0.2746914289266119], 
          Hue[0.32870376954732516`], 
          Hue[0.4382716603223596], 
          Hue[0.4575617794924555], 
          Hue[0.49228400094307295`], 
          Hue[0.5478395510973939], 
          Hue[0.5601852273662553], 
          Hue[0.6018518917181072], 
          Hue[0.6574074418724283], 
          Hue[0.7114197824931416], 
          Hue[0.8209876732681758], 
          Hue[0.11805564737654323`], 
          Hue[0.23611119058641977`], 
          Hue[0.3541667337962963], 
          Hue[0.5277778271604939], 
          Hue[0.6458333703703706], 
          Hue[0.763888913580247], 
          Hue[0.0416667337962963], 
          Hue[0.048611190586419765`], 
          Hue[0.05555564737654323], 
          Hue[0.007716068501371741], 
          Hue[0.023148177726337447`], 
          Hue[0.03163583710562415], 
          Hue[0.03858028695130315], 
          Hue[0.047067946330589853`], 
          Hue[0.06250005555555556], 
          Hue[0.07870376954732511], 
          Hue[0.0871914289266118], 
          Hue[0.09413587877229082], 
          Hue[0.14274698602537725`], 
          Hue[0.10262353815157753`], 
          Hue[0.10956798799725655`], 
          Hue[0.16512353815157754`], 
          Hue[0.11805564737654321`], 
          Hue[0.01543213005829904], 
          Hue[0.046296334619341566`], 
          Hue[0.09413585099451303], 
          Hue[0.12654326508916325`], 
          Hue[0.1574074696502058], 
          Hue[0.18827167421124832`], 
          Hue[0.20524698602537725`], 
          Hue[0.21913587877229085`], 
          Hue[0.2746914289266119], 
          Hue[0.23611119058641977`], 
          Hue[0.023148191615226337`], 
          Hue[0.1898148698559671], 
          Hue[0.23611116975308644`], 
          Hue[0.28240746965020586`], 
          Hue[0.3287037695473252], 
          Hue[0.3541667337962964], 
          Hue[0.03395067223936901], 
          Hue[0.15740746270576134`], 
          Hue[0.2191358579389575], 
          Hue[0.3148148698559672], 
          Hue[0.37654326508916336`], 
          Hue[0.4382716603223596], 
          Hue[0.035493888717421124`], 
          Hue[0.07098771493484225], 
          Hue[0.10570993638545956`], 
          Hue[0.11959882913237313`], 
          Hue[0.14120376260288067`], 
          Hue[0.17592598405349794`], 
          Hue[0.19675931970164612`], 
          Hue[0.21141981027091908`], 
          Hue[0.2461420317215364], 
          Hue[0.27391981027091916`], 
          Hue[0.28163585793895757`], 
          Hue[0.35185190560699603`], 
          Hue[0.38734573182441706`], 
          Hue[0.4220679532750344], 
          Hue[0.47067906052812086`], 
          Hue[0.45756177949245563`], 
          Hue[0.49228400094307295`], 
          Hue[0.5478395510973938], 
          Hue[0.5277778271604939], 
          Hue[0.043981555041152275`], 
          Hue[0.1296296980452675], 
          Hue[0.1736111766975309], 
          Hue[0.21527784104938277`], 
          Hue[0.2361111766975309], 
          Hue[0.2592593197016462], 
          Hue[0.300925984053498], 
          Hue[0.32870376260288076`], 
          Hue[0.34490746270576145`], 
          Hue[0.43055560570987667`], 
          Hue[0.5162037487139919], 
          Hue[0.5601852273662552], 
          Hue[0.6018518917181072], 
          Hue[0.6574074418724283], 
          Hue[0.6458333703703705], 
          Hue[0.052469221364883405`], 
          Hue[0.15354945970507547`], 
          Hue[0.2546296980452675], 
          Hue[0.3070988291323732], 
          Hue[0.35570993638545967`], 
          Hue[0.38348771493484235`], 
          Hue[0.40817906747256527`], 
          Hue[0.5092593058127572], 
          Hue[0.6103395441529494], 
          Hue[0.7114197824931416], 
          Hue[0.7638889135802471], 
          Hue[0.17746922136488344`], 
          Hue[0.29398155504115236`], 
          Hue[0.4104938887174212], 
          Hue[0.47145067223936915`], 
          Hue[0.587963005915638], 
          Hue[0.7044753395919069], 
          Hue[0.8209876732681759], 
          Hue[0.011767000471536351`], 
          Hue[0.01967596322016461], 
          Hue[0.02739202477709191], 
          Hue[0.05902782021604939], 
          Hue[0.054398198559670805`], 
          Hue[0.0821759771090535], 
          Hue[0.03163583710562414], 
          Hue[0.03858028695130316], 
          Hue[0.077546341563786], 
          Hue[0.10918215089163238`], 
          Hue[0.1369599294410151], 
          Hue[0.0698302938957476], 
          Hue[0.047067946330589853`], 
          Hue[0.11689819855967079`], 
          Hue[0.09413585099451303], 
          Hue[0.163966103223594], 
          Hue[0.09375005555555557], 
          Hue[0.06250005555555556], 
          Hue[0.007716068501371743], 
          Hue[0.01543213005829904], 
          Hue[0.02314819161522634], 
          Hue[0.05825627100480111], 
          Hue[0.023148177726337454`], 
          Hue[0.046296334619341566`], 
          Hue[0.01967596322016461], 
          Hue[0.011767000471536351`]},
        VertexNormals->CompressedData["
1:eJx0m3k0lV3Y/5UUSioJEQqVKCQp05YiSYNoLkpCaC5pQqhEZU6UJhpMiczT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         "]]},
      Axes->True,
      AxesLabel->{
        FormBox["\"\\nChoice A\"", TraditionalForm], 
        FormBox["\"\\nChoice B\"", TraditionalForm], 
        FormBox["\"Utility   \"", TraditionalForm]},
      AxesOrigin->{Automatic, Automatic, Automatic},
      BoxRatios->{1, 1, 0.4},
      DisplayFunction->Identity,
      FaceGrids->None,
      FaceGridsStyle->Automatic,
      Lighting->"Neutral",
      Method->{"DefaultBoundaryStyle" -> Directive[
          GrayLevel[0.3]], "RotationControl" -> "Globe"},
      PlotRange->All,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{}, {}, {{30, 
          FormBox["30", TraditionalForm]}}}], {576., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.},
     ContentSelectable->True]}, {}},
  ContentSelectable->True,
  ImageSize->550,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQYwCBwCy+qJeOhhwz05SANHfRkgcmPq8cNVpUfoLoB8rf
/oDoRzN+8JoC6Q92tZIgWmtK//xYIP2F55NrF5AusG083Q2khS/PULwIpE3O
BJheAtJuh+9c/AGke+1u/QTRKacXG/8E0muq9yb5+75yTFjwbCmIXvdQ58tm
/1eOPTJnOs8C6RM2HDmvg145WvefYHgDpBkYHp74FvzKceKijFCBEBA/4LEk
mE5tkgLS2tdUFzfGvnKcZPbrJIhuuuR6LzD+laNXEWOnY8Irx4xXnwQ+Jb5y
3Jq5y/UzkL698mI9iL7TullUMPmVY/NR0Z7ktFeOLiJBh026Xju+mTx9jRmQ
1vBe7zMTSHeEXWOQP/vaEQCST5il
  "],
 TextAlignment->Center,ExpressionUUID->"71bbd3d5-daae-4ce2-a3d1-78bf7152cb99"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.4.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Utility as a function of two choices."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500218290372*^9}, 
   3.5386855198191614`*^9},
 TextAlignment->Center,ExpressionUUID->"b2516e1d-be91-4948-b71f-a99fb526d7bf"],

Cell[TextData[{
 "While Bernoulli's game may be unappetizing, people ",
 StyleBox["do",
  FontSlant->"Italic"],
 " take other kinds of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"risks", 
    SuperscriptBox[".", 
     ButtonBox["2",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote2"]]}], TraditionalForm]],ExpressionUUID->
  "a9caab16-68aa-403e-80f3-df3184149bde"],
 " To help us deal with what we actually observe in people's actions, we make \
a critical assumption:  People ",
 StyleBox["do not",
  FontSlant->"Italic"],
 " value each dollar the same.  Further, we assume, people place a ",
 StyleBox["diminishing",
  FontSlant->"Italic"],
 " ",
 StyleBox["marginal",
  FontSlant->"Italic"],
 " value on each additional dollar (think about how much an extra $100 means \
to you and what you imagine an extra $100 means to the average billionaire)  \
Thus, people derive different \"utility\" from different amounts of money \
based on how much money they start with.  The mathematical way of expressing \
this is with a curved function to represent people's utility.  Figure 6.5 \
shows several such functions:"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529616030134599*^9, 3.5296160342138324`*^9}, {
   3.529699472999258*^9, 3.5296994756044073`*^9}, {3.5297096069858885`*^9, 
   3.529709616182415*^9}, {3.529709669468463*^9, 3.529709669468463*^9}, 
   3.529935664122072*^9, {3.5386855198191614`*^9, 
   3.5386855198211613`*^9}},ExpressionUUID->"367168ae-f20e-4cf6-ae0e-\
3a9e7b0eaf39"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"plA", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Log", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"Axes", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"False", ",", "True"}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<\!\(\*StyleBox[\"y\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)= Log \
\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"plB", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     SqrtBox["x"], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"Axes", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"False", ",", "True"}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<\!\(\*StyleBox[\"y\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)=\!\(\*SqrtBox[StyleBox[\"x\",FontSlant->\"Italic\"\
]]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"plC", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "a"}], " ", "x"}]]}], "/.", "\[InvisibleSpace]", 
      RowBox[{"a", "\[Rule]", "0.1`"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"Axes", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"False", ",", "True"}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<\!\(\*StyleBox[\"y\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)= -\!\(\*SuperscriptBox[\"\[ExponentialE]\", \
RowBox[{\"-\", StyleBox[\"\[Alpha]x\",FontSlant->\"Italic\"]}]]\)\>\""}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"plD", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "x"], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"Axes", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"False", ",", "True"}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<\!\(\*StyleBox[\"y\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)= \!\(\*SuperscriptBox[\"\[ExponentialE]\", \
StyleBox[\"x\",FontSlant->\"Italic\"]]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"fig4", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"GraphicsRow", "[", 
     RowBox[{"{", 
      RowBox[{"plA", ",", "plB", ",", "plC", ",", "plD"}], "}"}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.402659107203125*^9, 3.402659174203125*^9}, {
   3.5296157526457276`*^9, 3.5296158127021627`*^9}, {3.5296159473088617`*^9, 
   3.5296159534812145`*^9}, 3.5386855198211613`*^9, {3.5410130613956127`*^9, 
   3.541013084057909*^9}},ExpressionUUID->"f1bbe8d4-81ff-49ad-8339-\
ad53c0494c44"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVzXs81Pkex/GZH7XlsutSQprwqxTSZVfJGp9P6UYqlyxHUhTaLrq4JpVK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           "]]},
         Annotation[#, "Charting`Private`Tag$4062#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
StyleBox[\\\" \\\",FontSlant->\\\"Italic\\\"]\\)= Log \\!\\(\\*StyleBox[\\\"x\
\\\",FontSlant->\\\"Italic\\\"]\\)\"", TraditionalForm],
      PlotRange->{{0, 10}, {-1.623796532045525, 2.3025850725858823`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{{}, {}}], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVzXk81AkfwPFhDH6o3JscM/xETbQ8L6lc3++iZLKeJCq0MsVYV5snraIt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           "]]},
         Annotation[#, "Charting`Private`Tag$4106#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
StyleBox[\\\" \\\",FontSlant->\\\"Italic\\\"]\\)=\\!\\(\\*SqrtBox[StyleBox[\\\
\"x\\\",FontSlant->\\\"Italic\\\"]]\\)\"", TraditionalForm],
      PlotRange->{{0, 10}, {0., 3.16227762790024}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{{}, {}}], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVzH081AccwHF5mjjqiHm+O78buZD2Wlv2Kr+vamV5aJIesBaFHkSM1yuP
RR7SJYyVY6YLNRWlUZO6b/OQhOsV6neFknPnPORq180d6tb++Lze/31Y4bHb
IrS1tLT8PvW/Fenh+qv2cz15DCOlRiPH9n6m707mQVK5Yttw6gc5ah4ITjKZ
SWSPh7lKPSfHivv5DD1mHqk+rml/r5Rj9LrEI7MMHqndp2yZnpJj//yBkreM
WpIbq7CWUnL8bHDU6Q2jmUyfKcr4eF2O/EeVcVOMLrL+aLB5x1451l/PG4x2
e0EGPDppUn17BqPIJ7zpeDHpNr/3otx2BmMkzuLG+gnSuWu6aM2pN2jIynJ6
teYtOce3uMmenMazS7s5/L0KUiYcI3i7pzF8cDvq9PxLrg5UzTvcn8K4jqzw
WKc5ctvw6Wy+yxQ2HKUFWn7/gTRx8jTtrZlEfsrhSfedWvB2PDT+jMUkZlYu
BLyfXgRVu6ZncosnUKt/BO4m68BJlp/eOfMJdEyIPLadowcn7makXSuQ4Zjy
/A6je/oQPzykWGcuwy2SQ2m/xBmARvNzw5ricfQfK1xhb28IdSO3NJ4W4zjZ
Fn7iYZ0RhD4YuKNfLUU3+jO7DT8ZQ3rRU3oVR4qGpDJsSGECZK13AL9Fgpvf
BM86BC2Fzrqs7u7vJChq3b8o2IUOAe4MVt7AGDadat/DVNLBR9dWpIkew0i9
xBGh0BT8O5YLdDRi3Bef0kQrMwOvjYu9DpWJcWXUCqFv2DJID9EbbvIQ42NT
F6NED3Mol5xeLOsbxZb6zHIXHQuIyfntqCxhFFMWcX7oGbaArQX5zVb0UTQc
SvaOafwcbAxlBZyG1yi5xCqpTLUE1cqv6Cm7X2PJcivd5iAraLYyFvgvjGBh
WWRnGNMaBKFXb1peHsHgkh+FtHFr0FOYea4MGkHVxhp1pcAGDBzDapwXXqFY
sv5Ya64tmJUabpKGvsKL61bZ9IbZwVrPWUv88yXWZSfSo1zt4SNjy2Mdq5eY
G7TPR0dpD1KvbPamrGFcPcSvze1lgF3yWZWrdAhLncvren2YQLPL9KsIGsLj
9/NLfZqZEOLG28q+O4h+NkE1j9gsuFR60P3C8kH0iukMoeexoH800u0h/wVW
2oaze5QssPm11CPH9AWy2y6f8w9xAGNfv9jjBc+x0LWV0ydwAMd62nYu/TlG
KnSfdHEIaOIKO/lcEYY3/MPMKyDA1zn7my/pIozODFzYUkTA/ugE1bIlIkwM
bKRoxQRcaJfLZmkiPKVMPFt4joBGTdIugYEI6z3U8+crCNjdFhXnpyVC9d+a
Z5euElDXo52bIKewsI+W395JgFayLVvaS2FZ1ZEDOV0EPG5OEwq7KaxKEG7w
7iZg3Fp6+XYXhbcsCue6hQQM32kZz+ugcCjY7ED/UwLqB/XL3e9R6CS22jAq
JmCAkdGTc41C98Zk+2oJAVbpERHxVyj8NntQHTFOQMSSJa57/qDQ16nixsQk
AV+E8r2/rqYw/jDT/t07AogrW2/IyilMXZuhvqkgYKJ2UvCUR2G28ehAgpKA
zQachdbzFJZer+KqVJ9+adnavxdTePGEbtSdOQJC9vG6uUUUXg2IWJ+6QMCO
TV5tSQUUNjo8sPP8SABlkjQRlU+hQOGo1mgI+KtmrecOLoX/AdPHfWA=
           "]]},
         Annotation[#, "Charting`Private`Tag$4150#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, -0.999999979591837},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
StyleBox[\\\" \\\",FontSlant->\\\"Italic\\\"]\\)= -\\!\\(\\*SuperscriptBox[\\\
\"\[ExponentialE]\\\", RowBox[{\\\"-\\\", \
StyleBox[\\\"\[Alpha]x\\\",FontSlant->\\\"Italic\\\"]}]]\\)\"", 
        TraditionalForm],
      PlotRange->{{0, 10}, {-0.999999979591837, -0.3678794486791861}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{{}, {}}], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVxXk4lHkAB/AZ5n1cOaaUHSWrRUo6hJLa70+1qaRCko14SiXbjaUe+zDO
XCtMkvtKxYM0g+TqQW1JjiiSuwnleIfMiMLu/vF5PlonL9mclmIwGFb/+f/9
p4dbnn62+9X48nWKwRCBtUv9ci/HCD41t3PNmSJsTktI5nN2I3bRtFuglAiW
r9sfpXCOwMs7cJMMJYK963RlLMcVzdsUJpXlRejeELoriuMJ75g4Q11VEdKX
HgoJ5wQh1s+n+rSeCFxZ/uowDg/Dumk+m6xFOOaQUSiayMan9osMuTwRFBa4
jhYrC5FwMKI2lzEBHevx4doIAayWy4TsOzoB70ZTJEyVIS43oJNdPAE1AbuH
yaxGjPdq7d+VJ1EysKuhaXsNYp5KvEw9JlHjnrLcYbQOZr0lJc7tkxDr7lDO
v/APDkt+yhOYfIXUTJ7Kcp168FMFjcbpX2Gy4FJiW9CA3e5OY1WsKTQEGTU+
X9sEZfknPPNzU9C8OTLzYLwZQmv/1PCOKYxM9/a83fgGZXdCSdBOMbK/lNcr
/d0KtTClu3WlYihp3KOFwjaE8y+usDOQIPJc8Zl07XeY+uBxyyRFAgnJE7r5
tYP37uVDRc40PA3rBMtqO3ApKmOLbPQ0egvqIlq0OpGYY+sXyv6G7+5tSWuu
fwCB/oPTvG/QN5eZP1PehbjRC0ZzKjOwyNQ6W6TWA4NXOlFdiTPw1nBe1e/Y
C35Y2rOdK2exbtROod2qD791aY5kZsxiibJItm62D8N6kxGqm7+DVZ1U+Ety
P8wDLX8kVn7HH0bl7+UsB7CQfO1159EfyNt3Mr1KMgDRz4ndwaIfEI+oqwzG
f4Rjaa74RcAcim0tpHm7hYh/1LY+V3sefnuD0wSDQhQZQDxUNQ+t7v0dWcGf
kNWpuEzdYQHbtgTxOIaDOD+y3W2EySCOK5tmmK2DCG3JFBvZMoi4PmrgMncI
6vIh0M1nkATWCU8b7WG82MN91y/FJEt6ijOl6oZR9dhcOukYk1B/cY+YXvmM
OWNuol8pkzAenCgcWPwFof2d+kK2FLmaWBi1uOYLVO/NPuv3kiKV+jdk2RdH
YLrqlNzqTinC3n91XYDSKG55FEgSTaVJl0Fz67WKUZRvUbLakSVNHqZCW3hi
DHw6LnpIhkWcCk3YGvNjsFjWKh95nkX8gzO4XbnjqECZ88wHFskf1khSOkCD
leOwTm0PRW6kBLv0HKQh6fesFVtQxNVmTKfAmsalN6lBbfsosqKi4qGVPY2+
OwbBsVYUCY8+/jzyJI0I21Q/FTuKuJncmZC/RuO6nLyTqitFVgWp7pXJoaF2
TLbNLIAi81t9Fdvv05BNXyPQDKLI+7GPb3LyaLADm6ukQyhy057vtKeIhoFi
lW1DGEUW1tp4BFfQWDrk7+scQ5GuluhU6VYaXldHG6LSKfI4ZPpU61saLpF6
9p6ZFOGZOa/J6qDhb6i76Hg2RSzvrhfs7KGxQd9LonefIk98Xr/kfqbhq/aq
4XkhReINjKOtR2nQ733zC4oocmUg+YgWTaORKJXF8ymid+B879MpGsZKvYfP
llKExWzLvjlNo25ep/tQGUX6is3cXWZp1N87zttaTpEK96wNG+doaDYF/qlV
SZHbmgrihQUa49syA+WrKfIvk9dWVA==
           "]]},
         Annotation[#, "Charting`Private`Tag$4194#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 1.0000000204081634`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
StyleBox[\\\" \\\",FontSlant->\\\"Italic\\\"]\\)= \
\\!\\(\\*SuperscriptBox[\\\"\[ExponentialE]\\\", \
StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]]\\)\"", TraditionalForm],
      PlotRange->{{0, 1}, {1.0000000204081634`, 2.7182817729839064`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{{}, {}}], {1360.8000000000002, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->450,
  PlotRangePadding->{6, 5}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.40265864296875*^9, {3.4026591638125*^9, 3.402659176515625*^9}, 
   3.402699573251*^9, 3.5296157166136665`*^9, 3.5296157730058928`*^9, 
   3.529615813912232*^9, 3.529615954667283*^9, 3.529698556770853*^9, 
   3.529789999837097*^9, 3.529793116701788*^9, 3.5299351173798003`*^9, 
   3.5299373227179384`*^9, 3.530016399242857*^9, 3.530016719152155*^9, 
   3.530017181458597*^9, 3.5301936861683607`*^9, 3.5301942234510913`*^9, 
   3.5314482255895596`*^9, 3.5315006225554943`*^9, 3.5331346889024563`*^9, 
   3.533135878474496*^9, 3.53368224734375*^9, 3.5337345719318824`*^9, 
   3.533754138796875*^9, 3.53375541146875*^9, 3.538685209934437*^9, 
   3.5386855198251615`*^9, 3.539635954389959*^9, 3.5401267928882494`*^9, 
   3.541012616460164*^9, 3.5410130518060646`*^9, 3.541013085406986*^9, 
   3.5410150867534566`*^9, 3.541015551613045*^9, 3.541600430445138*^9, 
   3.543342177526408*^9, 3.6963384589319496`*^9, 3.696342373155919*^9, 
   3.6965443584143534`*^9, 3.7314211915393353`*^9},
 TextAlignment->Center,ExpressionUUID->"6c2a9454-4e9a-4e1a-aabd-f56bfb65d9ba"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.5.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Several forms of utility functions."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500239972612*^9}, 
   3.5386855198251615`*^9},
 TextAlignment->Center,ExpressionUUID->"c6150e68-d6d2-440f-9d68-9175e92742a5"],

Cell[TextData[{
 "An important and desirable property of any function we might use to \
illustrate decreasing marginal utility is that the curve of a plot of that \
function is concave.  Of the four curved functions in Figure 6.5, only the \
first three qualify (the fourth, being convex, represents ",
 StyleBox["increasing",
  FontSlant->"Italic"],
 " marginal utility).  Of the three, the one most often used by economists is \
the first one, the Log function.  Thus, Figure 6.6 illustrates the utility \
function as the Log of its argument, which is  wealth (w) in our case."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296161118272715`*^9, 3.529616124865018*^9}, {
   3.5296995287934494`*^9, 3.5296995310535784`*^9}, 
   3.5386855198251615`*^9},ExpressionUUID->"bd902d71-6bdb-4485-82db-\
10e0869931dd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "w_", "]"}], ":=", 
   RowBox[{"Log", "[", "w", "]"}]}], ";"}], "\n", 
 RowBox[{"fig5", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"u", "[", "w", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "30000", ",", "180000"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"10", ",", "12"}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"25000", ",", "10"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"None", ",", "None"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Hue", "[", "0.9", "]"}], "}"}], ",", 
      RowBox[{
      "{", "\"\<U[\!\(\*StyleBox[\"w\",FontSlant->\"Italic\"]\)]=Log[\!\(\*\
StyleBox[\"w\",FontSlant->\"Italic\"]\)]\>\"", "}"}]}], "]"}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529616181822275*^9, 3.5296162018804226`*^9}, {
   3.5296168350136356`*^9, 3.529616838801852*^9}, 3.5386855198251615`*^9, {
   3.6965446124853015`*^9, 3.6965446474894295`*^9}, {3.696544683146293*^9, 
   3.696544767357334*^9}, {3.6965448007802553`*^9, 
   3.6965448340708246`*^9}},ExpressionUUID->"4582a0b5-ea91-417d-9e5a-\
ef26d6ec51b5"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAADMAAAACAAAAxLQnMgBM3UCVe3cOL54kQEYp9n2A
V91AH1Va5veeJEDJncTJAGPdQAoFk2/AnyRAzoZhYQF63UD8u/uWUKEkQNhY
m5ACqN1Aa6ZTQG2kJEDs/A7vBATeQHLjfzGYqiRAFEX2qwm83kAGj/sitrYk
QLJq4pIJFuBARG19HR7OJEDHxS8dCKXhQMvvHnF3/SRAm7xU15UZ40AuBjI3
CyYlQNte3rbUhuRAG6iOr+1KJUDgy+amCBPmQJnp0GUlcCVApNTGxsuE50DZ
53LemJAlQC2oJfeDFelAeV85c5axJUAiJ+lM7Z7qQHRk/iUI0CVA1kGE0uUN
7EATf0en4uolQE8nnmjTm+1Apitw6n4GJkCHqI8uUA/vQNwvSE3+HiZAlury
DL898EBxL+Eh7DUmQEtm3YpQA/FADSwa+rBNJkDfr7OgqbvxQIPzXq3qYiZA
1l7JPn2D8kD6GOvS+HgmQINjkW+pR/NAWi6Yw7yNJkAPNkU4nf7zQA9vfmJf
oCZA/m04iQvF9EDVQjGT2LMmQMxzF3JBfvVA0mzoiGDFJkD93jXj8Ub2QBfL
qyG41yZA5J8G5/oL90AG+z0pHOkmQKsuw4LLw/dAJ+IMadH4JkDUIr+mFov4
QNVDfUBSCSdA3eSmYilF+UDTNkGSQxgnQJz8QLGU+/lAfeKCbIAmJ0C9eRqI
esH6QCB4HjGDNSdAvsTf9id6+0BSriFjIkMnQCF15O1PQvxAfmDP8n9RJ0A6
e5t30Ab9QO507bI4XydAM08+mRi+/UDuzlxgsmsnQI6IIEPbhP5AMF7YBOR4
J0DJj+6EZT7/QIPsV1bohCdAuuxuWUj0/0AGZSWSa5AnQIdXF9vSXABBteYR
YqCcJ0CgH21V5bgAQRlXTTLCpydAa5riE7UcAUFVC8chj7MnQCb8TZ7oeQFB
wEXnfVa+J0C7iBJySNUBQTJ0QoOwyCdAAsj2iWU4AkH9mdCsr9MnQDnu0G3m
lAJBLHrAob3dJ0Ahx8qVJPkCQSrJfAdr6CdA5ModB49bA0GyaaBFsPInQJe1
ZkRdtwNB0cD9Qxb8J0CWKuqPUd4DQQAAAAAAAChAB6x+Jg==
          "]]}, Annotation[#, "Charting`Private`Tag$4270#1"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {{}, {}}, 
     AxesOrigin -> {25000., 10.}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {25000., 10.}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{25000., 179999.9969387755}, {10, 12}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {Automatic, Automatic}}, Ticks -> {None, None}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"U[\\!\\(\\*StyleBox[\\\"w\\\",FontSlant->\\\"Italic\\\"]\\)]=Log[\\!\
\\(\\*StyleBox[\\\"w\\\",FontSlant->\\\"Italic\\\"]\\)]\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.9, 1, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.9, 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   Hue[0.9], 
                   RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                 "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                 FrameStyle -> Hue[0.9, 1., 0.6666666666666667], FrameTicks -> 
                 None, PlotRangePadding -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                StyleBox[
                 RowBox[{"Hue", "[", "0.9`", "]"}], NumberMarks -> False]], 
               Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   Hue[0.9, 1, 1]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              Hue[0.9], Editable -> False, Selectable -> False], "}"}], ",", 
           RowBox[{"{", #, "}"}]}], "]"}]& ), Editable -> True], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.696544751116125*^9, 3.6965447683028507`*^9}, {
   3.6965448282433195`*^9, 3.6965448348478975`*^9}, 3.731421191663632*^9},
 TextAlignment->Center,ExpressionUUID->"8bfedd28-c28d-4bed-82a3-71d3d31eea6b"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.6.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Utility as a function of the log of wealth."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500262158881*^9}, 
   3.5386855198281617`*^9},
 TextAlignment->Center,ExpressionUUID->"38dfff29-e470-40a1-9e3a-6354597fb481"],

Cell["In the original game, Bernoulli\[CloseCurlyQuote]s series leads to \
infinity.", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.52969961831857*^9, 3.529699642255939*^9}, 
   3.5296998268494973`*^9, 3.529936119334109*^9, 
   3.5386855198281617`*^9},ExpressionUUID->"2638298f-4978-4a24-a0f1-\
a78aed25f789"],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox[
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "n"], " ", 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}],
    FontSlant->"Italic"], 
   StyleBox["=",
    FontSlant->"Italic"], "\[Infinity]"}], 
  TraditionalForm]], "EquationNumbered",
 CellMargins->{{26., 22.666666666666742`}, {7., 7.}},
 CellChangeTimes->{{3.529699651523469*^9, 3.529699678918036*^9}, 
   3.5386855198281617`*^9},ExpressionUUID->"2e38c57a-6d93-4c66-be74-\
1ccf23430642"],

Cell[CellGroupData[{

Cell["\<\
Now when we apply Bernoulli's infinite series to the Log of the payoff it \
converges to a finite number...\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296997585675917`*^9, 3.529699759260631*^9}, {
   3.529699821553194*^9, 3.529699821863212*^9}, 
   3.5386855198281617`*^9},ExpressionUUID->"ac63c5ee-2aed-44e4-93cf-\
b0e34b406033"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"stPetePO", "=", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], 
       RowBox[{"n", "+", "1"}]], " ", 
      RowBox[{"Log", "[", 
       SuperscriptBox["2", "n"], "]"}]}], ")"}]}], "//", "N"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198281617`*^9},ExpressionUUID->"546f79d7-b2ff-475f-8985-\
78c2a6a85f72"],

Cell[BoxData["0.6931471805599454`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658643390625*^9, 3.40269957384475*^9, 
  3.529616239172556*^9, 3.5296985573698874`*^9, 3.5297900007891517`*^9, 
  3.5297931184408865`*^9, 3.529935118652873*^9, 3.5299373231789646`*^9, 
  3.530016400299917*^9, 3.530016719959201*^9, 3.5300171822876444`*^9, 
  3.53019368720642*^9, 3.5301942240011225`*^9, 3.5314482264986115`*^9, 
  3.531500623328539*^9, 3.533134690452545*^9, 3.5331358788895197`*^9, 
  3.533682248703125*^9, 3.533734573353964*^9, 3.533754140109375*^9, 
  3.533755412296875*^9, 3.5386852115365286`*^9, 3.5386855198281617`*^9, 
  3.5396359553240123`*^9, 3.5401267950153713`*^9, 3.541012618466279*^9, 
  3.5410150884715548`*^9, 3.54101555379517*^9, 3.5416004322892437`*^9, 
  3.543342179527523*^9, 3.696338459439299*^9, 3.6963423736371756`*^9, 
  3.696544358679057*^9, 
  3.7314211919433746`*^9},ExpressionUUID->"4a621f53-0981-4f50-8624-\
f13d36dac70d"]
}, Open  ]]
}, Closed]],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "n"], " ", 
      RowBox[{"Log", "[", 
       SuperscriptBox["2", "n"], "]"}]}]}], "=", "0.693147"}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellMargins->{{26., 21.333333333333485`}, {7., 7.}},
 CellChangeTimes->{{3.5296997196153636`*^9, 3.5296997346872253`*^9}, {
   3.5296997851961145`*^9, 3.529699812051651*^9}, 
   3.5386855198281617`*^9},ExpressionUUID->"12ae0bab-e68d-4f97-b85c-\
13e145629ce2"],

Cell["\<\
...which, we confirm by employing it as the exponent of the base of the \
natural log, is the natural log of 2. \
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198281617`*^9, {3.5410131352868395`*^9, 
   3.5410131367599235`*^9}},ExpressionUUID->"6b8684bb-62c1-41fd-87c2-\
030a7427f344"],

Cell[CellGroupData[{

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", "0.693147"]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296998629935646`*^9, 3.5296998717590656`*^9}, 
   3.5386855198281617`*^9},ExpressionUUID->"21cc9f51-5366-4169-a527-\
21c6f03bd53e"],

Cell[BoxData["1.999999638880142`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.40265864340625*^9, 3.4026995740635*^9, 
  3.5296162639219713`*^9, 3.52969855742089*^9, 3.5296998723791013`*^9, 
  3.529790000868156*^9, 3.5297931189249144`*^9, 3.5299351190228944`*^9, 
  3.5299373232189674`*^9, 3.5300164003809223`*^9, 3.530016720035205*^9, 
  3.530017182363649*^9, 3.5301936872864246`*^9, 3.53019422413313*^9, 
  3.5314482266156178`*^9, 3.5315006234325447`*^9, 3.533134690910571*^9, 
  3.533135878929522*^9, 3.533682248859375*^9, 3.5337345737839885`*^9, 
  3.533754140203125*^9, 3.533755412390625*^9, 3.5386852120495577`*^9, 
  3.5386855198281617`*^9, 3.539635955374015*^9, 3.5401267983805637`*^9, 
  3.541012619166319*^9, 3.5410150890715895`*^9, 3.5410155544992104`*^9, 
  3.5416004329552813`*^9, 3.543342180268565*^9, 3.696338459477401*^9, 
  3.696342373654232*^9, 3.6965443587492437`*^9, 
  3.731421191954405*^9},ExpressionUUID->"d7a03d56-bec9-4ced-93b4-\
645e013800d7"]
}, Open  ]],

Cell[TextData[{
 "This produces a reasonable amount one might pay to enter Bernoulli's game \
The two assumptions (1) that people maximize the utility of money not money \
itself and (2) that the utility function is concave, lead us to what is known \
as the Expected Utility Hypothesis. This is how the paradox is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"resolved", 
    SuperscriptBox[".", 
     ButtonBox["3",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote3"]]}], TraditionalForm]],ExpressionUUID->
  "f11c1904-496b-4504-9c71-d18e309cb04c"]
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.529616289571438*^9, {3.5296163313658285`*^9, 3.5296163493208556`*^9}, {
   3.529699911994367*^9, 3.5296999157115793`*^9}, {3.529709842613366*^9, 
   3.529709861264433*^9}, {3.5386855198291616`*^9, 
   3.5386855198301616`*^9}},ExpressionUUID->"d12f4d1f-480d-4641-afd9-\
8fddb0c5b04e"],

Cell[TextData[{
 "Recall from Chapter 2 that the numerical representation of utility had no ",
 StyleBox["cardinal",
  FontSlant->"Italic"],
 " meaning for the community, rather it was ",
 StyleBox["ordinal",
  FontSlant->"Italic"],
 " (meaning that its only usefulness is in ",
 StyleBox["ranking",
  FontSlant->"Italic"],
 " the value of alternatives).  This carries over to people and the choices \
they make about prospects with uncertain outcomes. In a real estate context, \
most people would view an investment in a true triple-net ground lease \
beneath a branch of the United States Post Office differently than an \
investment in an 18 unit apartment building occupied by 75 college students  \
Few would have any difficulty ranking these two in a risk hierarchy. We have \
purposely chosen extreme alternatives to illustrate our point.  One needs a \
mechanism for thinking about risk in more realistic settings when the \
alternatives may not be so obvious. For instance, how would we compare two \
commercial structures, one occupied by a major clothing retailer and another \
by a major appliance retailer? Or two similar apartment buildings on \
different sides of the street? Many such opportunities present themselves. \
They have different risk and while the difference may not be great ",
 StyleBox["there is a difference",
  FontSlant->"Italic"],
 " and one must be preferred over the other. Our goal in this chapter is to \
discover a way of ranking risky opportunities in a rational manner. As is so \
often the case, \"rational\" means ",
 Cell[BoxData[
  FormBox[
   RowBox[{"mathematical", 
    SuperscriptBox[".", 
     ButtonBox["4",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote4"]]}], TraditionalForm]],ExpressionUUID->
  "14a35243-616b-451c-be5d-f3b9011d8005"]
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529616289571438*^9, 3.529616290899514*^9}, 
   3.529616481068391*^9, {3.529710170186102*^9, 3.5297101816087556`*^9}, {
   3.5386855198301616`*^9, 
   3.538685519832162*^9}},ExpressionUUID->"aa9ec412-3b07-4744-bb5a-\
01d8cccf0f0a"],

Cell[CellGroupData[{

Cell["6.4. The \[OpenCurlyDoubleQuote]certainty equivalent\
\[CloseCurlyDoubleQuote] approach", "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531447172614333*^9, 3.5314480664524574`*^9, 
  3.538685519832162*^9},ExpressionUUID->"e3396474-1e18-4421-8f12-\
86ad136e0d78"],

Cell["\<\
The search for a sound way to evaluate risky alternatives leads to an inquiry \
into how discounts come about.  We assume that nearly anything of value can \
be sold if the price is lowered. Risky alternatives, as \"things of value\", \
become more appealing as the entry fee is reduced (because the return \
increases).  The idea that describes this situation well is known as the \
\"certainty equivalent\" approach.  We ask an investor to choose a point of \
indifference between opportunities having a certain outcome and an uncertain \
outcome, given that the price of the opportunity with the uncertain outcome \
is sufficiently discounted.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5296164182888002`*^9, 
  3.538685519832162*^9},ExpressionUUID->"ba3f26f9-c1bd-40f3-806c-\
8abbc07a0321"],

Cell[TextData[{
 "Let us use a concrete example to illustrate the concept.  Suppose someone \
has $100,000 and the chance to invest it that provides two (and only two) \
equiprobable outcomes, one of $150,000 (the good result) and the other of \
$50,000 (the unfortunate outcome). The certain alternative is to do nothing, \
which pays $100,000. We want to know what is necessary to entice our investor \
away from this certain position and into an investment with an uncertain \
outcome. In Figure 6.7 we see the plot ",
 StyleBox["of utility ",
  FontSlant->"Italic"],
 "of these uncertain outcomes as wealth rises or falls.  Note the three \
points of interest, constituting the original wealth and the two outcomes.  \
Our investor must decide if the gain in utility associated with winning \
$50,000 is more or less than the loss of utility associated with losing \
$50,000. The answer is found on the ",
 StyleBox["y",
  FontSlant->"Italic"],
 "-axis of Figure 6.7."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296164182888002`*^9, 3.529616419304858*^9}, {
   3.5296167389921436`*^9, 3.529616739646181*^9}, {3.529699972094805*^9, 
   3.529699974556946*^9}, {3.5297001003131385`*^9, 3.529700136026181*^9}, 
   3.538685519832162*^9},ExpressionUUID->"a58e2f5a-1052-4bf6-bc07-\
f68b6aa0aea7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pGeneral", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"u", "[", "w", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", "30000", ",", "180000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"10", ",", "12"}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"25000", ",", "10"}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"50000", ",", "\"\<$50,000\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"100000", ",", "\"\<$100,000\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"150000", ",", "\"\<$150,000\>\""}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "50000", "]"}], "]"}], ",", 
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "100000", "]"}], "]"}], ",", 
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "150000", "]"}], "]"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"50000", ",", "100000", ",", "150000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"u", "[", "50000", "]"}], ",", 
         RowBox[{"u", "[", "100000", "]"}], ",", 
         RowBox[{"u", "[", "150000", "]"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Wealth\>\"", ",", "\"\<U[Wealth]\>\""}], "}"}]}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.529616786685871*^9, 3.5296168196337557`*^9}, 
   3.538685519832162*^9},ExpressionUUID->"bf98e71b-e4df-4fd0-b489-\
2cacf6a73ed5"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAADMAAAACAAAAxLQnMgBM3UCVe3cOL54kQEYp9n2A
V91AH1Va5veeJEDJncTJAGPdQAoFk2/AnyRAzoZhYQF63UD8u/uWUKEkQNhY
m5ACqN1Aa6ZTQG2kJEDs/A7vBATeQHLjfzGYqiRAFEX2qwm83kAGj/sitrYk
QLJq4pIJFuBARG19HR7OJEDHxS8dCKXhQMvvHnF3/SRAm7xU15UZ40AuBjI3
CyYlQNte3rbUhuRAG6iOr+1KJUDgy+amCBPmQJnp0GUlcCVApNTGxsuE50DZ
53LemJAlQC2oJfeDFelAeV85c5axJUAiJ+lM7Z7qQHRk/iUI0CVA1kGE0uUN
7EATf0en4uolQE8nnmjTm+1Apitw6n4GJkCHqI8uUA/vQNwvSE3+HiZAlury
DL898EBxL+Eh7DUmQEtm3YpQA/FADSwa+rBNJkDfr7OgqbvxQIPzXq3qYiZA
1l7JPn2D8kD6GOvS+HgmQINjkW+pR/NAWi6Yw7yNJkAPNkU4nf7zQA9vfmJf
oCZA/m04iQvF9EDVQjGT2LMmQMxzF3JBfvVA0mzoiGDFJkD93jXj8Ub2QBfL
qyG41yZA5J8G5/oL90AG+z0pHOkmQKsuw4LLw/dAJ+IMadH4JkDUIr+mFov4
QNVDfUBSCSdA3eSmYilF+UDTNkGSQxgnQJz8QLGU+/lAfeKCbIAmJ0C9eRqI
esH6QCB4HjGDNSdAvsTf9id6+0BSriFjIkMnQCF15O1PQvxAfmDP8n9RJ0A6
e5t30Ab9QO507bI4XydAM08+mRi+/UDuzlxgsmsnQI6IIEPbhP5AMF7YBOR4
J0DJj+6EZT7/QIPsV1bohCdAuuxuWUj0/0AGZSWSa5AnQIdXF9vSXABBteYR
YqCcJ0CgH21V5bgAQRlXTTLCpydAa5riE7UcAUFVC8chj7MnQCb8TZ7oeQFB
wEXnfVa+J0C7iBJySNUBQTJ0QoOwyCdAAsj2iWU4AkH9mdCsr9MnQDnu0G3m
lAJBLHrAob3dJ0Ahx8qVJPkCQSrJfAdr6CdA5ModB49bA0GyaaBFsPInQJe1
ZkRdtwNB0cD9Qxb8J0CWKuqPUd4DQQAAAAAAAChAB6x+Jg==
       "]]},
     Annotation[#, "Charting`Private`Tag$4600#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Wealth\"", TraditionalForm], 
    FormBox["\"U[Wealth]\"", TraditionalForm]},
  AxesOrigin->{25000., 10.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->NCache[{{50000, 100000, 150000}, {
      Log[50000], 
      Log[100000], 
      Log[150000]}}, {{50000, 100000, 150000}, {10.819778284410283`, 
     11.512925464970229`, 11.918390573078392`}}],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{25000., 179999.9969387755}, {10, 12}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{{{50000, 
      FormBox["\"$50,000\"", TraditionalForm]}, {100000, 
      FormBox["\"$100,000\"", TraditionalForm]}, {150000, 
      FormBox["\"$150,000\"", TraditionalForm]}}, {{10.819778284410283`, 
      FormBox["10.819778284410283`", TraditionalForm]}, {11.512925464970229`, 
      FormBox["11.512925464970229`", TraditionalForm]}, {11.918390573078392`, 
      FormBox["11.918390573078392`", TraditionalForm]}}}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.402658643421875*^9, 3.402699574297875*^9, {3.529616776155269*^9, 
   3.5296168046468987`*^9}, 3.529698557471893*^9, 3.5297900009461603`*^9, 
   3.529793119451945*^9, 3.5299351194369183`*^9, 3.529937323283971*^9, 
   3.5300164004789276`*^9, 3.53001672012121*^9, 3.5300171824576545`*^9, 
   3.530193687346428*^9, 3.5301942241911335`*^9, 3.531448226658621*^9, 
   3.5315006234895477`*^9, 3.533134691432601*^9, 3.5331358789685245`*^9, 
   3.533682249*^9, 3.5337345743060184`*^9, 3.53375414028125*^9, 
   3.533755412484375*^9, 3.5386852125665874`*^9, 3.5386855198341618`*^9, 
   3.539635955437019*^9, 3.5401267989395957`*^9, 3.5410126197593527`*^9, 
   3.5410150897916307`*^9, 3.541015555141247*^9, 3.5416004335713167`*^9, 
   3.543342180835598*^9, 3.6963384595285378`*^9, 3.696342373733432*^9, 
   3.6965443588144164`*^9, 3.7314211920225873`*^9},
 TextAlignment->Center,ExpressionUUID->"ce32d382-b175-431a-97a1-e88707f6885c"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.7.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Utility of wealth as the log of wealth."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500288135367*^9}, 
   3.5386855198341618`*^9},
 TextAlignment->Center,ExpressionUUID->"d8c34382-7cdb-47a4-85ff-ecf382c17664"],

Cell["\<\
The question of how much to pay for an investment with an uncertain outcome \
is answered by placing a numerical value on the difference between the \
utility of the certain opportunity and the utility of the uncertain one. How \
do we do this in practice?  To begin with, notice that the expectation of \
wealth in this fair game is zero. That is, the mathematical expectation is \
Beginning Wealth + (probability of gain times winning payoff) - (probability \
of loss times amount of loss) = zero. Since the outcomes are equally \
probable, the probability of either event is .5 so we have\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5299361767593937`*^9, 3.5299361804536047`*^9}, 
   3.5386855198341618`*^9},ExpressionUUID->"149688bc-0f69-439e-8067-\
8361a96752a6"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001l`0@0006`0000300000@000<4100120000
00000000003<;P0010L00215CDH00040<1l006P000030000000000000000000000@00003000>0@00
b`0000000000000000000;0N103h60<0AP0002@7000F1`00AdA9@`4008000`00W:6kY@00003n1P00
0@090003O`<0008070000000100000<1200500002`8000001@0000`2e@281@D000090P0000050000
0@;oool0100000@13@0400000P4200<0000N00@0000W0Ooo0`0001h0100002L1ool300007P050000
0@;oool01@0000T2000000@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PCG08X5
o?olo`@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PCG08X5o?oloa`0003k0]Ko
00000000T04000000000045bJF5/000000000000000000000000000000000000100002d100040000
104=00@000020@406000038:100:00/0001@LVmRHF9YK6UdN@0L00h05`0G01L05`0:00X02P0<01D0
4000038:101@0@H0001@HGU_IVHL01L05@0G00d03@0@0000<PX406H21P0004=XHFiWIAh05`0G01L0
5`0G01T0000b2P@0EP<<0000@VEWJFhPEfEQK7AX700G01L02P0G00`0:P0G01L02P0<01L05P00038:
102N10X00015KV@PEfEQK7AX700G01L0300Z01L05`0:00`05`0<0000<PXh05000`00030^=@0G00`0
5`090000<PXh0=`00@0007P05P050000509N00/25@00038:>01I0@T0000X<C0`;30`<2T03P0G01L0
5`0<01L05`0G00h01@0001@2GP1D0@l0000b2SP060450000820P821U300<00`0300<00T0000b2SP0
E0410000800<00T0000b2SP06`810000?@0I00D0000D0Uh03P<C0000<PXh07<2200002Pe<2``<30Y
3P0G01L0300G01L05`0>00D0000D0Uh0LP8:0000<PXh05X20P00020P300<00T0000b2SP0LP810000
800<00T0000b2SP07P<10000:`0I00D0000D0Uh0B0@B0000<PXh0;831`00034`<2``<30Y5`0G01L0
300G01L05`050000509N0;434P00038:>01M0`L0000P820P820P:@`0300<00`0300<00`02@00038:
>02a0`40000P00`02@00038:>01V1040000m01T01@0001@2GP1_1A00000b2SP0l0@60000=C0/<30`
5`0G00`05`0G01L01@0001@2GP3]1100000b2SP0Y@@60000820P820P300<00`0300<00`02@00038:
>03]1040000P00`03000038:K01@00<0000`;SD05`0<01L02@00038:K03L0040001h01H01@0001@2
TP3m0A80000b2V`0I`470000<C0`;30`<2TG01L05`0<01L05`0G00D0000D0Y80H04@0000<PY/01P1
1P00020P820P80`0300<00`0300<00T0000b2V`0H0410000800<00T0000b2V`06`810000?@0I00D0
000D0Y8000<@0000<PY/08421P0003D`;30`<1L05`0<01L05`0G00D0000D0Y80OP8<0000<PY/05X2
0`00020P800<00`030090000<PY/07h20@00020030090000<PY/01h30@0002/06@05000050:B04P4
4P00038:K02b0`L0000a<30/<30`:AL05`0G00`05`0G01L01@0001@2TP2a0a80000b2V`0G@<70000
820P820P82T<00`0300<00`0300<00T0000b2V`0/@<10000800<00T0000b2V`0IP@10000?@0I00D0
000D0Y80K`DB0000<PY/0=T41`00034e<2``<30Y5`0G01L0300G01L05`05000050:B0=D43@00038:
K02U10@0000P820P300<00`030090000<PY/0=D40@000200300H0000<PZP01h12`0004EhL6ESM65d
JFm^01`05P0G01L05@0<01L0300:01L05`090000<PZP0?L20@0003005`05000050;606l54P00038:
X03I10L0000a<30/<30`:AL05`0G00`05`0G01L01@0001@2aP3E10d0000b2Z00Y@@40000820P80`0
300<00`02@00038:X03E1040000P00`070000?/240070000002l0P0000010P8RDgUcM6E]05P00000
00000000000D0P00e@@00>@400040000;@4100@0003`0@00100002L1ool3000000000140000<0000
200000/0000@0000aP4004@00009000040000<H1001400002P00010000000000000000T0000@0000
R0D00=D0000H000030000000000I000030000?ooo`0D0000300000d0000B000030000080000Q0000
20000280000<0000ooooob40000800008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
o?oooocooon:1@00e`000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0003looooo?ooohX5003G0000DP00070100010000e_ooo`00000000000000090100000000
00000440LP1Y0640K000000000000000000000000000000000000000000000000000000000000000
00000000000006L1002h04065@101QD0X8aW0N400028QFL1h`000:Q4nGL01`00oP@00;Sc4P3dh?Qg
002h0040002X0QD04<XH040000040000Z08E03S;600jR_Eg40000000E@6<>5d00000071mmGLjR_Eg
>?LI052N6P0`maT02<XH00005@0hmaT0@0<E040n6P0200001`0004RN6P0h?QX00P0000D0003h0aX0
3P0002H0002HRFL1@00^0TP0;P8000Una?3mO`3PoGl000000000000000000000;3d9OP80001P5`@d
H1L00?hj2GiP5`@dH1L4=040002dlQ80I7H02000000U000030000040000D0000300000d0000B0000
30000040001D0000T00000<000010000@P000100000100007T<7@@841d4:0000100000/0001<0000
0000000000000000oooooooooomT0000D01b06l0HP1Q0680J@1/06T0M01i0000700000h0000G0000
5`0001L0000G00002P0000X0000:0000300001D0001D0000L00006`000010000TP00010000010000
7T<7@@841d5@0@00100000H0001<00000000000000000000oooooooooomH0000D01Q07T0K`1V06H0
700001L0000E00005`0000d0000=0000E0000700003500000@000?<0000@00000@0001i31d4210M1
IP8000@000060000C00000000000000000000?ooooooooooF00004<0J01Q06h0I`1U01h0000G0000
5`0001L0000G00005`0005@0002D00004P400040001R0@0040000040000N@`M10P@7@EH300040000
300004`00000000000000000003oooooooooof@0001206D0I`1Y06h0801G06D0H@1/07@0J00L0000
5`0001L0000:00005`0000`0000Z00005`0001L0000:0000300001L0001D0000R00007/100010000
`@400100000100007T<7@@841d6N1000100000X0001<00000000000000000000oooooooooomP0000
A@1^06@0801G06D0H@1/07@0J00L00005`0001L0000<0000:P0001L0000G00002P0000`0000G0000
E0000600000J00004P0002`0000Q00000@0001i31d4210M1D00003P000030000C000000000000000
00000?ooooooooooE0000300;P0e00005`0000`0000G0000E00005@0001700004P0004h0000Q0000
0@0001i31d4210M1g00003P000010000C00000000000000000000?ooooooooooD00007P0000F0000
6`000100000;0P00GP0005@000240000K`000180002X00008@000040000N@`M10P@7@ET1000h0000
2@0004`00000000000000000003oooooooooof00000X0340<00`02`0<00`0300:@0000h0000G0000
5`0001L0000<00005`0001L0000G00003P0001/0000@0000E04005h0001D0000K00005X0000B0000
K@000240000100007T<7@@841d4H0@00>00000D0001<00000000000000000000oooooooooomH0000
800P0200800P0000300000`0000<0000300000`0001D0000E00006d0000B0000L000024000010000
7T<7@@841d5D0@00>0000040001<00000000000000000000oooooooooom@0000800000`0001D0000
E0000:d0000B0000]0000240000100007T<7@@841d4K0P00>0000040001<00000000000000000000
oooooooooom@0000?@0001T0000K0000400000h3001N0000E00007`0003900004P000?X0000Q0000
0@0001i31d4210M1L`8003P000080000C00000000000000000000?ooooooooooG00002P0=@0`02`0
<00`0300:@0>00005`0001L0000<00005`0001L0000G00003P0001/0000@0000LP8005h0001D0000
F0000<40000B0000b0000240000100007T<7@@841d5J0P00>0000080001<00000000000000000000
oooooooooom@0000800P00`0000<0000E00005@0003900004P000<`0000Q00000@0001i31d4210M1
LP8003P000010000C00000000000000000000?ooooooooooD0000200000<0000E00005@000000@00
4P0000L1000Q00000@0001i31d4210M17P<003P000010000C00000000000000000000?oooooooooo
D00002/0000I00006`00010000181000GP0005@0001h0000;`400180001O0@008@000040000N@`M1
0P@7@K83000h00001`0004`00000000000000000003ooooooooooe`0000a0300<00/0300<00`0000
5`0001L0000G0000300001L0000G00005`0001/0000@0000/@<005h0001D0000N00001@1000B0000
;P400240000100007T<7@@841d5M0`00>00000L0001<00000000000000000000oooooooooomL0000
800P0200800P0200800000`0000<0000300000`0000<0000300000`0001D0000E00002l1000B0000
<P400240000100007T<7@@841d6a0`00>0000040001<00000000000000000000oooooooooom@0000
800000`0001D0000E00006T1000B0000L0400240000100007T<7@@841d5V1000>0000040001<0000
0000000000000000oooooooooom@0000?@0001T0000K0000400006l5001N0000E0000700002E0@00
4P000;d1000Q00000@0001i31d4210M1l0@003P000060000C00000000000000000000?oooooooooo
F00003D0<00/0300<00`01L0000G0000300001L0000G00005`0001/0000@0000k@@005h0001D0000
L00007d1000B0000U0400240000100007T<7@@841d6U1000>00000H0001<00000000000000000000
oooooooooomH0000800P0200800P0200300000`0000<0000300000`0000<0000E00005@0002D0@00
4P0009L1000Q00000@0001i31d4210M1k@@003P000010000C00000000000000000000?oooooooooo
D0000200000<0000E0000600000J00008`0002`0000b00000@0001i31d4210M1D00006`000030000
C00000000000000000000?ooooooooooE0000300;P0e00005`0000`0000G0000E00005@000170000
8`0004h0000b00000@0001i31d4210M1g00006`000010000C00000000000000000000?oooooooooo
D00007P0000F00006`000100003m0@00TP0005@0001h0000L`0002<0002S0000<P000040000N@`M1
0P@7@FL1001/00001`0004`00000000000000000003ooooooooooe`0000a0300<00/0300<00`0000
5`0001L0000G0000300001L0000G00005`0001/0000@0000H0400980001D0000L00005X0000S0000
L@000380000100007T<7@@841d4H0@00K00000H0001<00000000000000000000oooooooooomH0000
800P0200800P0200300000`0000<0000300000`0000<0000E00005@0001a00008`0007@0000b0000
0@0001i31d4210M1H04006`000010000C00000000000000000000?ooooooooooD0000200000<0000
E00005@0002]00008`000;@0000b00000@0001i31d4210M16`8006`000010000C000000000000000
00000?ooooooooooD00003d0000I00006`00010000000`00TP0005@0001`0000cP0002<0003f0000
<P000040000N@`M10P@7@H42001/00001P0004`00000000000000000003ooooooooooeP0000e0300
;00`0300<00G00005`0000`0000G00005`0001L0000K0000400007h2002B0000E000060000310000
8`000<`0000b00000@0001i31d4210M1FP8006`000030000C00000000000000000000?oooooooooo
E0000200800P0000300000`0000<0000E00005@0003=00008`000=00000b00000@0001i31d4210M1
OP8006`000010000C00000000000000000000?ooooooooooD0000200000<0000E00005@000000@00
8`0000L1000b00000@0001i31d4210M17P<006`000010000C00000000000000000000?oooooooooo
D00002/0000I00006`00010000181000TP0005@0001h0000;`4002<0001O0@00<P000040000N@`M1
0P@7@K83001/00001`0004`00000000000000000003ooooooooooe`0000a0300<00/0300<00`0000
5`0001L0000G0000300001L0000G00005`0001/0000@0000/@<00980001D0000N00001@1000S0000
;P400380000100007T<7@@841d5M0`00K00000L0001<00000000000000000000oooooooooomL0000
800P0200800P0200800000`0000<0000300000`0000<0000300000`0001D0000E00002l1000S0000
<P400380000100007T<7@@841d6a0`00K0000040001<00000000000000000000oooooooooom@0000
800000`0001D0000E00006T1000S0000L0400380000100007T<7@@841d5V1000K0000040001<0000
0000000000000000oooooooooom@0000?@0001T0000K0000400006l5002B0000E00007P0002>0@00
8`000;h1000b00000@0001i31d4210M1f@@006`000070000C00000000000000000000?oooooooooo
G0000340=@0`02`0<00`0300000G00005`0001L0000<00005`0001L0000G00006`000100003E1000
TP0005@0001T0000O@4002<0002<0@00<P000040000N@`M10P@7@JD4001/0000100004`000000000
00000000003ooooooooooe@0000P0200800P00`0000<0000300000`0001D0000E00008d1000S0000
T0400380000100007T<7@@841d7E1000K0000040001<00000000000000000000oooooooooom@0000
800000`0001D0000T00005`0000c0000XP000480000100007T<7@@841d4N0@00X00000/0001<0000
0000000000000000oooooooooomT0000A@1h0700I@1S07@0H@1d06T0K`1^0000700001H0000G0000
5`0001D0000<00005`0000`0000:00005`0001L0001D0000E0000?<0000c0000nP00048000010000
7T<7@@841d7g0P00X0000040001<00000000000000000000oooooooooom@0000<00001L0000K0000
400006l500360000E00007P0002>0@00<`000;h1001200000@0001i31d4210M1f@@00:0000070000
C00000000000000000000?ooooooooooG0000340<00`02`0<00`0300000G00005`0001L0000<0000
5`0001L0000G00006`000100003E1000aP0005@0001T0000O@4003<0002<0@00@P000040000N@`M1
0P@7@JD4002P0000100004`00000000000000000003ooooooooooe@0000P0200800P00`0000<0000
300000`0001D0000E00008d1000c0000T0400480000100007T<7@@841d7E1000X0000040001<0000
0000000000000000oooooooooom@0000800000`0001B0000L0400080000@00001`00000000000000
_080000000010P8RD`1i07<0M01U06d0000000000000000000000000000000000000000000000000
000000000000000000000000M01Y06l0KP1X00002Gk4l?eo0>3mO`0000000000300001l0002PlQ80
00000<]4nGM8JQD0cH_eMnP65@0gT?Ege_HI051Z5@1@JQD0100000@000280QD0R08E00@0001P0AD0
000003Z:mGLhmaT0D9hJ033g6@08bQP0000E02S:60100aD0@3hJ008000070000B9hJ02S:60280QD0
00000000000000009P0009R9I`5002h20P0000000034l?eo0>3mO`80000@00000000051Z5@0001D0
M?0100005@3TlA80l8SjMmSb4P3`R?YgR1ceMooooomTMP08000002D0000<00000P0002P0000<0000
0@000280000<0000ooooobD0000<00001`00P2D0000<00000000P300000<00003`00P4/0000@0000
000000D0000X000030000080000>000050000000000@00005000
\>"], "Graphics",
 Editable->False,
 PageWidth->WindowWidth,
 TextAlignment->Center,
 ImageSize->{339.56299999999993`, 50.9375},
 ImageMargins->{{470.3333333333333, 0.}, {0., 
  0.}},ExpressionUUID->"d44fe9aa-af6f-420f-8107-7c33840e062e"],

Cell[TextData[{
 StyleBox["Table 6.2.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "TableTitleLabel"],
 "Mathematical expectation"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{12., 18.88888888888914}, {1., 7.}},
 CellChangeTimes->{3.5314998749897366`*^9, 3.5314999150800295`*^9, 
  3.5386855198341618`*^9},
 TextAlignment->Center,ExpressionUUID->"10405461-bfd3-48a7-88d5-c3288894c518"],

Cell[TextData[{
 "The graphic representation of this situation",
 StyleBox[" ", "MLHText"],
 "is, of course, linear and represents how people who are \"risk neutral\" \
view the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"world", 
    SuperscriptBox[".", 
     ButtonBox["5",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote5"]]}], TraditionalForm]],ExpressionUUID->
  "d81ffa9e-ef4e-4536-8b05-873d9495ce3c"],
 " Most people, as we will see in a moment, are presumed to be risk averse.  \
The perspective of the risk neutral party is the reference from which we \
start to place a value on risk bearing.  There are a variety of ways of \
plotting the risk neutral position, one of which appears In Figure 6.8."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296171491936054`*^9, 3.5296171652295227`*^9}, {
  3.52970018845818*^9, 3.529700230546587*^9}, {3.5297102310805855`*^9, 
  3.5297102344637785`*^9}, {3.5297103013796062`*^9, 3.5297103227478285`*^9}, {
  3.5386855198341618`*^9, 
  3.538685519835162*^9}},ExpressionUUID->"2af4e71b-7195-4788-b68d-\
e225699be125"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "b", ",", "ab"}], "]"}], ";", 
  RowBox[{"ab", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"a", " ", "x1"}], "+", "b"}], "\[Equal]", 
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "50000", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"a", " ", "x2"}], "+", "b"}], "\[Equal]", 
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "150000", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}]}], "]"}], "/.", "\[InvisibleSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x1", "\[Rule]", "50000"}], ",", 
      RowBox[{"x2", "\[Rule]", "150000"}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{"p1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", "x"}], "+", "b"}], "/.", "\[InvisibleSpace]", "ab"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "30000", ",", "180000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"10", ",", "12"}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"25000", ",", "10"}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"50000", ",", "100000", ",", "150000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "50000", "]"}], "]"}], ",", 
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "100000", "]"}], "]"}], ",", 
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "150000", "]"}], "]"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"50000", ",", "100000", ",", "150000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"u", "[", "50000", "]"}], ",", 
         RowBox[{"u", "[", "100000", "]"}], ",", 
         RowBox[{"u", "[", "150000", "]"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Wealth\>\"", ",", "\"\<U[Wealth]\>\""}], "}"}]}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.402752320454125*^9, 3.402752334766625*^9}, {
   3.402752384329125*^9, 3.402752395376*^9}, {3.402785762047875*^9, 
   3.40278578359475*^9}, {3.402785891501*^9, 3.402785894641625*^9}, {
   3.4027859665635*^9, 3.40278596965725*^9}, {3.529617094624484*^9, 
   3.52961710486007*^9}, 
   3.538685519836162*^9},ExpressionUUID->"c62a5dc4-0733-4e87-af53-\
4512a741911d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwBIQPe/CFib1JlAgAAADEAAAACAAAAxLQnMgBM3UDKlo+FOjMlQEYp9n2A
V91A1MRjxHwzJUDJncTJAGPdQN3yNwO/MyVAzoZhYQF63UDwTuCAQzQlQNhY
m5ACqN1AFgcxfEw1JUDs/A7vBATeQGF30nJeNyVAFEX2qwm83kD4VxVggjsl
QLJq4pIJFuBAJRmbOspDJUDHxS8dCKXhQP0DsI6+VSVAm7xU15UZ40AOtn9L
gmYlQNte3rbUhuRAcbp52PF2JUDgy+amCBPmQFAnfQTGiCVApNTGxsuE50Bp
WzuZaZklQC2oJfeDFelA//cCzXGrJUAiJ+lM7Z7qQObm9NAlvSVA1kGE0uUN
7EAHnaE9qc0lQE8nnmjTm+1ApLtXSZHfJUCHqI8uUA/vQHyhyL1I8CVAlury
DL898ECl2WMCrAAmQEtm3YpQA/FASnoI5nMSJkDfr7OgqbvxQCriZzILIyZA
1l7JPn2D8kCGstAdBzUmQINjkW+pR/NAM9Vj2a5GJkAPNkU4nf7zQBq/sf0l
VyZA/m04iQvF9EB+EQnBAWkmQMxzF3JBfvVAHCsb7ax5JkD93jXj8Ub2QDet
Nri8iyZA5J8G5/oL90CigXxTeJ0mQKsuw4LLw/dASB19VwOuJkDUIr+mFov4
QGohh/ryvyZA3eSmYilF+UDH7EsGstAmQJz8QLGU+/lAdAo74hzhJkC9eRqI
esH6QJ6QM13s8iZAvsTf9id6+0AD3uZAiwMnQCF15O1PQvxA5JOjw44VJ0A6
e5t30Ab9QBacihY+JydAM08+mRi+/UCBayzSvDcnQI6IIEPbhP5AaqPXLKBJ
J0DJj+6EZT7/QI2iPfBSWidAuuxuWUj0/0AA9M2DsWonQIdXF9vSXABB8a1n
tnR8J0CgH21V5bgAQRsvvFEHjSdAa5riE7UcAUHCGBqM/p4nQCb8TZ7oeQFB
pMkyL8WvJ0C7iBJySNUBQdbMdaI3wCdAAsj2iWU4AkGFOMK0DtInQDnu0G3m
lAJBbmvJL7XiJ0Ahx8qVJPkCQdQG2knA9CdAhWgESKM3A0EAAAAAAAAoQLCI
a5M=
       "]]},
     Annotation[#, "Charting`Private`Tag$4658#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Wealth\"", TraditionalForm], 
    FormBox["\"U[Wealth]\"", TraditionalForm]},
  AxesOrigin->{25000., 10.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->NCache[{{50000, 100000, 150000}, {
      Log[50000], 
      Log[100000], 
      Log[150000]}}, {{50000, 100000, 150000}, {10.819778284410283`, 
     11.512925464970229`, 11.918390573078392`}}],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{25000., 179999.9969387755}, {10, 12}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{{{50000, 
      FormBox["50000", TraditionalForm]}, {100000, 
      FormBox["100000", TraditionalForm]}, {150000, 
      FormBox["150000", TraditionalForm]}}, {{10.819778284410283`, 
      FormBox["10.819778284410283`", TraditionalForm]}, {11.512925464970229`, 
      FormBox["11.512925464970229`", TraditionalForm]}, {11.918390573078392`, 
      FormBox["11.918390573078392`", TraditionalForm]}}}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQZwCB/Cy+qJeOhh1sGUogmkOywQdMC/WB6Y6v00D0u/lF
l019XjkycercAtFHnDbPjwXSfv8V3LqAdIAI05luIH3l0U/Fi0D6jla+6SUg
nVcndOkHkOZ5zPYLRB/bf9H4J5C+J/g2yd8XqI+TYxmIvnA27Mtm/1eOy7k+
dp4F0kqsNTmvg145FrU/YXgDpBkYlE9+C37lqOBzPVQgBMTveywJohsmNUkB
6TSH+YsbY185cpz6dRJEH5IouBcY/8oxqe9jp2PCK8eEtimCnxJfOfbfCnH7
DKStAuoaQDRbpJ+YYPIrxz+/NvQkp71y/MlXctik67Xj+fNd8WZAmk1p1xoQ
LRV/x2cmkH5zjolR/uxrRwCZD5bo
  "],
 TextAlignment->Center,ExpressionUUID->"6bc88f27-9528-4345-83bf-d0790ce5734c"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.8.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Utility of wealth as linear function of wealth."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500309299577*^9}, 
   3.538685519837162*^9},
 TextAlignment->Center,ExpressionUUID->"2c8fd259-a91f-4156-ac70-c4afe486dd1e"],

Cell[TextData[{
 "Notice when comparing the two curves in Figure 6.9 that, relative to the ",
 StyleBox["y",
  FontSlant->"Italic"],
 "-axis, they both pass through the same points on the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis representing the alternative outcomes. But when they pass through \
initial wealth they generate different values on the ",
 StyleBox["y",
  FontSlant->"Italic"],
 "-axis. Figure 6.9 shows the two plots on one graph."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529617356853483*^9, 3.5296173900773835`*^9}, {
   3.5297002720719624`*^9, 3.529700274410096*^9}, 
   3.538685519837162*^9},ExpressionUUID->"5f8cf2a1-b010-4227-9362-\
aa985b2573c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"u", "[", "w", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"w", ",", "30000", ",", "180000"}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"10", ",", "12"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"25000", ",", "10"}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "8"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"50000", ",", "\"\<50000\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"0.5", " ", 
               RowBox[{"u", "[", "50000", "]"}]}], "+", 
              RowBox[{"0.5", " ", 
               RowBox[{"u", "[", "150000", "]"}]}]}]], ",", 
            "\"\<\\n$86,603\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"100000", ",", "\"\<$100,000\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"150000", ",", "\"\<$150,000\>\""}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"u", "[", "50000", "]"}], "]"}], ",", 
          RowBox[{"N", "[", 
           RowBox[{"u", "[", "100000", "]"}], "]"}], ",", 
          RowBox[{"N", "[", 
           RowBox[{"u", "[", "150000", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"0.5", " ", 
            RowBox[{"u", "[", "50000", "]"}]}], "+", 
           RowBox[{"0.5", " ", 
            RowBox[{"u", "[", "150000", "]"}]}]}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"50000", ",", "100000", ",", "150000", ",", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"0.5", " ", 
             RowBox[{"u", "[", "50000", "]"}]}], "+", 
            RowBox[{"0.5", " ", 
             RowBox[{"u", "[", "150000", "]"}]}]}]]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "[", "50000", "]"}], ",", 
          RowBox[{"u", "[", "100000", "]"}], ",", 
          RowBox[{"u", "[", "150000", "]"}], ",", 
          RowBox[{
           RowBox[{"0.5", " ", 
            RowBox[{"u", "[", "50000", "]"}]}], "+", 
           RowBox[{"0.5", " ", 
            RowBox[{"u", "[", "150000", "]"}]}]}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Wealth\>\"", ",", "\"\<U[Wealth]\>\""}], "}"}]}]}], 
    "]"}]}], ";", 
  RowBox[{"show1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"p2", ",", "p1"}], "]"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.52961734123559*^9, {3.529789283543127*^9, 3.5297892855232406`*^9}, {
   3.52978931716005*^9, 3.529789345323661*^9}, {3.529791122319299*^9, 
   3.529791124132403*^9}, 
   3.538685519838162*^9},ExpressionUUID->"ed425156-b23f-4771-bb1b-\
f3de9553a23c"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAADMAAAACAAAAxLQnMgBM3UCVe3cOL54kQEYp9n2A
V91AH1Va5veeJEDJncTJAGPdQAoFk2/AnyRAzoZhYQF63UD8u/uWUKEkQNhY
m5ACqN1Aa6ZTQG2kJEDs/A7vBATeQHLjfzGYqiRAFEX2qwm83kAGj/sitrYk
QLJq4pIJFuBARG19HR7OJEDHxS8dCKXhQMvvHnF3/SRAm7xU15UZ40AuBjI3
CyYlQNte3rbUhuRAG6iOr+1KJUDgy+amCBPmQJnp0GUlcCVApNTGxsuE50DZ
53LemJAlQC2oJfeDFelAeV85c5axJUAiJ+lM7Z7qQHRk/iUI0CVA1kGE0uUN
7EATf0en4uolQE8nnmjTm+1Apitw6n4GJkCHqI8uUA/vQNwvSE3+HiZAlury
DL898EBxL+Eh7DUmQEtm3YpQA/FADSwa+rBNJkDfr7OgqbvxQIPzXq3qYiZA
1l7JPn2D8kD6GOvS+HgmQINjkW+pR/NAWi6Yw7yNJkAPNkU4nf7zQA9vfmJf
oCZA/m04iQvF9EDVQjGT2LMmQMxzF3JBfvVA0mzoiGDFJkD93jXj8Ub2QBfL
qyG41yZA5J8G5/oL90AG+z0pHOkmQKsuw4LLw/dAJ+IMadH4JkDUIr+mFov4
QNVDfUBSCSdA3eSmYilF+UDTNkGSQxgnQJz8QLGU+/lAfeKCbIAmJ0C9eRqI
esH6QCB4HjGDNSdAvsTf9id6+0BSriFjIkMnQCF15O1PQvxAfmDP8n9RJ0A6
e5t30Ab9QO507bI4XydAM08+mRi+/UDuzlxgsmsnQI6IIEPbhP5AMF7YBOR4
J0DJj+6EZT7/QIPsV1bohCdAuuxuWUj0/0AGZSWSa5AnQIdXF9vSXABBteYR
YqCcJ0CgH21V5bgAQRlXTTLCpydAa5riE7UcAUFVC8chj7MnQCb8TZ7oeQFB
wEXnfVa+J0C7iBJySNUBQTJ0QoOwyCdAAsj2iWU4AkH9mdCsr9MnQDnu0G3m
lAJBLHrAob3dJ0Ahx8qVJPkCQSrJfAdr6CdA5ModB49bA0GyaaBFsPInQJe1
ZkRdtwNB0cD9Qxb8J0CWKuqPUd4DQQAAAAAAAChAB6x+Jg==
        "]]},
      Annotation[#, "Charting`Private`Tag$4716#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBIQPe/CFib1JlAgAAADEAAAACAAAAxLQnMgBM3UDKlo+FOjMlQEYp9n2A
V91A1MRjxHwzJUDJncTJAGPdQN3yNwO/MyVAzoZhYQF63UDwTuCAQzQlQNhY
m5ACqN1AFgcxfEw1JUDs/A7vBATeQGF30nJeNyVAFEX2qwm83kD4VxVggjsl
QLJq4pIJFuBAJRmbOspDJUDHxS8dCKXhQP0DsI6+VSVAm7xU15UZ40AOtn9L
gmYlQNte3rbUhuRAcbp52PF2JUDgy+amCBPmQFAnfQTGiCVApNTGxsuE50Bp
WzuZaZklQC2oJfeDFelA//cCzXGrJUAiJ+lM7Z7qQObm9NAlvSVA1kGE0uUN
7EAHnaE9qc0lQE8nnmjTm+1ApLtXSZHfJUCHqI8uUA/vQHyhyL1I8CVAlury
DL898ECl2WMCrAAmQEtm3YpQA/FASnoI5nMSJkDfr7OgqbvxQCriZzILIyZA
1l7JPn2D8kCGstAdBzUmQINjkW+pR/NAM9Vj2a5GJkAPNkU4nf7zQBq/sf0l
VyZA/m04iQvF9EB+EQnBAWkmQMxzF3JBfvVAHCsb7ax5JkD93jXj8Ub2QDet
Nri8iyZA5J8G5/oL90CigXxTeJ0mQKsuw4LLw/dASB19VwOuJkDUIr+mFov4
QGohh/ryvyZA3eSmYilF+UDH7EsGstAmQJz8QLGU+/lAdAo74hzhJkC9eRqI
esH6QJ6QM13s8iZAvsTf9id6+0AD3uZAiwMnQCF15O1PQvxA5JOjw44VJ0A6
e5t30Ab9QBacihY+JydAM08+mRi+/UCBayzSvDcnQI6IIEPbhP5AaqPXLKBJ
J0DJj+6EZT7/QI2iPfBSWidAuuxuWUj0/0AA9M2DsWonQIdXF9vSXABB8a1n
tnR8J0CgH21V5bgAQRsvvFEHjSdAa5riE7UcAUHCGBqM/p4nQCb8TZ7oeQFB
pMkyL8WvJ0C7iBJySNUBQdbMdaI3wCdAAsj2iWU4AkGFOMK0DtInQDnu0G3m
lAJBbmvJL7XiJ0Ahx8qVJPkCQdQG2knA9CdAhWgESKM3A0EAAAAAAAAoQLCI
a5M=
        "]]},
      Annotation[#, "Charting`Private`Tag$4658#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{25000., 10.},
  BaseStyle->(FontSize -> 8),
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"U[Wealth]\"", TraditionalForm], None}, {
     FormBox["\"Wealth\"", TraditionalForm], None}},
  FrameTicks->{{{{10.819778284410283`, 
       FormBox["10.819778284410283`", TraditionalForm]}, {11.512925464970229`, 
       FormBox["11.512925464970229`", TraditionalForm]}, {11.918390573078392`, 
       FormBox["11.918390573078392`", TraditionalForm]}, {11.369084428744337`, 
       FormBox["11.369084428744337`", TraditionalForm]}}, {{
      10.819778284410283`, 
       FormBox["10.819778284410283`", TraditionalForm]}, {11.512925464970229`, 
       FormBox["11.512925464970229`", TraditionalForm]}, {11.918390573078392`, 
       FormBox["11.918390573078392`", TraditionalForm]}, {11.369084428744337`, 
       FormBox["11.369084428744337`", TraditionalForm]}}}, {{{50000, 
       FormBox["\"50000\"", TraditionalForm]}, {86602.54037844377, 
       FormBox["\"\\n$86,603\"", TraditionalForm]}, {100000, 
       FormBox["\"$100,000\"", TraditionalForm]}, {150000, 
       FormBox["\"$150,000\"", TraditionalForm]}}, {{50000, 
       FormBox["\"50000\"", TraditionalForm]}, {86602.54037844377, 
       FormBox["\"\\n$86,603\"", TraditionalForm]}, {100000, 
       FormBox["\"$100,000\"", TraditionalForm]}, {150000, 
       FormBox["\"$150,000\"", TraditionalForm]}}}},
  GridLines->NCache[{{50000, 100000, 150000, 86602.54037844377}, {
      Log[50000], 
      Log[100000], 
      Log[150000], 11.369084428744337`}}, {{
     50000, 100000, 150000, 86602.54037844377}, {10.819778284410283`, 
     11.512925464970229`, 11.918390573078392`, 11.369084428744337`}}],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{25000., 179999.9969387755}, {10, 12}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQYwCBwiy+qJeOhh2CGUpAWuxy5WtTn1eOQuo8P0C03vf9
82NBdJnE204gbTNpyhcQLTZf2a0LSL9bxngZRJ+zVTvTDaRvbWRVugikLR4X
ml4C0l4LRS/9ANIHrnD+AtFFt64Y/wTSVl/fJfn7vnL0vMO5DERPnxHxZbP/
K8c9SZ86zwJpKf+enNdBrxxfv3/K8AZIA1178lswUF/xk1CBEBB/4mNJMD2j
SQpI3zi9enFj7CvHrFu/ToLoMtOie4HxrxzL6wS7HBNeOYbM3Sj4KfGV4+3Q
QrfPQHqN+qwGEK3xM0NMMPmV48w7x3uS0145um4oO2zS9drRLHPPGjMgrRFy
z2cmkLb/ysIof/a1IwBbQJhe
  "],
 TextAlignment->Center,ExpressionUUID->"c108422d-5d93-4ac0-aa43-93e893f820fe"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.9.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Different utility functions for different outcomes."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315003266845713`*^9}, 
   3.538685519839162*^9},
 TextAlignment->Center,ExpressionUUID->"c65f11ec-0a09-4997-af53-b6695765d053"],

Cell[TextData[{
 "Note that the difference between the change in utility associated with an \
increase in one's wealth and the change in utility associated with an \
equivalent (in nominal terms) decrease in one's wealth shows that the lost \
utility associated with losing $50,000 is greater than the utility gained by \
winning ",
 Cell[BoxData[
  FormBox[
   RowBox[{"$50", ",", 
    SuperscriptBox["000.", 
     ButtonBox["6",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote6"]]}], TraditionalForm]],ExpressionUUID->
  "52d4fbc6-68ea-4941-af67-364f8b6c2b43"],
 " "
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296184614246607`*^9, 3.5296184752374516`*^9}, {
  3.529700350029421*^9, 3.529700352304551*^9}, {3.529710501904075*^9, 
  3.529710520791156*^9}, {3.5386855198401623`*^9, 
  3.5386855198411627`*^9}},ExpressionUUID->"52133245-e9b8-4b5f-bfda-\
88df6d86cbc5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<Utility of wealth increase\>\"", ",", 
       "\"\<Utility of wealth decrease\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{"u", "[", "150000", "]"}], "]"}], "-", 
        RowBox[{"N", "[", 
         RowBox[{"u", "[", "100000", "]"}], "]"}]}], ",", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"u", "[", "100000", "]"}], "-", 
         RowBox[{"N", "[", 
          RowBox[{"u", "[", "50000", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Utility of Expectation\>\"", ",", 
       "\"\<Expectation of the utility\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{
         RowBox[{".5", " ", "50000"}], " ", "+", 
         RowBox[{".5", " ", "150000"}]}], "]"}], ",", 
       RowBox[{".5", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"u", "[", "150000", "]"}], "]"}], "+", 
          RowBox[{"N", "[", 
           RowBox[{"u", "[", "50000", "]"}], "]"}]}], ")"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", "Center", "}"}]}]}], "]"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.529617911754222*^9, 3.5296179916987944`*^9}, {
   3.529618022104533*^9, 3.529618040807603*^9}, {3.529618078091736*^9, 
   3.5296181016880856`*^9}, {3.529618138297179*^9, 3.529618145882613*^9}, {
   3.529618203757923*^9, 3.5296183511393533`*^9}, {3.5296184002551622`*^9, 
   3.529618433116042*^9}, {3.529760999734386*^9, 3.529761008353879*^9}, 
   3.5386855198411627`*^9},ExpressionUUID->"6dc73cef-b620-4a68-9c3e-\
be72a043c2dd"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Utility of wealth increase\"\>", "\<\"Utility of wealth \
decrease\"\>"},
    {"0.4054651081081637`", "0.6931471805599454`"},
    {"\<\"Utility of Expectation\"\>", "\<\"Expectation of the utility\"\>"},
    {"11.512925464970229`", "11.369084428744337`"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Center}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529617942338971*^9, 3.5296179924678383`*^9}, {
   3.529618026871806*^9, 3.5296180413886366`*^9}, 3.5296181025351334`*^9, 
   3.5296181466556573`*^9, {3.529618212539426*^9, 3.5296182641193757`*^9}, 
   3.5296183519003963`*^9, {3.5296184050804386`*^9, 3.529618434149101*^9}, 
   3.5296186246589975`*^9, 3.529698558391946*^9, {3.5297610003564215`*^9, 
   3.529761009469943*^9}, 3.529790001194175*^9, 3.5297931223961134`*^9, 
   3.5299351205969844`*^9, 3.5299373236199903`*^9, 3.5300164007919455`*^9, 
   3.530016720413227*^9, 3.530017182754671*^9, 3.530193687529438*^9, 
   3.5301942243671436`*^9, 3.5314482268196297`*^9, 3.5315006236205554`*^9, 
   3.533134692916686*^9, 3.5331358792345395`*^9, 3.533682249296875*^9, 
   3.533734575804104*^9, 3.533754140640625*^9, 3.53375541284375*^9, 
   3.5386852138116584`*^9, 3.5386855198411627`*^9, 3.53963595563603*^9, 
   3.5401268014547396`*^9, 3.5410126222894974`*^9, 3.541015092159766*^9, 
   3.5410155578664026`*^9, 3.541600435969454*^9, 3.5433421831377296`*^9, 
   3.696338459737092*^9, 3.6963423739259434`*^9, 3.6965443589979105`*^9, 
   3.731421192185017*^9},
 TextAlignment->Center,ExpressionUUID->"cd192202-93d5-46c0-9a83-66203ff5ea59"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table 6.3.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "TableTitleLabel"],
 "Difference in utilities for gains and losses"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{132.66666666666666`, 104.44444444444446`}, {1., 7.}},
 CellChangeTimes->{
  3.5314998749897366`*^9, {3.5314999150800295`*^9, 3.531499944359704*^9}, 
   3.5386855198411627`*^9},
 TextAlignment->Center,ExpressionUUID->"e4aee4e8-d407-43d6-b1c4-a6f986fd74b6"],

Cell[CellGroupData[{

Cell[TextData[{
 "The conclusion we reach is that ",
 StyleBox["in order to be compensated for bearing risk,",
  FontSlant->"Italic"],
 " our investor must be offered the opportunity to pay less than the raw \
expectation ($100,000) . This is reasonable. Why would someone who already \
has $100,000 pay $100,000 for a 50/50 proposition knowing that in a large \
number of trials he will merely breakeven? From the graph above we note that \
utility for the risky prospect is the same as the utility of the certainty of \
$100,000 (the \"do nothing\" position) if the risky opportunity is priced at \
$86,603.  Certainty equivalent is a way of saying that the investor is \
indifferent between paying $86,603 for the 50/50 opportunity to increase or \
decrease his wealth $50,000 or having a certain $100,000.  How is $86,603 \
calculated?  We know that the expectation of the utility of wealth as shown \
on the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axis of the plot is:"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529618656099796*^9, 3.529618657238861*^9}, 
   3.529618705913645*^9, 3.5386855198411627`*^9, 
   3.53960739945471*^9},ExpressionUUID->"471706fe-7a58-47a5-8877-\
b01b4ecd3e93"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"certequivW", "=", 
  RowBox[{
   RowBox[{".5", " ", 
    RowBox[{"u", "[", "50000", "]"}]}], "+", " ", 
   RowBox[{".5", " ", 
    RowBox[{"u", "[", "150000", "]"}]}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198411627`*^9},ExpressionUUID->"993fbe4d-8f78-4440-9acb-\
c9408ba08035"],

Cell[BoxData["11.369084428744337`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658643609375*^9, 3.402699587172875*^9, 
  3.5296187623028708`*^9, 3.529698558798969*^9, 3.529790001252178*^9, 
  3.5297931228751407`*^9, 3.5299351210350094`*^9, 3.529937323675993*^9, 
  3.530016400997957*^9, 3.5300167205002317`*^9, 3.5300171828506765`*^9, 
  3.5301936875894413`*^9, 3.530194224426147*^9, 3.531448226865632*^9, 
  3.531500623686559*^9, 3.5331346933587112`*^9, 3.5331358792865424`*^9, 
  3.53368224940625*^9, 3.5337345763891373`*^9, 3.53375414071875*^9, 
  3.5337554129375*^9, 3.538685214207681*^9, 3.5386855198411627`*^9, 
  3.5396359557000337`*^9, 3.540126802005771*^9, 3.5410126229205337`*^9, 
  3.541015092805803*^9, 3.5410155589534645`*^9, 3.5416004365854893`*^9, 
  3.5433421838567705`*^9, 3.69633845978121*^9, 3.696342373940984*^9, 
  3.6965443590219693`*^9, 
  3.731421192204068*^9},ExpressionUUID->"035be7e4-276e-4435-a2ca-\
9d60b238e0af"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "And we know that number is produced by a function we have chosen ",
 StyleBox["u1[w]",
  FontFamily->"Courier New",
  FontWeight->"Bold"],
 " = Log(",
 StyleBox["w",
  FontSlant->"Italic"],
 "). Thus, we solve for the known value of ",
 StyleBox["u",
  FontSlant->"Italic"],
 " by \"exponenting\" both sides of Equation 6.1:"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.529618783543085*^9, {3.5296189455203495`*^9, 3.52961895042063*^9}, 
   3.5386855198411627`*^9, 3.5410145257713704`*^9, {3.5410145724070377`*^9, 
   3.541014572642051*^9}},ExpressionUUID->"261ae636-07bf-48d6-96a7-\
027d9f4d97d7"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{"Certainty", " ", "Equivalent", " ", "Wealth"}], "]"}], "=", 
    "11.3691"}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529618806827417*^9, 3.5296188288146744`*^9}, 
   3.5386855198411627`*^9, {3.5410144380183516`*^9, 
   3.541014516889862*^9}},ExpressionUUID->"aaa4e324-a302-444f-b091-\
ac4422fce082"],

Cell[CellGroupData[{

Cell[TextData[{
 "Doing this to the left side eliminates the Log function and leaves the \
Certainty Equivalent Wealth as the unknown. Doing it to the right side leaves \
",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", "11.3691"], TraditionalForm]],
  ExpressionUUID->"a9a3cf01-473a-4a60-afb5-940de4b85c84"],
 "which is easily evaluated using a calculator because \[ExponentialE] is \
just a number, a constant approximately equal to 2.71828."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529618783543085*^9, 3.5296187899354506`*^9}, {
  3.538685519842162*^9, 
  3.538685519842162*^9}},ExpressionUUID->"ab2c54b1-f0f0-41b4-b7e0-\
85d47cfb1883"],

Cell[CellGroupData[{

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", "11.3691"]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296189100263195`*^9, 3.5296189131905003`*^9}, {
   3.529700435137289*^9, 3.5297004374674225`*^9}, 
   3.5386855198431625`*^9},ExpressionUUID->"845c007f-ef19-4be3-b0ea-\
1b80b0f722f2"],

Cell[BoxData["86603.88889924009`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658643625*^9, 3.402699587297875*^9, 
  3.5296188468737073`*^9, 3.529618914102553*^9, 3.5296985592109923`*^9, 
  3.5297004383284717`*^9, 3.5297900013881855`*^9, 3.529793123306165*^9, 
  3.52993512139703*^9, 3.5299373237329965`*^9, 3.530016401099963*^9, 
  3.530016720587237*^9, 3.5300171829466825`*^9, 3.530193687954462*^9, 
  3.5301942244861507`*^9, 3.531448227157649*^9, 3.531500623744562*^9, 
  3.533134693908743*^9, 3.5331358793285446`*^9, 3.5336822495*^9, 
  3.5337345770201735`*^9, 3.533754140796875*^9, 3.53375541303125*^9, 
  3.5386852147607126`*^9, 3.5386855198431625`*^9, 3.539635955761037*^9, 
  3.540126802579804*^9, 3.5410126237285795`*^9, 3.5410150935178432`*^9, 
  3.541015560074529*^9, 3.5416004372205257`*^9, 3.543342184527809*^9, 
  3.696338459795246*^9, 3.696342373983096*^9, 3.6965443590650835`*^9, 
  3.7314211922241316`*^9},ExpressionUUID->"2705ff88-5e14-49da-baf9-\
8d6100d92eb7"]
}, Open  ]]
}, Closed]],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"Log", "[", 
      RowBox[{"Certainty", " ", "Equivalent", " ", "Wealth"}], "]"}]], "=", 
    SuperscriptBox["\[ExponentialE]", "11.3691"]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529618985684647*^9, 3.529619043455951*^9}, 
   3.5386855198431625`*^9},ExpressionUUID->"841da71a-2d9c-41e7-b709-\
97de8954c320"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{
     RowBox[{"Certainty", " ", "Equivalent", " ", "Wealth"}], "=", "86"}], 
    ",", "603.90"}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529618985684647*^9, 3.5296190564186926`*^9}, {
   3.5296191622667465`*^9, 3.52961916302079*^9}, {3.5297004607917566`*^9, 
   3.5297004641839504`*^9}, 
   3.5386855198431625`*^9},ExpressionUUID->"aa002fc0-1604-49fb-8dd0-\
caa3e069a406"],

Cell[CellGroupData[{

Cell[TextData[{
 "The difference between this number and $100,000, the sum of $13,397, is the \
\"discount\" the investor applies to the raw expectation, given his specific \
preference for risk as represented by the shape of his utility function.  \
Stated differently, the discount is the compensation he requires to accept a",
 StyleBox[" ", "MLHText"],
 "prospect involving this sort of risk. When a real estate broker asks his \
client to take money out of a saving account to buy an apartment building it \
is the discount and its associated prospect of a higher return on the net \
invested that motivates the buyer to act."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198431625`*^9, {3.541013423392318*^9, 
   3.5410134306447325`*^9}},ExpressionUUID->"38f7e343-6595-484e-864c-\
91a6acc013b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"disc", "=", 
   RowBox[{"100000", "-", 
    RowBox[{"N", "[", 
     SuperscriptBox["\[ExponentialE]", "certequivW"], "]"}]}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.529619149409012*^9, 3.529619152208172*^9}, 
   3.5386855198431625`*^9, 
   3.541013438795199*^9},ExpressionUUID->"cceadca5-4e83-4394-bff9-\
fa5ec9c9a40f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Two final points about this simplified approach are useful.  Not only is \
the concavity of the utility function important, but \"how concave\" it is \
matters as we will see in the next section.  Additionally, the discount \
calculated above is a function of not only the ",
 StyleBox["shape",
  FontSlant->"Italic"],
 " of the utility function but the ",
 StyleBox["spread",
  FontSlant->"Italic"],
 " of potential returns.  Above our investor requires a relatively large \
discount of more than 13% as a percentage of the amount risked.  Below we \
lower the potential gain or loss to $10,000 and the discount drops to about \
.5%.  The conclusion one might reach is that risk aversion is relative to \
both one's initial wealth and the portion of that wealth at stake in an \
uncertain situation. This mathematically supports sage advice that one should \
not bet more than one can afford to lose."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.529619239963191*^9, 
  3.5386855198431625`*^9},ExpressionUUID->"9efad89f-bc0c-4e87-b55b-\
e8021a9aface"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"newcertequivW", "=", 
   RowBox[{
    RowBox[{".5", " ", 
     RowBox[{"u", "[", "90000", "]"}]}], "+", " ", 
    RowBox[{".5", " ", 
     RowBox[{"u", "[", "110000", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SuperscriptBox["\[ExponentialE]", "newcertequivW"], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"newdisc", "=", 
  RowBox[{"100000", "-", 
   SuperscriptBox["\[ExponentialE]", "newcertequivW"]}]}]}], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296192761092587`*^9, 3.529619282829643*^9}, 
   3.5386855198431625`*^9},ExpressionUUID->"c3ff18ed-fa13-4300-b75f-\
cda0fa55c42c"],

Cell[BoxData["501.25628933805274`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5296192838657017`*^9, 3.5296985600900426`*^9, 
  3.5297900015091925`*^9, 3.529793124144213*^9, 3.5299351223620853`*^9, 
  3.5299373238490033`*^9, 3.5300164012789736`*^9, 3.530016720840251*^9, 
  3.5300171832256985`*^9, 3.530193688115472*^9, 3.5301942246231585`*^9, 
  3.531448227255655*^9, 3.531500623826567*^9, 3.5331346950548086`*^9, 
  3.5331358794065495`*^9, 3.533682249671875*^9, 3.5337345779102244`*^9, 
  3.533754140953125*^9, 3.53375541325*^9, 3.5386852158687763`*^9, 
  3.5386855198431625`*^9, 3.539635955913046*^9, 3.540126804007886*^9, 
  3.5410126252476664`*^9, 3.5410150948859215`*^9, 3.541015561361603*^9, 
  3.541600438488598*^9, 3.5433421855158653`*^9, 3.6963384598243294`*^9, 
  3.6963423740121746`*^9, 3.696544359107197*^9, 
  3.731421192259216*^9},ExpressionUUID->"29f91ff8-b4ed-454a-9ef5-\
41287fb4ecf7"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.5. Changing utility functions", "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531447172614333*^9, 3.5314480924189425`*^9, 
  3.5386855198431625`*^9},ExpressionUUID->"f6874359-9d1d-40c2-9d1c-\
aa46e4e4a743"],

Cell[TextData[{
 "In Figure 6.5, we illustrated three curves that might be taken to represent \
utility.  We chose the first of these, ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = Log(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") and assumed it represented the way investors decide among uncertain \
alternatives.  To emphasize the importance of that assumption, let's choose \
one of the others.  The second one, ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SqrtBox["x"], TraditionalForm]],ExpressionUUID->
  "f41709bf-d038-48b2-bb5f-02741e515e3d"],
 " is as good as any.  We return to our original example but define a new \
utility function, ",
 StyleBox["u2",
  FontFamily->"Courier New",
  FontWeight->"Bold"],
 ":"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5299362587920856`*^9, 3.529936260846203*^9}, {
  3.5386855198431625`*^9, 
  3.5386855198441625`*^9}},ExpressionUUID->"5fc958b1-5df1-4f9d-b3e7-\
047fab2f17e5"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{"u2", "[", "w", "]"}], "=", 
    SqrtBox["w"]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.52970087014517*^9, 3.529700891435388*^9}, 
   3.5386855198441625`*^9},ExpressionUUID->"8332ae97-49a8-41d4-a499-\
db0466ed4eb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u2", "[", "w_", "]"}], ":=", 
   SqrtBox["w"]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198441625`*^9},ExpressionUUID->"dc0bfe0e-d095-43b0-9c5f-\
e4fdd31520b4"]
}, Closed]],

Cell["\<\
Of course if utility of wealth is the square root of wealth, the inverse \
(wealth in terms of utility) tells us that wealth is the square of utility of \
wealth. So with this utility function the certainty equivalent utility for \
our same 50/50 proposition is...\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198441625`*^9},ExpressionUUID->"1be1b8b2-efd0-43f8-b053-\
c7f28b773cb5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"certequivW2", "=", 
  RowBox[{
   RowBox[{".5", " ", 
    RowBox[{"u2", "[", "50000", "]"}]}], "+", 
   RowBox[{".5", " ", 
    RowBox[{"u2", "[", "150000", "]"}]}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198441625`*^9},ExpressionUUID->"668b4437-6684-4988-ad41-\
a21c3787735f"],

Cell[BoxData["305.4525661853603`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658643671875*^9, 3.4026995880635*^9, 
  3.529619345320217*^9, 3.5296985608890886`*^9, 3.5297900015961976`*^9, 
  3.5297931252152743`*^9, 3.529935123164131*^9, 3.5299373239230075`*^9, 
  3.530016401417981*^9, 3.530016720964258*^9, 3.5300171833557053`*^9, 
  3.530193688344485*^9, 3.530194224709163*^9, 3.5314482274526663`*^9, 
  3.531500623887571*^9, 3.533134695852854*^9, 3.533135879464553*^9, 
  3.533682249875*^9, 3.53373457853726*^9, 3.533754141078125*^9, 
  3.533755413375*^9, 3.5386852168238306`*^9, 3.5386855198451624`*^9, 
  3.5396359559940505`*^9, 3.5401268051079483`*^9, 3.5410126261767197`*^9, 
  3.541015095853977*^9, 3.5410155623276577`*^9, 3.54160043957266*^9, 
  3.543342186799939*^9, 3.696338459865433*^9, 3.696342374084365*^9, 
  3.6965443591463003`*^9, 
  3.7314211922913003`*^9},ExpressionUUID->"b257e040-fc7a-47cb-8013-\
af20395d5bef"]
}, Open  ]],

Cell["\<\
...which means that the wealth needed to produce that certainty equivalent \
utility is...\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198451624`*^9},ExpressionUUID->"2a5a2440-e9b2-48a3-b4c6-\
e8365ffd360b"],

Cell[CellGroupData[{

Cell[BoxData[
 SuperscriptBox["certequivW2", "2"]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198451624`*^9},ExpressionUUID->"7d3d21d9-28b2-45ed-b595-\
0b6ce300e1b1"],

Cell[BoxData["93301.27018922192`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.4026586436875*^9, 3.40269958809475*^9, 
  3.5296985613951173`*^9, 3.529790001655201*^9, 3.529793125858311*^9, 
  3.529935123463148*^9, 3.52993732397801*^9, 3.530016401516987*^9, 
  3.530016721047263*^9, 3.530017183448711*^9, 3.5301936884074883`*^9, 
  3.530194224767166*^9, 3.5314482274936686`*^9, 3.5315006239275727`*^9, 
  3.533134696199874*^9, 3.5331358795045547`*^9, 3.533682249953125*^9, 
  3.533734578922282*^9, 3.533754141140625*^9, 3.533755413453125*^9, 
  3.5386852171358485`*^9, 3.5386855198451624`*^9, 3.539635956057054*^9, 
  3.540126805801988*^9, 3.541012626623745*^9, 3.5410150963200035`*^9, 
  3.5410155634167204`*^9, 3.5416004400316863`*^9, 3.543342187363971*^9, 
  3.696338459887492*^9, 3.6963423740973997`*^9, 3.6965443591673803`*^9, 
  3.731421192312356*^9},ExpressionUUID->"0620e496-dfd6-4500-8676-\
b7ae8b3cfc0e"]
}, Open  ]],

Cell["\<\
...and the discount required to induce the investor to purchase the \
opportunity is...\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198451624`*^9},ExpressionUUID->"8f19d27c-225a-4198-bd22-\
4253aacb1e66"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"disc2", "=", 
  RowBox[{"100000", "-", 
   SuperscriptBox["certequivW2", "2"]}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198451624`*^9},ExpressionUUID->"7c7da99c-dc1e-4680-a6c2-\
199ef00f345b"],

Cell[BoxData["6698.729810778081`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658643703125*^9, 3.402699588891625*^9, 
  3.5296985616891336`*^9, 3.5297900017152042`*^9, 3.529793126347339*^9, 
  3.529935123753165*^9, 3.5299373240340137`*^9, 3.5300164016149926`*^9, 
  3.530016721130268*^9, 3.5300171835427165`*^9, 3.5301936884664917`*^9, 
  3.53019422482717*^9, 3.531448227534671*^9, 3.5315006239685755`*^9, 
  3.533134696588896*^9, 3.533135879543557*^9, 3.533682250046875*^9, 
  3.533734579342306*^9, 3.53375414121875*^9, 3.53375541353125*^9, 
  3.5386852175038695`*^9, 3.5386855198451624`*^9, 3.5396359561160574`*^9, 
  3.540126806309017*^9, 3.5410126271737766`*^9, 3.541015096884036*^9, 
  3.541015564603788*^9, 3.541600440512714*^9, 3.543342187880001*^9, 
  3.696338459937625*^9, 3.6963423741204615`*^9, 3.6965443592174964`*^9, 
  3.7314211923304043`*^9},ExpressionUUID->"26ebe24a-c931-4f60-abf7-\
b4412726302f"]
}, Open  ]],

Cell["\<\
...about half of the earlier discount. Therefore, we see that one who employs \
our second utility function will pay somewhat more (or requires less \
discount) for the opportunity than our first investor.  All of which serves \
as a warning to choose your utility function carefully. \
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.52961938821067*^9, {3.5297007625190144`*^9, 3.5297007640621023`*^9}, 
   3.5386855198451624`*^9},ExpressionUUID->"62a57653-29b2-461c-be86-\
1f2f9b7c0c79"],

Cell["\<\
In practice this becomes an admonition to choose your clients carefully. More \
specifically, one needs to carefully match the risk of investments offered to \
clients having the appropriate risk tolerance. Various consumer protection \
laws governing the standard of care required of investment advisors are based \
on whether investments are \"suitable\" for the client. Suitability may be a \
term of art but it starts with the client's ability to tolerate risk as \
reflected in his utility function.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.52961938821067*^9, 3.5296193892797313`*^9}, {
   3.5299363016295357`*^9, 3.529936311448097*^9}, 
   3.5386855198451624`*^9},ExpressionUUID->"d0c18094-f02c-4fe7-b11e-\
41ed185ef3ab"],

Cell[TextData[{
 "Note in Figure 6.10 that when we place a straight line on the plot of our \
second utility function we notice that the degree of curvature of the new \
utility function is less than that for our original utility function.  This \
result indicates that our investor with the second utility function is ",
 StyleBox["more risk tolerant ",
  FontSlant->"Italic"],
 "in that he will demand a smaller discount to enter this particular game. \
The fact that the scale of the ",
 StyleBox["y",
  FontSlant->"Italic"],
 "-axis is completely different from the prior example serves to reinforce \
what we have said about numerical utility. We care not about the actual value \
of utility, only how it is ranked relative to some other choice."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529619434554321*^9, 3.5296194352403603`*^9}, {
   3.529936287387721*^9, 3.529936291988984*^9}, 
   3.5386855198451624`*^9},ExpressionUUID->"775001ba-cd70-4271-8555-\
7f7ad2fb84a2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"u2", "[", "w", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"w", ",", "30000", ",", "180000"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"100", ",", "400"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"25000", ",", "100"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"50000", ",", "100000", ",", 
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{".5", " ", 
                RowBox[{"u2", "[", "50000", "]"}]}], "+", 
               RowBox[{".5", " ", 
                RowBox[{"u2", "[", "150000", "]"}]}]}], ")"}], "2"], ",", 
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"StringJoin", "[", 
               RowBox[{"\"\<\\n\>\"", ",", 
                RowBox[{"ToString", "[", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{".5", " ", 
                    RowBox[{"u2", "[", "50000", "]"}]}], "+", 
                    RowBox[{".5", " ", 
                    RowBox[{"u2", "[", "150000", "]"}]}]}], ")"}], "2"], 
                 "]"}]}], "]"}], ",", "Red"}], "]"}]}], "}"}], ",", 
          "150000"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"u2", "[", "50000", "]"}], "]"}], ",", 
          RowBox[{"N", "[", 
           RowBox[{"u2", "[", "100000", "]"}], "]"}], ",", 
          RowBox[{"N", "[", 
           RowBox[{"u2", "[", "150000", "]"}], "]"}], ",", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{".5", " ", 
             RowBox[{"u2", "[", "50000", "]"}]}], "+", " ", 
            RowBox[{".5", " ", 
             RowBox[{"u2", "[", "150000", "]"}]}]}], ")"}]}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"50000", ",", "100000", ",", "150000", ",", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{".5", " ", 
              RowBox[{"u2", "[", "50000", "]"}]}], "+", " ", 
             RowBox[{".5", " ", 
              RowBox[{"u2", "[", "150000", "]"}]}]}], ")"}], "2"]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u2", "[", "50000", "]"}], ",", 
          RowBox[{"u2", "[", "100000", "]"}], ",", 
          RowBox[{"u2", "[", "150000", "]"}], ",", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{".5", " ", 
             RowBox[{"u2", "[", "50000", "]"}]}], "+", 
            RowBox[{".5", " ", 
             RowBox[{"u2", "[", "150000", "]"}]}]}], ")"}]}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p4", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"u2", "[", "150000", "]"}], "]"}], "-", 
         RowBox[{"N", "[", 
          RowBox[{"u2", "[", "50000", "]"}], "]"}]}], "100000"], " ", "x"}], 
      "+", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{"u2", "[", "50000", "]"}], "]"}], "\[Equal]", 
              RowBox[{
               RowBox[{"50000", " ", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"N", "[", 
                    RowBox[{"u2", "[", "150000", "]"}], "]"}], "-", 
                   RowBox[{"N", "[", 
                    RowBox[{"u2", "[", "50000", "]"}], "]"}]}], ")"}], "/", 
                 "100000"}]}], "+", "b"}]}], ",", 
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{"u2", "[", "150000", "]"}], "]"}], "\[Equal]", 
              RowBox[{
               RowBox[{"150000", " ", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"N", "[", 
                    RowBox[{"u2", "[", "150000", "]"}], "]"}], "-", 
                   RowBox[{"N", "[", 
                    RowBox[{"u2", "[", "50000", "]"}], "]"}]}], ")"}], "/", 
                 "100000"}]}], "+", "b"}]}]}], "}"}], ",", "b"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "30000", ",", "180000"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"100", ",", "400"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"25000", ",", "100"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"p3", ",", "p4", ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"FontSize", "\[Rule]", "8"}]}]}], "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5296194783088236`*^9, 3.529619483084097*^9}, {
   3.529789467039623*^9, 3.529789625171667*^9}, {3.5297898225609574`*^9, 
   3.5297898322505116`*^9}, {3.5297898657614284`*^9, 3.529789948340152*^9}, {
   3.529790048737894*^9, 3.5297901007858706`*^9}, {3.5297901313956213`*^9, 
   3.5297902537236185`*^9}, {3.5297905115123634`*^9, 3.529790545438304*^9}, 
   3.5297905976332893`*^9, 
   3.5386855198451624`*^9},ExpressionUUID->"387901bd-4a27-4827-a4d2-\
cbee8f1f5a2d"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAAxLQnMgBM3UAPTw0YkKZlQEYp9n2A
V91AT5hZm8+qZUDJncTJAGPdQBChl0kOr2VAzoZhYQF63UAnlNwoibdlQNhY
m5ACqN1A+uQYAHXIZUDs/A7vBATeQHaISnwl6mVAFEX2qwm83kCfnVjr7Cxm
QLJq4pIJFuBA5A+APi6wZkDHxS8dCKXhQCcLuFoNw2dAm7xU15UZ40BFEw2r
8LhoQNte3rbUhuRADd50qBChaUDgy+amCBPmQBwBXWvqk2pApNTGxsuE50Bk
7G3v/G5rQC2oJfeDFelATyZ3Ke9UbEAiJ+lM7Z7qQBXjmEfOL21A1kGE0uUN
7EDbFRTiVvZtQE8nnmjTm+1AQyZbavjHbkCHqI8uUA/vQHcPLmrChm9Alury
DL898EBAKjT2wR5wQEtm3YpQA/FAimsj7ap/cEDfr7OgqbvxQBOkxxEh2HBA
1l7JPn2D8kAsu2RAAzZxQINjkW+pR/NA4NLt40WQcUAPNkU4nf7zQCjrPO/Y
4nFA/m04iQvF9EDP0WmswTpyQMxzF3JBfvVAR99sGFeLckD93jXj8Ub2QD3K
PF4k4XJA5J8G5/oL90A3q7DL7DNzQKsuw4LLw/dA0J49d+p/c0DUIr+mFov4
QAwNChUF0XNA3eSmYilF+UANH50flxt0QJz8QLGU+/lAnM71j6ljdEC9eRqI
esH6QJBLwa29sHRAvsTf9id6+0AhEqYMrPd0QCF15O1PQvxAMFq0MIFDdUA6
e5t30Ab9QFYcm1/wjHVAM08+mRi+/UAjZ6r7j9B1QI6IIEPbhP5AHI9auvsY
dkDJj+6EZT7/QC5T8qTCW3ZAuuxuWUj0/0D9kfV7eZx2QIdXF9vSXABBkvLJ
JOPhdkCgH21V5bgAQYQt6rPqIXdAa5riE7UcAUGQKVkxjmZ3QCb8TZ7oeQFB
7ZIoIPKld0C7iBJySNUBQbtj5qd043dAAsj2iWU4AkGdJ0bBeyV4QDnu0G3m
lAJB8WN7P3pieEAhx8qVJPkCQafs163oo3hA5ModB49bA0F1q218fuN4QD7d
ivAaiANBAAAAAAAAeUDAUIQ6
        "]]},
      Annotation[#, "Charting`Private`Tag$4796#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBIQPe/CFib1JlAgAAADEAAAACAAAAxLQnMgBM3UDuX9a2yttnQEYp9n2A
V91AC99LnjPeZ0DJncTJAGPdQChewYWc4GdAzoZhYQF63UBiXKxUbuVnQNhY
m5ACqN1A1liC8hHvZ0Ds/A7vBATeQL9RLi5ZAmhAFEX2qwm83kCQQ4al5yho
QLJq4pIJFuBAMyc2lAR2aEDHxS8dCKXhQK4B0XE3HWlAm7xU15UZ40A4ITvW
VblpQNte3rbUhuRA3x9DP2RSakDgy+amCBPmQLwxhqhr+GpApNTGxsuE50Co
iJiYXpNrQC2oJfeDFelAy/LliEo7bEAiJ+lM7Z7qQAo80X0m4GxA1kGE0uUN
7EBYyov57XltQE8nnmjTm+1A3GuBda4gbkCHqI8uUA/vQG9SRnhavG5Alury
DL898EAeGKl/9lRvQEtm3YpQA/FABfFGh4v6b0Dfr7OgqbvxQH0H2gqGSnBA
1l7JPn2D8kATIC7SQp5wQINjkW+pR/NANyjRm3fwcEAPNkU4nf7zQOLS2ygi
PXFA/m04iQvF9EApBwQ2SZBxQMxzF3JBfvVA992TBubdcUD93jXj8Ub2QGA+
QVf/MXJA5J8G5/oL90BYjj2qkIRyQKsuw4LLw/dA2IChwJfRckDUIr+mFov4
QPL8IlcbJXNA3eSmYilF+UCUGwyxFHNzQJz8QLGU+/lAxClEDYa/c0C9eRqI
esH6QI7BmelzEnRAvsTf9id6+0Di+1aJ1190QCF15O1PQvxA0L8xqbezdEA6
e5t30Ab9QExzW8sPBnVAM08+mRi+/UBPyeyw3VJ1QI6IIEPbhP5A7qibFiim
dUDJj+6EZT7/QBQrsj/o83VAuuxuWUj0/0DInBdrIEB2QIdXF9vSXABBGJia
FtWSdkCgH21V5bgAQe81hYX/33ZAa5riE7UcAUFiXY10pjN3QCb8TZ7oeQFB
XCf9JsOBd0C7iBJySNUBQeTgu9tXzndAAsj2iWU4AkEHJJgQaSF4QDnu0G3m
lAJBsgncCPBueEAhx8qVJPkCQfh4PYHzwnhA9je+GfxBA0EAAAAAAAB5QFov
fII=
        "]]},
      Annotation[#, "Charting`Private`Tag$4840#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{25000., 100.},
  BaseStyle->(FontSize -> 8),
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->
   NCache[{{50000, 100000, 150000, 93301.27018922192}, {
     100 5^Rational[1, 2], 100 10^Rational[1, 2], 100 15^Rational[1, 2], 
      305.4525661853603}}, {{50000, 100000, 150000, 93301.27018922192}, {
     223.60679774997897`, 316.22776601683796`, 387.2983346207417, 
     305.4525661853603}}],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{25000., 179999.9969387755}, {100, 400}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{{{50000, 
      FormBox["50000", TraditionalForm]}, {100000, 
      FormBox["100000", TraditionalForm]}, {93301.27018922192, 
      FormBox[
       StyleBox["\"\\n93301.3\"", 
        RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm]}, {150000, 
      FormBox["150000", TraditionalForm]}}, {{223.60679774997897`, 
      FormBox["223.60679774997897`", TraditionalForm]}, {316.22776601683796`, 
      FormBox["316.22776601683796`", TraditionalForm]}, {387.2983346207417, 
      FormBox["387.2983346207417`", TraditionalForm]}, {305.4525661853603, 
      FormBox["305.4525661853603`", TraditionalForm]}}}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297900767274947`*^9, 3.5297901015389137`*^9}, {
   3.529790177190241*^9, 3.5297902035667496`*^9}, {3.5297902400648375`*^9, 
   3.5297902546326704`*^9}, {3.529790520530879*^9, 3.5297905468023815`*^9}, 
   3.5297905994003897`*^9, 3.529793127005377*^9, 3.5299351241781893`*^9, 
   3.5299373240950174`*^9, 3.5300164017089977`*^9, 3.5300167212142725`*^9, 
   3.5300171836367216`*^9, 3.5301936885254955`*^9, 3.530194224887173*^9, 
   3.5314482276336765`*^9, 3.53150062405258*^9, 3.5331346970519223`*^9, 
   3.5331358795875597`*^9, 3.53368225015625*^9, 3.5337345799603415`*^9, 
   3.533754141328125*^9, 3.533755413640625*^9, 3.5386852179658957`*^9, 
   3.5386855198471627`*^9, 3.5396359561880617`*^9, 3.5401268071320643`*^9, 
   3.541012628014825*^9, 3.541015097737085*^9, 3.5410155653068285`*^9, 
   3.541600441180752*^9, 3.543342188502036*^9, 3.6963384600309005`*^9, 
   3.696342374238776*^9, 3.696544359331794*^9, 3.731421192449722*^9},
 TextAlignment->Center,ExpressionUUID->"ed492c49-5fbc-4d26-80a2-a1df630f6ddb"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.10.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "A different utility function."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500350724947*^9}, 
   3.5386855198471627`*^9},
 TextAlignment->Center,ExpressionUUID->"4da9a84b-5e20-412a-9e63-7625403164b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.6. A measure of risk aversion", "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531447172614333*^9, 3.531448110503977*^9, 
  3.5386855198471627`*^9},ExpressionUUID->"ae679044-68ed-484a-9b79-\
bfe13d68b387"],

Cell[TextData[{
 "Pratt (1964) observed that the degree of curvature in a utility function is \
a way to measure one's risk aversion ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     StyleBox["ra",
      FontSlant->"Italic"], ")"}], 
    SuperscriptBox[".", 
     ButtonBox["7",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote7"]]}], TraditionalForm]],ExpressionUUID->
  "c39f43f7-6141-4b16-981d-bceb4a34c975"],
 "  How curved a function is can be represented by the negative of the ratio \
of its second derivative to its first derivative."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529938690510172*^9, 3.529938706670096*^9}, {
  3.5386855198481627`*^9, 3.5386855198481627`*^9}, {3.5410135083411765`*^9, 
  3.5410135087422*^9}},ExpressionUUID->"311136bf-2836-405b-8c83-206d97fbc2ba"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    StyleBox["ra",
     FontSize->18], 
    StyleBox[" ",
     FontSize->18], 
    StyleBox["=",
     FontSize->18], 
    StyleBox[" ",
     FontSize->18], 
    RowBox[{
     StyleBox["-",
      FontSize->18], 
     FormBox[
      FractionBox[
       RowBox[{
        RowBox[{"u", "''"}], " ", "[", "w", "]"}], 
       RowBox[{
        RowBox[{"u", "'"}], "[", "w", "]"}]],
      TraditionalForm]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.529700816445099*^9, 
  3.5386855198481627`*^9},ExpressionUUID->"a546edca-deab-417d-8270-\
709cfe722058"],

Cell[TextData[{
 "For illustration purposes, it is convenient to have a function that \
contains a constant we can manipulate to demonstrate this effect, thus for \
this discussion we employ our third utility function of the three candidates \
described in Figure 6.5, which we name ",
 StyleBox["u3",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529936335638481*^9, 3.5299363398457212`*^9}, 
   3.538685519849163*^9, {3.541013524742115*^9, 
   3.5410135364667854`*^9}},ExpressionUUID->"5f66c0da-1d62-4f6c-8d5b-\
03cffd853310"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{"u3", "[", "w", "]"}], "=", 
    RowBox[{"-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "aw"}]]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297008539892464`*^9, 3.529700854387269*^9}, {
   3.529700920201033*^9, 3.529700936614972*^9}, 
   3.538685519849163*^9},ExpressionUUID->"0636856c-2810-4f89-9353-\
18f23f791ba6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u3", "[", "w_", "]"}], ":=", 
   RowBox[{"-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "a"}], " ", "w"}]]}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519849163*^9},ExpressionUUID->"dd16d628-74cc-4092-a8c8-\
1acb1831272c"]
}, Closed]],

Cell[TextData[{
 "Dividing the second derivative of this function by its first derivative \
shows that the \"coefficient of risk aversion\" for this utility function is \
a constant, ",
 StyleBox["a",
  FontSlant->"Italic"],
 ". [It should be noted that in general the curvature can change from point \
to point. The exponential is special in that the curvature is constant. This \
is another case of choosing a \"convenient\" mathematical form to model an \
economic ",
 StyleBox["behavioral ",
  CharacterEncoding -> "WindowsANSI"],
 "abstraction.]"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519849163*^9},ExpressionUUID->"7add042c-5a33-46a7-9cc3-\
8aae1d8e14a5"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{"ra", "[", "w", "]"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"w", ",", "w"}]], 
       RowBox[{"u3", "[", "w", "]"}]}], 
      RowBox[{
       SubscriptBox["\[PartialD]", "w"], 
       RowBox[{"u3", "[", "w", "]"}]}]], "=", "a"}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297009986155186`*^9, 3.5297010532046404`*^9}, {
   3.529936470264181*^9, 3.5299364721992917`*^9}, 
   3.538685519849163*^9},ExpressionUUID->"450dd822-e7c2-4182-971f-\
7579871c8d45"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ra", "[", "w_", "]"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"w", " ", ",", "w"}]], 
      RowBox[{"u3", "[", "w", "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "w"], " ", 
      RowBox[{"u3", "[", "w", "]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ra", "[", "w", "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519849163*^9},ExpressionUUID->"db27ea29-c51c-4ecf-9eee-\
3dfa0c40b327"],

Cell[BoxData["a"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.4026586438125*^9, 3.402699594751*^9, 
  3.402786130297875*^9, 3.5296195707661114`*^9, 3.529698562755195*^9, 
  3.529700971428963*^9, 3.5297900018772135`*^9, 3.5297931277844214`*^9, 
  3.529935124785224*^9, 3.529937324158021*^9, 3.5300164019910145`*^9, 
  3.53001672133928*^9, 3.5300171837757297`*^9, 3.5301936890395246`*^9, 
  3.5301942249741783`*^9, 3.5314482280547004`*^9, 3.5315006241115837`*^9, 
  3.533134698001977*^9, 3.5331358796465635`*^9, 3.533682250390625*^9, 
  3.5337345809173965`*^9, 3.533754141515625*^9, 3.533755413859375*^9, 
  3.5386852189159503`*^9, 3.538685519849163*^9, 3.5396359562780666`*^9, 
  3.5401268084671407`*^9, 3.5410126291578903`*^9, 3.541015098890151*^9, 
  3.541015566829915*^9, 3.5416004424618254`*^9, 3.5433421895560966`*^9, 
  3.696338460091034*^9, 3.6963423742949247`*^9, 3.69654435935686*^9, 
  3.7314211924808064`*^9},ExpressionUUID->"04b9173b-8de0-4a16-8be0-\
77f295a97e6c"]
}, Open  ]]
}, Closed]],

Cell[TextData[{
 "It is this number that determines how risk averse an investor is and what \
sort of discount he will require to take a particular risk.  In Figure 6.11 \
we take \"",
 StyleBox["a",
  FontSlant->"Italic"],
 "\" to equal 1."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5299364943115563`*^9, 3.529936500061885*^9}, 
   3.5331363065469804`*^9, 
   3.538685519849163*^9},ExpressionUUID->"3c27a47f-2436-4901-9e70-\
27d057a2070f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"u3", "[", "w", "]"}], "/.", "\[InvisibleSpace]", 
    RowBox[{"a", "\[Rule]", "1"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"w", ",", "1", ",", "1.8"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Wealth\>\"", ",", "\"\<Utility\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{3.529761932829756*^9, 
  3.538685519849163*^9},ExpressionUUID->"c274f7bf-d66f-467d-90af-\
fa0dbcf8bc16"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVxX1YywkcAPC1S3pKXlPuSc04p+sFvdAL+opudgqNU+OKysM93MbyUpcs
kvXCxh2LCNcjXF6usyS9+hb91tu2WmtNUfJ6UWlttbd+17388Xk+9IQDm3dT
KRTKhv/8f6w+3ppC0YLKULEk6owGI628wq2stDArcPutFzkaXDPN8CuVqoUr
F2p947M16O55mjbJWgs3CrrEHIEGRxNKgu1steC0flbSqeMaFLZTEx2na+HB
u6h75Yc0WC0p7HGfp4Wug6WdvjEadOG9L2Ot1kLJnLoerrcGbQ8075uSqYXk
GRt/YDR14oWuuUvcG7RgcLKXMbmdGPr4+QRpMwJJPvAk3bETac6G1uCIEdDU
LL1c90iNV96ckHQJR2Ax247+bIcaw5Zyxa/bR2BaJUc4iarGmSNPT95w1kEv
X5lxoqgD+a6Z6fXROiir9SmNjurAObK76Zuu6UD6MPaBZEKFkR9Wnl/Rq4MY
N/5Nv2IV3j8UWNznqofwqcxsQZwKAzJyWz4n6MHocev2JQcVxk3sNMcW6iFe
ViNOqmvH8vEz7ss/6iEgbvA0k9eOfhz6rgbvUSihWW0bpLdjBPOr4gruKHi9
Tgi17lai+Ha2xfHhKDz2qjYxRUo8ytserdSPQnn/cZcOhhLPVYseGYLGIH0p
aaocb8PGVA+aOm0MXjn1p6562IbXb/tfdsQxmJEn9S/ltWHhlgLHGmsD0Jhc
S9U3bcjgpBRIvzXAnRAi2EXZilNMVQE5AgOkn4gPidjSilSbuLbSZgO4AbeO
Kldg7vHElFB7I3jTfdZVsBTITn23IIBlBKF1Yfo6hRxDPtV2vc81gn7t0cQ9
m+T4tN6uYExthIxFwqKxbhkeoZf9uN/FBJK9KfaVO2RIfFQAM8YEYrG2+OZg
CwYtZC14kW+C9wPL1GfSWvDlG39bTZ8Jhhr5jH9sW9B1SubffnQzWD7aKJ2v
NaPoceCoeY8Z/PtCJdYezZivYI/PKzJD9zIPHau2CWXsNw5W/WYYWbnLN3J7
E3rtltPXe1uAs8gQfmioET16FjJGuRZIbE8eTstpxGjNq58ml1og7vfISTq3
RiwK++KaymSBPSlr984pb8CLruJeStA4VJlta0u2NWDpz5n0S2njsKrQYQVl
TIoH4MPhszgO5rM78gV5UtyY8qcq5J9xkA9kTWeAFGOWdfuxw0iok08OpPQR
ODn24M32UyTsdbqVkZNNoCmEKtIJSGC/nO9sk0Xgp3nnj8zMIuGT0wvipIBA
xTsJY3MOCb+s0R8+dpJAMWekXykiQfSX8MvEYwTOP8bzVl4kwS2p4uhOHoEr
8/eXtRaREEr77Vwkm8DF/Inrw3dISBooz2yLIpC282zWtHskHPZty4vcSiB1
QTF70x8k8K8MO7A2E9h0d8iikJAQ+6R6xZYIAqMqOaCoJCGX3l8Ys5pA5lVy
0ecqEgrDDN/1hhAYlCacPrWGhI68t3Zxqwicu+b+6w1Igprxfc+uYALfNg1k
yJ+RkNzHruf4E9hxL5UzVE8ClniGDvsSKBXZb3WQkjD7uuJ5og+Bd1meX29o
JGHfcj47eTGBV/2qpnKbSCDdBKstXgSKZocbhc0kPLu0dS3fk8A0Y/er+y0k
9DwZjKN4EMjr2tcok5GQU8K8nOFO4L+4l54j
       "]]},
     Annotation[#, "Charting`Private`Tag$4900#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Wealth\"", TraditionalForm], 
    FormBox["\"Utility\"", TraditionalForm]},
  AxesOrigin->{1.0000000163265306`, -0.3678794351652474},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658643828125*^9, 3.402699595016625*^9, 
  3.402786146735375*^9, 3.5296195817927427`*^9, 3.5296197010515633`*^9, 
  3.5296985630712132`*^9, 3.5297900019362173`*^9, 3.529793128140442*^9, 
  3.529935125151245*^9, 3.529937324196023*^9, 3.530016402077019*^9, 
  3.530016721425285*^9, 3.530017183853734*^9, 3.530193689097528*^9, 
  3.5301942250331817`*^9, 3.5314482281327047`*^9, 3.5315006241515856`*^9, 
  3.5331346985170064`*^9, 3.533135879685565*^9, 3.53368225046875*^9, 
  3.5337345812474155`*^9, 3.53375414159375*^9, 3.533755413953125*^9, 
  3.5386852193669763`*^9, 3.538685519851163*^9, 3.5396359563200693`*^9, 
  3.540126808946168*^9, 3.5410126296329174`*^9, 3.5410150993921795`*^9, 
  3.541015567553957*^9, 3.5416004430228577`*^9, 3.5433421902501364`*^9, 
  3.696338460150192*^9, 3.696342374347065*^9, 3.6965443594330645`*^9, 
  3.7314211925560055`*^9},
 TextAlignment->Center,ExpressionUUID->"6a9b192d-2f80-43ef-b252-499fb5b01ee8"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.11.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Utility[Wealth] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      StyleBox["aw",
       FontSlant->"Italic"]}]]}], TraditionalForm]],ExpressionUUID->
  "d875498d-a0f4-4f92-964d-e03bcdfb08a9"],
 " where ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = 1."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315003687059755`*^9}, {
  3.538685519851163*^9, 3.538685519852163*^9}, {3.5396074289023943`*^9, 
  3.539607429426424*^9}, {3.5410136204505887`*^9, 3.5410136303461547`*^9}},
 TextAlignment->Center,ExpressionUUID->"7ff9a4a6-c8fd-4216-8c63-024965f19ed8"],

Cell[TextData[{
 "Plotting the function with different values for \"",
 StyleBox["a",
  FontSlant->"Italic"],
 "\" we see that the higher the value for \"",
 StyleBox["a",
  FontSlant->"Italic"],
 "\" the more the function curves."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519852163*^9},ExpressionUUID->"cc91dbf6-46fd-4237-bf40-\
510e15622b07"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p4a", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"u3", "[", "w", "]"}], "/.", "\[InvisibleSpace]", 
         RowBox[{"a", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         RowBox[{"u3", "[", "w", "]"}], "/.", "\[InvisibleSpace]", 
         RowBox[{"a", "\[Rule]", "1.2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "2", ",", "4.5"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14"}], ",", "0"}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"-", "0.14"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{"Green", ",", 
           RowBox[{"Dashing", "[", 
            RowBox[{"{", 
             RowBox[{"0.02", ",", "0.04"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", "Red", "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Wealth\>\"", ",", "\"\<Utility\>\""}], "}"}]}]}], "]"}], 
    ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{"Green", ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{"0.02", ",", "0.02"}], "}"}], "]"}]}], "]"}], ",", 
        "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*StyleBox[\"\[Alpha]\",FontSlant->\"Italic\"]\) = 1\>\"", 
        ",", "\"\<\!\(\*StyleBox[\"\[Alpha]\",FontSlant->\"Italic\"]\) = \
1.2\>\""}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{66., 0.6666666666667425}, {5., 10.}},
 CellOpen->False,
 CellChangeTimes->{{3.529761946779554*^9, 3.5297619647185802`*^9}, {
   3.529762003848818*^9, 3.5297620158445044`*^9}, 3.538685519852163*^9, {
   3.6963425554629183`*^9, 3.696342605046835*^9}, {3.696342655313568*^9, 
   3.6963427561368265`*^9}, {3.6963427874992447`*^9, 3.696342799205388*^9}, {
   3.6963428526676226`*^9, 
   3.6963428685779552`*^9}},ExpressionUUID->"9c1b2b4b-1890-4563-9e1e-\
5bafa495d8d3"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{0.02, 0.04}]], 
         LineBox[CompressedData["
1:eJwVjHdQkwcYxj9WMKzkYwmOIiquFhSFqpTxgizZ6lUglFaWKdiG5cBFhNp8
VAUBGZEhSglRNLIcwIFvAogQwMq0IEfUIFCGgtUTMWjpH8/97rnfPY9paPTe
CGWCILwX8z+dtAZoi4C5s5NZZXslqNN4WC1TiYDOnqB4Z18JDhxjqq5VIUAo
4ymGPSUYI3dTcqcR8M6a0jF0kWBR3b1PF7UIkCSlmF/YLkHFz1kzJsYE6Nge
sOGvkOC9h76DDlsJOCr2FVqMifFrbouIG05A8bP6Yu9EMSZ6Dx2M7yLg9rPR
BmM3xA96hW0W25XgwmEzpl5TA/pf2eozmacEn6aXJk0G1KPp2ZmR5erKkMqP
XpYsr0MyNNBM/xdlcJn+7e6P/Fo8lD9x7MyAMjRrBzol7KpBEd9vatpZBeo5
rs2atPtokBaiseaGCsRjfSR/6i6ODefZdBiogse8aWuG9A7K1nP17U6qwj29
N45BbdX4wGoHs3xYFaIGN/e6DFSheqHxV9keapBQqMcpflGJRxcEfU7lamDL
1uvQoFWiXy2rKHwFDda7ObWMrKlAcufIOYqiwYnx8ODLxbdxrsJoVdwkDUzy
LGUbzUW4++yRR0/81cGrL9bT+tZNFPueNvpQrw4wVZfVvb8Mrx0VnczYtASC
2z82xH+4jlEhVYR5zhKYFXaCV4UQA51DN6fPL4HLj2pardNKsSrZJobNpoPd
uv0MVpgALWsbWLROOlxnD9p6sUowt9qAXbpFAwLbpGfGQ/9ENj3n97oCDXA1
c5uWhhVjsL/EO0dJE9ZKT+inJ13DBsJgwyhHE1bdCM69xr+Kahy7tdsHNeHg
FHv3MW4Rxvcwpb72WtC6mivu/1yInllayUNlWrBKfepVdFwB7vaulm9hasPy
4ohuuW4+Wkgt2Lx4bWAI60IfSC/j6eJuha9MG9TTuj13JvDxbZyp7YtdOtAy
6B6p5ZWLXVf4qaMVOqDprzAbNszB/sa6lGpDBszEcq+WqmZjU1mlIOkEAyyW
hr2vUc3CZa+f9DaNMiAqMqNkSJGJ7Vmd/aNmTIgZY4mGdTPR/rlrh+AHJhS4
BqwkVmegILVsb0QmE4rC2h1rHdPR5L5clNLMhE1PJKq179PQR8dSd3SeCc/z
18RMBKVi+ot9nkJzEkI49A0JM+exxTDEIPInEobmg3q+KzyHlceTx8OzSRBG
02+yHP7A8oDj6c2PSDjy+mmuET0FrSQbEwWtJFjeLszrUknBmo2Dh3hti3+9
Ki3nP1PYOG/j5t5OgpnsVrbKOwr7ChQL7Y9JEAx9TyrJKPz0nHuop4+EmBt7
HLfdpdAtkuf6Uk6C/jcekrhQCju6vrVqGlncnyeC/IIp9LMZMy15RUJVuY/B
5gAKWZruCxFji/7lnYk33hT+KqLf+WeCBN11D0juTgovzV4wnZ0l4WVsvnEP
k0Ijlh2j+y0J+x7vKGrUpLCgcVpR9S8J0fmJjtU0Cksv+fx9+D0J2tn0Z7kK
HtZaMy/OzZHADvcI4ozz0P6K+NTARxJMnAPwoJyHjbTYqLp5Ekr0VtgfGOZh
x9Mul1MKEqxcOs/t7+XhHkjeFrxAwkyZfcC+v3jYf32rqf1nEprVOQ57pDxk
kXIdky8kXOSuBL+HPJQdv6T4stirdjFYfmIe/gebbE+0
          "]]}, Annotation[#, "Charting`Private`Tag$4951#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwVjWs0lAkYgD+3EQbzlWt1MFt0cSjJFkVvaiPOYNWuNVvrsJiQ5PuKFVGT
jOQ+SOUShZqSu4myb7k2bidaQoUiRdpFKvdd++M5z3l+PWyPAGcvaYIgOMv8
b2tmL2NZcOvt/Wt25mJUqT0llyxFwJj5TwOdpmLsDWbJrpchwOSkwP+IsRhP
DtlI2TIIkDd19aLXiTG7unI+gUkAk21RXawsxoVjKRO62gQMtPpXHHtbiZUN
jn17thGQUmna2xJbiYYRjYURngS48/I5Du8qMJzzypvuIKDh9ZQoP6Ycv63K
lBjvkILImz8LXbll6JK1zeHjNSn4Sjz10NlbiuzIieE18tIgYX9IXfldCZIe
rvpqx6WB19HgutagGP2ujwWf65WGPck+UTV297Ew3Wn8034ZWH14B9wOvIfq
8e6K6+7IwPqDQYzjnSJ833/NolVdFuIPNxYMbL6DAxsi1CxDZcHy4vBDNXEB
/rl9J6uoXxaS4hpuBrjlo3ymtk6qnRzYbBBXXCbyMGgxr8u6SA7UHJLqY1tv
olMVN9tzLQOklGKfpCXnImk+HCMQMGCuMtTEPjAHZ4q19KiPDNiXLjFwp2/g
wcjTTc9c5MHMcKk7fjALHzue1fr2SB7KE0MMirUzMSeoMDRp8wo4J+fyiGN3
HX3dSwmjtBUwrBnvfyz7Krru99iSOLcCckZHR8s3pmMp3+Ikj6cA3pqNn9NF
aWhSVcNltCmAjt20ptGvqXilTJ2Xv1URdobXFRnqpyBPIe1idYYiXLr6Rbbi
QzIedXnCSZNSgrGoxtnxziSsIdQ3jpxQAo7mlHOXOBHlTliu39GnBKL5VQmE
dwLSz1nNjlZMaNq114OdEYf2KUz+KxETvvjbHpeTXMaDnLKhrSxliErgei0Z
x6BxszEvilaGybYe5lJZNJ7N7VxwHFCGGz17hia2CnCKYu9+s08FckKC9cxe
X8SOrPS4kWIVuNVcnvSCH4ndtdXRZRqqIPxn38YW5wtYJyrJO39GFebHQ++2
mfNx9d/P/qobUYWJ/E+P5decx5aUtu4RfRbcZRtEO+ieQ6vBA615R1hgXObn
K7IMx7w4kbNXMgtyZ6d/1/AKQ13xUGF0PQta9AeX7BrPoIOKycqRORb0mz3v
3aUbgolvDtkXGJEgbS3h9d8NxkYNd3UfNxJmxBo9Nw4HYUkI/4NnKgnRfRVa
W76ewqJfQhLrm0i4HSaZFtbSuP3JpvC8pyR4Bi5Zu9XQ+GBTn1+UhAQfb86E
4QMaa+csbGxbSJjwbfKWFNLYlbGw2NJOQvLIqiq1qzTOD0b4Pe8i4bQgK3c8
gEYbn6gDb4dIuGL0UTFbh8bWju+31w2TcEGwGJOqTaOTxXv2rXck6N15+luc
Go1cJdtFr/ck2HPXEecVafQvVCgfHSNB29JA74+vFAonY9mTkyQInOIEee0U
anEtVTunSDA466ddIqEwo/bTQulnEmwCTs/W1FOYL3ToOfWFhEXhvdyX1RRW
mbESZmZIkOUzEw0KKLTKehzWO7v877t3aXcuhbWMQN/qORLKTB62H8qksPVF
xw9hCyQkldabRwkp/BH4pkcXSVgbQbrlxFPYfXsb22qJBH5SQHvNJQq55JCK
7r8kPJoWCF5GUjgQIlz4d7lFzTIxcxEU/geFk1cD
          "]]}, Annotation[#, "Charting`Private`Tag$4951#2"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {2., -0.14}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"Wealth\"", TraditionalForm], 
       FormBox["\"Utility\"", TraditionalForm]}, AxesOrigin -> {2., -0.14}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{2., 4.499999948979592}, {-0.14, 0}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*StyleBox[\\\"\[Alpha]\\\",FontSlant->\\\"Italic\\\"]\\) = 1\
\"", "\"\\!\\(\\*StyleBox[\\\"\[Alpha]\\\",FontSlant->\\\"Italic\\\"]\\) = \
1.2\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    Dashing[{0.18, 0.18}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    Dashing[{0.18, 0.18}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0.02`", ",", "0.02`"}], "}"}], "]"}]}], "]"}], 
               ",", 
               InterpretationBox[
                ButtonBox[
                 TooltipBox[
                  GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                   "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                   FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                   FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                   Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  StyleBox[
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                   False]], Appearance -> None, BaseStyle -> {}, 
                 BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                 ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                   If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                 Automatic, Method -> "Preemptive"], 
                RGBColor[1, 0, 0], Editable -> False, Selectable -> False]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& ), Editable -> True], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.696342759281171*^9, 3.696342800927989*^9, 
  3.6963428718336143`*^9, 3.6965443595854692`*^9, 3.7314211927124205`*^9},
 TextAlignment->Center,ExpressionUUID->"8d4d1094-2f8d-4fff-9016-04653fbbae04"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.12.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Utility[Wealth] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "\[Alpha]w"}]]}], TraditionalForm]],ExpressionUUID->
  "82e4276a-3093-4cf7-bd04-10568f3aa66b"],
 " where \[Alpha] has different values."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315003904312177`*^9}, {
  3.5386855198621635`*^9, 3.538685519863164*^9}, {3.5396074364768276`*^9, 
  3.5396074369868565`*^9}},
 TextAlignment->Center,ExpressionUUID->"934a93a6-1f8a-4a9c-ae35-a02d8c651297"],

Cell["\<\
As the coefficient of risk aversion increases the investor becomes more risk \
averse, his utility function \"bows\" more and a larger discount is require \
to entice him into the game.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5296198804438243`*^9, 
  3.538685519863164*^9},ExpressionUUID->"b376738e-6a64-4ebc-b0fb-\
a6a3ebcac09e"],

Cell["\<\
Here are two examples of discounts required by different investors, each with \
a different level of risk aversion, as they approach the same investment \
opportunity.  In both cases they start with wealth equal to 3 (feel free to \
add your own zeros to scale it to whatever level of wealth seems reasonable) \
and a 50/50 chance of either increasing it to 4 or decreasing it to 2. The \
\"raw expectation\" is, of course the original wealth because one half of 2 + \
4 is 3.  The first investor has a risk aversion of 1.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5296198804438243`*^9, 3.5296198815418873`*^9}, {
   3.5296202270746503`*^9, 3.529620227556678*^9}, 
   3.538685519863164*^9},ExpressionUUID->"6dfc171e-6908-4bf6-b854-\
4b945aee1a33"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"exp1", "=", 
   RowBox[{
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{".5", " ", 
       RowBox[{"u3", "[", "2", "]"}]}], " ", "+", " ", 
      RowBox[{".5", " ", 
       RowBox[{"u3", "[", "4", "]"}]}]}], "]"}], "/.", 
    RowBox[{"a", "\[Rule]", "1"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"w1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "w"}], "\[Equal]", 
         RowBox[{"Log", "[", 
          RowBox[{"-", "exp1"}], "]"}]}], "/.", 
        RowBox[{"a", "\[Rule]", "1"}]}], ",", "w"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p5", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"u3", "[", "w", "]"}], "/.", "\[InvisibleSpace]", 
        RowBox[{"a", "\[Rule]", "1"}]}], ",", 
       RowBox[{
        RowBox[{"u3", "[", "w", "]"}], "/.", "\[InvisibleSpace]", 
        RowBox[{"a", "\[Rule]", "1.2"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"w", ",", "1.8", ",", "4.5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.15"}], ",", "0"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1.73", ",", 
        RowBox[{"-", "0.15"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{"0.02", ",", "0.04"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", "Red", "}"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"intcpt1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"u3", "[", "2", "]"}], "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           FractionBox["2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"N", "[", 
              RowBox[{"u3", "[", "4", "]"}], "]"}], "-", 
             RowBox[{"N", "[", 
              RowBox[{"u3", "[", "2", "]"}], "]"}]}], ")"}]}], "+", "b"}]}], "/.",
         "\[InvisibleSpace]", 
        RowBox[{"a", "\[Rule]", "1"}]}], ",", "b"}], "]"}], 
     "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], 
    "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p6", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"u3", "[", "4", "]"}], "]"}], "-", 
          RowBox[{"N", "[", 
           RowBox[{"u3", "[", "2", "]"}], "]"}]}], ")"}], " ", "x"}], "+", 
       "intcpt1"}], "/.", "\[InvisibleSpace]", 
      RowBox[{"a", "\[Rule]", "1"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1.8", ",", "4.5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Dashing", "[", 
         RowBox[{"{", 
          RowBox[{"0.02", ",", "0.04"}], "}"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1.73", ",", 
        RowBox[{"-", "0.15"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Wealth\>\"", ",", "\"\<Utility\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.15`"}], ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"w1", ",", 
            RowBox[{"NumberForm", "[", 
             RowBox[{"w1", ",", 
              RowBox[{"{", 
               RowBox[{"4", ",", "3"}], "}"}]}], "]"}]}], "}"}], ",", "3", 
          ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"u3", "[", "2", "]"}], ",", 
             TagBox[
              RowBox[{"N", "[", 
               RowBox[{"u3", "[", 
                InterpretationBox["\"\<2\>\"",
                 2,
                 Editable->False], "]"}], "]"}],
              NumberForm[#, 3]& ]}], "}"}], "/.", "\[InvisibleSpace]", 
           RowBox[{"a", "\[Rule]", "1"}]}], ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"exp1", ",", 
             TagBox[
              RowBox[{"N", "[", "exp1", "]"}],
              NumberForm[#, 3]& ]}], "}"}], "/.", "\[InvisibleSpace]", 
           RowBox[{"a", "\[Rule]", "1"}]}], ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"u3", "[", "3", "]"}], ",", 
             TagBox[
              RowBox[{"N", "[", 
               RowBox[{"u3", "[", 
                InterpretationBox["\"\<3\>\"",
                 3,
                 Editable->False], "]"}], "]"}],
              NumberForm[#, 3]& ]}], "}"}], "/.", "\[InvisibleSpace]", 
           RowBox[{"a", "\[Rule]", "1"}]}], ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"u3", "[", "4", "]"}], ",", 
             TagBox[
              RowBox[{"N", "[", 
               RowBox[{"u3", "[", 
                InterpretationBox["\"\<4\>\"",
                 4,
                 Editable->False], "]"}], "]"}],
              NumberForm[#, 3]& ]}], "}"}], "/.", "\[InvisibleSpace]", 
           RowBox[{"a", "\[Rule]", "1"}]}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "w1", ",", "3", ",", "4"}], "}"}], ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"u3", "[", "2", "]"}], "]"}], ",", "exp1", ",", 
           RowBox[{"N", "[", 
            RowBox[{"u3", "[", "3", "]"}], "]"}], ",", 
           RowBox[{"N", "[", 
            RowBox[{"u3", "[", "4", "]"}], "]"}]}], "}"}], "/.", 
         "\[InvisibleSpace]", 
         RowBox[{"a", "\[Rule]", "1"}]}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"s1", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p6", ",", "p5", ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "8"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{"\"\<Risk Aversion = 1.\>\"", ",", 
       RowBox[{"FontColor", "\[Rule]", "Green"}]}], "]"}]}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5296200958101425`*^9, 3.5296201123270874`*^9}, {
   3.5296203365789137`*^9, 3.5296203696348047`*^9}, {3.529620489187642*^9, 
   3.5296205014793453`*^9}, {3.529620538193445*^9, 3.5296206245483847`*^9}, {
   3.5299366961361*^9, 3.5299367396615896`*^9}, {3.529936778743825*^9, 
   3.529936993481107*^9}, 3.529937089970626*^9, 
   3.5386855198641634`*^9},ExpressionUUID->"b3e4c327-3f01-4820-8f41-\
a4dfd469fcc4"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
       Dashing[{0.02, 0.04}], LineBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAJ2KX28zM/D8OBhnOHdLCvzxRgSox
0Pw/B/laXofQwr9QQGt5ldP8PwDsnO7wzsK/eB4/F17a/D/z0SAPxMvCv8ja
5lLv5/w/2J0oUGrFwr9oUzbKEQP9P6I1ONK2uMK/qETVuFY5/T84ZVfWT5/C
vygnE5bgpf0/YcSV3oFswr+JAzi1NpH+P2aLV/NZ/sG/HivOa/Rs/z+y2uDK
fpfBv6UbdFQxIgBAEt2wJagywb9rrVWlCZcAQCXoxYRFxcC/y+TvwRUEAUB+
e6KmL1/Av9un3hBDegFAEi+ImRvhv783XQ+jSO4BQFLNWOzgB7+/LLj4AIJa
AkAefLjEPz2+v9GeNpHczwJAUDyipYZhvb8QKy3taj0DQA4NGwxnlLy/m6ll
jNGoA0D0QyF5UMu7v9az8l1ZHQRAQIyx7iHxur+rYzj7FIoEQBjl0OmMJbq/
MJ/SyvH/BEBWT3rt30i5vwDNrt2mcwVAvB+x9ztwuL9qoEO8j98FQLAAd4cx
pre/hP8szZlUBkAI88YfD8u2vzgEz6nXwQZA7PWlPYb+tb+clMW4NjgHQDYK
D2TlILW/TBf+Cm6sB0CohAWRTUe0v5U/7yjZGAhAqA+LQ098s7+O8zR5ZY4I
QAysmv44oLK/IU0zlSX8CED8WDk/vNKxvwCZc/S9ZwlAFmxlhkgJsb+PcAiG
d9wJQJSQG9a8LrC/uO1V42RJCkA8i8FWlcWuv5H293JzvwpAHBhgEoELrb+2
8dtFWjMLQExxGdt+Wau/dJJ45HSfC0CY6/Cur8Spv+K+abWwFAxAsIjck7AN
qL/qkBNSIIIMQNxG5oPkc6a/PlX/MWjtDEBc0QqBKuKkv0KlP0TRYQ1AqH5D
j0Auo7/gmjgibs4NQAhNmqiJl6G/LRyGMixEDkBwfAqmRb2fvxRDjA4esg5A
+KAcEd6FnL9HXNQt6B0PQCheZJaaXpm/KgFxf9OSD0DwYNQ99/KVv6hLxpzy
/w9A2KWA+7nBkr/rEDh2GTsQQLBgqrY5mI6/KPWtvyV1EEAAp76qR82HvzIs
AO9LqxBAoHFLyyF3gb8UqXy3AuYQQOCOUWB4MHW/w3jVZdMcEUCAhvoFi7hg
v8faZlKMQBFAAAAAAAAAAAB8uJ3D
        "]]},
      Annotation[#, "Charting`Private`Tag$5062#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
       Dashing[{0.02, 0.04}], LineBox[CompressedData["
1:eJwdkHs01HkYxmeY5G6+UVlkVaZUtIVmRmq9MmUj5UhbtNmybtHRutbqYo+2
329mllxKVLO6EePSIg3r9s5QU+lQbrMbXdV2aiW3iUhm7T7nPOc5n7+e5zwL
gw/6hWoxGIxNM/4v22z421p3T7s5/a9mFGnzb3Izp91CnJ5vtBhpQusVbVHq
Axq3TT4tc5rVCiywjPdfvYgB86yuq9brKTCqbEeBXg4DosNzXYLny/H+q0HF
XBYTNs+TqtNPNGJv4VO2RxITZu/qUma01iNvj8nVb94zoVKYWxLPq0P7mo+M
lEAtsEo4NtH58A9sz+NmPn6gBeNeH94o99Yge4XDQOR6bQiTnORXWVbjBWlo
anuRNhTnfGw6NHATVTdG9gQsYIEsTDo5KavCkh/4n8zELLAKMHmqzL+Bqy52
tAxrWCBkYrD410pktF5/ci1uFohco2PkVAVGXvKoT382C8QJRJ54qRx/0di3
nvPXAUlp9jiJ+B35rAfSPxU6wO2OehGjLEPJmds1XP5sKFllfjLIohS3zJ/W
jy6dDZI+7rMjacWY7TZo98hcFyYX/7V+eqUUT406/xR6Shey1zHT9t4pxIU+
TtmcKV1oXRnkiqJryDgXp24I14PE2nJlbHABpv+oSx16rAeDXUkqO6d8rBnY
8TJksz7wDtiJti69iplj47FxqA/+RcdHC8yuoGy4d2OgkwHwO32KJ+Zexvis
w6/iLxoAHHFnzl1zCfsa998sNzOEFvPeT8ckefhPhqmfTYohOO8KPlbP+g2/
3qFZHTFgCFVD3BKJ6AJuKHATtO8zgqiNggwz1nl8fp6/KLrNCBry3zualuai
gxXlaC8wBguOj42jdw6aeaQaW1caQ3L/Tq8U07Po+V2Xw5sFJlD/trZJPnwG
lzNjkjuzTCDLa5nV2runschbKRnRmAA/V8cyQZGF/Wx+4heubPg2r/TdnKpM
tPtQhpwENjgdf/Jqa20GOtozBr1L2OCZtEZwtC4dzaRHq7Ves8HbMflu61ga
Nh/uDu20ItAtL66YDEvFHPcHazL8CARgZQCMitHDdzTvSSqB3OFyVUSCCOsr
RgcEzQTSXdp6vrIV4l5zhx7eLQIc08L9idZCZCWHKZffJnCWMbW90VyI3lse
5bHvEGjOfujiZyTEnteN2x63ELAPXeIuHqNx3FJcEddBYJ1/x9jaezQ6UjYJ
V14QCOdm3pIcpFH1LmBfdh+By4lyW+NIGpO2n/YRviRwvECg+jmERoWNzpLo
vwmkvDewjwyg0beuX+XyloDnyt5zWzxojB6S8duHCNARfXzf+TTO2Tlke2t4
pi/EQKQiNMoalpHqEQKBgVmcIEMaP4slbyVqAhH6yRtimDSmclLOR3wkYPq9
i3ZhP4WrUuuo3RMEYjOqy3ivKewcUcdunSQg8Pryyr3nFFrIw72dpwhIk2PD
h7spbFxymbf0M4GuBgWPfkhhcFrPYovpmT/1mnyt71OoozZlG2lm9sVyKmW3
KZQG+kxpZlhmkbfbV07hv2aGHNI=
        "]]},
      Annotation[#, "Charting`Private`Tag$5017#1"]& ], 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVj2s0lAkYgMeYhGTmC6eLWKxLuZ2omE6X7y1aU0NZle6l2cSyq+b7ZLHV
1LjENCmVrMsiky1UR4l0GG+lFJFFaQ26uFVbkzHIVMNs++M5z3l+PraC/UGh
TAaDEfCN/+0kyOxqatKSCbkJweokOS778Zizx99aMrj1fdGBI3IMhMi4jHYt
Oemv6lHFyDHWmpy5S6El+byeKeNhcnykGAwaeqMlLcVVTnPWyjF8g1cjoT9B
zn+216/aVI6XfZ9VBS+ZIN+8TswNzarBeU5m518VTZCHdlV6ws1qTNXnVnil
T5Iriyfca7tuo7XLk8jRX3RknUeBmElWYZFl9EYPOwYEsv34O+sqMfLqpiKj
TAYsMnQIubOyAh/3D921YOmBe43QQ6kqx65LLzg+8XrQP2wt3JdzA713smW8
j3qw9sOjmmDBdXSt0jDE25igeluR1x9Yhq15XundLUxILeH1lcRcQ46LmzJi
uT6UK698rU+/gjnFodLWy/rAZC/4UN5egh3l6p1brVjAdnJW/2pajKU/cb+a
S1gQoPMxFYsv4YL8tsZhHQsGxrxTB1RFyGi+1vMXPQXCSn0FFUcvYkSBT82p
l1MgWBiQaUXKMFHn2py10QAaeLKvUs0F5LJaip/fNYC4VXlLA7oKMPfcgyov
7lR4KSTy10Tno//MSeOoK1PBplMp9Bb8iRnk0LzOWYawd3eVOfdsDqaNLIoL
TTOEFyp3xxB5FtoGLMxw0BpC9QnhEY3dH8jIokflYUYgWebylCo+j6cOGCb/
1m0Ed1wlqR/nZ2CVclPf3jXGIDNz36FSnMX0T+MUjcbgqGks9D5+BiuHu1Zv
WzgNqodTtjxen47RZ2L7o/OnQaemoucheRp7a3+uKDM3AS9ZUZLP5jT897RZ
kI3YBFr6/Cs7oqW4YpPOI1xpAociE6qZtyW4qoj0bd0zHY7xA1+ox1LwVTbX
LurJdBAJBtrGIo+j29xkT1dfUyjMbvAnu5PQ3Edqan3DFLhWBYmzRYnot+Op
21srNjTGmNwcWZ6AznpCUfsZNjToSm42jB/Dy/z6XLWODS3U4qY+xVF8z+HG
zF7KAY2f/bBFtAjnjV1Fh4Mc+GS7ryxNcBg9XRlD/FIObOd12xud+x3Niw/d
Yg5yoDQ+dWp2bRzWxT4LbZ9LwO5L+13S7GMxc2XL4tNBBKxjp/tuKY1Bn8CR
vB4pAWYzyo5buB7EmusjSt86AhipjMHAHhpDZrkpvO8TUNjJNy55TiNLtK/e
+QEBJyZXNLLaaOT7d+ZxHhKQE86zxHoaFYO167sbCZActhn7oYzGcUvJdbqN
gPOiWXayBBo9k20OFr4mYLZStETiQmPHh617MnoJWLFqq9rCkcb4DWcDUvoI
SAuO4cpsaLxrY+AYNUDAY7wVcc+CxsDq9x1L3hHgVcbcbsagMUpVyW1VEeD5
Md5Q95TCGZtV9veHCdD0KkJkLRRWyucTt9Tffm0Pk2saKZyQ5L7LHSXALabp
ZBZSKHUQZ4drCHDnxQn8SyhcIK1O3v6ZgAi6+ZX2IoXt6lFq3RcCCmYMvb6W
T+GcO2H8RVoCvsvsjZiZQWGt4wVvpwkC7uE/w82nKBScVHw/Z5KA8d7+z0kS
Cg1GzTjTdQRID2SJySQKi7cFaHXfev94yokvIgr/A6QTZUA=
        "]]},
      Annotation[#, "Charting`Private`Tag$5017#2"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1.73, -0.15},
  BaseStyle->(FontSize -> 8),
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"Utility\"", TraditionalForm], None}, {
     FormBox["\"Wealth\"", TraditionalForm], None}},
  FrameTicks->{{{{
       NCache[(-1) E^(-2), -0.1353352832366127], 
       FormBox[
        RowBox[{"-", "0.1353352832366127`"}], 
        TraditionalForm]}, {-0.07682546106267345, 
       FormBox[
        RowBox[{"-", "0.07682546106267345`"}], TraditionalForm]}, {
       NCache[(-1) E^(-3), -0.049787068367863944`], 
       FormBox[
        RowBox[{"-", "0.04978706836786395`"}], TraditionalForm]}, {
       NCache[(-1) E^(-4), -0.01831563888873418], 
       FormBox[
        RowBox[{"-", "0.018315638888734186`"}], TraditionalForm]}}, {{
       NCache[(-1) E^(-2), -0.1353352832366127], 
       FormBox[
        RowBox[{"-", "0.1353352832366127`"}], 
        TraditionalForm]}, {-0.07682546106267345, 
       FormBox[
        RowBox[{"-", "0.07682546106267345`"}], TraditionalForm]}, {
       NCache[(-1) E^(-3), -0.049787068367863944`], 
       FormBox[
        RowBox[{"-", "0.04978706836786395`"}], TraditionalForm]}, {
       NCache[(-1) E^(-4), -0.01831563888873418], 
       FormBox[
        RowBox[{"-", "0.018315638888734186`"}], TraditionalForm]}}}, {{{2, 
       FormBox["2", TraditionalForm]}, {2.5662191695169727`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"2.566\"", 2.5662191695169727`, AutoDelete -> True], 
         NumberForm[#, {4, 3}]& ], TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, {{2, 
       FormBox["2", TraditionalForm]}, {2.5662191695169727`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"2.566\"", 2.5662191695169727`, AutoDelete -> True], 
         NumberForm[#, {4, 3}]& ], TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}}},
  GridLines->{{
    2, 2.5662191695169727`, 3, 
     4}, {-0.1353352832366127, -0.07682546106267345, -0.04978706836786395, \
-0.018315638888734186`}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
    StyleBox[
    "\"Risk Aversion = 1.\"", FontColor -> RGBColor[0, 1, 0], StripOnInput -> 
     False], TraditionalForm],
  PlotRange->{{1.73, 4.499999944897959}, {-0.15, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5299369876317725`*^9, 3.5299369946431737`*^9}, 
   3.5299370911496935`*^9, 3.529937325138077*^9, 3.5300164040351315`*^9, 
   3.5300167233553953`*^9, 3.530017185790845*^9, 3.530193690520609*^9, 
   3.5301942270852995`*^9, 3.5314482292097664`*^9, 3.5315006252696495`*^9, 
   3.533134700443116*^9, 3.5331358806346197`*^9, 3.533682251984375*^9, 
   3.53373458307752*^9, 3.533754143171875*^9, 3.533755415765625*^9, 
   3.5386852213910923`*^9, 3.538685519865164*^9, 3.5396359574221325`*^9, 
   3.5401268111552944`*^9, 3.541012631633032*^9, 3.5410151015573034`*^9, 
   3.5410155703521166`*^9, 3.5416004450669746`*^9, 3.5433421926012707`*^9, 
   3.6963384615138283`*^9, 3.696342374507492*^9, 3.6965443597048154`*^9, 
   3.731421192857808*^9},
 TextAlignment->Center,ExpressionUUID->"fdf4cc32-210c-482f-9ce8-0fa5b4dd049a"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.13.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "First investor with risk aversion = 1."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500409543311*^9}, 
   3.538685519865164*^9},
 TextAlignment->Center,ExpressionUUID->"5451c6d5-3ac4-4201-83eb-bcb6abbb8c42"],

Cell["\<\
Figure 6.13 shows that an investor with a coefficient of risk aversion of 1 \
requires a discount of 3 - 2.566 = .434 as calculated below. The straight \
line shows risk neutrality as a reference point. We are interested in how \
risk averse a particular investor is. We see this graphically in the \
curvature of the line and numerically in the difference between the value at \
risk neutrality and the value at the price the investor is willing to pay. \
Imagine two family members, one a 25 year-old and the other the 25-year old's \
grandparent. Who would you expect to be more risk averse? Given an \
opportunity to invest in the same project who would you expect to be willing \
to pay more? It is true that age is not strictly determinative. There are \
very conservative 25 year olds and some of them may have gunslinger \
grandfathers. But for the vast majority the analogy is apt.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529778131394261*^9, 3.529778137358602*^9}, {
   3.5299371650489206`*^9, 3.529937190429372*^9}, 
   3.5386855198661633`*^9},ExpressionUUID->"814b6eb7-ecdc-4583-93a8-\
959af3175af8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"disc1", "=", 
   RowBox[{"3", "-", "w1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"NumberForm", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "3"}], "}"}]}], "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5299371025483456`*^9, 3.5299371169341683`*^9}, 
   3.5299372643556004`*^9, {3.5299374563985844`*^9, 3.5299374913375826`*^9}, 
   3.529937536411161*^9, 
   3.5386855198661633`*^9},ExpressionUUID->"5ffa5022-d4e6-43e3-8e46-\
bed0fb88f31e"],

Cell[BoxData[
 TagBox[
  InterpretationBox["\<\"0.434\"\>",
   0.4337808304830273,
   AutoDelete->True],
  NumberForm[#, {4, 3}]& ]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQYwCByVl8US8dDTukspSAtJxY7VRzn1eOrdJbFsQC6WOP
89y6gLSRgMG5biDNw/xG6SKQZuvcJ30JSM88KqYHoi9vWmoKon/uXeYFovfw
igWA6FteLZd+AOnaxLxfINo108bkJ5D+1xyU7O/7ynFpTMYyEH22YMWXzf6v
HO980Ow6C6SfeM3JfR0EpKvFGN8AaQaG5pPfgl85JjS+DxMIAfFfPpYE0Q2/
m6SAdPesnUsaY185ztn++ySI5qpbfy8w/pWj24eKbseEV44fnnIIf0oEij86
7v4ZSOewJzaBaL6rW8QFk185pv1T7UtOe+V4QGfTYZOu145V0ZfWmAHpvLc/
fGYC6f+VMozyZ187AgBRKZpA
  "],ExpressionUUID->"7069c75f-15ff-415b-81b6-f50981aec196"]
}, Open  ]],

Cell[TextData[{
 "Now we consider an investor with coefficient of risk aversion of 1.2 \
(Recall that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " syntax \[OpenCurlyDoubleQuote] /.",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[RightArrow]1.2 \[CloseCurlyDoubleQuote] means \
\[OpenCurlyDoubleQuote]given that ",
 StyleBox["a",
  FontSlant->"Italic"],
 " equals 1.2 for this calculation\[CloseCurlyDoubleQuote])"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5331364790518475`*^9, 3.533136515242917*^9}, {
   3.533136548881841*^9, 3.533136582526766*^9}, 
   3.5386855198661633`*^9},ExpressionUUID->"85892d79-7f2f-4774-a578-\
ac1cd5040d00"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp2", "=", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{".5", " ", 
      RowBox[{"u3", "[", "2", "]"}]}], " ", "+", " ", 
     RowBox[{".5", " ", 
      RowBox[{"u3", "[", "4", "]"}]}]}], "]"}], "/.", 
   RowBox[{"a", "\[Rule]", "1.2"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198661633`*^9},ExpressionUUID->"61fd5595-62ba-4a56-a018-\
1adb72ee47ae"],

Cell[BoxData[
 RowBox[{"-", "0.04947385016921628`"}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658644609375*^9, 3.402699600891625*^9, 
  3.5296207062140555`*^9, 3.5296985659483776`*^9, 3.5297900035253077`*^9, 
  3.5297931378689985`*^9, 3.5299351276753893`*^9, 3.529937281623588*^9, 
  3.529937325217081*^9, 3.5299374962818656`*^9, 3.5300164042271423`*^9, 
  3.5300167235414057`*^9, 3.530017185983856*^9, 3.5301936906366158`*^9, 
  3.5301942274783216`*^9, 3.531448229313772*^9, 3.5315006253536544`*^9, 
  3.5331347012441626`*^9, 3.533135880741626*^9, 3.5336822521875*^9, 
  3.5337345838355637`*^9, 3.53375414334375*^9, 3.5337554159375*^9, 
  3.5386852221311345`*^9, 3.5386855198661633`*^9, 3.539635957542139*^9, 
  3.5401268124663696`*^9, 3.541012632915105*^9, 3.5410151029593835`*^9, 
  3.5410155718602033`*^9, 3.541600446167037*^9, 3.5433421937453365`*^9, 
  3.6963384615809975`*^9, 3.6963423745856996`*^9, 3.696544359796028*^9, 
  3.731421192911951*^9},ExpressionUUID->"71cdb554-2af9-480c-acde-\
5fc2f301c5c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "w"}], "\[Equal]", 
        RowBox[{"Log", "[", 
         RowBox[{"-", "exp2"}], "]"}]}], "/.", 
       RowBox[{"a", "\[Rule]", "1.2"}]}], ",", "w"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855198661633`*^9},ExpressionUUID->"aec40cb5-3934-4c6d-830d-\
4c3708b5b362"],

Cell[BoxData["2.5052591903383297`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658644625*^9, 3.40269960096975*^9, 
  3.529620708810204*^9, 3.5296985662273936`*^9, 3.5297900035843115`*^9, 
  3.5297931382530203`*^9, 3.529935127918403*^9, 3.5299372777623672`*^9, 
  3.529937325257084*^9, 3.5299374987400064`*^9, 3.5300164043041463`*^9, 
  3.530016723636411*^9, 3.5300171860748615`*^9, 3.5301936906936193`*^9, 
  3.530194227709335*^9, 3.531448229356775*^9, 3.531500625396657*^9, 
  3.5331347015671806`*^9, 3.5331358807816277`*^9, 3.533682252265625*^9, 
  3.533734584114579*^9, 3.533754143421875*^9, 3.533755416015625*^9, 
  3.538685222432152*^9, 3.5386855198661633`*^9, 3.5396359576041427`*^9, 
  3.5401268129433966`*^9, 3.541012633371131*^9, 3.5410151034254103`*^9, 
  3.541015572276227*^9, 3.5416004465740604`*^9, 3.5433421940633545`*^9, 
  3.6963384616271334`*^9, 3.69634237461578*^9, 3.6965443598070583`*^9, 
  3.7314211929269915`*^9},ExpressionUUID->"77a270a0-e5fa-4892-ba1b-\
a1cd84973fbc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p7", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"u3", "[", "w", "]"}], "/.", 
        RowBox[{"a", "\[Rule]", "1"}]}], ",", 
       RowBox[{
        RowBox[{"u3", "[", "w", "]"}], "/.", 
        RowBox[{"a", "\[Rule]", "1.2"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"w", ",", "1.8", ",", "4.5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", ".15"}], ",", "0"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1.73", ",", 
        RowBox[{"-", ".15"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{".02", ",", ".04"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", "Red", "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"intcpt2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"u3", "[", "2", "]"}], "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"2", " ", 
           FractionBox[
            RowBox[{
             RowBox[{"N", "[", 
              RowBox[{"u3", "[", "4", "]"}], "]"}], "-", 
             RowBox[{"N", "[", 
              RowBox[{"u3", "[", "2", "]"}], "]"}]}], "2"]}], "+", "b"}]}], "/.", 
        RowBox[{"a", "\[Rule]", "1.2"}]}], ",", "b"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p8", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"u3", "[", "4", "]"}], "]"}], "-", 
          RowBox[{"N", "[", 
           RowBox[{"u3", "[", "2", "]"}], "]"}]}], "2"], " ", "x"}], "+", 
       "intcpt2"}], "/.", 
      RowBox[{"a", "\[Rule]", "1.2"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1.8", ",", "4.5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1.73", ",", 
        RowBox[{"-", ".15"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Wealth\>\"", ",", "\"\<Utility\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", ".15"}], ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"w2", ",", 
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"N", "[", "w2", "]"}], ",", "4"}], "]"}]}], "}"}], ",", 
          "3", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"u3", "[", "2", "]"}], ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"N", "[", 
                RowBox[{"u3", "[", "2", "]"}], "]"}], ",", "3"}], "]"}]}], 
            "}"}], "/.", 
           RowBox[{"a", "\[Rule]", "1.2"}]}], ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"exp2", ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{"exp2", ",", "3"}], "]"}]}], "}"}], "/.", 
           RowBox[{"a", "\[Rule]", "1.2"}]}], ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"u3", "[", "3", "]"}], ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"N", "[", 
                RowBox[{"u3", "[", "3", "]"}], "]"}], ",", "3"}], "]"}]}], 
            "}"}], "/.", 
           RowBox[{"a", "\[Rule]", "1.2"}]}], ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"u3", "[", "4", "]"}], ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"N", "[", 
                RowBox[{"u3", "[", "4", "]"}], "]"}], ",", "3"}], "]"}]}], 
            "}"}], "/.", 
           RowBox[{"a", "\[Rule]", "1.2"}]}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "w2", ",", "3", ",", "4"}], "}"}], ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"u3", "[", "2", "]"}], "]"}], ",", "exp2", ",", 
           RowBox[{"N", "[", 
            RowBox[{"u3", "[", "3", "]"}], "]"}], ",", 
           RowBox[{"N", "[", 
            RowBox[{"u3", "[", "4", "]"}], "]"}]}], "}"}], "/.", 
         RowBox[{"a", "\[Rule]", "1.2"}]}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"s2", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p8", ",", "p7", ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "8"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{"\"\<Risk Aversion = 1.2\>\"", ",", 
       RowBox[{"FontColor", "\[Rule]", "Red"}]}], "]"}]}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5297012644997263`*^9, 3.5297012724461803`*^9}, {
   3.5297621133690825`*^9, 3.529762146658986*^9}, {3.529763648273874*^9, 
   3.529763669988116*^9}, {3.5297653826870766`*^9, 3.529765436627162*^9}, 
   3.5386855198671637`*^9},ExpressionUUID->"84a5018e-c755-4742-9819-\
c471e33e87ee"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAADMAAAACAAAAJ2KX28zM/D/rh5bn4lW5vzxRgSox
0Pw/rpsy56VTub9QQGt5ldP8P3KvzuZoUbm/eB4/F17a/D/51gbm7ky5v8ja
5lLv5/w/ByZ35PpDub9oUzbKEQP9PyPEV+ESMrm/qETVuFY5/T9aABnbQg65
vygnE5bgpf0/ynibzqLGuL+JAzi1NpH+P1zfDQ1WK7i/HivOa/Rs/z+Y2mXo
U5q3v6UbdFQxIgBA2Qom9CkMt79rrVWlCZcAQMywU1fzcba/y+TvwRUEAUBq
62ZXB+K1v9un3hBDegFAu5vnrg5Gtb83XQ+jSO4BQA+B0DburLS/LLj4AIJa
AkAP+55bGB60v9GeNpHczwJAwura1zWDs78QKy3taj0DQCFv/PCd8rK/m6ll
jNGoA0CCKIY63mSyv9az8l1ZHQRAlld92xHLsb+rYzj7FIoEQFYbWhmQO7G/
MJ/SyvH/BEDIVKSuAaCwvwDNrt2mcwVAPsNWdEsHsL9qoEO8j98FQMCM3a2/
8a6/hP8szZlUBkBofughz7ytvzgEz6nXwQZAZpm+z3OcrL+clMW4NjgHQMqf
byz/Y6u/TBf+Cm6sB0A2EPHpOjGqv5U/7yjZGAhA+Kk94QsTqb+O8zR5ZY4I
QCAvZYfD3Ke/IU0zlSX8CECg3VdnELumvwCZc/S9ZwlAKPYaqA2fpb+PcAiG
d9wJQBD6uJfxaqS/uO1V42RJCkBUJyLBakujv5H293JzvwpA+D9mmcoTor+2
8dtFWjMLQKTCetLa4aC/dJJ45HSfC0BY3bSKAImfv+K+abWwFAxAMAwqzhge
nb/qkBNSIIIMQLCNNYVb3Jq/PlX/MWjtDEBA4+H9/qWYv0KlP0TRYQ1AmA9E
1G8/lr/gmjgibs4NQKCOPB4LApS/LRyGMixEDkB45OrFc5SRvxRDjA4esg5A
8Blfwg2gjr9HXNQt6B0PQBATKnz1LYq/KgFxf9OSD0DQuWDxd1uFv6hLxpzy
/w9A0AXETU/bgL/rEDh2GTsQQMD+JcuC9Xe/KPWtvyV1EEBAhI4C1MNsvzIs
AO9LqxBAAEEHF+zLVb9theqRU8wQQAAAAAAAAAAAsX2O1Q==
        "]]},
      Annotation[#, "Charting`Private`Tag$5190#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
       Dashing[{0.02, 0.04}], LineBox[CompressedData["
1:eJwdkHs01HkYxmeY5G6+UVlkVaZUtIVmRmq9MmUj5UhbtNmybtHRutbqYo+2
329mllxKVLO6EePSIg3r9s5QU+lQbrMbXdV2aiW3iUhm7T7nPOc5n7+e5zwL
gw/6hWoxGIxNM/4v22z421p3T7s5/a9mFGnzb3Izp91CnJ5vtBhpQusVbVHq
Axq3TT4tc5rVCiywjPdfvYgB86yuq9brKTCqbEeBXg4DosNzXYLny/H+q0HF
XBYTNs+TqtNPNGJv4VO2RxITZu/qUma01iNvj8nVb94zoVKYWxLPq0P7mo+M
lEAtsEo4NtH58A9sz+NmPn6gBeNeH94o99Yge4XDQOR6bQiTnORXWVbjBWlo
anuRNhTnfGw6NHATVTdG9gQsYIEsTDo5KavCkh/4n8zELLAKMHmqzL+Bqy52
tAxrWCBkYrD410pktF5/ci1uFohco2PkVAVGXvKoT382C8QJRJ54qRx/0di3
nvPXAUlp9jiJ+B35rAfSPxU6wO2OehGjLEPJmds1XP5sKFllfjLIohS3zJ/W
jy6dDZI+7rMjacWY7TZo98hcFyYX/7V+eqUUT406/xR6Shey1zHT9t4pxIU+
TtmcKV1oXRnkiqJryDgXp24I14PE2nJlbHABpv+oSx16rAeDXUkqO6d8rBnY
8TJksz7wDtiJti69iplj47FxqA/+RcdHC8yuoGy4d2OgkwHwO32KJ+Zexvis
w6/iLxoAHHFnzl1zCfsa998sNzOEFvPeT8ckefhPhqmfTYohOO8KPlbP+g2/
3qFZHTFgCFVD3BKJ6AJuKHATtO8zgqiNggwz1nl8fp6/KLrNCBry3zualuai
gxXlaC8wBguOj42jdw6aeaQaW1caQ3L/Tq8U07Po+V2Xw5sFJlD/trZJPnwG
lzNjkjuzTCDLa5nV2runschbKRnRmAA/V8cyQZGF/Wx+4heubPg2r/TdnKpM
tPtQhpwENjgdf/Jqa20GOtozBr1L2OCZtEZwtC4dzaRHq7Ves8HbMflu61ga
Nh/uDu20ItAtL66YDEvFHPcHazL8CARgZQCMitHDdzTvSSqB3OFyVUSCCOsr
RgcEzQTSXdp6vrIV4l5zhx7eLQIc08L9idZCZCWHKZffJnCWMbW90VyI3lse
5bHvEGjOfujiZyTEnteN2x63ELAPXeIuHqNx3FJcEddBYJ1/x9jaezQ6UjYJ
V14QCOdm3pIcpFH1LmBfdh+By4lyW+NIGpO2n/YRviRwvECg+jmERoWNzpLo
vwmkvDewjwyg0beuX+XyloDnyt5zWzxojB6S8duHCNARfXzf+TTO2Tlke2t4
pi/EQKQiNMoalpHqEQKBgVmcIEMaP4slbyVqAhH6yRtimDSmclLOR3wkYPq9
i3ZhP4WrUuuo3RMEYjOqy3ivKewcUcdunSQg8Pryyr3nFFrIw72dpwhIk2PD
h7spbFxymbf0M4GuBgWPfkhhcFrPYovpmT/1mnyt71OoozZlG2lm9sVyKmW3
KZQG+kxpZlhmkbfbV07hv2aGHNI=
        "]]},
      Annotation[#, "Charting`Private`Tag$5145#1"]& ], 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVj2s0lAkYgMeYhGTmC6eLWKxLuZ2omE6X7y1aU0NZle6l2cSyq+b7ZLHV
1LjENCmVrMsiky1UR4l0GG+lFJFFaQ26uFVbkzHIVMNs++M5z3l+PraC/UGh
TAaDEfCN/+0kyOxqatKSCbkJweokOS778Zizx99aMrj1fdGBI3IMhMi4jHYt
Oemv6lHFyDHWmpy5S6El+byeKeNhcnykGAwaeqMlLcVVTnPWyjF8g1cjoT9B
zn+216/aVI6XfZ9VBS+ZIN+8TswNzarBeU5m518VTZCHdlV6ws1qTNXnVnil
T5Iriyfca7tuo7XLk8jRX3RknUeBmElWYZFl9EYPOwYEsv34O+sqMfLqpiKj
TAYsMnQIubOyAh/3D921YOmBe43QQ6kqx65LLzg+8XrQP2wt3JdzA713smW8
j3qw9sOjmmDBdXSt0jDE25igeluR1x9Yhq15XundLUxILeH1lcRcQ46LmzJi
uT6UK698rU+/gjnFodLWy/rAZC/4UN5egh3l6p1brVjAdnJW/2pajKU/cb+a
S1gQoPMxFYsv4YL8tsZhHQsGxrxTB1RFyGi+1vMXPQXCSn0FFUcvYkSBT82p
l1MgWBiQaUXKMFHn2py10QAaeLKvUs0F5LJaip/fNYC4VXlLA7oKMPfcgyov
7lR4KSTy10Tno//MSeOoK1PBplMp9Bb8iRnk0LzOWYawd3eVOfdsDqaNLIoL
TTOEFyp3xxB5FtoGLMxw0BpC9QnhEY3dH8jIokflYUYgWebylCo+j6cOGCb/
1m0Ed1wlqR/nZ2CVclPf3jXGIDNz36FSnMX0T+MUjcbgqGks9D5+BiuHu1Zv
WzgNqodTtjxen47RZ2L7o/OnQaemoucheRp7a3+uKDM3AS9ZUZLP5jT897RZ
kI3YBFr6/Cs7oqW4YpPOI1xpAociE6qZtyW4qoj0bd0zHY7xA1+ox1LwVTbX
LurJdBAJBtrGIo+j29xkT1dfUyjMbvAnu5PQ3Edqan3DFLhWBYmzRYnot+Op
21srNjTGmNwcWZ6AznpCUfsZNjToSm42jB/Dy/z6XLWODS3U4qY+xVF8z+HG
zF7KAY2f/bBFtAjnjV1Fh4Mc+GS7ryxNcBg9XRlD/FIObOd12xud+x3Niw/d
Yg5yoDQ+dWp2bRzWxT4LbZ9LwO5L+13S7GMxc2XL4tNBBKxjp/tuKY1Bn8CR
vB4pAWYzyo5buB7EmusjSt86AhipjMHAHhpDZrkpvO8TUNjJNy55TiNLtK/e
+QEBJyZXNLLaaOT7d+ZxHhKQE86zxHoaFYO167sbCZActhn7oYzGcUvJdbqN
gPOiWXayBBo9k20OFr4mYLZStETiQmPHh617MnoJWLFqq9rCkcb4DWcDUvoI
SAuO4cpsaLxrY+AYNUDAY7wVcc+CxsDq9x1L3hHgVcbcbsagMUpVyW1VEeD5
Md5Q95TCGZtV9veHCdD0KkJkLRRWyucTt9Tffm0Pk2saKZyQ5L7LHSXALabp
ZBZSKHUQZ4drCHDnxQn8SyhcIK1O3v6ZgAi6+ZX2IoXt6lFq3RcCCmYMvb6W
T+GcO2H8RVoCvsvsjZiZQWGt4wVvpwkC7uE/w82nKBScVHw/Z5KA8d7+z0kS
Cg1GzTjTdQRID2SJySQKi7cFaHXfev94yokvIgr/A6QTZUA=
        "]]},
      Annotation[#, "Charting`Private`Tag$5145#2"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1.73, -0.15},
  BaseStyle->(FontSize -> 8),
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"Utility\"", TraditionalForm], None}, {
     FormBox["\"Wealth\"", TraditionalForm], None}},
  FrameTicks->{{{{-0.09071795328941251, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.0907\"", -0.09071795328941253, AutoDelete -> True], 
         NumberForm[#, 3]& ], TraditionalForm]}, {-0.04947385016921628, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.0495\"", -0.04947385016921628, AutoDelete -> True], 
         NumberForm[#, 3]& ], TraditionalForm]}, {-0.02732372244729257, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.0273\"", -0.027323722447292576`, AutoDelete -> True], 
         NumberForm[#, 3]& ], TraditionalForm]}, {-0.00822974704902003, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.00823\"", -0.008229747049020032, AutoDelete -> True], 
         NumberForm[#, 3]& ], TraditionalForm]}}, {{-0.09071795328941251, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.0907\"", -0.09071795328941253, AutoDelete -> True], 
         NumberForm[#, 3]& ], TraditionalForm]}, {-0.04947385016921628, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.0495\"", -0.04947385016921628, AutoDelete -> True], 
         NumberForm[#, 3]& ], TraditionalForm]}, {-0.02732372244729257, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.0273\"", -0.027323722447292576`, AutoDelete -> True], 
         NumberForm[#, 3]& ], TraditionalForm]}, {-0.00822974704902003, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.00823\"", -0.008229747049020032, AutoDelete -> True], 
         NumberForm[#, 3]& ], TraditionalForm]}}}, {{{2, 
       FormBox["2", TraditionalForm]}, {2.5052591903383297`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"2.505\"", 2.5052591903383297`, AutoDelete -> True], 
         NumberForm[#, 4]& ], TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, {{2, 
       FormBox["2", TraditionalForm]}, {2.5052591903383297`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"2.505\"", 2.5052591903383297`, AutoDelete -> True], 
         NumberForm[#, 4]& ], TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}}},
  GridLines->{{
    2, 2.5052591903383297`, 3, 
     4}, {-0.09071795328941253, -0.04947385016921628, -0.027323722447292576`, \
-0.008229747049020032}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageMargins->{{0., 9.333333333333147}, {1.9999999999993778`, 
   0.6666666666658864}},
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
    StyleBox[
    "\"Risk Aversion = 1.2\"", FontColor -> RGBColor[1, 0, 0], StripOnInput -> 
     False], TraditionalForm],
  PlotRange->{{1.73, 4.499999944897959}, {-0.15, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.40265864465625*^9, 3.402699601485375*^9, 3.40278641384475*^9, 
   3.529620729595393*^9, 3.52969856668242*^9, 3.529701275502355*^9, {
   3.529762127436887*^9, 3.5297621477210474`*^9}, {3.529763657977429*^9, 
   3.529763673285304*^9}, 3.52976538955647*^9, {3.529765425428521*^9, 
   3.5297654374492087`*^9}, 3.5297900036453147`*^9, 3.52979313860104*^9, 
   3.529935128121415*^9, 3.529937325299086*^9, 3.5300164043811507`*^9, 
   3.5300167237144156`*^9, 3.5300171861668663`*^9, 3.530193690755623*^9, 
   3.5301942281633606`*^9, 3.531448229398777*^9, 3.5315006254426594`*^9, 
   3.533134701816195*^9, 3.5331358808226304`*^9, 3.53368225234375*^9, 
   3.5337345843595934`*^9, 3.533754143515625*^9, 3.53375541609375*^9, 
   3.538685222669165*^9, 3.538685519869164*^9, 3.539635957663146*^9, 
   3.5401268134464254`*^9, 3.54101263386716*^9, 3.5410151039244385`*^9, 
   3.541015572658249*^9, 3.5416004470150857`*^9, 3.5433421943763723`*^9, 
   3.6963384617344055`*^9, 3.696342374732089*^9, 3.6965443599233675`*^9, 
   3.731421193039291*^9},
 TextAlignment->Center,ExpressionUUID->"28d21d8f-e1c9-4e28-8431-68f126489e92"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.14.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Second investor with risk aversion = 1.2."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315004324976234`*^9}, 
   3.538685519869164*^9},
 TextAlignment->Center,ExpressionUUID->"3c0be7ca-4300-47e3-aed5-500a6085a567"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s2a", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"GraphicsRow", "[", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5297013544538713`*^9, 3.5297013666435685`*^9}, 
   3.538685519869164*^9},ExpressionUUID->"255d6105-7fad-42fb-9c8c-\
5e0d2cb57018"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{{}, {}, 
         TagBox[
          {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
           Dashing[{0.02, 0.04}], LineBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAJ2KX28zM/D8OBhnOHdLCvzxRgSox
0Pw/B/laXofQwr9QQGt5ldP8PwDsnO7wzsK/eB4/F17a/D/z0SAPxMvCv8ja
5lLv5/w/2J0oUGrFwr9oUzbKEQP9P6I1ONK2uMK/qETVuFY5/T84ZVfWT5/C
vygnE5bgpf0/YcSV3oFswr+JAzi1NpH+P2aLV/NZ/sG/HivOa/Rs/z+y2uDK
fpfBv6UbdFQxIgBAEt2wJagywb9rrVWlCZcAQCXoxYRFxcC/y+TvwRUEAUB+
e6KmL1/Av9un3hBDegFAEi+ImRvhv783XQ+jSO4BQFLNWOzgB7+/LLj4AIJa
AkAefLjEPz2+v9GeNpHczwJAUDyipYZhvb8QKy3taj0DQA4NGwxnlLy/m6ll
jNGoA0D0QyF5UMu7v9az8l1ZHQRAQIyx7iHxur+rYzj7FIoEQBjl0OmMJbq/
MJ/SyvH/BEBWT3rt30i5vwDNrt2mcwVAvB+x9ztwuL9qoEO8j98FQLAAd4cx
pre/hP8szZlUBkAI88YfD8u2vzgEz6nXwQZA7PWlPYb+tb+clMW4NjgHQDYK
D2TlILW/TBf+Cm6sB0CohAWRTUe0v5U/7yjZGAhAqA+LQ098s7+O8zR5ZY4I
QAysmv44oLK/IU0zlSX8CED8WDk/vNKxvwCZc/S9ZwlAFmxlhkgJsb+PcAiG
d9wJQJSQG9a8LrC/uO1V42RJCkA8i8FWlcWuv5H293JzvwpAHBhgEoELrb+2
8dtFWjMLQExxGdt+Wau/dJJ45HSfC0CY6/Cur8Spv+K+abWwFAxAsIjck7AN
qL/qkBNSIIIMQNxG5oPkc6a/PlX/MWjtDEBc0QqBKuKkv0KlP0TRYQ1AqH5D
j0Auo7/gmjgibs4NQAhNmqiJl6G/LRyGMixEDkBwfAqmRb2fvxRDjA4esg5A
+KAcEd6FnL9HXNQt6B0PQCheZJaaXpm/KgFxf9OSD0DwYNQ99/KVv6hLxpzy
/w9A2KWA+7nBkr/rEDh2GTsQQLBgqrY5mI6/KPWtvyV1EEAAp76qR82HvzIs
AO9LqxBAoHFLyyF3gb8UqXy3AuYQQOCOUWB4MHW/w3jVZdMcEUCAhvoFi7hg
v8faZlKMQBFAAAAAAAAAAAB8uJ3D
            "]]},
          Annotation[#, "Charting`Private`Tag$5062#1"]& ]}, {}, {}}, {{{}, {}, 
         TagBox[
          {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
           Dashing[{0.02, 0.04}], LineBox[CompressedData["
1:eJwdkHs01HkYxmeY5G6+UVlkVaZUtIVmRmq9MmUj5UhbtNmybtHRutbqYo+2
329mllxKVLO6EePSIg3r9s5QU+lQbrMbXdV2aiW3iUhm7T7nPOc5n7+e5zwL
gw/6hWoxGIxNM/4v22z421p3T7s5/a9mFGnzb3Izp91CnJ5vtBhpQusVbVHq
Axq3TT4tc5rVCiywjPdfvYgB86yuq9brKTCqbEeBXg4DosNzXYLny/H+q0HF
XBYTNs+TqtNPNGJv4VO2RxITZu/qUma01iNvj8nVb94zoVKYWxLPq0P7mo+M
lEAtsEo4NtH58A9sz+NmPn6gBeNeH94o99Yge4XDQOR6bQiTnORXWVbjBWlo
anuRNhTnfGw6NHATVTdG9gQsYIEsTDo5KavCkh/4n8zELLAKMHmqzL+Bqy52
tAxrWCBkYrD410pktF5/ci1uFohco2PkVAVGXvKoT382C8QJRJ54qRx/0di3
nvPXAUlp9jiJ+B35rAfSPxU6wO2OehGjLEPJmds1XP5sKFllfjLIohS3zJ/W
jy6dDZI+7rMjacWY7TZo98hcFyYX/7V+eqUUT406/xR6Shey1zHT9t4pxIU+
TtmcKV1oXRnkiqJryDgXp24I14PE2nJlbHABpv+oSx16rAeDXUkqO6d8rBnY
8TJksz7wDtiJti69iplj47FxqA/+RcdHC8yuoGy4d2OgkwHwO32KJ+Zexvis
w6/iLxoAHHFnzl1zCfsa998sNzOEFvPeT8ckefhPhqmfTYohOO8KPlbP+g2/
3qFZHTFgCFVD3BKJ6AJuKHATtO8zgqiNggwz1nl8fp6/KLrNCBry3zualuai
gxXlaC8wBguOj42jdw6aeaQaW1caQ3L/Tq8U07Po+V2Xw5sFJlD/trZJPnwG
lzNjkjuzTCDLa5nV2runschbKRnRmAA/V8cyQZGF/Wx+4heubPg2r/TdnKpM
tPtQhpwENjgdf/Jqa20GOtozBr1L2OCZtEZwtC4dzaRHq7Ves8HbMflu61ga
Nh/uDu20ItAtL66YDEvFHPcHazL8CARgZQCMitHDdzTvSSqB3OFyVUSCCOsr
RgcEzQTSXdp6vrIV4l5zhx7eLQIc08L9idZCZCWHKZffJnCWMbW90VyI3lse
5bHvEGjOfujiZyTEnteN2x63ELAPXeIuHqNx3FJcEddBYJ1/x9jaezQ6UjYJ
V14QCOdm3pIcpFH1LmBfdh+By4lyW+NIGpO2n/YRviRwvECg+jmERoWNzpLo
vwmkvDewjwyg0beuX+XyloDnyt5zWzxojB6S8duHCNARfXzf+TTO2Tlke2t4
pi/EQKQiNMoalpHqEQKBgVmcIEMaP4slbyVqAhH6yRtimDSmclLOR3wkYPq9
i3ZhP4WrUuuo3RMEYjOqy3ivKewcUcdunSQg8Pryyr3nFFrIw72dpwhIk2PD
h7spbFxymbf0M4GuBgWPfkhhcFrPYovpmT/1mnyt71OoozZlG2lm9sVyKmW3
KZQG+kxpZlhmkbfbV07hv2aGHNI=
            "]]},
          Annotation[#, "Charting`Private`Tag$5017#1"]& ], 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwVj2s0lAkYgMeYhGTmC6eLWKxLuZ2omE6X7y1aU0NZle6l2cSyq+b7ZLHV
1LjENCmVrMsiky1UR4l0GG+lFJFFaQ26uFVbkzHIVMNs++M5z3l+PraC/UGh
TAaDEfCN/+0kyOxqatKSCbkJweokOS778Zizx99aMrj1fdGBI3IMhMi4jHYt
Oemv6lHFyDHWmpy5S6El+byeKeNhcnykGAwaeqMlLcVVTnPWyjF8g1cjoT9B
zn+216/aVI6XfZ9VBS+ZIN+8TswNzarBeU5m518VTZCHdlV6ws1qTNXnVnil
T5Iriyfca7tuo7XLk8jRX3RknUeBmElWYZFl9EYPOwYEsv34O+sqMfLqpiKj
TAYsMnQIubOyAh/3D921YOmBe43QQ6kqx65LLzg+8XrQP2wt3JdzA713smW8
j3qw9sOjmmDBdXSt0jDE25igeluR1x9Yhq15XundLUxILeH1lcRcQ46LmzJi
uT6UK698rU+/gjnFodLWy/rAZC/4UN5egh3l6p1brVjAdnJW/2pajKU/cb+a
S1gQoPMxFYsv4YL8tsZhHQsGxrxTB1RFyGi+1vMXPQXCSn0FFUcvYkSBT82p
l1MgWBiQaUXKMFHn2py10QAaeLKvUs0F5LJaip/fNYC4VXlLA7oKMPfcgyov
7lR4KSTy10Tno//MSeOoK1PBplMp9Bb8iRnk0LzOWYawd3eVOfdsDqaNLIoL
TTOEFyp3xxB5FtoGLMxw0BpC9QnhEY3dH8jIokflYUYgWebylCo+j6cOGCb/
1m0Ed1wlqR/nZ2CVclPf3jXGIDNz36FSnMX0T+MUjcbgqGks9D5+BiuHu1Zv
WzgNqodTtjxen47RZ2L7o/OnQaemoucheRp7a3+uKDM3AS9ZUZLP5jT897RZ
kI3YBFr6/Cs7oqW4YpPOI1xpAociE6qZtyW4qoj0bd0zHY7xA1+ox1LwVTbX
LurJdBAJBtrGIo+j29xkT1dfUyjMbvAnu5PQ3Edqan3DFLhWBYmzRYnot+Op
21srNjTGmNwcWZ6AznpCUfsZNjToSm42jB/Dy/z6XLWODS3U4qY+xVF8z+HG
zF7KAY2f/bBFtAjnjV1Fh4Mc+GS7ryxNcBg9XRlD/FIObOd12xud+x3Niw/d
Yg5yoDQ+dWp2bRzWxT4LbZ9LwO5L+13S7GMxc2XL4tNBBKxjp/tuKY1Bn8CR
vB4pAWYzyo5buB7EmusjSt86AhipjMHAHhpDZrkpvO8TUNjJNy55TiNLtK/e
+QEBJyZXNLLaaOT7d+ZxHhKQE86zxHoaFYO167sbCZActhn7oYzGcUvJdbqN
gPOiWXayBBo9k20OFr4mYLZStETiQmPHh617MnoJWLFqq9rCkcb4DWcDUvoI
SAuO4cpsaLxrY+AYNUDAY7wVcc+CxsDq9x1L3hHgVcbcbsagMUpVyW1VEeD5
Md5Q95TCGZtV9veHCdD0KkJkLRRWyucTt9Tffm0Pk2saKZyQ5L7LHSXALabp
ZBZSKHUQZ4drCHDnxQn8SyhcIK1O3v6ZgAi6+ZX2IoXt6lFq3RcCCmYMvb6W
T+GcO2H8RVoCvsvsjZiZQWGt4wVvpwkC7uE/w82nKBScVHw/Z5KA8d7+z0kS
Cg1GzTjTdQRID2SJySQKi7cFaHXfev94yokvIgr/A6QTZUA=
            "]]},
          Annotation[#, "Charting`Private`Tag$5017#2"]& ]}, {}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{1.73, -0.15},
      BaseStyle->(FontSize -> 8),
      DisplayFunction->Identity,
      Frame->{{True, False}, {True, False}},
      FrameLabel->{{
         FormBox["\"Utility\"", TraditionalForm], None}, {
         FormBox["\"Wealth\"", TraditionalForm], None}},
      FrameTicks->{{{{
           NCache[(-1) E^(-2), -0.1353352832366127], 
           FormBox[
            RowBox[{"-", "0.1353352832366127`"}], 
            TraditionalForm]}, {-0.07682546106267345, 
           FormBox[
            RowBox[{"-", "0.07682546106267345`"}], TraditionalForm]}, {
           NCache[(-1) E^(-3), -0.049787068367863944`], 
           FormBox[
            RowBox[{"-", "0.04978706836786395`"}], TraditionalForm]}, {
           NCache[(-1) E^(-4), -0.01831563888873418], 
           FormBox[
            RowBox[{"-", "0.018315638888734186`"}], TraditionalForm]}}, {{
           NCache[(-1) E^(-2), -0.1353352832366127], 
           FormBox[
            RowBox[{"-", "0.1353352832366127`"}], 
            TraditionalForm]}, {-0.07682546106267345, 
           FormBox[
            RowBox[{"-", "0.07682546106267345`"}], TraditionalForm]}, {
           NCache[(-1) E^(-3), -0.049787068367863944`], 
           FormBox[
            RowBox[{"-", "0.04978706836786395`"}], TraditionalForm]}, {
           NCache[(-1) E^(-4), -0.01831563888873418], 
           FormBox[
            RowBox[{"-", "0.018315638888734186`"}], TraditionalForm]}}}, {{{2, 
           FormBox["2", TraditionalForm]}, {2.5662191695169727`, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"2.566\"", 2.5662191695169727`, AutoDelete -> True], 
             NumberForm[#, {4, 3}]& ], TraditionalForm]}, {3, 
           FormBox["3", TraditionalForm]}, {4, 
           FormBox["4", TraditionalForm]}}, {{2, 
           FormBox["2", TraditionalForm]}, {2.5662191695169727`, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"2.566\"", 2.5662191695169727`, AutoDelete -> True], 
             NumberForm[#, {4, 3}]& ], TraditionalForm]}, {3, 
           FormBox["3", TraditionalForm]}, {4, 
           FormBox["4", TraditionalForm]}}}},
      GridLines->{{
        2, 2.5662191695169727`, 3, 
         4}, {-0.1353352832366127, -0.07682546106267345, \
-0.04978706836786395, -0.018315638888734186`}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        StyleBox[
        "\"Risk Aversion = 1.\"", FontColor -> RGBColor[0, 1, 0], 
         StripOnInput -> False], TraditionalForm],
      PlotRange->{{1.73, 4.499999944897959}, {-0.15, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{{}, {}, 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAADMAAAACAAAAJ2KX28zM/D/rh5bn4lW5vzxRgSox
0Pw/rpsy56VTub9QQGt5ldP8P3KvzuZoUbm/eB4/F17a/D/51gbm7ky5v8ja
5lLv5/w/ByZ35PpDub9oUzbKEQP9PyPEV+ESMrm/qETVuFY5/T9aABnbQg65
vygnE5bgpf0/ynibzqLGuL+JAzi1NpH+P1zfDQ1WK7i/HivOa/Rs/z+Y2mXo
U5q3v6UbdFQxIgBA2Qom9CkMt79rrVWlCZcAQMywU1fzcba/y+TvwRUEAUBq
62ZXB+K1v9un3hBDegFAu5vnrg5Gtb83XQ+jSO4BQA+B0DburLS/LLj4AIJa
AkAP+55bGB60v9GeNpHczwJAwura1zWDs78QKy3taj0DQCFv/PCd8rK/m6ll
jNGoA0CCKIY63mSyv9az8l1ZHQRAlld92xHLsb+rYzj7FIoEQFYbWhmQO7G/
MJ/SyvH/BEDIVKSuAaCwvwDNrt2mcwVAPsNWdEsHsL9qoEO8j98FQMCM3a2/
8a6/hP8szZlUBkBofughz7ytvzgEz6nXwQZAZpm+z3OcrL+clMW4NjgHQMqf
byz/Y6u/TBf+Cm6sB0A2EPHpOjGqv5U/7yjZGAhA+Kk94QsTqb+O8zR5ZY4I
QCAvZYfD3Ke/IU0zlSX8CECg3VdnELumvwCZc/S9ZwlAKPYaqA2fpb+PcAiG
d9wJQBD6uJfxaqS/uO1V42RJCkBUJyLBakujv5H293JzvwpA+D9mmcoTor+2
8dtFWjMLQKTCetLa4aC/dJJ45HSfC0BY3bSKAImfv+K+abWwFAxAMAwqzhge
nb/qkBNSIIIMQLCNNYVb3Jq/PlX/MWjtDEBA4+H9/qWYv0KlP0TRYQ1AmA9E
1G8/lr/gmjgibs4NQKCOPB4LApS/LRyGMixEDkB45OrFc5SRvxRDjA4esg5A
8Blfwg2gjr9HXNQt6B0PQBATKnz1LYq/KgFxf9OSD0DQuWDxd1uFv6hLxpzy
/w9A0AXETU/bgL/rEDh2GTsQQMD+JcuC9Xe/KPWtvyV1EEBAhI4C1MNsvzIs
AO9LqxBAAEEHF+zLVb9theqRU8wQQAAAAAAAAAAAsX2O1Q==
            "]]},
          Annotation[#, "Charting`Private`Tag$5190#1"]& ]}, {}, {}}, {{{}, {}, 
         TagBox[
          {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
           Dashing[{0.02, 0.04}], LineBox[CompressedData["
1:eJwdkHs01HkYxmeY5G6+UVlkVaZUtIVmRmq9MmUj5UhbtNmybtHRutbqYo+2
329mllxKVLO6EePSIg3r9s5QU+lQbrMbXdV2aiW3iUhm7T7nPOc5n7+e5zwL
gw/6hWoxGIxNM/4v22z421p3T7s5/a9mFGnzb3Izp91CnJ5vtBhpQusVbVHq
Axq3TT4tc5rVCiywjPdfvYgB86yuq9brKTCqbEeBXg4DosNzXYLny/H+q0HF
XBYTNs+TqtNPNGJv4VO2RxITZu/qUma01iNvj8nVb94zoVKYWxLPq0P7mo+M
lEAtsEo4NtH58A9sz+NmPn6gBeNeH94o99Yge4XDQOR6bQiTnORXWVbjBWlo
anuRNhTnfGw6NHATVTdG9gQsYIEsTDo5KavCkh/4n8zELLAKMHmqzL+Bqy52
tAxrWCBkYrD410pktF5/ci1uFohco2PkVAVGXvKoT382C8QJRJ54qRx/0di3
nvPXAUlp9jiJ+B35rAfSPxU6wO2OehGjLEPJmds1XP5sKFllfjLIohS3zJ/W
jy6dDZI+7rMjacWY7TZo98hcFyYX/7V+eqUUT406/xR6Shey1zHT9t4pxIU+
TtmcKV1oXRnkiqJryDgXp24I14PE2nJlbHABpv+oSx16rAeDXUkqO6d8rBnY
8TJksz7wDtiJti69iplj47FxqA/+RcdHC8yuoGy4d2OgkwHwO32KJ+Zexvis
w6/iLxoAHHFnzl1zCfsa998sNzOEFvPeT8ckefhPhqmfTYohOO8KPlbP+g2/
3qFZHTFgCFVD3BKJ6AJuKHATtO8zgqiNggwz1nl8fp6/KLrNCBry3zualuai
gxXlaC8wBguOj42jdw6aeaQaW1caQ3L/Tq8U07Po+V2Xw5sFJlD/trZJPnwG
lzNjkjuzTCDLa5nV2runschbKRnRmAA/V8cyQZGF/Wx+4heubPg2r/TdnKpM
tPtQhpwENjgdf/Jqa20GOtozBr1L2OCZtEZwtC4dzaRHq7Ves8HbMflu61ga
Nh/uDu20ItAtL66YDEvFHPcHazL8CARgZQCMitHDdzTvSSqB3OFyVUSCCOsr
RgcEzQTSXdp6vrIV4l5zhx7eLQIc08L9idZCZCWHKZffJnCWMbW90VyI3lse
5bHvEGjOfujiZyTEnteN2x63ELAPXeIuHqNx3FJcEddBYJ1/x9jaezQ6UjYJ
V14QCOdm3pIcpFH1LmBfdh+By4lyW+NIGpO2n/YRviRwvECg+jmERoWNzpLo
vwmkvDewjwyg0beuX+XyloDnyt5zWzxojB6S8duHCNARfXzf+TTO2Tlke2t4
pi/EQKQiNMoalpHqEQKBgVmcIEMaP4slbyVqAhH6yRtimDSmclLOR3wkYPq9
i3ZhP4WrUuuo3RMEYjOqy3ivKewcUcdunSQg8Pryyr3nFFrIw72dpwhIk2PD
h7spbFxymbf0M4GuBgWPfkhhcFrPYovpmT/1mnyt71OoozZlG2lm9sVyKmW3
KZQG+kxpZlhmkbfbV07hv2aGHNI=
            "]]},
          Annotation[#, "Charting`Private`Tag$5145#1"]& ], 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwVj2s0lAkYgMeYhGTmC6eLWKxLuZ2omE6X7y1aU0NZle6l2cSyq+b7ZLHV
1LjENCmVrMsiky1UR4l0GG+lFJFFaQ26uFVbkzHIVMNs++M5z3l+PraC/UGh
TAaDEfCN/+0kyOxqatKSCbkJweokOS778Zizx99aMrj1fdGBI3IMhMi4jHYt
Oemv6lHFyDHWmpy5S6El+byeKeNhcnykGAwaeqMlLcVVTnPWyjF8g1cjoT9B
zn+216/aVI6XfZ9VBS+ZIN+8TswNzarBeU5m518VTZCHdlV6ws1qTNXnVnil
T5Iriyfca7tuo7XLk8jRX3RknUeBmElWYZFl9EYPOwYEsv34O+sqMfLqpiKj
TAYsMnQIubOyAh/3D921YOmBe43QQ6kqx65LLzg+8XrQP2wt3JdzA713smW8
j3qw9sOjmmDBdXSt0jDE25igeluR1x9Yhq15XundLUxILeH1lcRcQ46LmzJi
uT6UK698rU+/gjnFodLWy/rAZC/4UN5egh3l6p1brVjAdnJW/2pajKU/cb+a
S1gQoPMxFYsv4YL8tsZhHQsGxrxTB1RFyGi+1vMXPQXCSn0FFUcvYkSBT82p
l1MgWBiQaUXKMFHn2py10QAaeLKvUs0F5LJaip/fNYC4VXlLA7oKMPfcgyov
7lR4KSTy10Tno//MSeOoK1PBplMp9Bb8iRnk0LzOWYawd3eVOfdsDqaNLIoL
TTOEFyp3xxB5FtoGLMxw0BpC9QnhEY3dH8jIokflYUYgWebylCo+j6cOGCb/
1m0Ed1wlqR/nZ2CVclPf3jXGIDNz36FSnMX0T+MUjcbgqGks9D5+BiuHu1Zv
WzgNqodTtjxen47RZ2L7o/OnQaemoucheRp7a3+uKDM3AS9ZUZLP5jT897RZ
kI3YBFr6/Cs7oqW4YpPOI1xpAociE6qZtyW4qoj0bd0zHY7xA1+ox1LwVTbX
LurJdBAJBtrGIo+j29xkT1dfUyjMbvAnu5PQ3Edqan3DFLhWBYmzRYnot+Op
21srNjTGmNwcWZ6AznpCUfsZNjToSm42jB/Dy/z6XLWODS3U4qY+xVF8z+HG
zF7KAY2f/bBFtAjnjV1Fh4Mc+GS7ryxNcBg9XRlD/FIObOd12xud+x3Niw/d
Yg5yoDQ+dWp2bRzWxT4LbZ9LwO5L+13S7GMxc2XL4tNBBKxjp/tuKY1Bn8CR
vB4pAWYzyo5buB7EmusjSt86AhipjMHAHhpDZrkpvO8TUNjJNy55TiNLtK/e
+QEBJyZXNLLaaOT7d+ZxHhKQE86zxHoaFYO167sbCZActhn7oYzGcUvJdbqN
gPOiWXayBBo9k20OFr4mYLZStETiQmPHh617MnoJWLFqq9rCkcb4DWcDUvoI
SAuO4cpsaLxrY+AYNUDAY7wVcc+CxsDq9x1L3hHgVcbcbsagMUpVyW1VEeD5
Md5Q95TCGZtV9veHCdD0KkJkLRRWyucTt9Tffm0Pk2saKZyQ5L7LHSXALabp
ZBZSKHUQZ4drCHDnxQn8SyhcIK1O3v6ZgAi6+ZX2IoXt6lFq3RcCCmYMvb6W
T+GcO2H8RVoCvsvsjZiZQWGt4wVvpwkC7uE/w82nKBScVHw/Z5KA8d7+z0kS
Cg1GzTjTdQRID2SJySQKi7cFaHXfev94yokvIgr/A6QTZUA=
            "]]},
          Annotation[#, "Charting`Private`Tag$5145#2"]& ]}, {}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{1.73, -0.15},
      BaseStyle->(FontSize -> 8),
      DisplayFunction->Identity,
      Frame->{{True, False}, {True, False}},
      FrameLabel->{{
         FormBox["\"Utility\"", TraditionalForm], None}, {
         FormBox["\"Wealth\"", TraditionalForm], None}},
      FrameTicks->{{{{-0.09071795328941251, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"-0.0907\"", -0.09071795328941253, AutoDelete -> True], 
             NumberForm[#, 3]& ], TraditionalForm]}, {-0.04947385016921628, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"-0.0495\"", -0.04947385016921628, AutoDelete -> True], 
             NumberForm[#, 3]& ], TraditionalForm]}, {-0.02732372244729257, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"-0.0273\"", -0.027323722447292576`, AutoDelete -> True], 
             NumberForm[#, 3]& ], TraditionalForm]}, {-0.00822974704902003, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"-0.00823\"", -0.008229747049020032, AutoDelete -> True], 
             NumberForm[#, 3]& ], TraditionalForm]}}, {{-0.09071795328941251, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"-0.0907\"", -0.09071795328941253, AutoDelete -> True], 
             NumberForm[#, 3]& ], TraditionalForm]}, {-0.04947385016921628, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"-0.0495\"", -0.04947385016921628, AutoDelete -> True], 
             NumberForm[#, 3]& ], TraditionalForm]}, {-0.02732372244729257, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"-0.0273\"", -0.027323722447292576`, AutoDelete -> True], 
             NumberForm[#, 3]& ], TraditionalForm]}, {-0.00822974704902003, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"-0.00823\"", -0.008229747049020032, AutoDelete -> True], 
             NumberForm[#, 3]& ], TraditionalForm]}}}, {{{2, 
           FormBox["2", TraditionalForm]}, {2.5052591903383297`, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"2.505\"", 2.5052591903383297`, AutoDelete -> True], 
             NumberForm[#, 4]& ], TraditionalForm]}, {3, 
           FormBox["3", TraditionalForm]}, {4, 
           FormBox["4", TraditionalForm]}}, {{2, 
           FormBox["2", TraditionalForm]}, {2.5052591903383297`, 
           FormBox[
            TagBox[
             InterpretationBox[
             "\"2.505\"", 2.5052591903383297`, AutoDelete -> True], 
             NumberForm[#, 4]& ], TraditionalForm]}, {3, 
           FormBox["3", TraditionalForm]}, {4, 
           FormBox["4", TraditionalForm]}}}},
      GridLines->{{
        2, 2.5052591903383297`, 3, 
         4}, {-0.09071795328941253, -0.04947385016921628, \
-0.027323722447292576`, -0.008229747049020032}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        StyleBox[
        "\"Risk Aversion = 1.2\"", FontColor -> RGBColor[1, 0, 0], 
         StripOnInput -> False], TraditionalForm],
      PlotRange->{{1.73, 4.499999944897959}, {-0.15, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->500,
  PlotRangePadding->{6, 5}]], "Output",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.402658644734375*^9, 3.402699601766625*^9, 3.402786429454125*^9, 
   3.529698567072442*^9, {3.529701363458386*^9, 3.5297013674596148`*^9}, 
   3.5297900037953234`*^9, 3.5297931391670723`*^9, 3.529935128465434*^9, 
   3.529937325397092*^9, 3.530016404577162*^9, 3.5300167239144273`*^9, 
   3.530017186436882*^9, 3.5301936909016314`*^9, 3.5301942286233873`*^9, 
   3.5314482295447855`*^9, 3.5315006255466657`*^9, 3.5331347022482195`*^9, 
   3.533135880921636*^9, 3.53368225253125*^9, 3.5337345848756227`*^9, 
   3.533754143703125*^9, 3.5337554163125*^9, 3.5386852230911894`*^9, 
   3.5386855198811646`*^9, 3.5396359577931533`*^9, 3.5401268140964622`*^9, 
   3.5410126358492727`*^9, 3.5410151045144725`*^9, 3.541015573413292*^9, 
   3.5416004478171315`*^9, 3.543342195161417*^9, 3.696338461876787*^9, 
   3.696342374839411*^9, 3.6965443600276723`*^9, 
   3.731421193214756*^9},ExpressionUUID->"a5bd980e-2daf-4e7e-a1e5-\
5b5263d4a16b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"disc2", "=", 
   RowBox[{"3", "-", "w2"}]}], ";", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"TextCell", "[", 
    RowBox[{
     RowBox[{
     "\"\<Figure 6.14 shows that one with a risk aversion of 1.2 requires a \
discount of 3 - \>\"", "<>", 
      RowBox[{"ToString", "[", "w2", "]"}], "<>", "\"\< = \>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"NumberForm", "[", 
        RowBox[{"disc2", ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "3"}], "}"}]}], "]"}], "]"}], "<>", 
      "\"\<, slightly higher (\>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"disc2", "-", "disc1"}], "]"}], "<>", 
      "\"\<) than that calculated for the investor with a risk aversion of 1.\
\>\""}], ",", "\"\<Text\>\""}], "]"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5331366478185*^9, 3.5331368139660034`*^9}, {
   3.533136863953862*^9, 3.5331368660079794`*^9}, {3.533136896662733*^9, 
   3.533136926238425*^9}, 
   3.5386855198811646`*^9},ExpressionUUID->"afd35332-76b4-438e-ad92-\
2161b0eec94e"],

Cell["\<\
Figure 6.14 shows that one with a risk aversion of 1.2 requires a discount of \
3 - 2.50526 = 0.495, slightly higher (0.06096) than that calculated for the \
investor with a risk aversion of 1.\
\>", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.7314211932398252`*^9},ExpressionUUID->"2c53739a-a806-4736-b861-\
c84f89b7abaf"]
}, Open  ]],

Cell[TextData[{
 "A concave utility function means that people value different dollars \
differently. The coefficient of risk aversion tells us ",
 StyleBox["how much differently",
  FontSlant->"Italic"],
 " those dollars are valued by different people. This has important \
implications for the market for uncertain investments.  Such a market \
commands higher prices if populated by people with low coefficients of risk \
aversion as they require smaller discounts. Figure 6.15 provides the \
opportunity to adjust the coefficient of risk aversion, noting how different \
investors would \[OpenCurlyDoubleQuote]price\[CloseCurlyDoubleQuote] the risk \
by following the discounted price (on the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis in ",
 StyleBox["red",
  FontColor->RGBColor[1, 0, 0]],
 ") offered under each situation."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297789411705775`*^9, 3.5297789973287897`*^9}, {
   3.529779318440156*^9, 3.5297793385733075`*^9}, {3.5299376302535286`*^9, 
   3.529937640164095*^9}, 
   3.5386855198811646`*^9},ExpressionUUID->"2c2af842-3c63-441f-ba56-\
93d04eb4e64f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fct", "[", "w_", "]"}], "=", 
     RowBox[{"-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "a"}], " ", "w"}]]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"exp1", "=", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{".5", " ", 
        RowBox[{"fct", "[", "2", "]"}]}], " ", "+", " ", 
       RowBox[{".5", " ", 
        RowBox[{"fct", "[", "4", "]"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"exp2", "=", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{".5", " ", 
        RowBox[{"fct", "[", "2", "]"}]}], " ", "+", " ", 
       RowBox[{".5", " ", 
        RowBox[{"fct", "[", "4", "]"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"w1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "w"}], "\[Equal]", 
          RowBox[{"Log", "[", 
           RowBox[{"-", "exp1"}], "]"}]}], ",", "w"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"w2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "w"}], "\[Equal]", 
          RowBox[{"Log", "[", 
           RowBox[{"-", "exp2"}], "]"}]}], ",", "w"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"intercept", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"fct", "[", "2", "]"}], "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{"2", " ", 
            FractionBox[
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{"fct", "[", "4", "]"}], "]"}], "-", 
              RowBox[{"N", "[", 
               RowBox[{"fct", "[", "2", "]"}], "]"}]}], "2"]}], "+", "b"}]}], 
         ",", "b"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"neutral", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"fct", "[", "4", "]"}], "]"}], "-", 
           RowBox[{"N", "[", 
            RowBox[{"fct", "[", "2", "]"}], "]"}]}], "2"], " ", "x"}], "+", 
        "intercept"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1.8", ",", "4.5"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"averse", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "a"}], " ", "w"}]]}], ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", "1.8", ",", "4.5"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{"neutral", ",", "averse", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1.73", ",", 
         RowBox[{"-", ".15"}]}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
      ",", 
      RowBox[{"FrameLabel", "->", 
       RowBox[{"{", 
        RowBox[{"\"\<Wealth\>\"", ",", "\"\<Utility\>\""}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", ".15"}], ",", "0"}], "}"}]}], ",", 
      RowBox[{"FrameTicks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", 
           RowBox[{"{", 
            RowBox[{"w2", ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"NumberForm", "[", 
                RowBox[{
                 RowBox[{"N", "[", "w2", "]"}], ",", "4"}], "]"}], ",", 
               "Red"}], "]"}]}], "}"}], ",", "3", ",", "4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fct", "[", "2", "]"}], ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"N", "[", 
                RowBox[{"fct", "[", "2", "]"}], "]"}], ",", "3"}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"exp2", ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{"exp2", ",", "3"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fct", "[", "3", "]"}], ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"N", "[", 
                RowBox[{"fct", "[", "3", "]"}], "]"}], ",", "3"}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fct", "[", "4", "]"}], ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"N", "[", 
                RowBox[{"fct", "[", "4", "]"}], "]"}], ",", "3"}], "]"}]}], 
            "}"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "w2", ",", "3", ",", "4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"fct", "[", "2", "]"}], "]"}], ",", "exp2", ",", 
           RowBox[{"N", "[", 
            RowBox[{"fct", "[", "3", "]"}], "]"}], ",", 
           RowBox[{"N", "[", 
            RowBox[{"fct", "[", "4", "]"}], "]"}]}], "}"}]}], "}"}]}]}], 
     "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "1.2", ",", "\"\<Coefficient of Risk Aversion\>\""}], 
      "}"}], ",", "1", ",", "1.5", ",", ".1", ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"SynchronousUpdating", "\[Rule]", "False"}], ",", 
   RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
    RowBox[{"{", "a", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5297636969336567`*^9, 3.5297637081152964`*^9}, {
   3.5297637537539067`*^9, 3.5297638245459557`*^9}, {3.5297638793540907`*^9, 
   3.5297639370843925`*^9}, {3.5297639737634907`*^9, 
   3.5297639791808004`*^9}, {3.529764017075968*^9, 3.5297640576832905`*^9}, {
   3.529764331399946*^9, 3.529764334070099*^9}, {3.5297646576516066`*^9, 
   3.529764848255509*^9}, 3.5297648834905243`*^9, {3.529764929098133*^9, 
   3.52976493219731*^9}, {3.5297654643427467`*^9, 3.529765532430641*^9}, {
   3.5297657358252745`*^9, 3.5297658050542345`*^9}, {3.529765839842224*^9, 
   3.5297659303133993`*^9}, {3.5297660599458137`*^9, 3.529766067023218*^9}, 
   3.529766145119685*^9, {3.529766205732152*^9, 3.529766216763783*^9}, {
   3.5297662575271144`*^9, 3.5297662762341843`*^9}, {3.5297663297302446`*^9, 
   3.5297664295589542`*^9}, {3.5297664631278744`*^9, 3.529766471535355*^9}, {
   3.5297668997098455`*^9, 3.5297669148377104`*^9}, {3.529766964687562*^9, 
   3.5297669700698695`*^9}, {3.5297670713896646`*^9, 
   3.5297670849224386`*^9}, {3.5297672027881804`*^9, 
   3.5297672493168416`*^9}, {3.5297674501993313`*^9, 
   3.5297675137639675`*^9}, {3.5297675465828447`*^9, 3.529767547007869*^9}, {
   3.5297790682858477`*^9, 3.52977919735023*^9}, {3.5297792539894695`*^9, 
   3.529779299290061*^9}, {3.5299377088580246`*^9, 3.529937709077037*^9}, 
   3.538685519882165*^9},ExpressionUUID->"e73b7af7-9297-4da8-8358-\
f758eb226987"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1.2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 1.2, "Coefficient of Risk Aversion"}, 1, 1.5, 
      0.1}}, Typeset`size$$ = {540., {161., 168.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`a$5348$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 1.2}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$5348$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`fct[
          Pattern[$CellContext`w$, 
           Blank[]]] = -
         E^((-$CellContext`a$$) $CellContext`w$); $CellContext`exp1 = 
        N[0.5 $CellContext`fct[2] + 
          0.5 $CellContext`fct[4]]; $CellContext`exp2 = 
        N[0.5 $CellContext`fct[2] + 0.5 $CellContext`fct[4]]; $CellContext`w1 = 
        Part[
          Part[
           
           Solve[(-$CellContext`a$$) $CellContext`w == 
            Log[-$CellContext`exp1], $CellContext`w], 1, 1], 
          2]; $CellContext`w2 = Part[
          Part[
           
           Solve[(-$CellContext`a$$) $CellContext`w == 
            Log[-$CellContext`exp2], $CellContext`w], 1, 1], 
          2]; $CellContext`intercept = Part[
          Part[
           Solve[N[
              $CellContext`fct[2]] == 2 ((N[
                  $CellContext`fct[4]] - N[
                 $CellContext`fct[2]])/2) + $CellContext`b, $CellContext`b], 
           1, 1], 2]; $CellContext`neutral = Plot[((N[
               $CellContext`fct[4]] - N[
              $CellContext`fct[2]])/
            2) $CellContext`x + $CellContext`intercept, {$CellContext`x, 1.8, 
           4.5}]; $CellContext`averse = 
        Plot[-E^((-$CellContext`a$$) $CellContext`w), {$CellContext`w, 1.8, 
           4.5}]; Show[$CellContext`neutral, $CellContext`averse, 
         AxesOrigin -> {1.73, -0.15}, Frame -> {True, True, False, False}, 
         FrameLabel -> {"Wealth", "Utility"}, PlotRange -> {-0.15, 0}, 
         FrameTicks -> {{2, {$CellContext`w2, 
             Style[
              NumberForm[
               N[$CellContext`w2], 4], Red]}, 3, 4}, {{
             $CellContext`fct[2], 
             NumberForm[
              N[
               $CellContext`fct[2]], 3]}, {$CellContext`exp2, 
             NumberForm[$CellContext`exp2, 3]}, {
             $CellContext`fct[3], 
             NumberForm[
              N[
               $CellContext`fct[3]], 3]}, {
             $CellContext`fct[4], 
             NumberForm[
              N[
               $CellContext`fct[4]], 3]}}}, 
         GridLines -> {{2, $CellContext`w2, 3, 4}, {
            N[
             $CellContext`fct[2]], $CellContext`exp2, 
            N[
             $CellContext`fct[3]], 
            N[
             $CellContext`fct[4]]}}]), 
      "Specifications" :> {{{$CellContext`a$$, 1.2, 
          "Coefficient of Risk Aversion"}, 1, 1.5, 0.1, ControlType -> 
         PopupMenu}}, 
      "Options" :> {
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`a$$}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{610., {230., 238.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`exp1 = -0.07682546106267345, \
$CellContext`exp2 = -0.04947385016921628, $CellContext`w1 = 
       2.5662191695169727`, $CellContext`w2 = 2.5052591903383297`}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297658556331277`*^9, 3.5297659311984496`*^9}, 
   3.5297659972152257`*^9, 3.5297660714824734`*^9, 3.5297664830850153`*^9, {
   3.529766903866083*^9, 3.529766915644757*^9}, 3.52976697147295*^9, {
   3.529767080154166*^9, 3.529767086284517*^9}, {3.5297672270725694`*^9, 
   3.529767252737037*^9}, {3.529767459051838*^9, 3.5297675147010207`*^9}, 
   3.5297675476659064`*^9, 3.529779016307875*^9, 3.5297790762673044`*^9, {
   3.5297791501395297`*^9, 3.529779197729252*^9}, 3.529779265588133*^9, 
   3.529779300406124*^9, 3.529790003996335*^9, 3.529793140401143*^9, 
   3.529935129561497*^9, 3.5299373255360994`*^9, 3.529937711608182*^9, 
   3.5300164048251762`*^9, 3.5300167242294455`*^9, 3.530017186837905*^9, 
   3.5301936911166434`*^9, 3.530194229672447*^9, 3.531448229709795*^9, 
   3.5315006256996746`*^9, 3.5331347035732956`*^9, 3.533135881061644*^9, {
   3.5331370463912973`*^9, 3.53313706934661*^9}, 3.53368225275*^9, 
   3.5337345857766743`*^9, 3.533754143921875*^9, 3.53375541653125*^9, 
   3.5386852238962355`*^9, 3.5386855199291677`*^9, 3.5396359579531627`*^9, 
   3.5401268150245156`*^9, 3.5410126367713256`*^9, 3.5410151054635267`*^9, 
   3.541015575321401*^9, 3.541600448745185*^9, 3.5433421963024826`*^9, 
   3.6963384620011415`*^9, 3.6963423749476967`*^9, 3.696544360118889*^9, 
   3.7314211932989817`*^9},
 TextAlignment->Center,ExpressionUUID->"f91c5bba-cacf-4bba-b009-5887115fc00d"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.15.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "A range of risk aversion functions."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315004549259067`*^9}, 
   3.5386855199291677`*^9},
 TextAlignment->Center,ExpressionUUID->"eef8b7e6-0ed7-4bb3-ac36-0f803b813894"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.7. Multiple (more than two) outcomes", "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531447172614333*^9, 3.5314481420907836`*^9, 
  3.5386855199291677`*^9},ExpressionUUID->"07d4e33e-096b-4bbf-9f3e-\
2fb72dad96f2"],

Cell[TextData[{
 "Returning to our first utility function (",
 StyleBox["u[w] = Log[w]",
  FontSlant->"Italic"],
 ") we can extend this result to more than two outcomes, each with different \
probabilities. In Table 6.4 we define some payoffs under different conditions \
(numbers can represent thousands or millions of dollars to make them more \
realistic):"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5299378415416136`*^9, 3.5299378468049145`*^9}, 
   3.5386855199291677`*^9, 
   3.5410137566043763`*^9},ExpressionUUID->"07f1e601-f992-4771-8608-\
cc859ebde579"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"payoff1", "=", 
   RowBox[{"{", 
    RowBox[{"35", ",", "65", ",", "20", ",", "80", ",", "95"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prob1", "=", 
   RowBox[{"{", 
    RowBox[{".15", ",", ".25", ",", ".1", ",", ".45", ",", ".05"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prods", "=", 
   RowBox[{"payoff1", " ", "prob1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sums", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<\>\"", ",", 
     RowBox[{"Plus", "@@", "prob1"}], ",", 
     RowBox[{"Plus", "@@", "prods"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"NumberForm", "[", 
    RowBox[{
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"payoff1", ",", "prob1", ",", "prods"}], "}"}], "]"}], ",", 
         RowBox[{"{", "sums", "}"}]}], "]"}], ",", 
       RowBox[{"TableHeadings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", 
            ",", "\"\<\>\"", ",", "\"\<sums\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<payoffs\>\"", ",", "\"\<probabilities\>\"", ",", 
            "\"\<products\>\""}], "}"}]}], "}"}]}], ",", 
       RowBox[{"TableAlignments", "\[Rule]", "\"\<.\>\""}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5297023493227744`*^9, 3.5297023935003014`*^9}, {
   3.529702440110967*^9, 3.529702494972105*^9}, {3.5297025639260488`*^9, 
   3.5297027129095707`*^9}, {3.5297027495096636`*^9, 3.529702775775166*^9}, {
   3.52970281990469*^9, 3.5297028637651987`*^9}, {3.529702894767972*^9, 
   3.5297029950077057`*^9}, {3.529703042095399*^9, 3.529703169408681*^9}, {
   3.5297032151252956`*^9, 3.529703249696273*^9}, {3.5297032820751247`*^9, 
   3.5297034295075574`*^9}, {3.5297034596502814`*^9, 3.529703636005368*^9}, {
   3.529703669936309*^9, 3.529703670088318*^9}, {3.529703825482206*^9, 
   3.5297038544298615`*^9}, {3.5297038913529735`*^9, 
   3.5297039876494813`*^9}, {3.529704025064621*^9, 3.5297044061984205`*^9}, {
   3.5297044474897823`*^9, 3.529704488693139*^9}, {3.5331370927189465`*^9, 
   3.533137116268294*^9}, 
   3.5386855199291677`*^9},ExpressionUUID->"961cee79-f591-4541-81d4-\
be113cd0221c"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        StyleBox["\[Null]",
         ShowStringCharacters->False], 
        TagBox["\<\"payoffs\"\>",
         HoldForm], 
        TagBox["\<\"probabilities\"\>",
         HoldForm], 
        TagBox["\<\"products\"\>",
         HoldForm]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"35\"\>",
         35,
         Editable->False], 
        InterpretationBox["\<\"0.15\"\>",
         0.15,
         AutoDelete->True], 
        InterpretationBox["\<\"5.25\"\>",
         5.25,
         AutoDelete->True]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"65\"\>",
         65,
         Editable->False], 
        InterpretationBox["\<\"0.25\"\>",
         0.25,
         AutoDelete->True], 
        InterpretationBox["\<\"16.25\"\>",
         16.25,
         AutoDelete->True]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"20\"\>",
         20,
         Editable->False], 
        InterpretationBox["\<\"0.10\"\>",
         0.1,
         AutoDelete->True], 
        InterpretationBox["\<\"2.00\"\>",
         2.,
         AutoDelete->True]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"80\"\>",
         80,
         Editable->False], 
        InterpretationBox["\<\"0.45\"\>",
         0.45,
         AutoDelete->True], 
        InterpretationBox["\<\"36.00\"\>",
         36.,
         AutoDelete->True]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"95\"\>",
         95,
         Editable->False], 
        InterpretationBox["\<\"0.05\"\>",
         0.05,
         AutoDelete->True], 
        InterpretationBox["\<\"4.75\"\>",
         4.75,
         AutoDelete->True]},
       {
        TagBox["\<\"sums\"\>",
         HoldForm], "\<\"\"\>", 
        InterpretationBox["\<\"1.00\"\>",
         1.,
         AutoDelete->True], 
        InterpretationBox["\<\"64.25\"\>",
         64.25,
         AutoDelete->True]}
      },
      GridBoxAlignment->{
       "Columns" -> {{"."}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, 
      TableHeadings -> {{"", "", "", "", "", "sums"}, {
        "payoffs", "probabilities", "products"}}, TableAlignments -> "."]]],
   NumberForm[#, {4, 2}]& ],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.5331371169123306`*^9, 3.533682253015625*^9, 
  3.5337345863427067`*^9, 3.533754144078125*^9, 3.533755416703125*^9, 
  3.5386852246252766`*^9, 3.5386855199291677`*^9, 3.539635958040168*^9, 
  3.5401268159415684`*^9, 3.5410126375103683`*^9, 3.5410151063305764`*^9, 
  3.5410155760554433`*^9, 3.541600449430224*^9, 3.543342196984522*^9, 
  3.6963384621184273`*^9, 3.696342375024867*^9, 3.6965443601880713`*^9, 
  3.731421193373179*^9},
 TextAlignment->Center,ExpressionUUID->"e73c2142-d6a0-4f29-ba6a-39bbba263454"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table 6.4.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "TableTitleLabel"],
 "Expected value of five payoffs"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{88.66666666666666, 10.}, {1., 7.}},
 CellChangeTimes->{
  3.5314998749897366`*^9, {3.5314999150800295`*^9, 3.531499944359704*^9}, 
   3.5315000365879793`*^9, 3.5386855199291677`*^9},
 TextAlignment->Center,ExpressionUUID->"6d36c9d9-0280-45fd-a029-c8cf84067088"],

Cell[TextData[{
 "We then associate a specific probability with each payoff. Note the \
important fact that they add up to 1. Where did these probabilities come \
from? Quite simply, we made them up!! (Alert readers will recognize these \
numbers from the discussion of Jensen's Inequality in Chapter 5). These are ",
 StyleBox["subjective",
  FontSlant->"Italic"],
 " probabilities, what we think or feel will happen. Objective probability \
comes, in part, from understanding large numbers representing what ",
 StyleBox["has",
  FontSlant->"Italic"],
 " happened. Five outcomes is certainly not a large number of possible \
outcomes, but we are approaching these ideas in increments."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199291677`*^9},ExpressionUUID->"a59d03e5-ad72-4d44-804f-\
f33fbf363455"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"exp5", "=", 
   RowBox[{"payoff1", ".", "prob1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uexp", "=", 
   RowBox[{"u", "[", "exp5", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"expu", "=", 
   RowBox[{"prob1", ".", 
    RowBox[{"N", "[", 
     RowBox[{"u", "[", "payoff1", "]"}], "]"}]}]}], ";", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"TextCell", "[", 
    RowBox[{
     RowBox[{
     "\"\<Multiplying the payoffs and the probabilities together and adding \
them up (the 'dot product' of two vectors in matrix algebra), we arrive at \
the expectation (note that this is the same as the sum in the lower right of \
Table 6.4) of \>\"", "<>", 
      RowBox[{"ToString", "[", "exp5", "]"}], "<>", 
      "\"\<, making the utility, based on our original log utility function, \
\>\"", "<>", 
      RowBox[{"ToString", "[", "uexp", "]"}], "<>", 
      "\"\<. We then compute the utility of each payoff, \>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"N", "[", 
        RowBox[{"u", "[", "payoff1", "]"}], "]"}], "]"}], "<>", 
      "\"\< and take the expectation \>\"", "<>", 
      RowBox[{"ToString", "[", "expu", "]"}], "<>", 
      "\"\< to conclude, not surprisingly, that the utility of the \
expectation is greater than the  expectation of the utility.\>\""}], ",", 
     "\"\<Text\>\""}], "]"}], "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.533137170560399*^9, 3.5331373211200104`*^9}, {
   3.533137354521921*^9, 3.5331375218854933`*^9}, 
   3.538685519930167*^9},ExpressionUUID->"51ff80e2-7d51-4a17-9524-\
5a4595a05e35"],

Cell["\<\
Multiplying the payoffs and the probabilities together and adding them up \
(the 'dot product' of two vectors in matrix algebra), we arrive at the \
expectation (note that this is the same as the sum in the lower right of \
Table 6.4) of 64.25, making the utility, based on our original log utility \
function, 4.16278. We then compute the utility of each payoff, {3.55535, \
4.17439, 2.99573, 4.38203, 4.55388} and take the expectation 4.07608 to \
conclude, not surprisingly, that the utility of the expectation is greater \
than the  expectation of the utility.\
\>", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731421193395237*^9},ExpressionUUID->"6c33e0ca-126c-4376-ab63-\
cda2236a243e"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"E", "(", "w", ")"}], "]"}], ">", 
   RowBox[{
    RowBox[{"E", "[", 
     RowBox[{"U", "(", "w", ")"}], "]"}], "\[DoubleLongLeftRightArrow]", 
    "4.16278"}], ">", "4.07608"}], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5297022705682697`*^9, {3.529705083532162*^9, 3.529705094954816*^9}, 
   3.538685519930167*^9},ExpressionUUID->"d4709be6-b89e-45c5-929e-\
7b393875a09c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uexp", "\[GreaterEqual]", "expu"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519930167*^9},ExpressionUUID->"a371506e-1fdf-4c2c-9923-\
5f2502384fee"],

Cell[BoxData["True"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658644890625*^9, 3.40269960271975*^9, 
  3.529698570467636*^9, 3.5297022487800236`*^9, 3.529790004453361*^9, 
  3.5297931412711926`*^9, 3.529935131764623*^9, 3.529937325794114*^9, 
  3.5300164054122095`*^9, 3.530016724817479*^9, 3.5300171873419333`*^9, 
  3.5301936915506682`*^9, 3.530194232603615*^9, 3.5314482299868107`*^9, 
  3.5315006260146923`*^9, 3.53313470609644*^9, 3.533135881318659*^9, 
  3.533682253203125*^9, 3.53373458727676*^9, 3.533754144328125*^9, 
  3.53375541696875*^9, 3.5386852261513643`*^9, 3.538685519930167*^9, 
  3.5396359581791754`*^9, 3.5401268175116577`*^9, 3.541012638926449*^9, 
  3.541015107761658*^9, 3.5410155794136353`*^9, 3.5416004507863016`*^9, 
  3.543342198147588*^9, 3.6963384621906195`*^9, 3.69634237508603*^9, 
  3.6965443602542477`*^9, 
  3.7314211934263487`*^9},ExpressionUUID->"06386e7e-7512-4724-bee6-\
1fb0d6e29c9e"]
}, Open  ]],

Cell["Table 6.5 summarizes the utility calculations above", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297050060507307`*^9, 3.5297050163973227`*^9}, {
   3.5297051030152764`*^9, 3.5297051047923784`*^9}, 
   3.538685519930167*^9},ExpressionUUID->"3a709367-181f-4206-a671-\
84afa4b1bd80"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"prodsU", "=", 
   RowBox[{
    RowBox[{"N", "[", 
     RowBox[{"u", "[", "payoff1", "]"}], "]"}], " ", "prob1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sums", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<\>\"", ",", 
     RowBox[{"Plus", "@@", "prob1"}], ",", 
     RowBox[{"Plus", "@@", "prodsU"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"NumberForm", "[", 
    RowBox[{
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"N", "[", 
             RowBox[{"u", "[", "payoff1", "]"}], "]"}], ",", "prob1", ",", 
            "prodsU"}], "}"}], "]"}], ",", 
         RowBox[{"{", "sums", "}"}]}], "]"}], ",", 
       RowBox[{"TableHeadings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", 
            ",", "\"\<\>\"", ",", "\"\<sums\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<U(payoffs)\>\"", ",", "\"\<probabilities\>\"", ",", 
            "\"\<products\>\""}], "}"}]}], "}"}]}], ",", 
       RowBox[{"TableAlignments", "\[Rule]", "\"\<.\>\""}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "4"}], "}"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.5297023493227744`*^9, 3.5297023935003014`*^9}, {
   3.529702440110967*^9, 3.529702494972105*^9}, {3.5297025639260488`*^9, 
   3.5297027129095707`*^9}, {3.5297027495096636`*^9, 3.529702775775166*^9}, {
   3.52970281990469*^9, 3.5297028637651987`*^9}, {3.529702894767972*^9, 
   3.5297029950077057`*^9}, {3.529703042095399*^9, 3.529703169408681*^9}, {
   3.5297032151252956`*^9, 3.529703249696273*^9}, {3.5297032820751247`*^9, 
   3.5297034295075574`*^9}, {3.5297034596502814`*^9, 3.529703636005368*^9}, {
   3.529703669936309*^9, 3.529703670088318*^9}, {3.529703825482206*^9, 
   3.5297038544298615`*^9}, {3.5297038913529735`*^9, 
   3.5297039876494813`*^9}, {3.529704025064621*^9, 3.5297044061984205`*^9}, {
   3.5297044474897823`*^9, 3.529704488693139*^9}, {3.5297048254794025`*^9, 
   3.5297049247840824`*^9}, {3.533137735803729*^9, 3.5331377524816833`*^9}, 
   3.538685519930167*^9},ExpressionUUID->"90e7ad97-33ac-4ca5-b62c-\
a86cc88ad045"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        StyleBox["\[Null]",
         ShowStringCharacters->False], 
        TagBox["\<\"U(payoffs)\"\>",
         HoldForm], 
        TagBox["\<\"probabilities\"\>",
         HoldForm], 
        TagBox["\<\"products\"\>",
         HoldForm]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"3.5553\"\>",
         3.5553480614894135`,
         AutoDelete->True], 
        InterpretationBox["\<\"0.1500\"\>",
         0.15,
         AutoDelete->True], 
        InterpretationBox["\<\"0.5333\"\>",
         0.533302209223412,
         AutoDelete->True]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"4.1744\"\>",
         4.174387269895637,
         AutoDelete->True], 
        InterpretationBox["\<\"0.2500\"\>",
         0.25,
         AutoDelete->True], 
        InterpretationBox["\<\"1.0436\"\>",
         1.0435968174739092`,
         AutoDelete->True]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"2.9957\"\>",
         2.995732273553991,
         AutoDelete->True], 
        InterpretationBox["\<\"0.1000\"\>",
         0.1,
         AutoDelete->True], 
        InterpretationBox["\<\"0.2996\"\>",
         0.2995732273553991,
         AutoDelete->True]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"4.3820\"\>",
         4.382026634673881,
         AutoDelete->True], 
        InterpretationBox["\<\"0.4500\"\>",
         0.45,
         AutoDelete->True], 
        InterpretationBox["\<\"1.9719\"\>",
         1.9719119856032465`,
         AutoDelete->True]},
       {
        TagBox["\<\"\"\>",
         HoldForm], 
        InterpretationBox["\<\"4.5539\"\>",
         4.553876891600541,
         AutoDelete->True], 
        InterpretationBox["\<\"0.0500\"\>",
         0.05,
         AutoDelete->True], 
        InterpretationBox["\<\"0.2277\"\>",
         0.22769384458002706`,
         AutoDelete->True]},
       {
        TagBox["\<\"sums\"\>",
         HoldForm], "\<\"\"\>", 
        InterpretationBox["\<\"1.0000\"\>",
         1.,
         AutoDelete->True], 
        InterpretationBox["\<\"4.0761\"\>",
         4.076078084235994,
         AutoDelete->True]}
      },
      GridBoxAlignment->{
       "Columns" -> {{"."}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, 
      TableHeadings -> {{"", "", "", "", "", "sums"}, {
        "U(payoffs)", "probabilities", "products"}}, TableAlignments -> "."]]],
   NumberForm[#, {8, 4}]& ],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531500626177702*^9, 3.531500674539468*^9, 
  3.5331347067124753`*^9, 3.5331358813586607`*^9, 3.533137753200724*^9, 
  3.533682253296875*^9, 3.5337345876007786`*^9, 3.533754144421875*^9, 
  3.533755417046875*^9, 3.5386852264873834`*^9, 3.538685519930167*^9, 
  3.5396359582511797`*^9, 3.540126817998686*^9, 3.5410126395974874`*^9, 
  3.541015108261687*^9, 3.5410155799406652`*^9, 3.5416004514823413`*^9, 
  3.5433421988326273`*^9, 3.6963384622136807`*^9, 3.6963423750990653`*^9, 
  3.696544360287381*^9, 3.731421193450385*^9},
 TextAlignment->Center,ExpressionUUID->"f5ad8cce-0511-4f9b-9108-0de9874fe127"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table 6.5.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "TableTitleLabel"],
 "Expected utility of five payoffs"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{98, 10}, {1, 7}},
 CellChangeTimes->{
  3.5314998749897366`*^9, {3.5314999150800295`*^9, 3.531499944359704*^9}, {
   3.5315000365879793`*^9, 3.5315000550070324`*^9}, 3.5386855199311676`*^9},
 TextAlignment->Center,ExpressionUUID->"feb1bb7c-39ab-460a-925b-afc7802f7028"],

Cell[TextData[{
 "So far we have been working with discrete outcomes matched by given \
probabilities.  Essentially we claim to know the range of possibilities \
represented by a ",
 StyleBox["discrete",
  FontSlant->"Italic"],
 " probability distribution. The claim that we ",
 StyleBox["know",
  FontSlant->"Italic"],
 " these precise probabilities is ambitious to say the least."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199311676`*^9},ExpressionUUID->"8a46827e-20e7-4b35-8e51-\
b34f4bed4988"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "6.8. The continuous ",
 StyleBox["normal",
  FontVariations->{"Underline"->True}],
 " case"
}], "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.531447172614333*^9, 3.5314481601188145`*^9, {3.5337347702092233`*^9, 
   3.5337347703172293`*^9}, 
   3.5386855199311676`*^9},ExpressionUUID->"eb1be7dc-b395-40e4-87d3-\
a8f97a2b93ff"],

Cell[TextData[{
 "The final step for this chapter is to imagine a very large number of \
possible payoffs and an equally large number of associated specific \
probabilities. What can one say about those circumstances?  The limit of this \
question is the notion of a",
 StyleBox[" ", "MLHText"],
 "probability",
 StyleBox[" ", "MLHText"],
 "distribution and the related concept of a probability density function (",
 StyleBox["pdf",
  FontSlant->"Italic"],
 "). ",
 StyleBox["Recall from Chapter 3 that ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["pdf",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["s arise from histograms which are merely ordered groups of \
outcomes. In this case we assume that we know the result of investing in many \
buildings (the payoffs) by many investors with different utility functions \
and coefficients of risk ",
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   RowBox[{"aversion", 
    SuperscriptBox[".", 
     ButtonBox["8",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote8"]]}], TraditionalForm]],ExpressionUUID->
  "6a83ffb0-00cc-4563-8333-8a52a552c508"],
 StyleBox[" Properly arranged and processed, such data would produce a ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["pdf",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[".  Alternatively, if we choose a convenient specific \
distributional form, we can postulate that a large number of payoffs \
resulting from an equally large number of associated probabilities would \
produce outcomes such as those described in Figure 6.16.",
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297052620113707`*^9, 3.5297052634244514`*^9}, 
   3.529705307698984*^9, {3.52971072157664*^9, 3.5297107447469654`*^9}, {
   3.5299379037641726`*^9, 3.529937908809461*^9}, {3.5299387537057867`*^9, 
   3.5299388242428207`*^9}, {3.5386855199311676`*^9, 
   3.5386855199331675`*^9}},ExpressionUUID->"6c6d637b-9da2-4b67-a73f-\
c132407609cc"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a function that specifies a probability density function (when one \
exists) for a continuous variable when one knows something about the \
distribution. In our case the variable, ",
 StyleBox["w",
  FontSlant->"Italic"],
 ", will be different wealth levels arising from undertaking different \
propositions with uncertain outcomes. The easiest distribution to work with \
is the normal distribution because it can be completely described if one only \
knows its first two moments, its mean and its ",
 Cell[BoxData[
  FormBox[
   RowBox[{"variance", 
    SuperscriptBox[".", 
     ButtonBox["9",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote9"]]}], TraditionalForm]],ExpressionUUID->
  "a5d7e5bb-51b3-46c2-845f-c18c0c17483e"],
 "  So we assume we know these two parameters, therefore its shape. (Beware: \
this claim is a little less ambitious than the one we made above in the \
discrete case but still requires a leap of faith). Equation 6.11 defines the \
probability density function of the normal distribution when the mean is \
$1,000,000 and the standard deviation is $200,000"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297052620113707`*^9, 3.5297052634244514`*^9}, {
  3.529705307698984*^9, 3.529705339683813*^9}, {3.529705376791936*^9, 
  3.529705379162071*^9}, {3.529705461973808*^9, 3.5297054827779975`*^9}, {
  3.5297055426354218`*^9, 3.529705571786089*^9}, {3.5297109344938183`*^9, 
  3.529710955495019*^9}, {3.5299379236443095`*^9, 3.529937937166083*^9}, {
  3.529938834815426*^9, 3.529938854617558*^9}, {3.5386855199331675`*^9, 
  3.538685519934168*^9}, {3.5396301969606524`*^9, 3.5396301977736993`*^9}, {
  3.5410137979367404`*^9, 
  3.5410138122365584`*^9}},ExpressionUUID->"1172e52c-7220-48f5-b44c-\
fff379d2831e"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    SubscriptBox["pdf", "1"], "=", 
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1000000"}], "+", "w"}], ")"}], "2"], 
        "80000000000"]}]], 
     RowBox[{"200000", " ", 
      SqrtBox[
       RowBox[{"2", " ", "\[Pi]"}]]}]]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297054237296205`*^9, 3.5297054296939616`*^9}, {
   3.5297065459268064`*^9, 3.5297065464108343`*^9}, 
   3.538685519934168*^9},ExpressionUUID->"18d4bc9f-3d1c-4140-8a9a-\
1f2336c0ffb7"],

Cell[TextData[{
 "Note the second parameter in the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " input statement - the standard deviation - is in ",
 StyleBox["color ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "in the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 "input line to distinguish it as it will change in a subsequent example."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199351673`*^9, {3.538753749280663*^9, 3.538753749730689*^9}, {
   3.539630351237477*^9, 
   3.5396303585288935`*^9}},ExpressionUUID->"cbbeb256-f1da-45d2-a383-\
8c689b729ea0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pdw1", "=", 
  RowBox[{"PDF", "[", 
   RowBox[{
    RowBox[{"NormalDistribution", "[", 
     RowBox[{
      SuperscriptBox["10", "6"], ",", 
      StyleBox[
       RowBox[{"2", " ", 
        SuperscriptBox["10", "5"]}],
       FontColor->RGBColor[1, 0, 0]]}], "]"}], ",", "w"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199351673`*^9, {3.54101387450412*^9, 3.541013888878942*^9}, {
   3.5410141764823923`*^9, 
   3.5410141773134394`*^9}},ExpressionUUID->"d107a633-ab90-406c-92af-\
b7668f774518"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1000000"}], "+", "w"}], ")"}], "2"], "80000000000"]}]], 
  RowBox[{"200000", " ", 
   SqrtBox[
    RowBox[{"2", " ", "\[Pi]"}]]}]]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.402658645140625*^9, 3.402699602860375*^9, 3.5296985710186677`*^9, 
   3.5297900045963693`*^9, 3.5297931421352425`*^9, 3.529935133477721*^9, 
   3.529937325876119*^9, 3.5300164055712185`*^9, 3.530016724973488*^9, 
   3.530017187497943*^9, 3.530193691668675*^9, 3.530194233380659*^9, 
   3.5301946194777427`*^9, 3.5301947094618893`*^9, 3.5314482300738163`*^9, 
   3.5315006263327103`*^9, 3.533134707342511*^9, 3.5331358813986635`*^9, 
   3.53368225340625*^9, 3.5337345880938067`*^9, 3.533754144515625*^9, 
   3.53375541715625*^9, 3.5386852270544157`*^9, 3.5386855199351673`*^9, 
   3.5396359583881874`*^9, 3.540126818724727*^9, 3.541012640211522*^9, {
   3.5410138841086693`*^9, 3.541013889958004*^9}, 3.541014178119486*^9, 
   3.54101510884772*^9, 3.5410155806057034`*^9, 3.541600452173381*^9, 
   3.543342199646674*^9, 3.6963384627821937`*^9, 3.6963423756455455`*^9, 
   3.6965443608227606`*^9, 
   3.7314211934834933`*^9},ExpressionUUID->"aa1f22db-850c-4f77-aa75-\
da60010f392a"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "In the case of discrete outcomes the expectation is the result of simply \
multiplying the outcome times the probabilities and adding up the products as \
we did in ",
 StyleBox["Table 6.4",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 "and ",
 StyleBox["Table 6.5",
  FontFamily->"Times New Roman"],
 ". For continuous variables the expectation is the mean. Having the ",
 StyleBox["pdf",
  FontSlant->"Italic"],
 " we can plot this function and its central moment, the mean, also known as \
its expectation. The amount of probability mass around the mean but away from \
the mean represents the variance from our expectation, loosely the \
probability that we are wrong.  Imagine the converse, a certain outcome, \
something guaranteed to happen without fail. The outcome would ALWAYS match \
our expectation, there would be no variance and the entire distribution would \
be the straight line in the middle, a single value.  But if an opportunity \
has uncertain outcomes we must allow for outcomes that do not match our \
expectations, some better and some worse, that aggregate around the \
expectation. ",
 StyleBox["So we begin to think about risk in terms of the shape of a \
function",
  FontSlant->"Italic"],
 " in which we have a field of possible outcomes sprinkled about a line \
called the expectation. The distribution is shaped in a way that it \"peaks\" \
at one (and only one) point. The area of the field is expressed graphically \
in Figure 6.16 for the normal distribution as a plot of its probability \
density function."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.529705823094463*^9, {3.529705853414197*^9, 3.5297058626647263`*^9}, {
   3.5297059352268763`*^9, 3.529705952560868*^9}, {3.52993797225809*^9, 
   3.5299379948393817`*^9}, 3.5386855199351673`*^9, {3.5396302237761865`*^9, 
   3.539630225045259*^9}},ExpressionUUID->"e55500ad-9e4b-4948-a9de-\
9bc1ef061438"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p9", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"pdw1", ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", "0", ",", 
      RowBox[{"2", " ", 
       SuperscriptBox["10", "6"]}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        SuperscriptBox["10", "6"], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Wealth Distribution\>\""}], ",", 
    RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
    RowBox[{"Axes", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.402658689515625*^9, 3.40265869609375*^9}, {
   3.5300173209635763`*^9, 3.5300173258088536`*^9}, 
   3.5386855199351673`*^9},ExpressionUUID->"7c5cf601-c4d7-4a66-ac46-\
277f3ef06df3"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwtmnc4lf//x22ysveWyDj2Pve780LGR4mSighZlcjOzE42SSVkJbPssk82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       "]]},
     Annotation[#, "Charting`Private`Tag$5429#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{{1000000}, {}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Wealth Distribution\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{{}, {}}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658645171875*^9, 3.40265869709375*^9, 
  3.402699603141625*^9, 3.5296985715316973`*^9, 3.5297900046573725`*^9, 
  3.5297931424892626`*^9, 3.529935133968749*^9, 3.529937325915121*^9, 
  3.5300164056502237`*^9, 3.530016725051492*^9, 3.530017187575947*^9, 
  3.5300173265128937`*^9, 3.5301936917266784`*^9, 3.5301942336496744`*^9, 
  3.5301947095508947`*^9, 3.5314482301168184`*^9, 3.531500626374713*^9, 
  3.533134707919544*^9, 3.533135881439666*^9, 3.5336822535*^9, 
  3.533734588555833*^9, 3.533754144609375*^9, 3.53375541725*^9, 
  3.5386852274224367`*^9, 3.5386855199361677`*^9, 3.539635958501194*^9, 
  3.540126819208755*^9, 3.5410126407155514`*^9, 3.5410151093797507`*^9, 
  3.541015581173736*^9, 3.541600452667409*^9, 3.543342200198705*^9, 
  3.6963384629697156`*^9, 3.6963423758219886`*^9, 3.6965443609822206`*^9, 
  3.731421193555685*^9},
 TextAlignment->Center,ExpressionUUID->"b07f9bdf-d0c4-4064-b38e-d001319eb1d0"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.16.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Wealth distribution where \[Mu] = $1,000,000 and \[Sigma] = $200,000."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.531500480667379*^9}, 
   3.5386855199361677`*^9},
 TextAlignment->Center,ExpressionUUID->"f5220e15-44b5-411b-9d09-e86451c2f5a3"],

Cell["\<\
Note that the domain is carefully chosen so that the distribution contains \
mostly positive values.  This constraint is for ease of the present \
exposition with the full discussion of why left for another time (until then \
we can agree that negative wealth and its related utility does not have a lot \
of meaning).  The integration of the function below shows as much of the \
probability mass as is to the right of zero. [One must accept that ALL normal \
distributions have negative values. Mathematically one cannot have it any \
other way. This leads to two observations. First, and most importantly, in a \
very general sense it speaks of the futility of attempting to reduce risk to \
zero; second, it points up how the social sciences sometimes must bend \
mathematics to their purpose].\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199361677`*^9, {3.539607465357479*^9, 3.5396074657185*^9}, {
   3.6965441016061826`*^9, 
   3.6965441020283036`*^9}},ExpressionUUID->"d8eb75a3-ab9a-4c57-b9a6-\
a9582a00dca9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"2", " ", 
     SuperscriptBox["10", "6"]}]], 
   RowBox[{"pdw1", 
    RowBox[{"\[DifferentialD]", "w"}]}]}], "//", "N"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199361677`*^9},ExpressionUUID->"80ef14ba-2622-4e95-b6cb-\
8ad4971170f0"],

Cell[BoxData["0.9999994266968563`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658646015625*^9, 3.402699605047875*^9, 
  3.529698572540755*^9, 3.5297900049733906`*^9, 3.529793143364312*^9, 
  3.529935134453777*^9, 3.5299373260321283`*^9, 3.5300164060572467`*^9, 
  3.5300167251865*^9, 3.5300171877109547`*^9, 3.530193691872687*^9, 
  3.530194234162704*^9, 3.530194709704903*^9, 3.5314482303548317`*^9, 
  3.5315006267127323`*^9, 3.533134708495577*^9, 3.5331358815546722`*^9, 
  3.53368225384375*^9, 3.533734589339878*^9, 3.53375414496875*^9, 
  3.533755417484375*^9, 3.5386852283744917`*^9, 3.5386855199361677`*^9, 
  3.5396359590112233`*^9, 3.5401268203858223`*^9, 3.541012641811614*^9, 
  3.5410151103538065`*^9, 3.5410155822917995`*^9, 3.5416004534734554`*^9, 
  3.5433422009457483`*^9, 3.6963384630378737`*^9, 3.6963423759062123`*^9, 
  3.696544361090472*^9, 
  3.7314211936669593`*^9},ExpressionUUID->"f6cca286-d181-45a7-a2c9-\
174932f6f45d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Alternatively, suppose we had a second game, also having normally \
distributed outcomes but with different parameters.  The critical change is \
that, while both have the same mean, the second proposition, Equation 6.12, \
has a larger ",
 StyleBox["standard deviation",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297065988858356`*^9, 3.5297066057442274`*^9}, 
   3.5386855199361677`*^9, {3.5396303859464617`*^9, 3.539630389472664*^9}, {
   3.541013858367197*^9, 
   3.5410138594152565`*^9}},ExpressionUUID->"ff982631-6b3b-4244-8b10-\
fed060e902fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pdw2", "=", 
  RowBox[{"PDF", "[", 
   RowBox[{
    RowBox[{"NormalDistribution", "[", 
     RowBox[{
      SuperscriptBox["10", "6"], ",", 
      StyleBox[
       RowBox[{"2.5", " ", 
        SuperscriptBox["10", "5"]}],
       FontColor->RGBColor[0, 0, 1]]}], "]"}], ",", "w"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529706255003166*^9, 3.5297062636676617`*^9}, {
   3.529706332308588*^9, 3.5297063501156063`*^9}, {3.529706400896511*^9, 
   3.5297064138232503`*^9}, 3.5386855199361677`*^9, {3.5410139010176363`*^9, 
   3.541013919527695*^9}, {3.541014139325267*^9, 
   3.54101417050105*^9}},ExpressionUUID->"31acf606-9c38-460c-abbd-\
8bc87c44672b"],

Cell[BoxData[
 RowBox[{"1.595769121605731`*^-6", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "8.`*^-12"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1000000"}], "+", "w"}], ")"}], "2"]}]]}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.402658646078125*^9, 3.4026996084385*^9, 3.529698572914776*^9, 
   3.5297059875448685`*^9, {3.5297062527280364`*^9, 3.5297062678208995`*^9}, {
   3.5297063330716314`*^9, 3.529706366131523*^9}, {3.5297064053657665`*^9, 
   3.529706414532291*^9}, 3.5297900050343943`*^9, 3.5297931437483344`*^9, 
   3.5299351347437935`*^9, 3.52993732607213*^9, 3.530016406235257*^9, 
   3.5300167252635045`*^9, 3.5300171878799644`*^9, 3.53019369193069*^9, 
   3.530194234477722*^9, 3.530194644482173*^9, 3.530194709774907*^9, 
   3.531448230403835*^9, 3.531500626768736*^9, 3.5331347088935995`*^9, 
   3.533135881594674*^9, 3.53368225403125*^9, 3.533734589885909*^9, 
   3.533754145046875*^9, 3.533755417578125*^9, 3.538685228757513*^9, 
   3.5386855199361677`*^9, 3.539635959060226*^9, 3.540126821079862*^9, 
   3.5410126425266547`*^9, 3.5410139099851494`*^9, {3.5410141483397827`*^9, 
   3.5410141713310976`*^9}, 3.541015111043846*^9, 3.5410155831468487`*^9, 
   3.5416004541554937`*^9, 3.5433422014897795`*^9, 3.6963384630809884`*^9, 
   3.6963423759403024`*^9, 3.6965443611045103`*^9, 
   3.731421193732155*^9},ExpressionUUID->"12fa10e6-7b9d-4670-a9b1-\
a4bfeda9484b"]
}, Open  ]],

Cell[TextData[{
 "Likewise, our second ",
 StyleBox["pdf",
  FontSlant->"Italic"],
 " covers mostly positive outcomes..."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199361677`*^9},ExpressionUUID->"139c6458-f8c9-48bd-9a43-\
c123bf6e6379"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"2.5", " ", 
     SuperscriptBox["10", "6"]}]], 
   RowBox[{"pdw2", 
    RowBox[{"\[DifferentialD]", "w"}]}]}], "//", "N"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199361677`*^9},ExpressionUUID->"79319bad-d7cc-4db7-83f2-\
e4df4af61879"],

Cell[BoxData["0.9999683277715793`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658646140625*^9, 3.402699609454125*^9, 
  3.5296985733758025`*^9, 3.529705990730051*^9, 3.5297900050933976`*^9, 
  3.529793144116356*^9, 3.5299351350788126`*^9, 3.5299373261581354`*^9, 
  3.530016406311261*^9, 3.5300167253385086`*^9, 3.530017187955969*^9, 
  3.530193691988693*^9, 3.530194234814741*^9, 3.5301947098369107`*^9, 
  3.5314482304568377`*^9, 3.5315006268087378`*^9, 3.5331347092396193`*^9, 
  3.5331358816826797`*^9, 3.533682254125*^9, 3.5337345902039275`*^9, 
  3.533754145140625*^9, 3.53375541765625*^9, 3.5386852291035333`*^9, 
  3.5386855199361677`*^9, 3.5396359591072283`*^9, 3.540126821546889*^9, 
  3.5410126431686916`*^9, 3.5410151115218735`*^9, 3.5410155836688786`*^9, 
  3.5416004547895308`*^9, 3.5433422020888133`*^9, 3.6963384631121063`*^9, 
  3.696342375988431*^9, 3.6965443611486616`*^9, 
  3.7314211937692585`*^9},ExpressionUUID->"8fdcc045-8686-4153-8476-\
136ebff38fda"]
}, Open  ]],

Cell["...and has the same familiar shape...", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199361677`*^9},ExpressionUUID->"97af86de-69d5-4de5-98d0-\
ac86b136e29f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p10", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"pdw2", ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", "0", ",", 
      RowBox[{"2.5", " ", 
       SuperscriptBox["10", "6"]}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        SuperscriptBox["10", "6"], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Wealth Distribution\>\""}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"AbsoluteDashing", "[", 
        RowBox[{"{", 
         RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
    RowBox[{"Axes", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.402659222703125*^9, 3.40265922796875*^9}, {
   3.5297062363280983`*^9, 3.529706239535282*^9}, {3.530017345065955*^9, 
   3.530017345760995*^9}, 
   3.538685519937168*^9},ExpressionUUID->"2debe1dc-376b-4243-9679-\
aaf32674511b"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
      AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwVl3c81d8fx2WvbDKzMuO69jXOcd8XoWQlJVmFZJUShSSrjEpFZhlFviUi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       "]]},
     Annotation[#, "Charting`Private`Tag$5607#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{{1000000}, {}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Wealth Distribution\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{{}, {}}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.402658646171875*^9, 3.402659229671875*^9, 3.402699609610375*^9, 
   3.5296985736968207`*^9, 3.5297059976234455`*^9, 3.529706241846414*^9, 
   3.529790005152401*^9, 3.529793144182359*^9, 3.529935135466835*^9, 
   3.5299373261981373`*^9, 3.5300164063882656`*^9, 3.5300167255125184`*^9, 
   3.530017188031973*^9, 3.5300173465820417`*^9, 3.5301936920466967`*^9, 
   3.5301942353687725`*^9, {3.5301946378167915`*^9, 3.5301946646253247`*^9}, 
   3.5301947098999147`*^9, 3.5314482304998407`*^9, 3.53150062684874*^9, 
   3.53313470959864*^9, 3.533135881722682*^9, 3.53368225421875*^9, 
   3.533734590542947*^9, 3.533754145328125*^9, 3.53375541775*^9, 
   3.538685229422551*^9, 3.538685519937168*^9, 3.539635959154231*^9, 
   3.540126822110921*^9, 3.541012643729724*^9, 3.541015112091906*^9, 
   3.54101558421091*^9, 3.5416004554535685`*^9, 3.5433422028068542`*^9, 
   3.696338463193287*^9, 3.6963423760626383`*^9, 3.696544361226836*^9, 
   3.731421193851451*^9},
 TextAlignment->Center,ExpressionUUID->"0009b9c6-f5b9-47f5-9491-38dc5771843f"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.17.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Wealth distribution where \[Mu] = $1,000,000 and \[Sigma] = $250,000."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315005037576995`*^9}, 
   3.538685519937168*^9},
 TextAlignment->Center,ExpressionUUID->"416f2e08-905b-4dcc-afe8-cb8c85c9562f"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    StyleBox["pdf",
     FontSlant->"Italic"], "2"], "=", 
   RowBox[{"1.59577", "\[Times]", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "8.`*^-12"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"w", "-", "1000000"}], ")"}], "2"]}]]}]}], 
  TraditionalForm]], "EquationNumbered",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297065658269444`*^9, 3.5297065794457235`*^9}, 
   3.538685519937168*^9},ExpressionUUID->"2a65aa97-ad26-4f77-982d-\
b7a09e795086"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"s3", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"p9", ",", "p10"}], "]"}]}], ";"}], "\n", 
 RowBox[{"fig9", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{"s3", ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], "]"}]}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{"Blue", ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\[Sigma]= 200,000\>\"", ",", "\"\<\[Sigma]= 250,000\>\""}], 
       "}"}]}], "]"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.402788193126*^9, {3.402788499016625*^9, 3.402788542516625*^9}, {
   3.4027886083135*^9, 3.402788692297875*^9}, 3.402788833235375*^9, 
   3.40278886828225*^9, 3.4027889914385*^9, {3.402789066547875*^9, 
   3.4027892068135*^9}, {3.5297060720497017`*^9, 3.529706072204711*^9}, {
   3.5300173624619503`*^9, 3.5300173889174633`*^9}, 3.538685519937168*^9, {
   3.6963432581034355`*^9, 
   3.6963433928368893`*^9}},ExpressionUUID->"902c195e-dcac-4417-9128-\
9afe21a080a7"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0, 0]], 
          LineBox[CompressedData["
1:eJwtmnc4lf//x22ysveWyDj2Pve780LGR4mSighZlcjOzE42SSVkJbPssk82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           "]]}, 
         Annotation[#, 
          "Charting`Private`Tag$5429#1"]& ]}}, {}, {}}, {{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0, 0, 1], 
           AbsoluteDashing[{2, 5}]], 
          LineBox[CompressedData["
1:eJwVl3c81d8fx2WvbDKzMuO69jXOcd8XoWQlJVmFZJUShSSrjEpFZhlFviUi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           "]]}, 
         Annotation[#, "Charting`Private`Tag$5607#1"]& ]}}, {}, {}}}, {
    DisplayFunction -> Identity, Ticks -> {{}, {}}, AxesOrigin -> {0, 0}, 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {{1000000}, {}}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {{1000000}, {}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"Wealth Distribution\"", TraditionalForm], 
     PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {None, None}}],FormBox[
    FormBox[
     TemplateBox[{"\"\[Sigma]= 200,000\"", "\"\[Sigma]= 250,000\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    AbsoluteDashing[{1, 0}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    AbsoluteDashing[{1, 0}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    AbsoluteDashing[{2, 5}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    AbsoluteDashing[{2, 5}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}], "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& ), Editable -> True], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.402788840126*^9, 3.402788996626*^9, 3.402789125641625*^9, {
   3.40278915834475*^9, 3.4027891753135*^9}, 3.402789210579125*^9, 
   3.529698583489381*^9, 3.529706077521015*^9, 3.5297061384515*^9, 
   3.5297900053844147`*^9, 3.529793144342368*^9, 3.529935136014866*^9, 
   3.529937326348146*^9, 3.5300164066852827`*^9, 3.5300167258255367`*^9, 
   3.53001718832799*^9, {3.5300173577736816`*^9, 3.5300173899415216`*^9}, 
   3.5301936922737093`*^9, 3.5301942366578465`*^9, 3.5301947099729185`*^9, 
   3.53144823067185*^9, 3.531500627008749*^9, 3.5331347104326878`*^9, 
   3.5331358818736906`*^9, 3.533682254515625*^9, 3.533734591151982*^9, 
   3.533754145625*^9, 3.53375541809375*^9, 3.538685230029586*^9, 
   3.538685519940168*^9, 3.5396359593182406`*^9, 3.540126822863964*^9, 
   3.5410126444547653`*^9, 3.5410151128369484`*^9, 3.541015586404035*^9, 
   3.541600456167609*^9, 3.5433422036839046`*^9, 3.696338463327645*^9, 
   3.6963423760866923`*^9, 3.6963433800498734`*^9, 3.6965443612849894`*^9, 
   3.731421193919633*^9},
 TextAlignment->Center,ExpressionUUID->"1d19fce4-97e1-40f1-8046-b06c586e8ebb"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.18.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Distributions with different standard deviations."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315005216417227`*^9}, 
   3.538685519940168*^9},
 TextAlignment->Center,ExpressionUUID->"5f5f05a0-4ca7-4588-9e97-af86a7b7bb4e"],

Cell[TextData[{
 "The difference in these shapes means that the spread of outcomes away from \
our expectation is different, therefore the risk is different.  Recall in \
Chapter 4 we had an investment which modeled in different ways had produced \
substantially the same 13% ",
 StyleBox["irr",
  FontSlant->"Italic"],
 ". We postulated that the two ",
 StyleBox["irr",
  FontSlant->"Italic"],
 "s, while ",
 StyleBox["quantitatively ",
  CharacterEncoding -> "WindowsANSI"],
 "the same, were qualitatively different.  We pondered how they were \
different from the standpoint of risk. With the introduction of a probability \
distribution we move closer to answering that question. We have discussed \
risk tolerance and utility. We now judiciously combine these ideas with the \
notion of the distribution's spread, more precisely variance from expectation."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5297066684488144`*^9, 3.5299380228339825`*^9, 3.538685519940168*^9, {
   3.541014234174692*^9, 
   3.5410142454613376`*^9}},ExpressionUUID->"a64100ac-bc6d-40dc-8a5a-\
b37d69ff6d19"],

Cell[CellGroupData[{

Cell["\<\
Suppose we have an investor whose decisions about risky alternatives are \
based on a logarithmic utility function. How would such an investor decide \
between the two alternatives illustrated in Figure 6.18?\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529706160578766*^9, 3.5297061753156085`*^9}, {
   3.5297069770574656`*^9, 3.5297069816067257`*^9}, 3.529938122338674*^9, {
   3.533137973019297*^9, 3.5331379922633977`*^9}, 3.538685407428733*^9, 
   3.538685519940168*^9},ExpressionUUID->"8aa0aaf1-4035-4e70-a4ec-\
2578d8513abb"],

Cell[TextData[{
 "Before we become too tangled in the mathematics let us step back and remind \
ourselves that the notion of \"shape\" assists us in understanding risk. It \
seems that we are interested in both ",
 StyleBox["the shape",
  FontSlant->"Italic"],
 " of the utility function and ",
 StyleBox["the shape",
  FontSlant->"Italic"],
 " of the distribution of outcomes. Specifically, we want to know how much \
area underneath the curve is away from the mean and on what side of the mean. \
 We shall tuck that in the back of our minds for the moment while we wade \
through some more details. "
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529706160578766*^9, 3.529706176596682*^9}, 
   3.538685519940168*^9, {3.541014256063944*^9, 
   3.541014258530085*^9}},ExpressionUUID->"8ac8ee69-2538-495b-9c01-\
02aae1ecde95"],

Cell[TextData[{
 "What follows proceeds on the basis that the reader has some familiarity \
with transformations of random variables. Transformations can make an \
otherwise intractable problem ",
 StyleBox["manageable",
  CharacterEncoding -> "WindowsANSI"],
 ". At a minimum, one should know that certain transformations are \"shape \
preserving\", thus after transformation the shape of the distribution is the \
same.  The simplest example is a linear transformation, illustrated in Figure \
3-16 of Chapter 3, where multiplying a set of values by a constant and/or \
adding a constant merely rescales and re-centers the distribution. This is \
how a normal distribution is \"standardized\" into \"standard normal\" where \
the mean is zero and the variance is one.  More generally, there are rules \
for transformations that must be adhered to and certain properties are \
essential.  Numerous references (such as ",
 StyleBox["Hogg & Craig,",
  FontColor->GrayLevel[0]],
 " 5th ed. p. 168, et seq) are available to fully elaborate this area.  Here \
is a brief exposition."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529706160578766*^9, 3.5297061625548787`*^9}, 
   3.529707101757598*^9, 3.538685519940168*^9, {3.5410142669395657`*^9, 
   3.541014272990912*^9}},ExpressionUUID->"4dbe4c89-7199-4242-9d3d-\
c226d9e12f6b"],

Cell[TextData[{
 "A key to transformation is the ",
 StyleBox["existence",
  CharacterEncoding -> "WindowsANSI"],
 " of an inverse, at least over the range of interest.  This is easier if \
there is a one-to-one mapping of set \[ScriptCapitalA] onto a set \
\[ScriptCapitalB] as a result of the transformation.  By example, suppose we \
have a random variable ",
 StyleBox["y",
  FontSlant->"Italic"],
 " that is a function of ",
 StyleBox["x",
  FontSlant->"Italic"],
 ", Thus:"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519940168*^9},ExpressionUUID->"7ebfecff-7fc9-4855-8403-\
544f210238de"],

Cell[TextData[{
 StyleBox["y",
  FontSlant->"Italic"],
 " = f(",
 StyleBox["x",
  FontSlant->"Italic"],
 ")"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.538685519940168*^9},
 TextAlignment->Center,ExpressionUUID->"8786373a-1dc6-4ef7-8f30-a14ada2da114"],

Cell["But further assume that the inverse function is:", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519940168*^9},ExpressionUUID->"b97794a1-b13e-47bf-9571-\
3e1c5229decc"],

Cell[TextData[{
 StyleBox["x",
  FontSlant->"Italic"],
 " = g(",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = g(f(",
 StyleBox["x",
  FontSlant->"Italic"],
 "))"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.538685519940168*^9},
 TextAlignment->Center,ExpressionUUID->"062ab86a-4f2a-4ada-88a7-e2e1bae1650d"],

Cell[TextData[{
 "If our interest is the ",
 StyleBox["pdf",
  FontSlant->"Italic"],
 " of ",
 StyleBox["y",
  FontSlant->"Italic"],
 " and we know the pdf of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " we can get where we need to go with a transformation"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.538685519940168*^9},ExpressionUUID->"f640e7e4-74ef-4aeb-b2ca-\
e55a42f30dde"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["pdf",
     FontSlant->"Italic"], "y"], TraditionalForm]],ExpressionUUID->
  "4d159256-f8d3-4e98-9e27-427a34b139da"],
 "[",
 StyleBox["y",
  FontSlant->"Italic"],
 "] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["pdf", "x"], "[", 
      RowBox[{"g", "(", "y", ")"}], "]"}], "*"}], "|", 
    RowBox[{
     RowBox[{"g", "'"}], 
     RowBox[{"(", "y", ")"}]}], "|"}], TraditionalForm]],ExpressionUUID->
  "0383730b-4eb6-4613-9c75-1ba7b8edd467"]
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.538685519940168*^9, 3.538685519942168*^9}},
 TextAlignment->Center,ExpressionUUID->"ea435030-a9ef-4704-baaa-4d820b5b30c7"],

Cell[TextData[{
 "In a later chapter we will encounter an otherwise ",
 StyleBox["unmanageable",
  CharacterEncoding -> "WindowsANSI"],
 " situation in which we are interested in the distribution of utility based \
on knowing the distribution of wealth.  Substituting an appropriate utility \
function for g(",
 StyleBox["y",
  FontSlant->"Italic"],
 ") and using wealth, ",
 StyleBox["w",
  FontSlant->"Italic"],
 ", for ",
 StyleBox["x",
  FontSlant->"Italic"],
 " in the above we accomplish desirable results."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297071855833926`*^9, 3.5297071961369963`*^9}, 
   3.538685519942168*^9},ExpressionUUID->"ca3adee8-52f9-4ba0-817d-\
cb4801d17346"],

Cell[TextData[{
 "Basing utility of wealth on the natural log of wealth is convenient because \
the inverse of the log function exists (this is also true of the square root \
function and many others but not all).  We can, therefore, express wealth as \
a function of utility as readily as we can express utility as a function of \
wealth. Simply ",
 StyleBox["w",
  FontSlant->"Italic"],
 ", the inverse of utility, is always exponented utility, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"u", "[", "w", "]"}]], TraditionalForm]],ExpressionUUID->
  "29b25906-2413-47fa-a19f-9a2080623ae6"],
 ". Also the exponential is, amazingly, its own first derivative, ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    FractionBox["du", "dw"], "=", " ", 
    RowBox[{
     FractionBox["d", "dw"], 
     SuperscriptBox["\[ExponentialE]", "w"]}]}],
   FontSlant->"Italic"]],ExpressionUUID->
  "484deeae-403c-4f57-a917-0e9e38ad11fc"],
 " = ",
 Cell[BoxData[
  StyleBox[
   SuperscriptBox["\[ExponentialE]", "w"],
   FontSlant->"Italic"]],ExpressionUUID->
  "4df6ee6c-bedd-4225-8d8b-552ee5eca396"],
 "= u[",
 StyleBox["w",
  FontSlant->"Italic"],
 "]. Therefore we can create two lognormal utility distributions from the ",
 StyleBox["pdf",
  FontSlant->"Italic"],
 "s above. Note that the modes of the utility of wealth as a result of the \
transformation has moved to the right of their location in the original ",
 StyleBox["pdf",
  FontSlant->"Italic"],
 "s for wealth."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.538685519942168*^9, 
  3.5386855199551687`*^9}},ExpressionUUID->"d3746b23-5923-4586-b24a-\
4ac8be535808"]
}, Open  ]],

Cell["\<\
Returning to the importance of shapes, note that the (normal) symmetry of \
wealth distribution is lost when operated on by the Log utility function.  In \
Figure 6.19, the plot on the right shows a distinct left skew with the mode \
to the right of the mean. This is to be expected considering the shape of the \
utility function. \
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529708073504179*^9, 3.5297080780754404`*^9}, 
   3.529938182712127*^9, 
   3.5386855199551687`*^9},ExpressionUUID->"b8553f65-4c58-4181-a18c-\
34c4cbfae78a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pduw1", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "u1"], " ", "pdw1"}], "/.", 
    RowBox[{"w", "\[Rule]", 
     SuperscriptBox["\[ExponentialE]", "u1"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pduw2", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "u2"], " ", "pdw2"}], "/.", 
    RowBox[{"w", "\[Rule]", 
     SuperscriptBox["\[ExponentialE]", "u2"]}]}]}], ";", 
  RowBox[{"p11", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{"pduw1", ",", 
     RowBox[{"{", 
      RowBox[{"u1", ",", 
       RowBox[{"Log", "[", 
        RowBox[{"2", " ", 
         SuperscriptBox["10", "5"]}], "]"}], ",", 
       RowBox[{"Log", "[", 
        RowBox[{"2", " ", 
         SuperscriptBox["10", "6"]}], "]"}]}], "}"}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"12.5`", ",", "0"}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Log", "[", 
          SuperscriptBox["10", "6"], "]"}], "}"}], ",", 
        RowBox[{"{", "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Hue", "[", "0.9`", "]"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Utility Distribution\>\""}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"Axes", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p12", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{"pduw2", ",", 
     RowBox[{"{", 
      RowBox[{"u2", ",", 
       RowBox[{"Log", "[", 
        RowBox[{"2", " ", 
         SuperscriptBox["10", "5"]}], "]"}], ",", 
       RowBox[{"Log", "[", 
        RowBox[{"2", " ", 
         SuperscriptBox["10", "6"]}], "]"}]}], "}"}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"12.5`", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Hue", "[", "0.5`", "]"}], ",", 
        RowBox[{"AbsoluteDashing", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s4", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"p11", ",", "p12"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"uwTwo", "=", 
   RowBox[{"ShowLegend", "[", 
    RowBox[{"s4", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Hue", "[", "0.9`", "]"}], ",", 
              RowBox[{"AbsoluteDashing", "[", 
               RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}], "]"}], ",", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
            "]"}], ",", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<pduw1\>\"", ",", "TraditionalForm", ",", 
             RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Hue", "[", "0.5`", "]"}], ",", 
              RowBox[{"AbsoluteDashing", "[", 
               RowBox[{"{", 
                RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
            "]"}], ",", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<pduw2\>\"", ",", "TraditionalForm", ",", 
             RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}], "}"}]}], "}"}], 
       ",", 
       RowBox[{"LegendSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0.5`", ",", "0.2`"}], "}"}]}], ",", 
       RowBox[{"LegendPosition", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0.7`", ",", 
          RowBox[{"-", "0.4`"}]}], "}"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"fig10", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"GraphicsRow", "[", 
     RowBox[{"{", 
      RowBox[{"s3", ",", "s4"}], "}"}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.530016565236351*^9, 3.5300165842274375`*^9}, {
   3.530016628080946*^9, 3.5300166501032057`*^9}, 
   3.538685519956169*^9},ExpressionUUID->"23635fef-8385-406e-8a6f-\
0dafa8669c33"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{{}, {}, 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwtmnc4lf//x22ysveWyDj2Pve780LGR4mSighZlcjOzE42SSVkJbPssk82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            "]]},
          Annotation[#, "Charting`Private`Tag$5429#1"]& ]}, {}, {}}, {{{}, {}, 
         TagBox[
          {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
           AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwVl3c81d8fx2WvbDKzMuO69jXOcd8XoWQlJVmFZJUShSSrjEpFZhlFviUi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            "]]},
          Annotation[#, "Charting`Private`Tag$5607#1"]& ]}, {}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}},
      GridLines->{{1000000}, {}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Wealth Distribution\"", TraditionalForm],
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{{}, {}}], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{{}, {}, 
         TagBox[
          {Hue[0.9, 1, 1], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwV13c81t8XAPDHyEhDKqVs0jM+ZooyzlWiKKkvUkZFRlQiISFUZrZQ9pa9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            "]]},
          Annotation[#, "Charting`Private`Tag$5672#1"]& ]}, {}, {}}, {{{}, {}, 
         TagBox[
          {Hue[0.5, 1, 1], AbsoluteThickness[1.6], Opacity[1.], 
           AbsoluteDashing[{2, 5}], LineBox[CompressedData["
1:eJwV13k8lF8XAHBJoV3il1KpxMw8T5aKiJyrpAWRJEJKkRChZE9K9rLTQtn3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            "]]},
          Annotation[#, "Charting`Private`Tag$5716#1"]& ]}, {}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{12.5, 0.},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}},
      GridLines->NCache[{{
          Log[1000000]}, {}}, {{13.815510557964274`}, {}}],
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Utility Distribution\"", TraditionalForm],
      PlotRange->NCache[{{
          Log[200000], 
          Log[2000000]}, {0., 2.033477499563062}}, {{12.206072645530174`, 
        14.508657738524219`}, {0., 2.033477499563062}}],
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{{}, {}}], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->500,
  PlotRangePadding->{6, 5}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.402658646359375*^9, 3.4026996113135*^9, 3.5296985864875526`*^9, 
   3.529707309044454*^9, 3.5297077818744984`*^9, {3.5297078709065905`*^9, 
   3.5297078998722477`*^9}, 3.52979000583644*^9, 3.5297931446043835`*^9, 
   3.52993513695592*^9, 3.5299373265821595`*^9, 3.5300164068212905`*^9, 
   3.5300165883346725`*^9, 3.5300166555645175`*^9, 3.530016726277562*^9, 
   3.530017188752014*^9, 3.530193692594728*^9, 3.530194238432948*^9, {
   3.5301946042338705`*^9, 3.5301946726577845`*^9}, 3.5301947101339283`*^9, 
   3.5314482309078636`*^9, 3.531500627254763*^9, 3.533134711294737*^9, 
   3.5331358820867023`*^9, 3.533682254890625*^9, 3.533734592469057*^9, 
   3.533754146015625*^9, 3.5337554185*^9, 3.538685230768628*^9, 
   3.538685519958169*^9, 3.539635959548254*^9, 3.5401268240770335`*^9, 
   3.54101264541282*^9, 3.5410151139940147`*^9, 3.541015587326088*^9, 
   3.541600457033659*^9, 3.5433422045559545`*^9, 3.696338463598365*^9, 
   3.6963423762641644`*^9, 3.6965443614564457`*^9, 3.7314211941542773`*^9},
 TextAlignment->Center,ExpressionUUID->"7c0be288-e3da-4e35-82e0-9e5fd4ba057f"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.19.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "The shape of the distribution of wealth and the shape of the distribution \
of utility of wealth."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315005398327627`*^9}, 
   3.538685519958169*^9},
 TextAlignment->Center,ExpressionUUID->"0b0a51c6-fa95-4b67-a008-d30b0a0b900a"],

Cell[TextData[{
 "In the parametric plot in Figure 6.20 we plot the intersection of ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[ExponentialE]", "u1"],
    FontColor->GrayLevel[0]], TraditionalForm]],ExpressionUUID->
  "3ad29a0b-4f00-4bed-9033-31291c9831c5"],
 "(which you recall is wealth) and the distribution of utility of wealth as \
utility (",
 StyleBox["u1",
  FontColor->RGBColor[1, 0, 0]],
 ") changes. This permits plotting utility distribution for our first utility \
function on a wealth scale."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297082168653784`*^9, 3.529708243499902*^9}, {
  3.529938196209899*^9, 3.529938196407911*^9}, {3.538685519958169*^9, 
  3.5386855199591694`*^9}, {3.6965441698808265`*^9, 
  3.696544170656909*^9}},ExpressionUUID->"31cc6b51-9289-4b28-b213-\
ea23303125d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p13", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "u1"], ",", "pduw1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u1", ",", 
      RowBox[{"Log", "[", "200000", "]"}], ",", 
      RowBox[{"Log", "[", 
       RowBox[{"2", " ", 
        SuperscriptBox["10", "6"]}], "]"}]}], "}"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", 
     RowBox[{"1", "/", "2"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<wealth\>\"", ",", "\"\<utility of wealth\>\"", ",", "None", ",", 
       "None"}], "}"}]}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"500000", ",", "1000000", ",", "1500000"}], "}"}], ",", 
       "Automatic", ",", "None", ",", "None"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Hue", "[", "0.99`", "]"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.402786537391625*^9, 3.40278654446975*^9}, 
   3.5386855199591694`*^9},ExpressionUUID->"abe3b62d-7a71-4d5e-b300-\
6034be2efefc"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   TagBox[
    {Hue[0.99, 1, 1], AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
     0.3]], LineBox[CompressedData["
1:eJwVl3c8198Xxz8a9t57iwqfjz0/zucQivpmRCQR2SEj2WlJdlmFQmkrZKtk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      "]]},
    Annotation[#, "Charting`Private`Tag$5777#1"]& ]},
  AspectRatio->NCache[
    Rational[1, 2], 0.5],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{200000.00000000006`, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"utility of wealth\"", TraditionalForm], None}, {
     FormBox["\"wealth\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->Automatic,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.402658646390625*^9, 3.40269961203225*^9, 
  3.402786559266625*^9, 3.5296985871165886`*^9, 3.5297079389264812`*^9, 
  3.5297900058984437`*^9, 3.5297931446453857`*^9, 3.5299351374689493`*^9, 
  3.529937326625162*^9, 3.530016407211313*^9, 3.5300166624359107`*^9, 
  3.530016726357567*^9, 3.5300171889290247`*^9, 3.5301936927227354`*^9, 
  3.5301942390469832`*^9, 3.5314482309578667`*^9, 3.5315006273467684`*^9, 
  3.5331347118277674`*^9, 3.5331358821297054`*^9, 3.533682255171875*^9, 
  3.5337345938311353`*^9, 3.533754146109375*^9, 3.533755418609375*^9, 
  3.5386852314126654`*^9, 3.5386855199611692`*^9, 3.5396359596482596`*^9, 
  3.540126824942083*^9, 3.5410126462518682`*^9, 3.5410151148380632`*^9, 
  3.5410155879851255`*^9, 3.541600457859706*^9, 3.543342205156989*^9, 
  3.696338463651506*^9, 3.6963423763173327`*^9, 3.69654436152162*^9, 
  3.731421194217424*^9},
 TextAlignment->Center,ExpressionUUID->"56d7fdab-f94d-4224-ac7f-b8c20f4b1a9d"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.20.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Parametric plot of utility of wealth against wealth."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315005562707033`*^9}, 
   3.5386855199611692`*^9, 3.5396074854916306`*^9},
 TextAlignment->Center,ExpressionUUID->"13b82c8b-1157-4d2f-a47e-642ca2048c1a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"Log", "[", "1", "]"}], 
    RowBox[{"Log", "[", 
     RowBox[{"2", " ", 
      SuperscriptBox["10", "6"]}], "]"}]], 
   RowBox[{"pduw1", 
    RowBox[{"\[DifferentialD]", "u1"}]}]}], "//", "N"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.5386855199611692`*^9},ExpressionUUID->"e80609c7-af17-4ba2-9725-\
5272aafd78c6"],

Cell[BoxData["0.9999994266894225`"], "Output",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{3.402658646890625*^9, 3.402699613329125*^9, 
  3.529698587980638*^9, 3.529707947759987*^9, 3.529790006590483*^9, 
  3.5297931459794617`*^9, 3.5299351384730067`*^9, 3.5299373268891773`*^9, 
  3.5300164073843226`*^9, 3.5300166714554267`*^9, 3.530016726738589*^9, 
  3.530017189219041*^9, 3.5301936930697556`*^9, 3.5301942401910486`*^9, 
  3.531448231587902*^9, 3.531500627920801*^9, 3.5331347126118126`*^9, 
  3.53313588239072*^9, 3.533682256359375*^9, 3.533734594912197*^9, 
  3.53375414725*^9, 3.53375541909375*^9, 3.5386852325887327`*^9, 
  3.5386855199611692`*^9, 3.539635960258294*^9, 3.5401268270812054`*^9, 
  3.541012647454937*^9, 3.541015115697112*^9, 3.541015588961181*^9, 
  3.5416004589377675`*^9, 3.543342206262052*^9, 3.696338463739741*^9, 
  3.696342376400544*^9, 3.696544361599828*^9, 
  3.731421194326715*^9},ExpressionUUID->"de390c04-f24e-4a8e-9458-\
9492c0675746"]
}, Open  ]],

Cell["\<\
We now combine, in Figure 6.21, two parametric plots showing both \
distributions on a wealth scale.  \
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5299382079585714`*^9, 3.529938212198814*^9}, 
   3.5386855199611692`*^9},ExpressionUUID->"1f54a247-211c-45e9-bf73-\
f993ab4d4d54"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p14", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "u2"], ",", "pduw2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u2", ",", 
       RowBox[{"Log", "[", "200000", "]"}], ",", 
       RowBox[{"Log", "[", 
        RowBox[{"2", " ", 
         SuperscriptBox["10", "6"]}], "]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Hue", "[", "0.5", "]"}], ",", 
        RowBox[{"AbsoluteDashing", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"s5", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"p13", ",", "p14", ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Legended", "[", 
  RowBox[{"s5", ",", 
   RowBox[{"LineLegend", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Directive", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", ".9", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Directive", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", ".5", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "}"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SuperscriptBox[\"\[ExponentialE]\", \
StyleBox[\"u1\",FontSlant->\"Italic\"]]\)\>\"", ",", 
       "\"\<\!\(\*SuperscriptBox[\"\[ExponentialE]\", \
StyleBox[\"u2\",FontSlant->\"Italic\"]]\)\>\""}], "}"}]}], "]"}]}], 
  "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{
  3.402786684376*^9, 3.402788000547875*^9, {3.402788037485375*^9, 
   3.4027880649385*^9}, {3.529707962018802*^9, 3.529707974461514*^9}, 
   3.5386855199611692`*^9, {3.696343576892564*^9, 3.6963437083031845`*^9}, 
   3.6963437408889027`*^9},ExpressionUUID->"40c2eecf-8e2e-4f24-8b4e-\
4a71f90660a2"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          Hue[0.99, 1, 1]], 
         LineBox[CompressedData["
1:eJwVl3c8198Xxz8a9t57iwqfjz0/zucQivpmRCQR2SEj2WlJdlmFQmkrZKtk
S0lKZmaKKBllr9/n98f7/X48H+fc+zrnnvO4974lnHwtXLYRCIRc6uv/3/8/
BE96rCit/XYzVgJ2mkaZefrQ458d+aLhmRKwcsXLu8ufHnl/9Yb4PpGAzBe8
LM/D6HEnqagr+p0EWDxvm3BPoEcVZQbhUCZJ+OOpsndnMT0eNFqcu5gsCQLe
xJneZXqU1DBovftQCjJu7y9YiGXArwR3seusu+CrqW/dUhIDFvMUEj9L74Kh
PYufVlMZMO2+1CF5nV1w5snkj+05DDjF4rpH3n0XCAi0D0mUUP0Lej/bN+yC
223DkPCVASdUnKLzI2XhYUmNkJQCI/qSUy7dZ9gNqcZnwLqTEXkNbuvohMhD
lKdPIPQyok7ohV3dqfLQ/C01afcgI7bTW7xLLJIHssv2EMIEI8oqprXY/pQH
WccdIlWrjFgeLudzzFYB8nfcbreSZEIpO5lHMqgINFVLNHr+TFh/J/JSADcJ
HHwvcnRyM+P7CQ+hCZIy9C3u+W9QgBmzzZqnHuorw5Cei/9PUWY0D8/5FnZE
GfYfVfOn2c2M8TbE+/bBylCs9clSj8yMKX+fTDPWKUPBp/CGMRdmpC0bfChu
rQJxStahQxXMSBOwenM4SRUO3f1vdedrZuQR2PtdOV8Vwo4JuCnWM+Nl7eRj
2ZWqcODZR7qLbcwYNmar9GJUFWQG3DxVR5mxpeK1+29VNWg8m9PXxMiCR8PN
Q18Mq8HJmqvx2SdY8HC3D/N+Yw2YI6SeOnKKBRknMm8nO2pAkX+eLYsnC3If
0fdaCtGAyrHbWRfPsiDb5sBR8WcaIGGjdCU0ngU14ocbx7g1YWktRiy3mgV/
rEryHJnShGxvz5UGPlY8Vyt0aOuZNkjWzg3miLDi9+6crRPvteE6zfnxcClW
HOA4p/ntpzZceZt4SpvIitzx8wuW0jpQzVsj2GDEik5Pul9OZusAbb5VHlMQ
Ky5v+ydDn6YLbI0XHod2seJHpol2r7t6EGD09zv3V1aMy151M6/Xg0stG9JF
I6z4bc8eV7tvelCnmlUy+YsVLWdk9g1KAtg+kmX32MaGywOKAbfvA/Q/kJy9
SWTDXaSbo0K2FMjLNcysiWVDWtWdP5IDEfap6jaFJLPhExc7l6VohK+NLatq
6Wx4JE9BKOAWwqP7DtHFeWzoHUif/KQG4WfHiHRZJRsGExwvCTPqQ4NQ1eM/
42y4L79bTvq+PmiXx3LzSrKj/fO0hOjfBoBx+ccNZNjxQumV4evb9wGd8/d9
fnLsWPe4xrBacB+UGh5ZbFdkx4TsHb+dDuwDfUePkes67Gj89uci36N9kJYj
Ma1mxY7Wg6vBql6GUJbe27IUw44KnH0DJxiMIT7W0EIrnh1tJn7S2UsbQ09z
V1RYEjsOy9nmRIAx6LuPvqNJZ8fOZ/Xtu4KM4f0wkZf3HjseZNA7IfrDGNZE
uR7Yv2bH9gWj1LbW/cB0OynJY54dD5G8Y6ILTeBoTYhx0QI7lp9wnL3dbgKP
2mLylpbZ8cvTkwUD0yYgK5CiG7PFjtMsIf865E3hwN0WjmJmDmTeepubWWAK
R3+Tj0jIciAx9qP+t5KDwNbExBdxnAMn9biffvr2HzA4Npn1OnDg6YC7S0B3
GPo+ZZJUnTkw2EC5fWDvYXhbIjA27cGBHsdZee+dPQwV4r95Pc5xYNCLkujS
nWawGifSHXmDA0fzNbsZcs1gT+q7NLlWDuQZ4ugZnjCH12IJ9+zbOPCpxmDm
xzVzOOt8wjDlIwfSfvhg28NmAQ/HMgwJ3RzYI3zWgKhpAaHRljqj3zhwc0Na
dkesBfDvduZ6s86BCn2e9fbKlpAleF35F4kTjbz6HpSlHwGFBf1FZVVOZKys
Uhx7dgSE9zubh2lwovG6eLd80xHwTD/ezqLHiU7XZrh4/h2Bw/nEcS1TTiRY
sx4gW1rBezXr+89dOHFjf9MuFj5riBfLkWTK4sQJv5PXqsqOAqSRrzy/w4mv
5FV71j8fhf6Y9dsWdznR5zPvmuvsUbBw8ZzPfsyJbc6v7xTttQHf/t97tCs5
keXN22Ni+Taw3t+/kt7FicmxLH1Z2bYgMKXL9JWdC+8W0r58+swORAwCzqVx
c6EAIdtCq8MOvI6a3jHj58K9nAkKC/N28LjEX7hVjAszWC+8WNY8Dr+7bw/V
K3JhIGsiSb3lOJjJhWb2HeRCM/k7a02/7eHVLbf51GtceOMkfzUn0RHM66qW
ZBK40MqEBNL6juDAW3GvIpkLdzyKbTtk5QgnaRRmBzK48EGI+fnJMEfYErE7
QXzAhaNbr1uN3jlC3MfwJ3/rqf4CZx+VeZ0Ew8ah3tV1LkymN39qWe8EoYEL
f3IJ3Fjw7YP6w14nOFKbVGi8gxt7I+yE+WacwOfFe1IGEzeuz2bFHxR2ho75
VnU9QW68dqNQgTPYGT7La58u0ODGpVbK+T1qp2Di8E8bxgBuDMtnX3vS7AIj
/31QKAnixtb0G68tRlxA5qHNk+Oh3NT9lfap4KoLlHv2ZxZf4EZltsBCJkVX
IGR3HndO5sZ2tXS6cxmu0IMrkePPuFEmJmf95hk3aHfgZD89yY306uPhRmQP
YBoz5d4zzY0j3/meHrDzgAijxYafs9wYw/X4pX+IB4x58e9yX+bGue+uphrl
HqCQ9mfZh44HafeHPkpS8oTKmz1/s2V4cK7M1PIJ0Qvo/N35wpx48BqjUPOG
iTfQqs1w33XlwaYJ7XEJP2+wFRgcafXkwRJmxazQDG+wuJ34XSiABycySHPv
vnuD++OCnNZLPDjywOz+zAUfuCfHRn/wPg/67LezT2j2hcMw8Gr6Jw/m9517
85jsB5omV7oUp3kw/ukzN4sjflAl9bDuzBwPBolKRQl6+cHUtRXupRWq/5fG
coZbfiDfZVPAwsSL9/8o63os+sEfTYF6JwVevHRMMdmqwh+sHu0seObPi3Xb
325pWgbCDm6/zzVBvBjL05dqfzoQDJ5GlHWE8uKplQfjd68Ewn2e7S8WL/Ji
juSbM8mVgeBgGBFjmsKLRQdWN9bEzkJEm3orfykv0jy7UaO7cBZkPhjE6S/y
4k0K53hh9TlgW7gU47XKi4Hju9iMes9B9EK5UdomL5ZSvsxsWzwHr49doP1F
y4e/w/ofzSkFwxOu8IwcPj58X3v0zaOnwfCIpk5EQYsP9Ru5MgsehEBOd9qL
/nA+5Emc0095FQa+eeYp5y7wYVVl97Zj38KAXLVkxxPNh/JZH29Z04eDI33V
fcskPnxbYBczfyQcxvJZxL/m8aGU3x/xmtlwUDKh7+Vp4UPLt6EJv5Qj4RG4
Z+hw8uPSCY2gFb8omJo51r7Ay4+CwCgSFxMF74ZX54uE+FH+8DsOck4U9JI3
du6R4UehNre72z5EAQNpt42sJj+mLj/OFthzAXhpdnX/d4Ife/6Z1udNXYBL
gn0XLZ7yY291j0FU9CXgd/IQ5C6izrdpsWMz9xLcpKnO7i7lx+bWQPG8l5cg
xs7c6UQNP56witG3mbsER34eWgz+xI/Fuz+LJp+4DJ7xRh79S/zI5Hu01ppy
BbR/7Xt52FAAR4Q44r5IXoU+KZ3tRBMB1OpdKffSvwpcbE912A4LICz3JxGd
rsLn0OLIzzYCuPeO5AG9u1fhHr23xanTAriRwzQfKR0DruccbMtSBPDNNR/2
FqVrkOvOqsA6JoB/zvO2WfnFgQn/+suyCQF8P5W9GZIaB/0echInfgsgXVB1
bltFHHxn6/EpXhBAx8BPezc34yCgolHIiV4Qax0nNW4lxcPgq+rBXwqCyJrw
nGmiKgEkVE0474YI4s4DsVK2gslAeKNWeipSEPl/XnbjICZDtbiektwlQUwN
ouX5YZAMlrQGr4vjBXF0OUNv2DsZfNR8JD7mCOLLDOIXyYZkUDL7qavSLIjt
jBcm6QKug1BYZ3celxDW/1qcOzZ5A4ajHe5P8guhXsnF0MHtKVBXGB+mLCqE
708Vc0WLpkAPw01okRNCmu3TFiZHUiB8glt+gyyEH7TNOO/XpUBxQm9DprsQ
Kk+d2/pyLxXGKNLH7tQI4fEnbseqr6YDi7jqBbpGIZwS4/vq8zAdusddyv1a
hXBg+MOAWUs6yM/QHDzwRQhv9wa53aHLgKNXRnfvnBLCvyKW71xjM8DdN2Go
kEcYW7vdz07cvAkPJBRyP3sLY8ISI/v1r5kQcH/bsS1/YRwdN1Sf38wERtuV
HQrBwrj6i/vZRcksmJpYUYy7KIxR/ePRyp5ZEJPI22uRIYxiCz+6vqxlwWTm
4ftsdcL44YWr7nG520DD/+8khUcEPR/vGj3wKAdi+dLS4gRFEJbaPLg/50CG
49ibHjERPHf8VAnveg5U+ems+O8RwV8Ny90n5XIh5X3j9jIQQdNHzE+cI3NB
WbQ4x81TBL3of6R/JeaBeKwRKaZWBCtOylk8e3wXrA53hLg2i6DuhL6mZ+Nd
CPz6+Jdhmwja7yrIPzR8F3yE1A/Q94pgjY3qZAzPPZi5JDifOSOCzHskRHsu
3YNV9QDFZVFRXJY/zbTdPR/G1d7+SYkUxW31uSWKZg9g+6pbacZlUWwUPtu0
58wDIOOrx9mxomhdald0JPkB9T7tL/0kXRR9zg+wqXx6AFmhdx07n4ui1rna
dXGrh7BZ9UbOYVgUpRvnPq+6PIJTfLk59iiGvEjbcOHZE2iXnubwMhbD8ne+
pXSdT0CDaFQUckgMIxL0BOuXn0BQ0Q7/TFsxfDqof7xr31MIZ+Vgn/ITw/bZ
0fCI4aeglx4yWXdXDK+YRjlyiT2DClbN7ifbxFFs6xrnydZC0MvvimncKY68
Z9ZkdiwWgv9Xma4henF08WpL9OcoAj59Kx0eNnG0w7NbRXpFkFmtjNeExNFQ
vEz/UWYRfLrLcShRVRyVnjD059sUg112vwaLmzjuMNoVsOPPC5D3ILRs9xTH
q/oVsjW0JWAzqDi8elocB6Wdr2SIlYBnE/3TKX9xXF9b6HxsXgIXO11LOiLF
ca/v+LRZRQnsz4jPLk8XxwOz5VzvY0oh5tWZ81PN4hhsVah21bAcPgutOMy3
iiNjI2fMRadyyKN92rbaRtXv4Um8e74cot/PmrB0iuO7rB5H8+pyWNjzblBz
WBzvr1oN+ihVQAPHP/8nS+Lo7XIt8+OuSphZ4GZdlpPA1YLVVWdiNRTWWZ0/
Ii+BG+qOM3JHqkGVRexWMVECGUKXqsVCqiFe9WOzt7oElteXf7jXUA0p9w1Y
/xhI4DWC1SNmu5fQ43zBk9VBAndzkeVvpryCLLZW/JgmgbLPflw4pvAGir/H
78BbErjNp/9nl80bcFKgDSzJlkA1prL9cZffAM+ZXNvMexJYvXMn3f2BN/A0
Xs7gTLEEMt7bz9RuXAsLUQbPdD9IYOcE/U4vQh0ET/1os9kpiXW/pr5pXquH
uxxdfvn0kphvUvtpV149xBswFc8ySeJ6RO6iUlU9tD54vRnLKYmKV9pP5E7W
w7H75v3NYpIY6fGea9S0AUjmNE/ttCWR4YBqIQtvI1ysHA9Z9ZXEU2abjAt1
TfCR3HTHNkASRWj0rrUMNoH987CTVUGS+GFqeP/LlSaQaRurDY2QxKQYGS46
5WYojHw3tSNOErmlmWNU8pshiXJ4h8YDSZQcWuzaSGyBbX5aglyDkvixNGzR
5HwruNja9wWOUPXEtKZ/3GmF7q5ylZ4xSVRpZmS4X9MKYYMh1benJNHrb7xG
8mYrfDl/kEt5WRI7HMvkRKPeAStkMAZzSWH/ZtVh9dj38N+E85cQEymsVXnJ
YvLyAzQuXSbNHJLC84EN9gXDH8CnwWGvi7kU5onb79bY0Q76p0o3LGyk0CxR
oK75UDuQPi/xqbtKoe3xpK5P39qhwvanjuBFKfw9UeRkx9gB1hVXGO2qpXDz
Hr+H3cFPcDo4wEypRgof7teh33D6BNujva3o66Ww9YSHWFXIJ1gkCt2ubJVC
dVYLzgsPPwHnXx9ZyT4pLN135rrFjs9Qmp+3X2BZCssOuSuyN3yGW+kbDTfV
pfFf9AWfDKsvQHm89ft7mTR6qZ2u7+zsAeUnFWoPq6RRfKTEt3mmB/Atr4Ln
a2m8Z+PK3cXUC6BwQG6+URqvGpCvGe3rBdFbS5aMX6Rxfy3ntvDyXvjbZ5Vt
Ny+Nxt9rmCi5fTBmKfbpIlEGf4vmb8+99hXkvcyGpp7KoFFw60eBimE45NCi
o1gkgzMJz/5EDQ7Dvdo/vv6lMnhBJSWfdtsIlNYtHd94JYOerPcW3smNwLdD
Kf+JtMsgo9kxLdVzI2DvzV52ZVYGt0x8FJP4RuGwe1/VitouLD15NSzZ9RsM
OApwBzfsQrTim3uo9wMCrL8+uT0mi7y5oh9rS39BL7ONj+qGHN76ak9asJ6D
M6H9nkDeg4/3mDO+ClqA7IzKdt+gvSiZ8ozpi/UKbHM7HW0Tthc7h2/dj3VZ
gcDeRlH9qL3oHmQiqRO4AuH7d8zzxe7FxObew9eurwB3pJRs++29mLty+UDP
+xV4Prl35lTTXjSMU+oTg1XoeCbDSeaRx1XbnZtJYmtg/qlZXl9QHnkvJtAe
UFiDB6liCvvF5LH0/C7ZZe01uKSfPWy9Wx51OLSVNa3XQLYN2c+T5RGvmS/r
xK9B936LxlUXeYzM87VRX1wD2jsvbuVWyOPL970x3HXrsLskP0v5tTymOlkH
H29fh0dFSi+a6uWRHH54JeXrOpxg/isy80Eez8V8pPu0sA6BUv8W/vsujzZV
DTWRuzdAYoW/R59DAdN02N9dStiAT52LOuO8CkjboSpafGsDZObaK2OFFXBE
6j/n9/c3wEzLeK1bVgHn3P34m19vwICa6eNwPQXkfn/05sffGxCpY9+37qWA
G2a3bFmNN8HP2Kun2E8Bz2x7I7ZkvglbQYOzbucU8LOHls6745uwU+FdUM9F
BfxPjumDov8m+Lx696XhlgIeOKM28DtrEzQbqhg+tyjgpixlmv/XJnz68KPn
5gcFVOwM7k35twnFl6caHTsVsElWInFxYxMuXD++/ndIAUnmV6r82beg9eXa
uOyiAkqVvXuFqltQHsE60CStiPaPqwz5z22B5MhuF+09imh5R+5HUOQW8PXT
/CokKqK/Wat1zZUtULh+Z/q2tiIaz5ap06VuQVlTQucVM0V8zaeTFVG4BQnO
ycbbrBVRjHI0Qqx8C2Y8aqrO2ymib5gFPn61BVvlR25FuCriNZ7TKwGtW/DW
LNDkSrgizgoeXv82ugXGy19LGS4qIv3i5ZraiS2Ynx4WTbqqiBtdD8OuTG/B
tq6z89k3FDH1vwNBDctb8HJ0KrvxkSJypbcr0dERKDvZjBjMn/8/nuMhyQwE
yv6rRUFDJYr4vFG9g5mZQOE85221XqOIypZng4bYCRTXjRzZfV2K+Ju9V/W7
AIFiNJ+Q19uviCmFv67sECZQbh0giPqMKKLaEmcknyiBkmiqIJb9SxHLnrgo
8UgSKJfzDPNV5xTR6GRl55YUgeJVdFu+fVERQxa8fw3IECidBW+Nd2wjokpc
uInPbgIl5tpKfy4dEfe87Q2R3Eug+G7I+OuxEFFs+c6ft/IEyuK4wrNwfiLK
xzwO+U0kUAIoEnY7iUTMIf34Eq9GoFQKWXM9USXimU9L05/UCZSXY1sdh7WJ
GG20MkevSaA0R/va3zEkos3Oj0kHtQmUWpFUeWNTIjqEn+W21SFQjgn8opkz
I+KdV4W2R3Wp+tx/3hgfJ+IG5/i6nB6BEsW98ujfSSJuuVUYrVP5VOi/m3fd
iGiV3SJXBwRK11e2ZHNvIiY8PHLrHIVAIfaEJtIEEHHMoSZRDAmUNC6X1BfB
RPRrit6qpHIuZTPvVCQRZQ5ZfDPQJ1CieYMq+C4T0X/vT4VaKltar395f42I
EXeU+xQMCJSH5QW9a0lEFHnnJp9K5dQgSS6FdCImCj/VmqTym8TMyw7ZRKRL
WVqQ30fV226hkHKXiEZqodYOVA79cYXl7SMiKl+8YRZF5U2zAJnN50Ss//q5
L4nK4T5Hz6qVEdFpnvAzgcqW/r4b3i+J2EPk9QulMuH28uuHdUQkSFC8rKi8
U4dU8a2FiLeGR9pEqdyebzkp2k7E2tCk+G5qPG16uUeOfyEigwN/XjiVb4dY
rmT2E7HtdQQNB5X/fHrS0z9CxOK/S/kp1HyPdYzNCE1Q6/ln4eIOKl9n0NU/
MU3E7BsiKc7U9TorOtee95cav+jBD0XU9d3+ipI+vkLEyYT03b+p659xSPUg
L4GEXZsHcnmofInSOaW1nYSX2H/vVqDWK0hMWPYELQnrDHXeKJMJFL4+BZpL
DCRcPUW03UWtd1CZbFI7GwnDaGmjerQIlKXOQwYLnCQkvVzZSqX2T1ZjZZow
LwlvBpd5UjSo9bbu4/EWJuHt74qTjqoEynvpDwbpYiTM8u+e61Km9rfIRfZa
SRKyhAp+1FQiUDbkC6J5dpPwR9K3vy0KBIpbrgMJ5UkYbKqq/I/a70ErZiHe
RBK+vlyjzLqHQPnvmOdkixoJ5+1eezLtIlBGxL4bXtYnYevLTqs9IgQKDs3/
LjUkYfXsY4NGQWp/iGirju8n4ZBiVr8pP4Fy4NvMPZPDJLyfubwmxUWgBCt6
MgkdJ+Fu87mxJep+wBD0vMKMGoLDutLs5g5q/52S3XnViYQpkZHZf2kIlPwa
tcsL7iRMOyb/1HRpC+jO6/D2nyXhPfbXZXYDW/DTpvJ+XRJVP4pOKSuHul8d
K7B5d4OaX3g9/MrYgsy3k7c600j4RGgqVCh5Cx6RHrdMZJHwfdrjG8JRW3BR
i6eT9xEJr3sdlr57Ygv2isTWJtWS8Ir7PEcDzxZYGB09lddAwrPVJhyCzFtg
uJvjZkkzCT/t2TNkvm0LdG6WFva1kTDycwTfqT+b8Cbu9l35PhLm2+7O427a
BGYtqefTcyQsS9qlXXp6Ex5FS9rTL1DzeeBzSuzkJpwvLL8ttUxCTdVTHqet
NsHBkP6L3SYJR36etSogb4JtkC5/J6MSsrAWMjczU+35NryDUkr44c8/5rPU
8y3fcuS+g7USNvG3j52jnq/bBlpaw22VcNj76+nMF+sg6tAfnnlcCQkppur3
7q1DgupEco+TEloNkxncr6xDiYZfgI2vEhLrtnTqjanjnw9pno1Rwl9w9FR3
yxqkMn4JFXqphHtJPJbh5asAAyo3xSWV8ZJ9mHeN9TKoCqWerGZQQZb9K4oS
5+fBxdc6hsSigqLacmmX3edBcVnD7CG7Cg5Pex2dMJ+HZ18/NKTzqWCGgG7n
U+l52BkVSo6QUUE2OYZe9XdzUB2UluqOKpjg81UnmmcOONIHc6tCVHCNgbLM
bz8Dd/q7Xpr+VsFGhs+TFr8mgYfP+oXmrArSf+l4Gfd6Eu7P9Pvs+qeCy0W/
pUaTJmEwMVF7x7oK/pPtcRtTnQSriTHxViZVvPzDwtk86ifQOKaYBu9VRWWy
kLSCyASQ92/Je3up4r2Y4KhIv+9wNApJAb6qyPvv2yGG/d/h2fi5zZAAVbza
dMjsleh3uKVzcv1amCq+3DYplt02BjRFVy+WxKli8YnxAZM9Y3B10+SrfIEq
zkn+l5M7PQruHNF9VdOqOOUmGnl77zBUfv5+oHlOFQd2Gdfs/DEER0rqL3Yu
qOIgTaBp650hcN5M/292QxX3JNV6OHMNQW/KqIUKqxpWHwmh/UUYBDVFXtKw
ohpW7Dm8K2y6H9grDA9/PKOGfX6OM60sPcCiTBFaCFTDhvWnpI3P3RCWllcq
FKKG0VPnUpNvdkMki6aZ1wU1NHm11tkj3Q0vNFiJ3DfUMPAHl+ZP7AIVn4PP
40uoetNd/oyJnTAwxdomsKSGOYc7xuq9O2B3l1o4+xp1vpxi/W36HeDsHzRG
t6WGdV/nCm/wdoDmwtueZVp1fOm6wHfwwkfoLTO3G+NVxw8ZjR+klNrhRPLq
VL+6OmpkmHQ+eP6e+r9sJDyorY4nb6SsC558DzmNb2hH9NSx9I/14h7u9/AV
39D9NFJHvq7s88Lh7yBwNOs14ag6DkumhmtatsIhNzleq3Pq2NjhW/NNpAW6
BjYmncLUsUpF3KG3rxl65gVC/M6r45fckqST6c2QrPKsNfmqOkr96bOS52iG
qvq/Gr0Z6thQ1cqXwtIEtttLXGMr1bFlc2BQRKIBEn+9XwtfVcdaOjrfI/Zv
IG/fia21TXU8vDlNrzpTA8u0ct/DtmtghEDSK/LFGojj4bSIZNbA5NwghbdP
X4PmCe7GBFENjEwwXLzC/Ap8JRNle/Q10CBBfHzn9ipI5rWwPGWsgTzXe+of
P6gE9wxO53lTDezcd2XR1rQSNCt1iBxWGqg8sva2J6MCwp9znLd108B/Vytq
uMjl0Dq1TZonXgNF2GSDR8pLIH0xLr8oWQNVLrXlnfIsgeNew0yH0jTwUbXH
1W7REmjRzkyKuaOB7yWFB8JiX8AMs8UZxmIN9ODs48o4XQyjAeE1Wt0ayG1X
ja2lz8HId6p2rF8Ds0V4CG80noPO5ZWCxGENfGcYZm/56hncHyrWn/ipgap/
A5b3vyuA4CsJHvfWNPDJGsF4a/kJOCaIfTCW0MR75XwP7e88hBub5apFMpr4
c4L9ohzlIag98PEU2KOJPcUW9bvHHoCSbhflj7ImmnJ/62mQfwAtETm38/Zp
Yi9dU8XO9nxwbdfTJLprogvL9Po+o7tQzpeUkn9aE//K32cVX80DTyP7N4J+
mnjKoiBgR2EebH/BdI0hVBPLnYech4TyoODrwM/ZOE2UynHsjqPJhRu7366N
F2riWzV9a5qFLDA3GDnjUaqJQ8r+/G5hWSD7o7/yd6Um2jbvVojfngXdQxz1
C3WaeFit6SJBIBP8aN+85viiibXlf5kYbG6CWZxUe2avJuZaT9qM/MqA/+Jy
XkgPauLW2jUlswsZkLMevKw9ronMRa6vxovSoVVxNsxvWRPruJmveEumAWn8
PyWaDU10rizUv1qfCgkday+v02jhwaiSDu5TqdAiPmBexqiFkYmcOSFPU2DZ
b+0SrYgWWsvJP5wxuQGjR+elPqEWPtI2qSq4ngQ/ZAxojxpReeiBq95WInSM
TlcMmmghjVrtiIBvIigU/7g2bamFjl/bPiRbJYD/9jO/eV21kG7m8I5S3ThI
c8s7dM9TC7X6b0i0voyFoIvW50m+WvjvP7m2P7qx4ACjRw4Fa6FvxHkrM8Nr
wLU9uS05VgvD+EcjCr2vwqTgYplUkhZqn9YdiFuPhu/2TH4VKVqY/OL7OYOE
aNi603d8NFsLb3j7TOwpvQKZgpJsUKiFXlX/YvfyXQb7yJNbEl+0MOJaPzyT
vwBKBGee+l6qXcgFHbuj4OFd3y2nQS1s2t3pnXQhCr6p6Js9HNdC78us4rcq
z8Ml74WfWivU/BUbzY8ZRkDzk+B7IxvUeFxHr9sUhsPNRA2VmG3amHraVW9N
KBzIrDSdfUzaaDJxloF2IxTkP8zxXRXVRp912rfig8EwOx0VpSqljTunGrYr
2QWD92zEm2+y2lhYIDFw8+s5iNG2q0MlbaQpp6M1HQuCkMaeXoZ92ticdiOd
wnIWztqmB9d7aOMzOfIgTaMfRE0ep3z30cbGWzGlTnZ+oBTpSkcXqI0nUrOd
Jv6dgTIJhtTDkdoos2YlrK54Buqc1gp+39BGX9GFqHd+3sA4vj+Q96Y2Fhd2
KdfWngYHdNPF29pYIi3z1IvrNNhJDH289VAb6Zbom3IaPMGXXZ7h6Cuqfc8b
9meH3MHy1rmBmDptTCSPPD5f6QY3tKRfvGzWRia26H9XdrnBi5seLtKftDHg
tivdHJMrCI1Iz9GMa2OF8WjW/VVnwD/LAzq/tJH84VhmcIQzLNbXtgXNaqPU
t6zvTNud4dinhcqZVW3UrlhtIvM6QaxUZOs0mw7SSBhpONs5wp764H4ijw5m
FguLZ/xwgJ0m67P+gjr41PlasbCAA8yc9CCuS+tgpd5RqZ8J9nD+7+klQW0d
PFBy0ICm4Bh09YC2C+ig5B859aUNW8gAlctF+3QwaPyx6IylLfhL7lc0OayD
6CCqe4PJBtilG0eundJBlg6LoaCHVkDXpuo04KGD4U7+qqZ8VvCa2fE30VcH
uXUZdl+JPQLR4qVC/SE6OEuzbWM01BICtRd+aSfpYPQlBknbC+YQyDRYmZZK
1XdTXvNjNIcSBuHkuVs6OHAnIto93Qwa031OFOTrYOLm5ReO3ofhwimOKMVq
Hez4s7SbWfEgDK/3O6m90cEZp0MCJedM4d3YX0Vyow6e3/b9enyTCSx2v7p0
uJ3q71KZeN77APy9fkj6/DcdNN6e/JfntxHgYxXrhAkdJP3VerR5xAhKDrzy
z/6tgyPnHwUE1hlChJXD6deLOhiZR3B9mb8PJNLSXBmZdNGNVepA+Q19kH+l
OS/Grov6uV1tO3j1gSu100OdRxeFyL+0zbMRHkVkibiK6eIrmVjLu8UUyFiV
yu5Q0cUGL1H/nlUydKupxk9r6qIeHcJXBTK0a6V4MOnpotevdJXvLrpQ9HLy
94H9ujjFeHVb2ndtKNEuFPx8XBePHGDjDRfQhNf8v0MWT+ri9A9e7kI/DRB6
19EiRG1h9Z3/FXK1q4NUnR7Jw08X5c2lwjhS1KDT21OTLVoX10f/fDhqqgLL
Ivc4dOKo4299fBpfrwzdeUP9bsm6OBGUnKJHVoZwbWa9xkxd7I42SG7RVYIY
GtqDMYW66Jt6QSOpURGuego8eVmqi3Jcm4ZB4wrAlRu/MlOli30lfrHSrAow
ewm97Rp1MSaxqt/UZy988ikqIPfpIp0L3pDwkYNyw4TM4CFdnJzppL9VLQsR
g3JhpWO6yMr/SeELkywInDzIQ/yji48CLDzEX8mA4xzvC+J2MpYNhSVsmUlB
dJP7D1YGMi7Puc7NFUrCYsfi/hlWMvq9BsdaLkmwGX+dVyJIxgWLePSYFAd6
Xf+MDHEydjS1VdHYicNeR9ua8F1kNB84dv57nhhkqlbkmihT5+8gJtbeEIGg
1MfHVTTJyNb5WW1fhjBMSjSbiOiRkdSyV+naPSF48fxszb8DZFR58+9q8GcB
KCgIZnxxkoxf3pt9l7rMC2IQfSLfjYxaP7YxDtfyQDFf4XiGNxmbf162q9vO
Axa8B1MvhpDxTqPadaMsLqgXIFeHnCcjg0LN1PUZTqgVMeDxv0JGlnmTQ1YH
OEHfO8bL9ToZjxqkeeYxcwCs7XNzyiCjc1y/79ez7FDLynHL4TYZd8YfZRlp
YQO6ns859o/JWOX/0V8hmwXOyA5S3OvImEcXfVDiGQNYNi789W4hY1Bo1mJ2
Ez2kWvAMB34gY3mca1bZDzpYm3I5Ed1HxmtdUWydOrRg4MHzN3mYjIzCFlGu
fjuht/ZtbfYPMt64SidU+mwH7PDTpK+cI2O8d/XkU63tIJYfcLFliYx7s05/
nI3ZBkkuReq9G9R4g2RIMkM0QNMt/98Ggx6CsSxd3i0CrLHIUawl9fBETtQZ
4dx1Pc81l+u+cnooqb9cO5Cypjdrck80VlEPv/wwlO9IXtUTnhH6U6+th4yV
f3fJ3l/W+2zZQxql6KHF7OmItZdLeu7aN4oIxnrYlvTQ8Xv/ot6GDp27gaUe
bm0nv/1FXNCrasdcV1s9rBsG0TiXf3pdn8N54xz0cM4yOJZy96/etucLr3u8
9NDsl0rgdtK83uip0pktPz1sCFwn5kbN6c0dPOu4O1gP5cenXP16ZvU6FoPZ
j0Tq4XSAb7++6qzextbW1vnLeihIXnvdoDCj9z/4yMBA
          "]]}, Annotation[#, "Charting`Private`Tag$5777#1"]& ]}}, {{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          Hue[0.5, 1, 1], 
          AbsoluteDashing[{2, 5}]], 
         LineBox[CompressedData["
1:eJwVl3c4Vv8bx40KJXtFkhUynmPPx90tktLSIitkh1CyE5GZnb6FzKKQFYoG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          "]]}, Annotation[#, "Charting`Private`Tag$5928#1"]& ]}}}, {
    ImageSize -> 400, DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], Axes -> {True, True}, AxesLabel -> {None, None}, 
     AxesOrigin -> {200000.00000000006`, 0}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox["\"utility of wealth\"", TraditionalForm], None}, {
        FormBox["\"wealth\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> Automatic, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {All, All}, PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*SuperscriptBox[\\\"\[ExponentialE]\\\", \
StyleBox[\\\"u1\\\",FontSlant->\\\"Italic\\\"]]\\)\"", 
       "\"\\!\\(\\*SuperscriptBox[\\\"\[ExponentialE]\\\", \
StyleBox[\\\"u2\\\",FontSlant->\\\"Italic\\\"]]\\)\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.9, 1, 1], 
                    AbsoluteDashing[{1, 0}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.9, 1, 1], 
                    AbsoluteDashing[{1, 0}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.5, 1, 1], 
                    AbsoluteDashing[{2, 5}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.5, 1, 1], 
                    AbsoluteDashing[{2, 5}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{"{", 
                   RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.9, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.9`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.9], Editable -> False, Selectable -> False], ",", 
                    RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{"{", 
                   RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.5, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.5`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.5, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.5], Editable -> False, Selectable -> False], ",", 
                    RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "5"}], "}"}], "]"}]}], "}"}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& ), Editable -> True], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.402786687079125*^9, 3.40278801653225*^9, 3.40278808803225*^9, 
   3.529698588922692*^9, 3.529707976858651*^9, 3.529708330112856*^9, 
   3.529790007438532*^9, 3.5297931465604954`*^9, 3.5299351392120495`*^9, 
   3.529937327379205*^9, 3.530016408994415*^9, 3.53001667675873*^9, 
   3.5300167276816425`*^9, 3.530017190224098*^9, 3.5301936938457994`*^9, 
   3.5301942415031233`*^9, 3.531448232223939*^9, 3.5315006284818335`*^9, 
   3.5331347134878626`*^9, 3.533135882869747*^9, 3.533682257234375*^9, 
   3.533734596386281*^9, 3.533754148625*^9, 3.53375542003125*^9, 
   3.5386852335027847`*^9, 3.5386855199711695`*^9, 3.539635960827327*^9, 
   3.540126829839363*^9, 3.541012648438993*^9, 3.541015116661167*^9, 
   3.541015590068245*^9, 3.5410156549129534`*^9, 3.5416004598738213`*^9, 
   3.543342207381116*^9, 3.6963384640275064`*^9, 3.6963423764917765`*^9, 
   3.696343668404028*^9, {3.696343698626438*^9, 3.696343711414456*^9}, 
   3.6963437518209634`*^9, 3.6965443616930757`*^9, 3.731421194438011*^9},
 TextAlignment->Center,ExpressionUUID->"6909ce09-20e7-4a7b-b0c7-d332c572abf8"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6.21.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 "Parametric plot of utility of wealth against wealth for two different \
distributions (portrayals of risk)."
}], "FigureCaption",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5315001553967743`*^9, 3.5315005826322107`*^9}, 
   3.53868551997217*^9, {3.5387544977804747`*^9, 3.5387544981934986`*^9}, 
   3.5396074930510635`*^9},
 TextAlignment->Center,ExpressionUUID->"2dc161e1-3d4d-4913-8b6a-2e06586c270c"],

Cell["\<\
The question becomes: Is the investor better off with the investment having \
the first or second probability distribution? The same Expected Utility \
Hypothesis that resolved Bernoulli's paradox provides the answer.  Remember \
that the distributions differed only in the variance.  \
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5297084127765837`*^9, 
  3.53868551997217*^9},ExpressionUUID->"463dcf1f-dbf2-4628-b6a6-0fe4779b308a"],

Cell["\<\
We compute the expected utility of each by integrating the product of the \
utility function and its probability distribution (this integration is the \
definition of expectation for continuous variables).\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5297084127765837`*^9, 
  3.53868551997217*^9},ExpressionUUID->"c6cf1e3e-0ac1-4dc5-935c-d7857be9261e"],

Cell[CellGroupData[{

Cell[TextData[{
 "Integrating the functions above is shown below this cell and includes a \
very small error to consider the fact that we are not including a tiny \
fraction of the distribution which is negative. The correct output involves \
creating a truncated ",
 StyleBox["pdf",
  FontSlant->"Italic"],
 " that specifically precludes negative values and produces the correct \
expectations you see here:"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.530228425959363*^9, 3.530228549186411*^9}, {
   3.5302286163662534`*^9, 3.530228646396971*^9}, 
   3.53868551997217*^9},ExpressionUUID->"61a897a5-1566-4388-ba9d-\
0cd7fedd25f4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      StyleBox["u1",
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       RowBox[{"pd", 
        StyleBox["uw1",
         FontColor->RGBColor[1, 0, 0]]}]]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      StyleBox["u1",
       FontColor->RGBColor[1, 0, 0]], ",", 
      RowBox[{"Log", "[", 
       RowBox[{"2", " ", 
        SuperscriptBox["10", "5"]}], "]"}], ",", 
      RowBox[{"Log", "[", 
       RowBox[{"2", " ", 
        SuperscriptBox["10", "6"]}], "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      StyleBox["u2",
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       RowBox[{"pd", 
        StyleBox["uw2",
         FontColor->RGBColor[0, 0, 1]]}]]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      StyleBox["u2",
       FontColor->RGBColor[0, 0, 1]], ",", 
      RowBox[{"Log", "[", 
       RowBox[{"2", " ", 
        SuperscriptBox["10", "5"]}], "]"}], ",", 
      RowBox[{"Log", "[", 
       RowBox[{"2", " ", 
        SuperscriptBox["10", "6"]}], "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<Expected Utility \!\(\*SubscriptBox[\(pdf\), \(1\)]\)\>\"", ",", 
       "\"\<Expected Utility \!\(\*SubscriptBox[\(pdf\), \(2\)]\)\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"%%", ",", "%"}], "}"}]}], "}"}], "]"}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.529708439572117*^9, 3.52970861848635*^9}, 
   3.53868551997217*^9, 
   3.539635909090368*^9},ExpressionUUID->"ee16f6e9-38eb-4521-88d4-\
6af85578742f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"twdSV", "=", 
   RowBox[{"TruncatedDistribution", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "\[Infinity]"}], "}"}], ",", 
     RowBox[{"NormalDistribution", "[", 
      RowBox[{
       RowBox[{"10", "^", "6"}], ",", 
       RowBox[{"2", " ", 
        RowBox[{"10", "^", "5"}]}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twdLV", "=", 
   RowBox[{"TruncatedDistribution", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "\[Infinity]"}], "}"}], ",", 
     RowBox[{"NormalDistribution", "[", 
      RowBox[{
       RowBox[{"10", "^", "6"}], ",", 
       RowBox[{"2.5", " ", 
        RowBox[{"10", "^", "5"}]}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"etwdSV", "=", 
   RowBox[{"Expectation", "[", 
    RowBox[{
     RowBox[{"Log", "[", "x", "]"}], ",", 
     RowBox[{"x", "\[Distributed]", "twdSV"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"etwdLV", "=", 
   RowBox[{"Expectation", "[", 
    RowBox[{
     RowBox[{"Log", "[", "x", "]"}], ",", 
     RowBox[{"x", "\[Distributed]", "twdLV"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Expected Utility \
\!\(\*SubscriptBox[StyleBox[\"pdf\",FontSlant->\"Italic\"], \"1\"]\)\>\"", 
        ",", "\"\<Expected Utility \
\!\(\*SubscriptBox[StyleBox[\"pdf\",FontSlant->\"Italic\"], \"2\"]\)\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"N", "[", "etwdSV", "]"}], ",", 
        RowBox[{"N", "[", "etwdLV", "]"}]}], "}"}]}], "}"}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.530228205297742*^9, 3.530228375850497*^9}, {
   3.533138038576047*^9, 3.5331380497086835`*^9}, 
   3.5386855199731703`*^9},ExpressionUUID->"1ac8be0b-e636-4723-9c2a-\
80754829ee54"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"Expected Utility \
\\!\\(\\*SubscriptBox[StyleBox[\\\"pdf\\\",FontSlant->\\\"Italic\\\"], \
\\\"1\\\"]\\)\"\>", "\<\"Expected Utility \
\\!\\(\\*SubscriptBox[StyleBox[\\\"pdf\\\",FontSlant->\\\"Italic\\\"], \
\\\"2\\\"]\\)\"\>"},
     {"13.794100960889805`", "13.780417354392059`"}
    },
    AutoDelete->False,
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.539635969919847*^9, 3.540126841598036*^9, 
  3.541012658244554*^9, 3.5410146980732255`*^9, 3.5410151260497046`*^9, 
  3.5410155995057845`*^9, 3.5416004694073668`*^9, 3.5433422169506636`*^9, 
  3.696338464239073*^9, 3.6963423839415903`*^9, 3.696544369132902*^9, 
  3.7314212036846404`*^9},
 TextAlignment->Center,ExpressionUUID->"ce77eb72-72cf-46e4-ab2e-80d4154bfa17"]
}, Open  ]],

Cell[TextData[{
 "The result, that the expected utility of ",
 StyleBox["u1",
  FontWeight->"Bold"],
 " is slightly larger, is intuitively satisfying as one would expect, given \
identical means and the specific form of the utility function we have chosen, \
that the distribution having the higher variance (risk) produces less \
expected utility."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199731703`*^9},ExpressionUUID->"6019f7c5-b9a2-4040-bf54-\
70461bb7265c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.9. Conclusion", "Section",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.531447172614333*^9, 3.5314481940477552`*^9, 
  3.5386855199731703`*^9},ExpressionUUID->"e9433530-2321-4085-8e05-\
a815b7762740"],

Cell["\<\
This chapter lays the foundation upon which we must stand to begin our \
discussion of risk in real estate. One must appreciate how risk has been \
dealt with by others to understand how real estate risk differs. Most risk \
models in finance depend on the classical mathematics of binary probability \
(coin flipping) and its close cousin, the normal probability distribution. \
Much ground has been gained on the subject using these models. Important \
messages to be transferred into our thinking about real estate risk include:\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199731703`*^9},ExpressionUUID->"52720199-80dd-486b-bc87-\
586683506cd3"],

Cell["\<\
Utility is a powerful way to express the consequences that arise from making \
choices;\
\>", "Item1",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.529708717461011*^9, 
  3.5386855199731703`*^9},ExpressionUUID->"da5b95b3-41d7-462a-9350-\
583e4d88f7cd"],

Cell[TextData[{
 StyleBox["By valuing different dollars differently, people make decisions on \
the margins. It is not average outcomes that count but marginal outcomes",
  CharacterEncoding -> "WindowsANSI"],
 ";"
}], "Item1",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5297087192551136`*^9, 
  3.5386855199731703`*^9},ExpressionUUID->"d63e4e83-c142-4a11-833f-\
6d1fd049a715"],

Cell["\<\
The assumption that utility functions are concave is supported by \
considerable evidence, thus the shape of the utility function bears on the \
way people evaluate risk;\
\>", "Item1",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5297087210372157`*^9, 
  3.5386855199731703`*^9},ExpressionUUID->"82034d51-08f0-46d7-a5bd-\
afce2c17b00a"],

Cell["\<\
A closer look at the shape of utility functions discloses that different \
people see the same risk differently. Through a bidding process in the market \
their aggregate behavior determines the price of risky assets;\
\>", "Item1",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5297087228703203`*^9, 
  3.5386855199731703`*^9},ExpressionUUID->"d28174d0-51c9-4676-a46d-\
bdbd50858b16"],

Cell["\<\
Risk is a shape. Specifically, it is the shape of a probability distribution \
of wealth, a plot of numerous outcomes representing the realization of \
previously uncertain events; and\
\>", "Item1",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5297087247724295`*^9, 
  3.5386855199731703`*^9},ExpressionUUID->"537aa3d1-add2-44f9-b0f9-\
8bbcc1344f8d"],

Cell["\<\
The shape of the transformed probability distribution is related to the shape \
of one's utility function through the mathematical expectation and the \
variance.\
\>", "Item1",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5297087264745264`*^9, 
  3.5386855199731703`*^9},ExpressionUUID->"8df168b0-c012-42d0-9603-\
cb08a7f8cf40"],

Cell["\<\
But, you say, empirical tests of these models have been conducted primarily \
in the market for financial products. In those markets one can justify using \
tools based on random outcomes (stock price changes either up or down out of \
control of the investor).To a good approximation these outcomes may be \
modeled as continuous. A  harsh position might claim that the stock market \
can be modeled with tools based on gambling because the stock market looks a \
lot like gambling to some people.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.5386855199731703`*^9, 
  3.5410147199454765`*^9},ExpressionUUID->"ecc699ea-2651-4221-b8d2-\
4fb92520333d"]
}, Open  ]],

Cell["\<\
The \"some people\" who might make this uncharitable characterization are \
very often real estate investors. At this point they might rightfully ask: \
\"What about us? How should we model risk? These shapes don't look much like \
our world.\" These people contend that their market is neither random nor \
continuous. It may be that it is neither linear nor static (few things are, \
including the stock market). Accordingly, the risk they face is a very \
different kind of risk.

It is to those people and their questions that we now turn.\
\>", "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.5386855199731703`*^9, {3.5410147199454765`*^9, 3.5410147296550317`*^9}, {
   3.541601003884937*^9, 
   3.5416010107843313`*^9}},ExpressionUUID->"6b0648c4-2cf9-43a9-8872-\
8c31f76710be"],

Cell["Endnotes", "EndnoteSection",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529708912522168*^9, 3.5297089146602902`*^9}, 
   3.5386855199731703`*^9},ExpressionUUID->"dbc70116-1053-4dc2-b564-\
bda6ea356bb2"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "1"], TraditionalForm]],ExpressionUUID->
  "ccb3b147-5c89-4cd6-b3e3-f212e9d06c6b"],
 "There is a further constraint, provided solely in the interest of \
exposition, that the maximum value of either choice is 10, hence the minimum \
to produce 30 is 3."
}], "Endnote",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellChangeTimes->{{3.529708933994396*^9, 3.529708944777013*^9}, 
   3.529709453394104*^9, {3.5297095416981544`*^9, 3.529709541702155*^9}, {
   3.5386855199731703`*^9, 3.53868551997517*^9}},
 CellTags->"endnote1",ExpressionUUID->"93e93859-ce69-457b-a1e1-d23c252617aa"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]],ExpressionUUID->
  "f57c25b2-7e6f-4cdb-8a5a-25bfb26d3494"],
 "Not everyone is risk averse and even those who are can be inconsistent. \
People buy insurance and lottery tickets. The idea of \
\[OpenCurlyDoubleQuote]risk loving\[CloseCurlyDoubleQuote] exists but is \
assumed not be of sufficient importance to affect our discussion here."
}], "Endnote",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellChangeTimes->{{3.529709546128408*^9, 3.5297095704688005`*^9}, {
  3.529709701452292*^9, 3.529709701456292*^9}, {3.53868551997517*^9, 
  3.53868551997617*^9}},
 CellTags->"endnote2",ExpressionUUID->"9e9f6067-29ce-45d2-b13c-6f2c6e78297f"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "3"], TraditionalForm]],ExpressionUUID->
  "2297c48e-1e2d-4454-85b7-6aaac51d533d"],
 "Using this reasoning we will shortly develop the idea of risk averse \
behavior. There is another, less common, resolution using a ",
 StyleBox["convex",
  FontSlant->"Italic"],
 " utility function. While permitted under the Expected Utility Hypothesis, \
it implies risk loving behavior, something we observe less frequently than \
the alternative. The interested student may wish to inquire into the \
Friedman-Savage utility function."
}], "Endnote",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellChangeTimes->{{3.52970970910273*^9, 3.529709719197307*^9}, 
   3.5297097727463703`*^9, {3.52970986908188*^9, 3.52970986908688*^9}, {
   3.5299389827018843`*^9, 3.529939030866639*^9}, {3.5331381202067156`*^9, 
   3.533138121413785*^9}, {3.53868551997617*^9, 3.53868551997717*^9}},
 CellTags->"endnote3",ExpressionUUID->"7f15b561-c91e-4fff-a1d2-ad6c3cc2ac89"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "4"], TraditionalForm]],ExpressionUUID->
  "30788a1b-7a83-4937-a8eb-db27f2ae9b33"],
 "The reader is urged to be patient with the abstract notion of utility as it \
is pervasive in economics and in life. It has been observed that even those \
who don\[CloseCurlyQuote]t believe in the expected utility hypothesis ",
 StyleBox["act",
  FontSlant->"Italic"],
 " as if they do."
}], "Endnote",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellChangeTimes->{{3.529709871157999*^9, 3.5297099147154903`*^9}, {
  3.529709985038512*^9, 3.529710013621147*^9}, {3.5297102414561787`*^9, 
  3.529710241461179*^9}, {3.53868551997717*^9, 3.53868551997717*^9}},
 CellTags->"endnote4",ExpressionUUID->"8b9809ef-19f8-4e2e-9ffc-6786251f6a4d"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "5"], TraditionalForm]],ExpressionUUID->
  "3e4c34b1-ee3d-4dba-90ed-d462fa2b0e52"],
 "Such people are usually not people at all but companies, namely insurance \
companies having unlimited life and access to capital."
}], "Endnote",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellChangeTimes->{{3.52971024410233*^9, 3.5297102588131714`*^9}, {
  3.529710330401266*^9, 3.529710330405266*^9}, {3.5386855199781704`*^9, 
  3.5386855199781704`*^9}},
 CellTags->"endnote5",ExpressionUUID->"9ede99b8-7033-4f3d-861f-8e669294f49d"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "6"], TraditionalForm]],ExpressionUUID->
  "0829e069-39e2-4cd4-b951-e6a707319de4"],
 StyleBox["Note the important generality that the utility of the expectation \
is larger than the expectation of the utility, something that is no surprise \
to mathematicians who have long known about \[OpenCurlyDoubleQuote]Jensen\
\[CloseCurlyQuote]s Inequality\[CloseCurlyDoubleQuote] which we discussed in \
Chapter 5. (This is the converse of the Jensen case in Chapter 5 as this \
example deals with concave functions and most of our Chapter 5 case involved \
a convex function).",
  FontColor->GrayLevel[0]]
}], "Endnote",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellChangeTimes->{{3.529710332791403*^9, 3.529710340659853*^9}, 
   3.5297104605087075`*^9, {3.5297105274005337`*^9, 3.5297105274045343`*^9}, 
   3.529710666089466*^9, {3.5299384391587954`*^9, 3.5299384391637955`*^9}, {
   3.5386855199781704`*^9, 3.5386855199801702`*^9}},
 CellTags->"endnote6",ExpressionUUID->"63cb079d-3452-496e-afbc-4534626f1113"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "7"], TraditionalForm]],ExpressionUUID->
  "c0f22c95-7f27-43b3-9a2b-8699bcadd1d7"],
 "This is also known as \[OpenCurlyDoubleQuote]Arrow-Pratt Absolute Risk \
Aversion\[CloseCurlyDoubleQuote] which may be contrasted with \
\[OpenCurlyDoubleQuote]Relative Risk Aversion\[CloseCurlyDoubleQuote] and may \
be found in most microeconomics texts."
}], "Endnote",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellChangeTimes->{{3.529938441458927*^9, 3.529938537962446*^9}, {
  3.5386855199801702`*^9, 3.5386855199811707`*^9}},
 CellTags->"endnote7",ExpressionUUID->"3cf3f7af-148b-45bb-a50f-041d7037bd6e"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "8"], TraditionalForm]],ExpressionUUID->
  "7fb91ad1-698d-452f-ad7a-25eb3dad4e7a"],
 "Perhaps a better characterization is investing in the same building a large \
number of times."
}], "Endnote",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellChangeTimes->{{3.5297105297486677`*^9, 3.5297105367830706`*^9}, 
   3.5297105848298187`*^9, {3.529938636350074*^9, 3.529938636350074*^9}, {
   3.53868551998217*^9, 3.5386855199831705`*^9}},
 CellTags->"endnote8",ExpressionUUID->"367c8c69-6d35-49b4-a7b1-2b517e171887"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "9"], TraditionalForm]],ExpressionUUID->
  "c58fb559-18ba-46b8-aee2-77fc70837499"],
 "Or the standard deviation, which is the square root of the variance. As the \
square root transformation is monotonic, it does not matter which is used. \
The reader is asked to tolerate the rocky motion of moving back and forth \
between them, something that is unfortunately too common in texts on this \
subject."
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 PageBreakBelow->True,
 CellChangeTimes->{
  3.5297106592510753`*^9, {3.529710884126937*^9, 3.5297109007878904`*^9}, {
   3.529710961190345*^9, 3.5297109611943455`*^9}, {3.529938641298357*^9, 
   3.529938641298357*^9}, {3.5386855199831705`*^9, 3.5386855199841704`*^9}},
 CellTags->"endnote9",ExpressionUUID->"14e06746-7bef-448d-a41e-2dbf5c40a3cc"],

Cell["References", "ReferenceSection",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297089792469845`*^9, 3.5297089818371325`*^9}, 
   3.5386855199841704`*^9},ExpressionUUID->"ea8dd882-20ec-4f0c-9a36-\
e79b5a75d662"],

Cell[TextData[{
 "Dowd, K. (1999). ",
 StyleBox["Too Big to Fail? Long Term Capital Management and the Federal \
Reserve",
  FontVariations->{"Underline"->True}],
 ". Washington, CD: Cato Institute Briefing Paper #52."
}], "Reference",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297090402854757`*^9, 3.5297090464298267`*^9}, 
   3.5386855199841704`*^9, 
   3.539636042689009*^9},ExpressionUUID->"1c87383c-4f8c-4856-99c2-\
6ed48ec7437a"],

Cell[TextData[{
 "Feller, W. (1971). ",
 StyleBox["An Introduction to Probability Theory and Its Applications",
  FontVariations->{"Underline"->True}],
 ". New York: John Wiley & Sons, Inc."
}], "Reference",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.52970904806192*^9, 3.5297090582485027`*^9}, {
   3.5297091365269804`*^9, 3.5297091365279803`*^9}, 3.5386855199841704`*^9, 
   3.5396360443931065`*^9},ExpressionUUID->"22514e19-7562-4502-9600-\
a860da0f7e43"],

Cell[TextData[{
 "Hogg, R.V. and Craig, A. T. (1994). ",
 StyleBox["Introduction to Mathematical Statistics",
  FontVariations->{"Underline"->True}],
 ", 5",
 StyleBox["th",
  FontVariations->{"CompatibilityType"->Superscript}],
 " Edition. New York: MacMillan."
}], "Reference",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.52970914509947*^9, 3.5297091481086426`*^9}, 
   3.5386855199841704`*^9, 3.5396360460252*^9, 
   3.5410147552954984`*^9},ExpressionUUID->"f0e38f45-ea64-49bc-8871-\
944a97cd093b"],

Cell[TextData[{
 "Lowenstein, R. (2000). ",
 StyleBox["When Genius Failed, The Rise and Fall of Long Term Capital \
Management",
  FontVariations->{"Underline"->True}],
 ". New York, NY: Random House."
}], "Reference",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297090597485886`*^9, 3.529709071520262*^9}, {
   3.5297091625264673`*^9, 3.5297091625274677`*^9}, 3.5386855199841704`*^9, 
   3.5396360489923697`*^9},ExpressionUUID->"aa923ccd-7a3c-4153-a0e9-\
aba183f6bc69"],

Cell[TextData[{
 "Nicholson, W. (2002). ",
 StyleBox["Microeconomic Theory",
  FontVariations->{"Underline"->True}],
 ", 8",
 StyleBox["th",
  FontVariations->{"CompatibilityType"->Superscript}],
 " Edition. New York: Thompson Learning."
}], "Reference",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297091644575777`*^9, 3.5297091693388567`*^9}, 
   3.5386855199841704`*^9, 3.539636051063488*^9, 
   3.541014759660748*^9},ExpressionUUID->"1c720577-7bd7-46a6-a913-\
67231424f5fc"],

Cell[TextData[{
 "Pratt, J. W. (1964). Risk aversion in the small and in the large. ",
 StyleBox["Econometrica",
  FontVariations->{"Underline"->True}],
 " 32(1-2). p. 122-136."
}], "Reference",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529709171062956*^9, 3.5297091765132675`*^9}, {
   3.5297092342845716`*^9, 3.5297092858415203`*^9}, 3.5386855199841704`*^9, 
   3.539636053997656*^9},ExpressionUUID->"c04ff80e-ac66-437d-a0bd-\
9c4445917722"],

Cell["Problems", "ExerciseSection",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297093258088064`*^9, 3.529709327584908*^9}, 
   3.5386855199841704`*^9},ExpressionUUID->"72803ca7-eb89-4ad9-af41-\
3b63dffbd77b"],

Cell["\<\
Assume you are offered a project requiring a $300,000 down payment. Using \
Figure 6.15 determine the dollar amount of discount you would require, \
provided your coefficient of risk aversion is 1.\
\>", "Item1Exercise",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297093354293566`*^9, 3.5297093381905146`*^9}, {
   3.529779373564309*^9, 3.529779373566309*^9}, {3.5297992776498027`*^9, 
   3.5297994166637535`*^9}, {3.5297994874898047`*^9, 3.529799505503835*^9}, 
   3.5386855199841704`*^9},ExpressionUUID->"0c62d202-5881-4ae9-b54a-\
89f303615db6"],

Cell["\<\
Change the coefficient of risk aversion in Figure 6.15 to another value and \
compute the discount you would require on an investment offered which \
requires a capital investment of $500,000, given the coefficient of risk \
aversion you selected.\
\>", "Item1Exercise",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297093354293566`*^9, 3.5297093381905146`*^9}, {
   3.529779373564309*^9, 3.529779373566309*^9}, {3.5297992776498027`*^9, 
   3.5297994831675577`*^9}, 
   3.5386855199841704`*^9},ExpressionUUID->"f19592bd-f292-48d3-86ee-\
cab21622df48"],

Cell["\<\
Using the graphic below, describe an investment that requires a capital \
outlay. Provide appropriate details for a market offering. Assume there are \
two investors, one with a risk aversion function which is the log of wealth \
and one with a risk aversion function of the square root of wealth. Which \
investor will make the highest offer? How much will that offer be?\
\>", "Item1Exercise",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.529799519842655*^9, 3.529799630312974*^9}, {
   3.529799699741945*^9, 3.5297997006639977`*^9}, 3.52984473103125*^9, {
   3.533138206734665*^9, 3.533138216631231*^9}, 
   3.5386855199841704`*^9},ExpressionUUID->"4a7f7aed-999b-4f9e-b7df-\
93a77834289b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "ab"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"ab", "=", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"a", " ", "x1"}], "+", "b"}], "\[Equal]", 
           RowBox[{"N", "[", 
            RowBox[{"func", "[", "5", "]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"a", " ", "x2"}], "+", "b"}], "\[Equal]", 
           RowBox[{"N", "[", 
            RowBox[{"func", "[", "15", "]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"a", ",", "b"}], "}"}]}], "]"}], "/.", "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x1", "\[Rule]", "5"}], ",", 
        RowBox[{"x2", "\[Rule]", "15"}]}], "}"}]}]}], ";", "\n", 
    RowBox[{"line", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", " ", "x"}], "+", "b"}], "/.", "\[InvisibleSpace]", 
        "ab"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "3", ",", "18"}], "}"}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"2.5", ",", ".10"}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"func", "===", "Sqrt"}], ",", 
            RowBox[{"{", 
             RowBox[{"5", ",", "10", ",", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{".5", " ", 
                    RowBox[{"func", "[", "5", "]"}]}], "+", 
                   RowBox[{".5", " ", 
                    RowBox[{"func", "[", "15", "]"}]}]}], ")"}], "2"], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<\\n\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{".5", " ", 
                    RowBox[{"func", "[", "5", "]"}]}], "+", 
                    RowBox[{".5", " ", 
                    RowBox[{"func", "[", "15", "]"}]}]}], ")"}], "2"], 
                    "]"}]}], "]"}], ",", "Red"}], "]"}]}], "}"}], ",", "15"}],
              "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"5", ",", "10", ",", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{
                  RowBox[{".5", " ", 
                   RowBox[{"func", "[", "5", "]"}]}], "+", 
                  RowBox[{".5", " ", 
                   RowBox[{"func", "[", "15", "]"}]}]}]], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<\\n\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{".5", " ", 
                    RowBox[{"func", "[", "5", "]"}]}], "+", 
                    RowBox[{".5", " ", 
                    RowBox[{"func", "[", "15", "]"}]}]}]], "]"}]}], "]"}], 
                  ",", "Red"}], "]"}]}], "}"}], ",", "15"}], "}"}]}], "]"}], 
          ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"func", "===", "Sqrt"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{"func", "[", "5", "]"}], "]"}], ",", 
              RowBox[{"N", "[", 
               RowBox[{"func", "[", "10", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{".5", " ", 
                   RowBox[{"func", "[", "5", "]"}]}], "+", 
                  RowBox[{".5", " ", 
                   RowBox[{"func", "[", "15", "]"}]}]}], ")"}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<\\n\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{".5", " ", 
                    RowBox[{"func", "[", "5", "]"}]}], "+", 
                    RowBox[{".5", " ", 
                    RowBox[{"func", "[", "15", "]"}]}]}], ")"}], "]"}]}], 
                   "]"}], ",", "Red"}], "]"}]}], "}"}], ",", 
              RowBox[{"N", "[", 
               RowBox[{"func", "[", "15", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{"func", "[", "5", "]"}], "]"}], ",", 
              RowBox[{"N", "[", 
               RowBox[{"func", "[", "10", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{".5", " ", 
                  RowBox[{"func", "[", "5", "]"}]}], "+", 
                 RowBox[{".5", " ", 
                  RowBox[{"func", "[", "15", "]"}]}]}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"\"\<\>\"", ",", 
                    RowBox[{"ToString", "[", 
                    RowBox[{
                    RowBox[{".5", " ", 
                    RowBox[{"func", "[", "5", "]"}]}], "+", 
                    RowBox[{".5", " ", 
                    RowBox[{"func", "[", "15", "]"}]}]}], "]"}]}], "]"}], ",",
                   "Red"}], "]"}]}], "}"}], ",", 
              RowBox[{"N", "[", 
               RowBox[{"func", "[", "15", "]"}], "]"}]}], "}"}]}], "]"}]}], 
         "}"}]}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"func", "===", "Sqrt"}], ",", 
            RowBox[{"{", 
             RowBox[{"5", ",", "10", ",", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{".5", " ", 
                  RowBox[{"func", "[", "5", "]"}]}], "+", 
                 RowBox[{".5", " ", 
                  RowBox[{"func", "[", "15", "]"}]}]}], ")"}], "2"], ",", 
              "15"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"5", ",", "10", ",", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                RowBox[{".5", " ", 
                 RowBox[{"func", "[", "5", "]"}]}], "+", 
                RowBox[{".5", " ", 
                 RowBox[{"func", "[", "15", "]"}]}]}]], ",", "15"}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"func", "===", "Sqrt"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"func", "[", "5", "]"}], ",", 
              RowBox[{"func", "[", "10", "]"}], ",", 
              RowBox[{
               RowBox[{".5", " ", 
                RowBox[{"func", "[", "5", "]"}]}], "+", 
               RowBox[{".5", " ", 
                RowBox[{"func", "[", "15", "]"}]}]}], ",", 
              RowBox[{"func", "[", "15", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"func", "[", "5", "]"}], ",", 
              RowBox[{"func", "[", "10", "]"}], ",", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{".5", " ", 
                 RowBox[{"func", "[", "5", "]"}]}], "+", 
                RowBox[{".5", " ", 
                 RowBox[{"func", "[", "15", "]"}]}]}], ")"}], ",", 
              RowBox[{"func", "[", "15", "]"}]}], "}"}]}], "]"}]}], "}"}]}], 
       ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Wealth\>\"", ",", "\"\<U[Wealth]\>\""}], "}"}]}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"utilPlot", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"func", "[", "w", "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", "3", ",", "18"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{"line", ",", "utilPlot"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"func", ",", "Log", ",", "\"\<Function\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Log", "\[Rule]", "\"\<Log[w]\>\""}], ",", 
       RowBox[{"Sqrt", "\[Rule]", "\"\<\!\(\*SqrtBox[\(w\)]\)\>\""}]}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 CellChangeTimes->{{3.529786497024748*^9, 3.5297866465452995`*^9}, {
   3.529786754047448*^9, 3.529786822157344*^9}, {3.5297868991987505`*^9, 
   3.5297869700498033`*^9}, {3.5297870238178787`*^9, 
   3.5297870303632526`*^9}, {3.5297870909567184`*^9, 3.52978709482894*^9}, {
   3.5297871466879063`*^9, 3.5297871522162223`*^9}, {3.529787280188542*^9, 
   3.5297873046399403`*^9}, {3.5297873410750246`*^9, 3.529787453776471*^9}, 
   3.5297878891363716`*^9, {3.5297907933824854`*^9, 3.5297909818662663`*^9}, {
   3.5297911627486115`*^9, 3.5297911852248974`*^9}, {3.5297912368938527`*^9, 
   3.5297912977073307`*^9}, {3.5297913395717254`*^9, 
   3.5297913649751787`*^9}, {3.52979143580223*^9, 3.5297914745594463`*^9}, {
   3.5297915047621737`*^9, 3.5297915071353097`*^9}, {3.5297915532809486`*^9, 
   3.529791557079166*^9}, {3.529791621973878*^9, 3.529791681060258*^9}, {
   3.5297917325222006`*^9, 3.529791761595864*^9}, 3.5297922911001496`*^9, {
   3.5297924818560605`*^9, 3.529792489477496*^9}, {3.529792552151081*^9, 
   3.5297926356288557`*^9}, 3.5297926752101192`*^9, {3.529792706268896*^9, 
   3.5297927217687826`*^9}, {3.5297931788033395`*^9, 
   3.5297931790163517`*^9}, {3.5297932698751774`*^9, 3.529793411159259*^9}, 
   3.529793472814785*^9, {3.5297935492981596`*^9, 3.5297935702103558`*^9}, {
   3.5297936367471614`*^9, 3.5297936381852436`*^9}, {3.5297936914262886`*^9, 
   3.5297937115804415`*^9}, {3.5297937584321213`*^9, 3.529793821120707*^9}, {
   3.529793875655826*^9, 3.529793902961388*^9}, {3.529794197135214*^9, 
   3.529794228442004*^9}, {3.5297942785808725`*^9, 3.5297942990950456`*^9}, {
   3.5297943342030535`*^9, 3.529794339024329*^9}, {3.5297947565722117`*^9, 
   3.5297948476554213`*^9}, {3.5297948830414457`*^9, 3.529795060806613*^9}, {
   3.52979565694571*^9, 3.529795711767846*^9}, {3.529795820601071*^9, 
   3.529795839921176*^9}, {3.5297958826596203`*^9, 3.529795886265826*^9}, {
   3.529795916305545*^9, 3.529795941135965*^9}, {3.5297962024839134`*^9, 
   3.529796253145811*^9}, {3.529796304162729*^9, 3.5297963064308586`*^9}, {
   3.529796504977215*^9, 3.529796547919671*^9}, {3.5297966096982045`*^9, 
   3.5297966215508823`*^9}, {3.5297966597170653`*^9, 3.5297967283379903`*^9}, 
   3.5297967652141*^9, {3.5297968179621162`*^9, 3.529796838083267*^9}, {
   3.529796993114135*^9, 3.529797001454612*^9}, {3.5297970327624025`*^9, 
   3.5297970873115225`*^9}, {3.529797138003422*^9, 3.5297971686301737`*^9}, {
   3.5297972104985685`*^9, 3.529797239880249*^9}, {3.529797495356861*^9, 
   3.5297975088736343`*^9}, {3.5297975986397686`*^9, 3.529797613206602*^9}, {
   3.5297977121282597`*^9, 3.529797714891418*^9}, {3.5297977716846666`*^9, 
   3.5297978065606613`*^9}, {3.529797842274704*^9, 3.529797878625783*^9}, {
   3.529797949250822*^9, 3.52979795182897*^9}, {3.5297980193598323`*^9, 
   3.5297980216719646`*^9}, {3.5297980588590918`*^9, 
   3.5297980776191645`*^9}, {3.5297981419688454`*^9, 3.5297981584557886`*^9}, 
   3.5297982122338643`*^9, {3.529798260097602*^9, 3.529798271040228*^9}, 
   3.529798522299599*^9, 3.529798563821974*^9, 3.5297986030282164`*^9, {
   3.5297986628276367`*^9, 3.5297986851969166`*^9}, {3.5297987169757338`*^9, 
   3.529798770390789*^9}, {3.529798838299673*^9, 3.529798864177153*^9}, {
   3.529798899549176*^9, 3.5297989269497433`*^9}, {3.529798988934289*^9, 
   3.529798994959634*^9}, 3.5386855199851704`*^9, {3.543342313253172*^9, 
   3.5433423197245417`*^9}},ExpressionUUID->"de2168b5-c516-429d-9d55-\
c83065b0c189"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`func$$ = Log, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`func$$], Log, "Function"}, {
      Log -> "Log[w]", Sqrt -> "\!\(\*SqrtBox[\(w\)]\)"}}}, Typeset`size$$ = {
    540., {162., 169.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`func$22482$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`func$$ = Log}, 
      "ControllerVariables" :> {
        Hold[$CellContext`func$$, $CellContext`func$22482$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> (
       Clear[$CellContext`a, $CellContext`b, $CellContext`ab]; \
$CellContext`ab = ReplaceAll[
          Solve[{$CellContext`a $CellContext`x1 + $CellContext`b == N[
              $CellContext`func$$[
              5]], $CellContext`a $CellContext`x2 + $CellContext`b == N[
              $CellContext`func$$[
              15]]}, {$CellContext`a, $CellContext`b}], {$CellContext`x1 -> 
           5, $CellContext`x2 -> 15}]; $CellContext`line = Plot[
          
          ReplaceAll[$CellContext`a $CellContext`x + $CellContext`b, \
$CellContext`ab], {$CellContext`x, 3, 18}, AxesOrigin -> {2.5, 0.1}, Ticks -> {
            
            If[$CellContext`func$$ === Sqrt, {
             5, 10, {(0.5 $CellContext`func$$[5] + 
                0.5 $CellContext`func$$[15])^2, 
               Style[
                StringJoin["\n", 
                 
                 ToString[(0.5 $CellContext`func$$[5] + 
                   0.5 $CellContext`func$$[15])^2]], Red]}, 15}, {
             5, 10, {E^(0.5 $CellContext`func$$[5] + 
                0.5 $CellContext`func$$[15]), 
               Style[
                StringJoin["\n", 
                 ToString[
                 E^(0.5 $CellContext`func$$[5] + 
                   0.5 $CellContext`func$$[15])]], Red]}, 15}], 
            If[$CellContext`func$$ === Sqrt, {
              N[
               $CellContext`func$$[5]], 
              N[
               $CellContext`func$$[10]], {
              0.5 $CellContext`func$$[5] + 0.5 $CellContext`func$$[15], 
               Style[
                StringJoin["\n", 
                 ToString[
                 0.5 $CellContext`func$$[5] + 0.5 $CellContext`func$$[15]]], 
                Red]}, 
              N[
               $CellContext`func$$[15]]}, {
              N[
               $CellContext`func$$[5]], 
              N[
               $CellContext`func$$[10]], {
              0.5 $CellContext`func$$[5] + 0.5 $CellContext`func$$[15], 
               Style[
                StringJoin["", 
                 ToString[
                 0.5 $CellContext`func$$[5] + 0.5 $CellContext`func$$[15]]], 
                Red]}, 
              N[
               $CellContext`func$$[15]]}]}, GridLines -> {
            
            If[$CellContext`func$$ === Sqrt, {
             5, 10, (0.5 $CellContext`func$$[5] + 
               0.5 $CellContext`func$$[15])^2, 15}, {
             5, 10, E^(0.5 $CellContext`func$$[5] + 
               0.5 $CellContext`func$$[15]), 15}], 
            If[$CellContext`func$$ === Sqrt, {
              $CellContext`func$$[5], 
              $CellContext`func$$[10], 0.5 $CellContext`func$$[5] + 
              0.5 $CellContext`func$$[15], 
              $CellContext`func$$[15]}, {
              $CellContext`func$$[5], 
              $CellContext`func$$[10], 0.5 $CellContext`func$$[5] + 
              0.5 $CellContext`func$$[15], 
              $CellContext`func$$[15]}]}, 
          AxesLabel -> {"Wealth", "U[Wealth]"}]; $CellContext`utilPlot = Plot[{
           $CellContext`func$$[$CellContext`w]}, {$CellContext`w, 3, 18}]; 
       Show[$CellContext`line, $CellContext`utilPlot]), 
      "Specifications" :> {{{$CellContext`func$$, Log, "Function"}, {
         Log -> "Log[w]", Sqrt -> "\!\(\*SqrtBox[\(w\)]\)"}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{610., {229., 237.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`ab = {{$CellContext`a -> 
          0.000010986122886681092`, $CellContext`b -> 10.270472140076231`}}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5297949174994164`*^9, 3.5297949592378035`*^9}, {
   3.529794994751835*^9, 3.529795064617831*^9}, 3.5297955890318255`*^9, 
   3.5297957902043324`*^9, 3.52979616326567*^9, 3.5297969622663703`*^9, 
   3.529797534516101*^9, 3.529797901161072*^9, 3.5297990303016553`*^9, 
   3.529935139999094*^9, 3.5299373275182133`*^9, 3.5300164094244394`*^9, 
   3.5300167279706593`*^9, 3.530017190485113*^9, 3.531448241466468*^9, 
   3.5315006375393515`*^9, 3.533134723522436*^9, 3.533135891563245*^9, 
   3.533682269296875*^9, 3.5337346063948536`*^9, 3.5337541605*^9, 
   3.533755430828125*^9, 3.5386852439033794`*^9, 3.5386855200191727`*^9, 
   3.5396359701048574`*^9, 3.540126842173068*^9, 3.5410126588095865`*^9, 
   3.5410151265997353`*^9, 3.5410156001358204`*^9, 3.541600469975399*^9, 
   3.543342217521696*^9, 3.5433423215576468`*^9, 3.6963384642801943`*^9, 
   3.6963423841070395`*^9, 3.6965443692772813`*^9, 3.7314212038259783`*^9},
 TextAlignment->Center,ExpressionUUID->"fb03e00c-d516-4b11-97da-62abcf160f1c"]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{1280, 637},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
Visible->True,
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{32000, 32000},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{576.12, 720.12}},
ShowSelection->True,
ShowCellLabel->False,
CellLabelAutoDelete->True,
InputAliases->{"notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "notation>" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "notation<" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "symb" -> RowBox[{"Symbolize", "[", 
     TagBox[
     "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"], 
     "]"}], "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        ",", "\[Placeholder]"}], "]"}], "addia" -> 
  RowBox[{"AddInputAlias", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        ",", "\[Placeholder]"}], "]"}], "pattwraper" -> 
  TagBox["\[Placeholder]", NotationPatternTag, TagStyle -> 
    "NotationPatternWrapperStyle"], "madeboxeswraper" -> 
  TagBox["\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
    "NotationMadeBoxesWrapperStyle"]},
CounterAssignments->{{"BookChapterNumber", 6}},
AspectRatioFixed->False,
ImageSize->Automatic,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Book"}, "Textbook.nb", CharacterEncoding -> 
       "WindowsANSI"]]], 
   Cell[
    StyleData["BookChapterTitle"], FontColor -> GrayLevel[0.5]], 
   Cell[
    StyleData["Section"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["Subsection"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["TableTitle"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["PageBreak"], Editable -> True, CellMargins -> {{0, 0}, {1, 1}},
     CellBracketOptions -> {
     "Color" -> RGBColor[0.500008, 0.500008, 1], "Margins" -> {Inherited, 3}, 
      "Thickness" -> 1, "Widths" -> {5, 5}}, 
    CellElementSpacings -> {"CellMinHeight" -> 1}, 
    ConversionRules :> {"TeX" -> {"\n\n\\pagebreak", 
        $CellContext`NoOutput[], ""}, "HTML" -> {"<br class=\"PageBreak\">", 
        $CellContext`NoOutput[], ""}}, PageBreakAbove -> Automatic, 
    CellSize -> {Automatic, 9.120000000000005}, TabFilling -> "- ", 
    TabSpacings -> 1000, FontSize -> 6, FontColor -> GrayLevel[0.700008]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Hyperlink", StyleDefinitions -> StyleData["Link"]], 
       ContextMenu -> FEPrivate`FrontEndResource["ContextMenus", "Hyperlink"],
        FontVariations -> {"Underline" -> True}, FontColor -> 
       RGBColor[0, 0, 1], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["Hyperlink", "Condensed"], FontSize -> 11], 
      Cell[
       StyleData[
       "Hyperlink", "Printout", StyleDefinitions -> StyleData["Link"]], 
       ContextMenu -> FEPrivate`FrontEndResource["ContextMenus", "Hyperlink"],
        FontVariations -> {"Underline" -> True}, FontColor -> 
       RGBColor[0, 0, 1], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ReferenceSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["ReferenceSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["EndnoteSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["EndnoteSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ExerciseSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["ExerciseSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    StyleData["BookChapterNumber"], Background -> 
    RGBColor[0.9333333333333333, 0.1803921568627451, 0.1411764705882353]], 
   Cell[
    StyleData["EquationNumbered"], CellFrame -> True, CellFrameColor -> 
    RGBColor[0.501961, 0, 0], FontColor -> 
    RGBColor[0.5019607843137255, 0., 0.]], 
   Cell[
    CellGroupData[{
      Cell[
      "Figure", "Subsubsection", FontFamily -> "Times New Roman", FontSize -> 
       12, FontColor -> RGBColor[0, 0, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Figure"], Editable -> False, 
          CellMargins -> {{12, Inherited}, {8, 6}}, CellGroupingRules -> 
          "InputGrouping", ConversionRules :> {"TeX" -> {"\n\\begin{center}", 
              $CellContext`ExtractFigure[], "\n\\end{center}"}}, 
          TaggingRules :> {
           "CounterSettings" -> {"CounterTarget" -> "Style:FigureCaption"}, 
            "ExtraConversionRules" -> {
             "General" -> {
               "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, 
              "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}}, 
          PageBreakAbove -> False, Hyphenation -> True, CounterIncrements -> 
          "Figure", FontFamily -> "Times New Roman", FontSize -> 12, 
          FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["Figure", "Printout"], 
          CellMargins -> {{2, Inherited}, {6, 4}}, Magnification -> 0.8], 
         Cell[
          StyleData["Figure", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, Inherited}, {6, 4}}, Magnification -> 0.8]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FigureCaption"], CellMargins -> {{12, 10}, {6, 2}}, 
          CellGroupingRules -> "OutputGrouping", 
          ConversionRules :> {"TeX" -> {"\n\\caption{", "}"}}, 
          TaggingRules :> {
           "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "Figure"}, 
              "CounterTarget" -> "Cell", "XRefPrefix" -> "Figure"}, 
            "ExtraConversionRules" -> {
             "General" -> {"NestingLevel" -> 90}, 
              "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}}, 
          PageBreakAbove -> False, Hyphenation -> True, CounterIncrements -> 
          "FigureCaption", CounterAssignments -> {{"Nil", 0}}, FontFamily -> 
          "Times New Roman", FontSize -> 12, FontWeight -> "Plain", FontSlant -> 
          "Plain", 
          FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}, 
          FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["FigureCaption", "Printout"], 
          CellMargins -> {{2, 2}, {4, 1}}], 
         Cell[
          StyleData["FigureCaption", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 2}, {4, 1}}, LineSpacing -> {2, 1}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FigureCaptionLabel"], Editable -> False, 
          ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, FontFamily -> "Times New Roman", 
          FontSize -> 12, FontWeight -> "Bold", FontColor -> 
          RGBColor[0, 0, 1]], 
         Cell[
          StyleData["FigureCaptionLabel", "Printout"]], 
         Cell[
          StyleData["FigureCaptionLabel", "DoubleSpacedPrintout"]]}, Open]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell[
      "Tables", "Subsubsection", FontFamily -> "Times New Roman", FontColor -> 
       RGBColor[0, 0, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableTitle"], PageWidth -> 530, 
          CellMargins -> {{12, 10}, {1, 7}}, CellGroupingRules -> 
          "InputGrouping", 
          ConversionRules :> {"TeX" -> {"\n\\caption{", Automatic, "} "}}, 
          TaggingRules :> {
           "ExtraConversionRules" -> {
             "General" -> {
               "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, 
              "TeX" -> {"CellGroupEnvironment" -> "table"}}, 
            "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "TableTitle"}, 
              "CounterTarget" -> "Cell", "XRefPrefix" -> "Table"}}, 
          LineSpacing -> {1, 2}, CounterIncrements -> "TableTitle", 
          FontFamily -> "Times New Roman", FontWeight -> "Plain", FontColor -> 
          RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{40}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableTitle", "Printout"], 
          CellMargins -> {{2, 10}, {1, 5}}, FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["TableTitle", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 10}, {1, 5}}, FontFamily -> "Times New Roman", 
          FontSize -> 10]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableTitleLabel"], Editable -> True, 
          ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, LineSpacing -> {1, 2}, 
          CounterIncrements -> "TableTitleLabel", 
          CounterAssignments -> {{"Nil", 0}}, FontFamily -> "Times New Roman",
           FontWeight -> "Bold", FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{40}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableTitleLabel", "Printout"]], 
         Cell[
          StyleData["TableTitleLabel", "DoubleSpacedPrintout"], FontSize -> 
          10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Table"], Editable -> True, PageWidth -> WindowWidth, 
          CellMargins -> {{12, 10}, {4, 1}}, CellGroupingRules -> 
          "OutputGrouping", 
          ConversionRules :> {
           "TeX" -> {"\n\\begin{tabular}\n", Automatic, "\n\\end{tabular}"}, 
            "HTML" -> {{"", Automatic, ""}, {"", Automatic, ""}}}, 
          TaggingRules :> {
           "ExtraConversionRules" -> {
             "General" -> {"NestingLevel" -> 90}, 
              "TeX" -> {"CellGroupEnvironment" -> "table"}}, 
            "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "TableTitle"}, 
              "CounterTarget" -> "CellGroup"}}, CellHorizontalScrolling -> 
          True, CounterIncrements -> "Table", 
          CounterAssignments -> {{"TableNote", 0}}, FontFamily -> 
          "Times New Roman", FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}}, 
            GridBoxDividers -> {
             "Columns" -> {False, {False}, False}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                AbsoluteThickness[2], {False}, 
                AbsoluteThickness[0.5]}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {"Columns" -> {{
                 Scaled[0.503]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}, GridDefaultElement :> 
            Cell["Data", "TableText"]}], 
         Cell[
          StyleData["Table", "Printout"], PageWidth -> PaperWidth, 
          CellMargins -> {{2, 10}, {3, 1}}], 
         Cell[
          StyleData["Table", "DoubleSpacedPrintout"], PageWidth -> PaperWidth,
           CellMargins -> {{2, 10}, {3, 1}}, FontSize -> 10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableNote"], Editable -> True, 
          CellMargins -> {{12, 10}, {7, -3}}, CellGroupingRules -> 
          "OutputGrouping", ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, 
          TaggingRules :> {
           "CounterSettings" -> {
             "CounterFormat" -> {"Table"}, "CounterTarget" -> "CellGroup"}}, 
          LineSpacing -> {1, 1}, ParagraphSpacing -> {0.3, 0}, 
          CounterIncrements -> "TableNote", FontFamily -> "Times New Roman", 
          FontSize -> 10, FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["TableNote", "Printout"], 
          CellMargins -> {{2, 10}, {5, -2}}], 
         Cell[
          StyleData["TableNote", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 10}, {5, -2}}, LineSpacing -> {2, 1}, FontSize -> 
          9]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Inline Table Styles", "Subsubsubsection", FontFamily -> 
          "Times New Roman", FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableColumnHead"], Editable -> True, 
             ConversionRules :> {
              "TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic, ""}}}, 
             FontFamily -> "Times New Roman", FontSlant -> "Italic", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableColumnHead", "Printout"]], 
            Cell[
             StyleData["TableColumnHead", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableSpanHead"], Editable -> True, 
             ConversionRules :> {
              "TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic, ""}}}, 
             TextAlignment -> Center, FontFamily -> "Times New Roman", 
             FontSlant -> "Italic", FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableSpanHead", "Printout"]], 
            Cell[
             StyleData["TableSpanHead", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableText"], Editable -> True, TextAlignment -> Left, 
             LineSpacing -> {1, 1}, FontFamily -> "Times New Roman", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableText", "Printout"]], 
            Cell[
             StyleData["TableText", "DoubleSpacedPrintout"], 
             LineSpacing -> {2, 1}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableSpanText"], Editable -> True, TextAlignment -> 
             Center, LineSpacing -> {1, 1}, FontFamily -> "Times New Roman", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["TableSpanText", "Printout"]], 
            Cell[
             StyleData["TableSpanText", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          StyleData["TableSubGrid"], FontFamily -> "Times New Roman", 
          FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {{0.1}}, 
              "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.27999999999999997`]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
            Cell["Data", "TableText"]}], 
         Cell[
          StyleData["TableMasterGrid"], FontFamily -> "Times New Roman", 
          FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                 Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.004]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableLineElement"], Editable -> False, 
          CellFrame -> {{0, 0}, {0.5, 0}}, 
          CellElementSpacings -> {"CellMinHeight" -> 1}, 
          ConversionRules :> {"HTML" -> {{"&nbsp;", 
               $CellContext`NoOutput[], ""}, {"", Automatic, ""}}}, 
          CellSize -> {Inherited, 1.25}, TabFilling -> " ", TabSpacings -> 
          1000, FontFamily -> "Times New Roman", FontSize -> 1, FontColor -> 
          RGBColor[0, 0, 1]], 
         Cell[
          StyleData["TableBlankElement"], Editable -> False, 
          CellElementSpacings -> {"CellMinHeight" -> 1}, 
          CellSize -> {Inherited, 1.25}, FontFamily -> "Times New Roman", 
          FontSize -> 1, FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanLeft"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanLeft", "Printout"]], 
            Cell[
             StyleData["SpanLeft", "DoubleSpacedPrintout"], FontSize -> 14]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanCenter"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanCenter", "Printout"]], 
            Cell[
             StyleData["SpanCenter", "DoubleSpacedPrintout"], FontSize -> 
             14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanRight"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanRight", "Printout"]], 
            Cell[
             StyleData["SpanRight", "DoubleSpacedPrintout"], FontSize -> 14]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AppendixSection"], 
             CellMargins -> {{12, 12}, {24, 48}}, FontColor -> 
             GrayLevel[0.5]], 
            Cell[
             StyleData["AppendixSection", "Printout"], 
             CellMargins -> {{12, 12}, {24, 48}}, FontColor -> 
             GrayLevel[0.5]]}, Open]]}, Open]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> "11.3 for Microsoft Windows (64-bit) (March 6, 2018)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "endnote1"->{
  Cell[772962, 16685, 674, 15, 28, "Endnote",ExpressionUUID->"93e93859-ce69-457b-a1e1-d23c252617aa",
   PageBreakAbove->False,
   PageBreakBelow->False,
   CellTags->"endnote1"]},
 "endnote2"->{
  Cell[773639, 16702, 756, 16, 51, "Endnote",ExpressionUUID->"9e9f6067-29ce-45d2-b13c-6f2c6e78297f",
   PageBreakAbove->False,
   PageBreakBelow->False,
   CellTags->"endnote2"]},
 "endnote3"->{
  Cell[774398, 16720, 1039, 21, 74, "Endnote",ExpressionUUID->"7f15b561-c91e-4fff-a1d2-ad6c3cc2ac89",
   PageBreakAbove->False,
   PageBreakBelow->False,
   CellTags->"endnote3"]},
 "endnote4"->{
  Cell[775440, 16743, 816, 18, 51, "Endnote",ExpressionUUID->"8b9809ef-19f8-4e2e-9ffc-6786251f6a4d",
   PageBreakAbove->False,
   PageBreakBelow->False,
   CellTags->"endnote4"]},
 "endnote5"->{
  Cell[776259, 16763, 616, 14, 28, "Endnote",ExpressionUUID->"9ede99b8-7033-4f3d-861f-8e669294f49d",
   PageBreakAbove->False,
   PageBreakBelow->False,
   CellTags->"endnote5"]},
 "endnote6"->{
  Cell[776878, 16779, 1102, 21, 74, "Endnote",ExpressionUUID->"63cb079d-3452-496e-afbc-4534626f1113",
   PageBreakAbove->False,
   PageBreakBelow->False,
   CellTags->"endnote6"]},
 "endnote7"->{
  Cell[777983, 16802, 691, 15, 28, "Endnote",ExpressionUUID->"3cf3f7af-148b-45bb-a50f-041d7037bd6e",
   PageBreakAbove->False,
   PageBreakBelow->False,
   CellTags->"endnote7"]},
 "endnote8"->{
  Cell[778677, 16819, 606, 14, 28, "Endnote",ExpressionUUID->"367c8c69-6d35-49b4-a7b1-2b517e171887",
   PageBreakAbove->False,
   PageBreakBelow->False,
   CellTags->"endnote8"]},
 "endnote9"->{
  Cell[779286, 16835, 875, 18, 60, "Text",ExpressionUUID->"14e06746-7bef-448d-a41e-2dbf5c40a3cc",
   PageBreakAbove->False,
   PageBreakBelow->True,
   CellTags->"endnote9"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"endnote1", 829088, 17950},
 {"endnote2", 829283, 17955},
 {"endnote3", 829478, 17960},
 {"endnote4", 829674, 17965},
 {"endnote5", 829869, 17970},
 {"endnote6", 830064, 17975},
 {"endnote7", 830260, 17980},
 {"endnote8", 830455, 17985},
 {"endnote9", 830650, 17990}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[1488, 33, 219, 4, 232, "BookChapterNumber",ExpressionUUID->"0b48d162-3a49-4c9d-b22a-7f1a35a4dcc9"],
Cell[1710, 39, 237, 3, 194, "BookChapterTitle",ExpressionUUID->"bf3a545f-732e-4f0a-be24-a62a427e24b1"],
Cell[1950, 44, 390, 7, 56, "Epigraph",ExpressionUUID->"faa8c295-14af-4c30-ad1b-e63706d77548"],
Cell[2343, 53, 701, 19, 75, "EpigraphAuthor",ExpressionUUID->"0fcc0e09-797b-483a-b6a6-8cbc1cf9befe"],
Cell[3047, 74, 552, 12, 28, "Input",ExpressionUUID->"b9058593-caf2-44ca-b7ab-1318967df2c6",
 CellOpen->False],
Cell[CellGroupData[{
Cell[3624, 90, 211, 4, 87, "Section",ExpressionUUID->"06937bd4-b053-4a9d-8b9e-1ce2847b4363"],
Cell[3838, 96, 1817, 33, 229, "Text",ExpressionUUID->"6fc66632-139d-4c62-8e78-ca0cbf5e6460"],
Cell[5658, 131, 301, 8, 33, "Text",ExpressionUUID->"83058c91-592f-4a43-854c-fade824723d7"],
Cell[5962, 141, 356, 7, 27, "Item1",ExpressionUUID->"be369688-88a6-46cf-bc26-5a86d16c7505"],
Cell[6321, 150, 339, 6, 27, "Item1",ExpressionUUID->"d73f1057-5b48-467f-b9e0-ca810f4d03f0"],
Cell[6663, 158, 364, 9, 27, "Item1",ExpressionUUID->"c14bf3b6-20a2-4b49-a172-39814344ca5f"],
Cell[7030, 169, 425, 9, 49, "Item1",ExpressionUUID->"9b33e9fe-2308-4584-8ac2-8a38324570bd"],
Cell[CellGroupData[{
Cell[7480, 182, 231, 4, 51, "Subsection",ExpressionUUID->"e4304088-20e9-4aec-852c-54ee4fd61e83"],
Cell[7714, 188, 1399, 28, 156, "Text",ExpressionUUID->"c27a9b20-bed3-4c8d-9339-a24413d24c94"],
Cell[9116, 218, 1937, 33, 254, "Text",ExpressionUUID->"6dd6d9cc-f043-48c2-a1c1-b2a9286a9783"]
}, Open  ]],
Cell[11068, 254, 437, 9, 58, "Text",ExpressionUUID->"fc89fcd8-45d2-428a-9f28-4aea00e87adc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11542, 268, 231, 4, 87, "Section",ExpressionUUID->"08d33cfb-39e2-45c7-8def-9f0ecebd6fde"],
Cell[11776, 274, 410, 8, 58, "Text",ExpressionUUID->"edcb91f1-c9f8-4354-90ba-10b8e61bceb5"],
Cell[12189, 284, 924, 15, 107, "Text",ExpressionUUID->"039649d5-e5e4-4d40-a270-220b37141c81"],
Cell[13116, 301, 1265, 19, 156, "Text",ExpressionUUID->"fab53c44-2a3d-4c5e-94be-eb94eed51398"],
Cell[CellGroupData[{
Cell[14406, 324, 885, 16, 107, "Text",ExpressionUUID->"1bddd1e7-7bcc-43ed-8fa2-be8055e7fd78"],
Cell[15294, 342, 594, 16, 58, "Text",ExpressionUUID->"b906da55-b60f-4d3e-8963-9c0a580db46f"],
Cell[CellGroupData[{
Cell[15913, 362, 424, 14, 81, "Input",ExpressionUUID->"6c5ae1b1-0d64-43ec-b526-149c6e121dbb"],
Cell[16340, 378, 1061, 18, 35, "Message",ExpressionUUID->"e19a7dd4-c9f4-48f8-9207-ba771c38e82e"],
Cell[17404, 398, 1082, 18, 80, "Output",ExpressionUUID->"275df707-dc6b-4ab1-9676-54bf29b90ed3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18535, 422, 1634, 44, 28, "Input",ExpressionUUID->"f6005a76-ba18-4c57-bd45-3537555c4b49",
 CellOpen->False],
Cell[20172, 468, 2774, 61, 308, "Output",ExpressionUUID->"124e7a33-0d1f-4dc6-b489-d849822134cf"]
}, Open  ]],
Cell[22961, 532, 369, 7, 33, "TableTitle",ExpressionUUID->"5b8e047a-82d9-4442-861c-018bf51a7688"],
Cell[23333, 541, 393, 9, 33, "Text",ExpressionUUID->"9c1bcdcd-59c5-4a0e-85ea-fbc64a676098"],
Cell[23729, 552, 1792, 48, 123, "Text",ExpressionUUID->"452c4e11-1258-453b-9dc1-20822fef4355"],
Cell[CellGroupData[{
Cell[25546, 604, 2142, 49, 28, "Input",ExpressionUUID->"e251e7da-c394-4735-b7c1-8316da38e65a",
 CellOpen->False],
Cell[27691, 655, 3953, 77, 319, "Output",ExpressionUUID->"6a1bab21-10bb-4cb7-928a-e9fe91ad7d52"]
}, Open  ]],
Cell[31659, 735, 349, 7, 32, "FigureCaption",ExpressionUUID->"db06071c-0db4-4770-81a9-a877d81c5a46"],
Cell[32011, 744, 916, 24, 60, "Text",ExpressionUUID->"c6bf02df-43cc-489d-8fa7-346abb9372f6"],
Cell[CellGroupData[{
Cell[32952, 772, 1995, 55, 28, "Input",ExpressionUUID->"3d6fbace-c4eb-4c43-a3a4-7928646945d6",
 CellOpen->False],
Cell[34950, 829, 14526, 290, 324, "Output",ExpressionUUID->"43edc92e-92c6-4e5b-85cd-4990c09eee9e"]
}, Open  ]],
Cell[49491, 1122, 423, 9, 32, "FigureCaption",ExpressionUUID->"e39077c7-5b64-40cb-868d-e9cdf99a7327"],
Cell[49917, 1133, 1423, 28, 139, "Text",ExpressionUUID->"c5d27fa6-56b6-4d47-8519-076fd2772c6f"],
Cell[CellGroupData[{
Cell[51365, 1165, 3927, 113, 28, "Input",ExpressionUUID->"d88a3520-b6e2-41f2-b657-3bfd055a3707",
 CellOpen->False],
Cell[55295, 1280, 18251, 323, 263, "Output",ExpressionUUID->"61921493-1f37-40d1-996c-e8969b645ab1"]
}, Open  ]],
Cell[73561, 1606, 401, 8, 32, "FigureCaption",ExpressionUUID->"ac3c9775-c959-4440-91b6-95695b851a5e"],
Cell[73965, 1616, 376, 10, 33, "Text",ExpressionUUID->"84e9c4f4-b544-4385-9a06-55f004a9c81b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74378, 1631, 229, 4, 87, "Section",ExpressionUUID->"0e4e25b3-167f-4ef2-a941-261e37be21ba"],
Cell[74610, 1637, 933, 15, 131, "Text",ExpressionUUID->"7589ede0-8842-49d2-8d46-125b54bd075b"],
Cell[75546, 1654, 538, 10, 58, "Text",ExpressionUUID->"641bcb4c-c982-4f55-bbcf-75dda17a02fd"],
Cell[76087, 1666, 1968, 38, 161, "Text",ExpressionUUID->"6d93a378-1a73-48a5-aec3-4d760c5b2872"],
Cell[CellGroupData[{
Cell[78080, 1708, 3677, 100, 28, "Input",ExpressionUUID->"00ed8709-05c8-47ae-bc5d-f488a0d8a936",
 CellOpen->False],
Cell[81760, 1810, 201211, 4322, 454, "Output",ExpressionUUID->"71bbd3d5-daae-4ce2-a3d1-78bf7152cb99"]
}, Open  ]],
Cell[282986, 6135, 367, 8, 32, "FigureCaption",ExpressionUUID->"b2516e1d-be91-4948-b71f-a99fb526d7bf"],
Cell[283356, 6145, 1512, 36, 136, "Text",ExpressionUUID->"367168ae-f20e-4cf6-ae0e-3a9e7b0eaf39"],
Cell[CellGroupData[{
Cell[284893, 6185, 3193, 84, 28, "Input",ExpressionUUID->"f1bbe8d4-81ff-49ad-8339-ad53c0494c44",
 CellOpen->False],
Cell[288089, 6271, 17222, 344, 132, "Output",ExpressionUUID->"6c2a9454-4e9a-4e1a-aabd-f56bfb65d9ba"]
}, Open  ]],
Cell[305326, 6618, 365, 8, 32, "FigureCaption",ExpressionUUID->"c6150e68-d6d2-440f-9d68-9175e92742a5"],
Cell[305694, 6628, 823, 15, 82, "Text",ExpressionUUID->"bd902d71-6bdb-4485-82db-10e0869931dd"],
Cell[CellGroupData[{
Cell[306542, 6647, 1437, 37, 102, "Input",ExpressionUUID->"4582a0b5-ea91-417d-9e5a-ef26d6ec51b5"],
Cell[307982, 6686, 8427, 174, 359, "Output",ExpressionUUID->"8bfedd28-c28d-4bed-82a3-71d3d31eea6b"]
}, Open  ]]
}, Open  ]],
Cell[316436, 6864, 373, 8, 32, "FigureCaption",ExpressionUUID->"38dfff29-e470-40a1-9e3a-6354597fb481"],
Cell[316812, 6874, 319, 6, 33, "Text",ExpressionUUID->"2638298f-4978-4a24-a0f1-a78aed25f789"],
Cell[317134, 6882, 648, 20, 103, "EquationNumbered",ExpressionUUID->"2e38c57a-6d93-4c66-be74-1ccf23430642"],
Cell[CellGroupData[{
Cell[317807, 6906, 359, 8, 33, "Text",ExpressionUUID->"ac63c5ee-2aed-44e4-93cf-b0e34b406033"],
Cell[CellGroupData[{
Cell[318191, 6918, 529, 17, 257629, "Input",ExpressionUUID->"546f79d7-b2ff-475f-8985-78c2a6a85f72"],
Cell[318723, 6937, 961, 15, 70, "Output",ExpressionUUID->"4a621f53-0981-4f50-8624-f13d36dac70d"]
}, Open  ]]
}, Closed]],
Cell[319711, 6956, 690, 19, 96, "EquationNumbered",ExpressionUUID->"12ae0bab-e68d-4f97-b85c-13e145629ce2"],
Cell[320404, 6977, 319, 8, 33, "Text",ExpressionUUID->"6b8684bb-62c1-41fd-87c2-030a7427f344"],
Cell[CellGroupData[{
Cell[320748, 6989, 251, 5, 47, "Input",ExpressionUUID->"21cc9f51-5366-4169-a527-21c6f03bd53e"],
Cell[321002, 6996, 982, 15, 45, "Output",ExpressionUUID->"d7a03d56-bec9-4ced-93b4-645e013800d7"]
}, Open  ]],
Cell[321999, 7014, 898, 20, 63, "Text",ExpressionUUID->"d12f4d1f-480d-4641-afd9-8fddb0c5b04e"],
Cell[322900, 7036, 2091, 42, 234, "Text",ExpressionUUID->"aa9ec412-3b07-4744-bb5a-01d8cccf0f0a"],
Cell[CellGroupData[{
Cell[325016, 7082, 279, 5, 87, "Section",ExpressionUUID->"e3396474-1e18-4421-8f12-86ad136e0d78"],
Cell[325298, 7089, 821, 14, 107, "Text",ExpressionUUID->"ba3f26f9-c1bd-40f3-806c-8abbc07a0321"],
Cell[326122, 7105, 1310, 24, 156, "Text",ExpressionUUID->"a58e2f5a-1052-4bf6-bc07-f68b6aa0aea7"],
Cell[CellGroupData[{
Cell[327457, 7133, 1821, 50, 28, "Input",ExpressionUUID->"bf98e71b-e4df-4fd0-b489-2cacf6a73ed5",
 CellOpen->False],
Cell[329281, 7185, 4139, 84, 345, "Output",ExpressionUUID->"ce32d382-b175-431a-97a1-e88707f6885c"]
}, Open  ]],
Cell[333435, 7272, 369, 8, 32, "FigureCaption",ExpressionUUID->"d8c34382-7cdb-47a4-85ff-ecf382c17664"],
Cell[333807, 7282, 795, 13, 107, "Text",ExpressionUUID->"149688bc-0f69-439e-8067-8361a96752a6"],
Cell[334605, 7297, 11099, 141, 89, "Graphics",ExpressionUUID->"d44fe9aa-af6f-420f-8107-7c33840e062e"],
Cell[345707, 7440, 398, 9, 33, "TableTitle",ExpressionUUID->"10405461-bfd3-48a7-88d5-c3288894c518"],
Cell[346108, 7451, 1084, 24, 87, "Text",ExpressionUUID->"2af4e71b-7195-4788-b68d-e225699be125"],
Cell[CellGroupData[{
Cell[347217, 7479, 2719, 76, 28, "Input",ExpressionUUID->"c62a5dc4-0733-4e87-af53-4512a741911d",
 CellOpen->False],
Cell[349939, 7557, 3648, 80, 345, "Output",ExpressionUUID->"6bc88f27-9528-4345-83bf-d0790ce5734c"]
}, Open  ]],
Cell[353602, 7640, 375, 8, 32, "FigureCaption",ExpressionUUID->"2c8fd259-a91f-4156-ac70-c4afe486dd1e"],
Cell[353980, 7650, 695, 17, 58, "Text",ExpressionUUID->"5f8cf2a1-b010-4227-9362-aa985b2573c1"],
Cell[CellGroupData[{
Cell[354700, 7671, 3309, 88, 28, "Input",ExpressionUUID->"ed425156-b23f-4771-bb1b-f3de9553a23c",
 CellOpen->False],
Cell[358012, 7761, 5781, 115, 378, "Output",ExpressionUUID->"c108422d-5d93-4ac0-aa43-93e893f820fe"]
}, Open  ]],
Cell[363808, 7879, 381, 8, 32, "FigureCaption",ExpressionUUID->"c65f11ec-0a09-4997-af53-b6695765d053"],
Cell[364192, 7889, 892, 21, 63, "Text",ExpressionUUID->"52133245-e9b8-4b5f-bfda-88df6d86cbc5"],
Cell[CellGroupData[{
Cell[365109, 7914, 1866, 50, 28, "Input",ExpressionUUID->"6dc73cef-b620-4a68-9c3e-be72a043c2dd",
 CellOpen->False],
Cell[366978, 7966, 1764, 30, 134, "Output",ExpressionUUID->"cd192202-93d5-46c0-9a83-66203ff5ea59"]
}, Open  ]],
Cell[368757, 7999, 464, 10, 33, "TableTitle",ExpressionUUID->"e4aee4e8-d407-43d6-b1c4-a6f986fd74b6"],
Cell[CellGroupData[{
Cell[369246, 8013, 1214, 23, 156, "Text",ExpressionUUID->"471706fe-7a58-47a5-8877-b01b4ecd3e93"],
Cell[CellGroupData[{
Cell[370485, 8040, 334, 10, 45, "Input",ExpressionUUID->"993fbe4d-8f78-4440-9acb-c9408ba08035"],
Cell[370822, 8052, 959, 15, 45, "Output",ExpressionUUID->"035be7e4-276e-4435-a2ca-9d60b238e0af"]
}, Open  ]]
}, Open  ]],
Cell[371808, 8071, 633, 18, 59, "Text",ExpressionUUID->"261ae636-07bf-48d6-96a7-027d9f4d97d7"],
Cell[372444, 8091, 458, 12, 68, "EquationNumbered",ExpressionUUID->"aaa4e324-a302-444f-b091-ac4422fce082"],
Cell[CellGroupData[{
Cell[372927, 8107, 675, 15, 60, "Text",ExpressionUUID->"ab2c54b1-f0f0-41b4-b7e0-85d47cfb1883"],
Cell[CellGroupData[{
Cell[373627, 8126, 302, 6, 65409, "Input",ExpressionUUID->"845c007f-ef19-4be3-b0ea-1b80b0f722f2"],
Cell[373932, 8134, 997, 15, 70, "Output",ExpressionUUID->"2705ff88-5e14-49da-baf9-8d6100d92eb7"]
}, Open  ]]
}, Closed]],
Cell[374956, 8153, 481, 12, 64, "EquationNumbered",ExpressionUUID->"841da71a-2d9c-41e7-b709-97de8954c320"],
Cell[375440, 8167, 504, 13, 68, "EquationNumbered",ExpressionUUID->"aa002fc0-1604-49fb-8dd0-caa3e069a406"],
Cell[CellGroupData[{
Cell[375969, 8184, 824, 15, 107, "Text",ExpressionUUID->"38f7e343-6595-484e-864c-91a6acc013b0"],
Cell[376796, 8201, 402, 12, 28, "Input",ExpressionUUID->"cceadca5-4e83-4394-bff9-fa5ec9c9a40f",
 CellOpen->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[377235, 8218, 1083, 21, 131, "Text",ExpressionUUID->"9efad89f-bc0c-4e87-b55b-e8021a9aface"],
Cell[CellGroupData[{
Cell[378343, 8243, 644, 17, 106, "Input",ExpressionUUID->"c3ff18ed-fa13-4300-b75f-cda0fa55c42c"],
Cell[378990, 8262, 917, 14, 45, "Output",ExpressionUUID->"29f91ff8-b4ed-454a-9ef5-41287fb4ecf7"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[379968, 8283, 225, 4, 87, "Section",ExpressionUUID->"f6874359-9d1d-40c2-9d1c-aa46e4e4a743"],
Cell[380196, 8289, 974, 29, 93, "Text",ExpressionUUID->"5fc958b1-5df1-4f9d-b3e7-047fab2f17e5"],
Cell[CellGroupData[{
Cell[381195, 8322, 347, 10, 78, "EquationNumbered",ExpressionUUID->"8332ae97-49a8-41d4-a499-db0466ed4eb5"],
Cell[381545, 8334, 241, 8, 73496, "Input",ExpressionUUID->"dc0bfe0e-d095-43b0-9c5f-e4fdd31520b4"]
}, Closed]],
Cell[381801, 8345, 417, 9, 54, "Text",ExpressionUUID->"1be1b8b2-efd0-43f8-b053-c7f28b773cb5"],
Cell[CellGroupData[{
Cell[382243, 8358, 332, 10, 45, "Input",ExpressionUUID->"668b4437-6684-4988-ad41-a21c3787735f"],
Cell[382578, 8370, 949, 15, 45, "Output",ExpressionUUID->"b257e040-fc7a-47cb-8013-af20395d5bef"]
}, Open  ]],
Cell[383542, 8388, 243, 7, 33, "Text",ExpressionUUID->"2a5a2440-e9b2-48a3-b4c6-e8365ffd360b"],
Cell[CellGroupData[{
Cell[383810, 8399, 189, 5, 47, "Input",ExpressionUUID->"7d3d21d9-28b2-45ed-b595-0b6ce300e1b1"],
Cell[384002, 8406, 926, 14, 45, "Output",ExpressionUUID->"0620e496-dfd6-4500-8676-b7ae8b3cfc0e"]
}, Open  ]],
Cell[384943, 8423, 240, 7, 33, "Text",ExpressionUUID->"8f19d27c-225a-4198-bd22-4253aacb1e66"],
Cell[CellGroupData[{
Cell[385208, 8434, 245, 7, 47, "Input",ExpressionUUID->"7c7da99c-dc1e-4680-a6c2-199ef00f345b"],
Cell[385456, 8443, 931, 14, 45, "Output",ExpressionUUID->"26ebe24a-c931-4f60-abf7-b4412726302f"]
}, Open  ]],
Cell[386402, 8460, 513, 10, 58, "Text",ExpressionUUID->"62a57653-29b2-461c-be86-1f2f9b7c0c79"],
Cell[386918, 8472, 757, 13, 82, "Text",ExpressionUUID->"d0c18094-f02c-4fe7-b11e-41ed185ef3ab"],
Cell[387678, 8487, 991, 19, 107, "Text",ExpressionUUID->"775001ba-cd70-4271-8555-7f7ad2fb84a2"],
Cell[CellGroupData[{
Cell[388694, 8510, 5729, 152, 28, "Input",ExpressionUUID->"387901bd-4a27-4827-a4d2-cbee8f1f5a2d",
 CellOpen->False],
Cell[394426, 8664, 5790, 112, 376, "Output",ExpressionUUID->"ed492c49-5fbc-4d26-80a2-a1df630f6ddb"]
}, Open  ]],
Cell[400231, 8779, 360, 8, 32, "FigureCaption",ExpressionUUID->"4da9a84b-5e20-412a-9e63-7625403164b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[400628, 8792, 223, 4, 87, "Section",ExpressionUUID->"ae679044-68ed-484a-9b79-bfe13d68b387"],
Cell[400854, 8798, 824, 20, 63, "Text",ExpressionUUID->"311136bf-2836-405b-8c83-206d97fbc2ba"],
Cell[401681, 8820, 664, 26, 101, "EquationNumbered",ExpressionUUID->"a546edca-deab-417d-8270-709cfe722058"],
Cell[402348, 8848, 592, 13, 59, "Text",ExpressionUUID->"5f66c0da-1d62-4f6c-8d5b-03cffd853310"],
Cell[CellGroupData[{
Cell[402965, 8865, 468, 13, 68, "EquationNumbered",ExpressionUUID->"0636856c-2810-4f89-9353-18f23f791ba6"],
Cell[403436, 8880, 333, 11, 148, "Input",ExpressionUUID->"dd16d628-74cc-4092-a8c8-1acb1831272c"]
}, Closed]],
Cell[403784, 8894, 690, 17, 78, "Text",ExpressionUUID->"7add042c-5a33-46a7-9cc3-8aae1d8e14a5"],
Cell[CellGroupData[{
Cell[404499, 8915, 652, 19, 102, "EquationNumbered",ExpressionUUID->"450dd822-e7c2-4182-971f-7579871c8d45"],
Cell[CellGroupData[{
Cell[405176, 8938, 544, 17, 19746, "Input",ExpressionUUID->"db27ea29-c51c-4ecf-9eee-3dfa0c40b327"],
Cell[405723, 8957, 989, 15, 70, "Output",ExpressionUUID->"04b9173b-8de0-4a16-8be0-77f295a97e6c"]
}, Open  ]]
}, Closed]],
Cell[406739, 8976, 457, 12, 29, "Text",ExpressionUUID->"3c27a47f-2436-4901-9e70-27d057a2070f"],
Cell[CellGroupData[{
Cell[407221, 8992, 595, 17, 28, "Input",ExpressionUUID->"c274f7bf-d66f-467d-90af-fa0dbcf8bc16",
 CellOpen->False],
Cell[407819, 9011, 4147, 85, 338, "Output",ExpressionUUID->"6a9b192d-2f80-43ef-b252-499fb5b01ee8"]
}, Open  ]],
Cell[411981, 9099, 768, 21, 32, "FigureCaption",ExpressionUUID->"7ff9a4a6-c8fd-4216-8c63-024965f19ed8"],
Cell[412752, 9122, 370, 12, 33, "Text",ExpressionUUID->"cc91dbf6-46fd-4237-bf40-510e15622b07"],
Cell[CellGroupData[{
Cell[413147, 9138, 2324, 61, 28, "Input",ExpressionUUID->"9c1b2b4b-1890-4563-9e1e-5bafa495d8d3",
 CellOpen->False],
Cell[415474, 9201, 14623, 294, 354, "Output",ExpressionUUID->"8d4d1094-2f8d-4fff-9016-04653fbbae04"]
}, Open  ]],
Cell[430112, 9498, 665, 16, 32, "FigureCaption",ExpressionUUID->"934a93a6-1f8a-4a9c-ae35-a02d8c651297"],
Cell[430780, 9516, 360, 8, 58, "Text",ExpressionUUID->"b376738e-6a64-4ebc-b0fb-a6a3ebcac09e"],
Cell[431143, 9526, 776, 13, 82, "Text",ExpressionUUID->"6dfc171e-6908-4bf6-b854-4b945aee1a33"],
Cell[CellGroupData[{
Cell[431944, 9543, 7461, 212, 28, "Input",ExpressionUUID->"b3e4c327-3f01-4820-8f41-a4dfd469fcc4",
 CellOpen->False],
Cell[439408, 9757, 9044, 183, 362, "Output",ExpressionUUID->"fdf4cc32-210c-482f-9ce8-0fa5b4dd049a"]
}, Open  ]],
Cell[448467, 9943, 367, 8, 32, "FigureCaption",ExpressionUUID->"5451c6d5-3ac4-4201-83eb-bcb6abbb8c42"],
Cell[448837, 9953, 1142, 18, 156, "Text",ExpressionUUID->"814b6eb7-ecdc-4583-93a8-959af3175af8"],
Cell[CellGroupData[{
Cell[450004, 9975, 518, 13, 74, "Input",ExpressionUUID->"5ffa5022-d4e6-43e3-8e46-bed0fb88f31e"],
Cell[450525, 9990, 657, 15, 45, "Output",ExpressionUUID->"7069c75f-15ff-415b-81b6-f50981aec196"]
}, Open  ]],
Cell[451197, 10008, 660, 18, 33, "Text",ExpressionUUID->"85892d79-7f2f-4774-a578-ac1cd5040d00"],
Cell[CellGroupData[{
Cell[451882, 10030, 421, 13, 45, "Input",ExpressionUUID->"61fd5595-62ba-4a56-a018-1adb72ee47ae"],
Cell[452306, 10045, 1031, 16, 45, "Output",ExpressionUUID->"71cdb554-2af9-480c-acde-5fc2f301c5c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[453374, 10066, 588, 19, 45, "Input",ExpressionUUID->"aec40cb5-3934-4c6d-830d-4c3708b5b362"],
Cell[453965, 10087, 1009, 15, 45, "Output",ExpressionUUID->"77a270a0-e5fa-4892-ba1b-a1cd84973fbc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455011, 10107, 5914, 168, 28, "Input",ExpressionUUID->"84a5018e-c755-4742-9819-c471e33e87ee",
 CellOpen->False],
Cell[460928, 10277, 9935, 205, 374, "Output",ExpressionUUID->"28d21d8f-e1c9-4e28-8431-68f126489e92"]
}, Open  ]],
Cell[470878, 10485, 372, 8, 32, "FigureCaption",ExpressionUUID->"3c0be7ca-4300-47e3-aed5-500a6085a567"],
Cell[CellGroupData[{
Cell[471275, 10497, 438, 12, 28, "Input",ExpressionUUID->"255d6105-7fad-42fb-9c8c-5e0d2cb57018",
 CellOpen->False],
Cell[471716, 10511, 18964, 378, 28, "Output",ExpressionUUID->"a5bd980e-2daf-4e7e-a1e5-5b5263d4a16b",
 CellOpen->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[490717, 10894, 1074, 26, 28, "Input",ExpressionUUID->"afd35332-76b4-438e-ad92-2161b0eec94e",
 CellOpen->False],
Cell[491794, 10922, 369, 9, 58, "Text",ExpressionUUID->"2c53739a-a806-4736-b861-c84f89b7abaf"]
}, Open  ]],
Cell[492178, 10934, 1133, 24, 107, "Text",ExpressionUUID->"2c2af842-3c63-441f-ba56-93d04eb4e64f"],
Cell[CellGroupData[{
Cell[493336, 10962, 7911, 203, 28, "Input",ExpressionUUID->"e73b7af7-9297-4da8-8358-f758eb226987",
 CellOpen->False],
Cell[501250, 11167, 5663, 116, 493, "Output",ExpressionUUID->"f91c5bba-cacf-4bba-b009-5887115fc00d"]
}, Open  ]],
Cell[506928, 11286, 368, 8, 32, "FigureCaption",ExpressionUUID->"eef8b7e6-0ed7-4bb3-ac36-0f803b813894"]
}, Open  ]],
Cell[CellGroupData[{
Cell[507333, 11299, 232, 4, 87, "Section",ExpressionUUID->"07d4e33e-096b-4bbf-9f3e-2fb72dad96f2"],
Cell[507568, 11305, 580, 13, 58, "Text",ExpressionUUID->"07f1e601-f992-4771-8608-cc859ebde579"],
Cell[CellGroupData[{
Cell[508173, 11322, 2632, 62, 28, "Input",ExpressionUUID->"961cee79-f591-4541-81d4-be113cd0221c",
 CellOpen->False],
Cell[510808, 11386, 3601, 113, 188, "Output",ExpressionUUID->"e73c2142-d6a0-4f29-ba6a-39bbba263454"]
}, Open  ]],
Cell[514424, 11502, 456, 10, 33, "TableTitle",ExpressionUUID->"6d36c9d9-0280-45fd-a029-c8cf84067088"],
Cell[514883, 11514, 828, 17, 107, "Text",ExpressionUUID->"a59d03e5-ad72-4d44-804f-f33fbf363455"],
Cell[CellGroupData[{
Cell[515736, 11535, 1622, 37, 28, "Input",ExpressionUUID->"51ff80e2-7d51-4a17-9524-5a4595a05e35",
 CellOpen->False],
Cell[517361, 11574, 738, 14, 107, "Text",ExpressionUUID->"6c33e0ca-126c-4376-ab63-cda2236a243e"]
}, Open  ]],
Cell[518114, 11591, 487, 13, 68, "EquationNumbered",ExpressionUUID->"d4709be6-b89e-45c5-929e-7b393875a09c"],
Cell[CellGroupData[{
Cell[518626, 11608, 196, 5, 45, "Input",ExpressionUUID->"a371506e-1fdf-4c2c-9923-5f2502384fee"],
Cell[518825, 11615, 942, 15, 45, "Output",ExpressionUUID->"06386e7e-7512-4724-bee6-1fb0d6e29c9e"]
}, Open  ]],
Cell[519782, 11633, 299, 5, 33, "Text",ExpressionUUID->"3a709367-181f-4206-a671-84afa4b1bd80"],
Cell[CellGroupData[{
Cell[520106, 11642, 2519, 59, 28, "Input",ExpressionUUID->"90e7ad97-33ac-4ca5-b62c-a86cc88ad045",
 CellOpen->False],
Cell[522628, 11703, 3935, 115, 188, "Output",ExpressionUUID->"f5ad8cce-0511-4f9b-9108-0de9874fe127"]
}, Open  ]],
Cell[526578, 11821, 466, 10, 33, "TableTitle",ExpressionUUID->"feb1bb7c-39ab-460a-925b-afc7802f7028"],
Cell[527047, 11833, 523, 14, 58, "Text",ExpressionUUID->"8a46827e-20e7-4b35-8e51-b34f4bed4988"]
}, Open  ]],
Cell[CellGroupData[{
Cell[527607, 11852, 357, 11, 87, "Section",ExpressionUUID->"eb1be7dc-b395-40e4-87d3-a8f97a2b93ff"],
Cell[527967, 11865, 2054, 47, 161, "Text",ExpressionUUID->"6c6d637b-9da2-4b67-a73f-c132407609cc"],
Cell[530024, 11914, 1834, 36, 136, "Text",ExpressionUUID->"1172e52c-7220-48f5-b44c-fff379d2831e"],
Cell[CellGroupData[{
Cell[531883, 11954, 719, 22, 133, "EquationNumbered",ExpressionUUID->"18d4bc9f-3d1c-4140-8a9a-1f2336c0ffb7"],
Cell[532605, 11978, 659, 20, 58, "Text",ExpressionUUID->"cbbeb256-f1da-45d2-a383-8c689b729ea0"],
Cell[CellGroupData[{
Cell[533289, 12002, 553, 16, 51, "Input",ExpressionUUID->"d107a633-ab90-406c-92af-b7668f774518"],
Cell[533845, 12020, 1350, 28, 100, "Output",ExpressionUUID->"aa1f22db-850c-4f77-aa75-da60010f392a"]
}, Open  ]]
}, Open  ]],
Cell[535222, 12052, 1989, 40, 205, "Text",ExpressionUUID->"e55500ad-9e4b-4948-a9de-9bc1ef061438"],
Cell[CellGroupData[{
Cell[537236, 12096, 986, 26, 28, "Input",ExpressionUUID->"7c5cf601-c4d7-4a66-ac46-277f3ef06df3",
 CellOpen->False],
Cell[538225, 12124, 17445, 304, 377, "Output",ExpressionUUID->"b07f9bdf-d0c4-4064-b38e-d001319eb1d0"]
}, Open  ]],
Cell[555685, 12431, 400, 8, 32, "FigureCaption",ExpressionUUID->"f5220e15-44b5-411b-9d09-e86451c2f5a3"],
Cell[556088, 12441, 1053, 18, 131, "Text",ExpressionUUID->"d8eb75a3-ab9a-4c57-b9a6-a9582a00dca9"],
Cell[CellGroupData[{
Cell[557166, 12463, 350, 11, 72, "Input",ExpressionUUID->"80ef14ba-2622-4e95-b6cb-8ad4971170f0"],
Cell[557519, 12476, 964, 15, 45, "Output",ExpressionUUID->"f6cca286-d181-45a7-a2c9-174932f6f45d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[558520, 12496, 645, 15, 58, "Text",ExpressionUUID->"ff982631-6b3b-4244-8b10-fed060e902fc"],
Cell[CellGroupData[{
Cell[559190, 12515, 702, 17, 51, "Input",ExpressionUUID->"31acf606-9c38-460c-abbd-8bc87c44672b"],
Cell[559895, 12534, 1470, 27, 53, "Output",ExpressionUUID->"12fa10e6-7b9d-4670-a9b1-a4bfeda9484b"]
}, Open  ]],
Cell[561380, 12564, 262, 9, 33, "Text",ExpressionUUID->"139c6458-f8c9-48bd-9a43-c123bf6e6379"],
Cell[CellGroupData[{
Cell[561667, 12577, 352, 11, 72, "Input",ExpressionUUID->"79319bad-d7cc-4db7-83f2-e4df4af61879"],
Cell[562022, 12590, 994, 15, 45, "Output",ExpressionUUID->"8fdcc045-8686-4153-8476-136ebff38fda"]
}, Open  ]],
Cell[563031, 12608, 182, 4, 33, "Text",ExpressionUUID->"97af86de-69d5-4de5-98d0-ac86b136e29f"],
Cell[CellGroupData[{
Cell[563238, 12616, 1195, 32, 28, "Input",ExpressionUUID->"2debe1dc-376b-4243-9679-aaf32674511b",
 CellOpen->False],
Cell[564436, 12650, 17961, 312, 377, "Output",ExpressionUUID->"0009b9c6-f5b9-47f5-9491-38dc5771843f"]
}, Open  ]]
}, Open  ]],
Cell[582424, 12966, 400, 8, 32, "FigureCaption",ExpressionUUID->"416f2e08-905b-4dcc-afe8-cb8c85c9562f"],
Cell[582827, 12976, 617, 19, 79, "EquationNumbered",ExpressionUUID->"2a65aa97-ad26-4f77-982d-b7a09e795086"],
Cell[CellGroupData[{
Cell[583469, 12999, 1377, 36, 28, "Input",ExpressionUUID->"902c195e-dcac-4417-9128-9afe21a080a7",
 CellOpen->False],
Cell[584849, 13037, 42976, 762, 379, "Output",ExpressionUUID->"1d19fce4-97e1-40f1-8046-b06c586e8ebb"]
}, Open  ]],
Cell[627840, 13802, 380, 8, 32, "FigureCaption",ExpressionUUID->"5f5f05a0-4ca7-4588-9e97-af86a7b7bb4e"],
Cell[628223, 13812, 1104, 24, 131, "Text",ExpressionUUID->"a64100ac-bc6d-40dc-8a5a-b37d69ff6d19"],
Cell[CellGroupData[{
Cell[629352, 13840, 558, 10, 58, "Text",ExpressionUUID->"8aa0aaf1-4035-4e70-a4ec-2578d8513abb"],
Cell[629913, 13852, 839, 18, 82, "Text",ExpressionUUID->"8ac8ee69-2538-495b-9c01-02aae1ecde95"],
Cell[630755, 13872, 1341, 24, 156, "Text",ExpressionUUID->"4dbe4c89-7199-4242-9d3d-c226d9e12f6b"],
Cell[632099, 13898, 618, 18, 58, "Text",ExpressionUUID->"7ebfecff-7fc9-4855-8403-544f210238de"],
Cell[632720, 13918, 266, 10, 33, "Text",ExpressionUUID->"8786373a-1dc6-4ef7-8f30-a14ada2da114"],
Cell[632989, 13930, 191, 4, 33, "Text",ExpressionUUID->"b97794a1-b13e-47bf-9571-3e1c5229decc"],
Cell[633183, 13936, 319, 13, 33, "Text",ExpressionUUID->"062ab86a-4f2a-4ada-88a7-e2e1bae1650d"],
Cell[633505, 13951, 396, 15, 33, "Text",ExpressionUUID->"f640e7e4-74ef-4aeb-b2ca-e55a42f30dde"],
Cell[633904, 13968, 739, 25, 38, "Text",ExpressionUUID->"ea435030-a9ef-4704-baaa-4d820b5b30c7"],
Cell[634646, 13995, 703, 20, 58, "Text",ExpressionUUID->"ca3adee8-52f9-4ba0-817d-cb4801d17346"],
Cell[635352, 14017, 1655, 45, 146, "Text",ExpressionUUID->"d3746b23-5923-4586-b24a-4ac8be535808"]
}, Open  ]],
Cell[637022, 14065, 560, 11, 58, "Text",ExpressionUUID->"b8553f65-4c58-4181-a18c-34c4cbfae78a"],
Cell[CellGroupData[{
Cell[637607, 14080, 4984, 141, 28, "Input",ExpressionUUID->"23635fef-8385-406e-8a6f-0dafa8669c33",
 CellOpen->False],
Cell[642594, 14223, 60378, 1025, 269, "Output",ExpressionUUID->"7c0be288-e3da-4e35-82e0-9e5fd4ba057f"]
}, Open  ]],
Cell[702987, 15251, 428, 9, 32, "FigureCaption",ExpressionUUID->"0b0a51c6-fa95-4b67-a008-d30b0a0b900a"],
Cell[703418, 15262, 839, 20, 60, "Text",ExpressionUUID->"31cc6b51-9289-4b28-b213-ea23303125d1"],
Cell[CellGroupData[{
Cell[704282, 15286, 1330, 35, 28, "Input",ExpressionUUID->"abe3b62d-7a71-4d5e-b300-6034be2efefc",
 CellOpen->False],
Cell[705615, 15323, 15962, 274, 319, "Output",ExpressionUUID->"56d7fdab-f94d-4224-ac7f-b8c20f4b1a9d"]
}, Open  ]],
Cell[721592, 15600, 409, 8, 32, "FigureCaption",ExpressionUUID->"13b82c8b-1157-4d2f-a47e-642ca2048c1a"],
Cell[CellGroupData[{
Cell[722026, 15612, 436, 14, 28, "Input",ExpressionUUID->"e80609c7-af17-4ba2-9725-5272aafd78c6",
 CellOpen->False],
Cell[722465, 15628, 990, 16, 28, "Output",ExpressionUUID->"de390c04-f24e-4a8e-9458-9492c0675746",
 CellOpen->False]
}, Open  ]],
Cell[723470, 15647, 304, 7, 33, "Text",ExpressionUUID->"1f54a247-211c-45e9-bf73-f993ab4d4d54"],
Cell[CellGroupData[{
Cell[723799, 15658, 2227, 63, 28, "Input",ExpressionUUID->"40c2eecf-8e2e-4f24-8b4e-4a71f90660a2",
 CellOpen->False],
Cell[726029, 15723, 34793, 622, 352, "Output",ExpressionUUID->"6909ce09-20e7-4a7b-b0c7-d332c572abf8"]
}, Open  ]],
Cell[760837, 16348, 515, 10, 32, "FigureCaption",ExpressionUUID->"2dc161e1-3d4d-4913-8b6a-2e06586c270c"],
Cell[761355, 16360, 457, 8, 58, "Text",ExpressionUUID->"463dcf1f-dbf2-4628-b6a6-0fe4779b308a"],
Cell[761815, 16370, 377, 7, 58, "Text",ExpressionUUID->"c6cf1e3e-0ac1-4dc5-935c-d7857be9261e"],
Cell[CellGroupData[{
Cell[762217, 16381, 646, 14, 58, "Text",ExpressionUUID->"61a897a5-1566-4388-ba9d-0cd7fedd25f4"],
Cell[762866, 16397, 1851, 61, 28, "Input",ExpressionUUID->"ee16f6e9-38eb-4521-88d4-6af85578742f",
 CellOpen->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[764754, 16463, 2046, 61, 28, "Input",ExpressionUUID->"1ac8be0b-e636-4723-9c2a-80754829ee54",
 CellOpen->False],
Cell[766803, 16526, 902, 20, 67, "Output",ExpressionUUID->"ce77eb72-72cf-46e4-ab2e-80d4154bfa17"]
}, Open  ]],
Cell[767720, 16549, 490, 12, 58, "Text",ExpressionUUID->"6019f7c5-b9a2-4040-bf54-70461bb7265c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[768247, 16566, 209, 4, 87, "Section",ExpressionUUID->"e9433530-2321-4085-8e05-a815b7762740"],
Cell[768459, 16572, 684, 12, 107, "Text",ExpressionUUID->"52720199-80dd-486b-bc87-586683506cd3"],
Cell[769146, 16586, 263, 7, 27, "Item1",ExpressionUUID->"da5b95b3-41d7-462a-9350-583e4d88f7cd"],
Cell[769412, 16595, 380, 9, 27, "Item1",ExpressionUUID->"d63e4e83-c142-4a11-833f-6d1fd049a715"],
Cell[769795, 16606, 348, 8, 49, "Item1",ExpressionUUID->"82034d51-08f0-46d7-a5bd-afce2c17b00a"],
Cell[770146, 16616, 395, 8, 49, "Item1",ExpressionUUID->"d28174d0-51c9-4676-a46d-bdbd50858b16"],
Cell[770544, 16626, 362, 8, 49, "Item1",ExpressionUUID->"537aa3d1-add2-44f9-b0f9-8bbcc1344f8d"],
Cell[770909, 16636, 340, 8, 27, "Item1",ExpressionUUID->"8df168b0-c012-42d0-9603-cb08a7f8cf40"],
Cell[771252, 16646, 675, 12, 82, "Text",ExpressionUUID->"ecc699ea-2651-4221-b8d2-4fb92520333d"]
}, Open  ]],
Cell[771942, 16661, 802, 16, 131, "Text",ExpressionUUID->"6b0648c4-2cf9-43a9-8872-8c31f76710be"],
Cell[772747, 16679, 212, 4, 155, "EndnoteSection",ExpressionUUID->"dbc70116-1053-4dc2-b564-bda6ea356bb2"],
Cell[772962, 16685, 674, 15, 28, "Endnote",ExpressionUUID->"93e93859-ce69-457b-a1e1-d23c252617aa",
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellTags->"endnote1"],
Cell[773639, 16702, 756, 16, 51, "Endnote",ExpressionUUID->"9e9f6067-29ce-45d2-b13c-6f2c6e78297f",
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellTags->"endnote2"],
Cell[774398, 16720, 1039, 21, 74, "Endnote",ExpressionUUID->"7f15b561-c91e-4fff-a1d2-ad6c3cc2ac89",
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellTags->"endnote3"],
Cell[775440, 16743, 816, 18, 51, "Endnote",ExpressionUUID->"8b9809ef-19f8-4e2e-9ffc-6786251f6a4d",
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellTags->"endnote4"],
Cell[776259, 16763, 616, 14, 28, "Endnote",ExpressionUUID->"9ede99b8-7033-4f3d-861f-8e669294f49d",
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellTags->"endnote5"],
Cell[776878, 16779, 1102, 21, 74, "Endnote",ExpressionUUID->"63cb079d-3452-496e-afbc-4534626f1113",
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellTags->"endnote6"],
Cell[777983, 16802, 691, 15, 28, "Endnote",ExpressionUUID->"3cf3f7af-148b-45bb-a50f-041d7037bd6e",
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellTags->"endnote7"],
Cell[778677, 16819, 606, 14, 28, "Endnote",ExpressionUUID->"367c8c69-6d35-49b4-a7b1-2b517e171887",
 PageBreakAbove->False,
 PageBreakBelow->False,
 CellTags->"endnote8"],
Cell[779286, 16835, 875, 18, 60, "Text",ExpressionUUID->"14e06746-7bef-448d-a41e-2dbf5c40a3cc",
 PageBreakAbove->False,
 PageBreakBelow->True,
 CellTags->"endnote9"],
Cell[780164, 16855, 218, 4, 155, "ReferenceSection",ExpressionUUID->"ea8dd882-20ec-4f0c-9a36-e79b5a75d662"],
Cell[780385, 16861, 441, 11, 24, "Reference",ExpressionUUID->"1c87383c-4f8c-4856-99c2-6ed48ec7437a"],
Cell[780829, 16874, 462, 10, 26, "Reference",ExpressionUUID->"22514e19-7562-4502-9600-a860da0f7e43"],
Cell[781294, 16886, 504, 13, 38, "Reference",ExpressionUUID->"f0e38f45-ea64-49bc-8871-944a97cd093b"],
Cell[781801, 16901, 474, 11, 26, "Reference",ExpressionUUID->"aa923ccd-7a3c-4153-a0e9-aba183f6bc69"],
Cell[782278, 16914, 482, 13, 38, "Reference",ExpressionUUID->"1c720577-7bd7-46a6-a913-67231424f5fc"],
Cell[782763, 16929, 448, 10, 26, "Reference",ExpressionUUID->"c04ff80e-ac66-437d-a0bd-9c4445917722"],
Cell[783214, 16941, 213, 4, 155, "ExerciseSection",ExpressionUUID->"72803ca7-eb89-4ad9-af41-3b63dffbd77b"],
Cell[783430, 16947, 562, 10, 48, "Item1Exercise",ExpressionUUID->"0c62d202-5881-4ae9-b54a-89f303615db6"],
Cell[783995, 16959, 564, 11, 49, "Item1Exercise",ExpressionUUID->"f19592bd-f292-48d3-86ee-cab21622df48"],
Cell[784562, 16972, 704, 12, 70, "Item1Exercise",ExpressionUUID->"4a7f7aed-999b-4f9e-b7df-93a77834289b"],
Cell[CellGroupData[{
Cell[785291, 16988, 12480, 276, 28, "Input",ExpressionUUID->"de2168b5-c516-429d-9d55-c83065b0c189",
 CellOpen->False],
Cell[797774, 17266, 6022, 122, 491, "Output",ExpressionUUID->"fb03e00c-d516-4b11-97da-62abcf160f1c"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature fxprSJiNSZCZRC10VxMGU95J *)
