(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.3' *)

(***************************************************************************)
(*                                                                         *)
(*                                                                         *)
(*  Under the Wolfram FreeCDF terms of use, this file and its content are  *)
(*  bound by the Creative Commons BY-SA Attribution-ShareAlike license.    *)
(*                                                                         *)
(*        For additional information concerning CDF licensing, see:        *)
(*                                                                         *)
(*         www.wolfram.com/cdf/adopting-cdf/licensing-options.html         *)
(*                                                                         *)
(*                                                                         *)
(***************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1088,         20]
NotebookDataLength[   1249828,      24687]
NotebookOptionsPosition[   1191728,      23619]
NotebookOutlinePosition[   1218875,      24220]
CellTagsIndexPosition[   1218456,      24204]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["8", "BookChapterNumber",
 CellChangeTimes->{3.5305411808502855`*^9, 3.5390216353200808`*^9, 
  3.53903474584396*^9},
 Background->RGBColor[
  0.9333333333333333, 0.1803921568627451, 
   0.1411764705882353],ExpressionUUID->"9535a802-6019-4842-8cdb-15bffde71964"],

Cell["The Labor Component of Private Investor Real Estate Returns", \
"BookChapterTitle",
 CellChangeTimes->{3.530541200540411*^9, 3.5390216353200808`*^9, 
  3.53903474584396*^9},
 TextAlignment->Center,ExpressionUUID->"8028d1df-3900-4323-ad35-424a4950af20"],

Cell["\<\
\[OpenCurlyDoubleQuote]If we restrict ourselves to models which can be solved \
analytically, we will be modeling for our mutual entertainment, not to \
maximize explanatory or predictive  power.\[CloseCurlyDoubleQuote]\
\>", "Epigraph",
 CellChangeTimes->{3.5305412234047194`*^9, 3.5390216353200808`*^9, 
  3.53903474584396*^9},
 TextAlignment->Center,ExpressionUUID->"106feaf1-24d7-4c03-848d-36edbc88c1df"],

Cell[TextData[{
 StyleBox["Harry M. Markowitz",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " commenting on ",
 StyleBox["Microscopic Simulation of Financial Markets",
  FontVariations->{"Underline"->True}],
 " by Levy, Levy, and Solomon (2000)"
}], "EpigraphAuthor",
 CellChangeTimes->{3.5305412421867933`*^9, 3.5390216353200808`*^9, 
  3.53903474584396*^9},
 TextAlignment->Center,ExpressionUUID->"b2b84873-f054-41a6-9729-e76979d5b069"],

Cell[BoxData[{
 RowBox[{"<<", "Notation`"}], "\n", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Rasterize", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "350"}]}], "]"}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.410115115046875*^9, 3.41011516728125*^9}, 
   3.41011525746875*^9, {3.41037859026425*^9, 3.4103786000455*^9}, {
   3.5305527084966288`*^9, 3.530552731493944*^9}, {3.539021068241646*^9, 
   3.5390210822594476`*^9}, 3.53902122041735*^9, 3.5390216353200808`*^9, 
   3.53903474584396*^9, {3.697233972186077*^9, 
   3.697233972603119*^9}},ExpressionUUID->"c096ec2f-aa95-46ec-93e1-\
62aaecf6b98d"],

Cell[CellGroupData[{

Cell["8.1. Introduction", "Section",
 CellChangeTimes->{3.531616892212791*^9, 3.5390216353200808`*^9, 
  3.53903474584396*^9},ExpressionUUID->"f3cf010e-8e30-4561-a2c1-fe04186d6e72"],

Cell["\<\
Suppose that private (Tier II) real estate investment return distributions \
exhibit non-normal, stable distributions having so-called \"fat tails\". \
Further, suppose that these fat tails are skewed right. What might explain \
this? Anecdotal evidence and intuition suggests that a portion of real estate \
returns observed in this market is attributable to the investor's \
entrepreneurial effort.  In the field this concept is sometimes referred to \
as \"sweat equity\" or \[OpenCurlyDoubleQuote]value added\
\[CloseCurlyDoubleQuote]. Technically this constitutes an addition of labor, \
implicitly a non-cash but valuable additional contribution of human capital \
to the investment. If the private real estate market is dominated by \
investors who self-select into this market because they have the ability or \
time to enhance their investment, and if the addition of this time and effort \
increases returns, this would contribute to the explanation of a fat right \
tail. By studying investor returns we hope to uncover a return generating \
process. Chapter 7 offered an empirical argument for such a process. This \
chapter further explores the \"add labor\" theory.\
\>", "Text",
 CellChangeTimes->{{3.5305414927201233`*^9, 3.530541507310958*^9}, {
   3.53161690687663*^9, 3.5316169231675615`*^9}, 3.5390216353200808`*^9, 
   3.53903474584396*^9, {3.5390350511884246`*^9, 3.5390350549046373`*^9}, {
   3.541186968635603*^9, 
   3.541186979341215*^9}},ExpressionUUID->"fc9b614f-f0a3-4f90-9a19-\
db741db6f391"],

Cell["In this chapter we will:", "Text",
 CellChangeTimes->{3.5390216353200808`*^9, 
  3.53903474584396*^9},ExpressionUUID->"e0ce66f7-d621-4996-b1cc-dd4179572011"],

Cell["\<\
Discuss how the addition of labor enters into the return equation;\
\>", "Item1",
 CellChangeTimes->{3.530541447348528*^9, 3.5390216353210807`*^9, 
  3.53903474584396*^9},ExpressionUUID->"00858320-0156-4504-b20e-1f7d12ec7b73"],

Cell["\<\
Build a two-part model of investor behavior where real estate investment \
decisions are a labor trade-off rather than a portfolio trade-off;\
\>", "Item1",
 CellChangeTimes->{3.530541450123687*^9, 3.5390216353210807`*^9, 
  3.53903474584396*^9},ExpressionUUID->"35abf51f-389e-48ac-82f2-4c8996973c70"],

Cell["Perform simulations to illustrate how the model works; and", "Item1",
 CellChangeTimes->{3.5305414523748155`*^9, 3.5390216353210807`*^9, 
  3.53903474584396*^9},ExpressionUUID->"0fb9ba32-3817-45c0-a083-26b9eb1c77ab"],

Cell["\<\
Attempt to find a natural point in time where real estate investing is \
supplanted by investing in financial assets.\
\>", "Item1",
 CellChangeTimes->{3.5305414545649405`*^9, 3.5390216353210807`*^9, 
  3.53903474584396*^9},ExpressionUUID->"e88287a6-edb8-4373-90b1-bb1ce6166ea1"],

Cell["8.1.1. The important aspect of time", "Subsection",
 CellChangeTimes->{3.5316169420886436`*^9, 3.5390216353210807`*^9, 
  3.53903474584396*^9},ExpressionUUID->"2eed8071-71d3-4cfc-a797-238c88619825"],

Cell[TextData[StyleBox["The model developed here includes considerable real \
world complexity. Academia has not yet explained why people invest in \
individual parcels of real property. The reason for this may be traced to the \
fact that no model yet proposed offers an analytical solution.  This \
obstacle, often fatal in academia, does not constrain actors in the market. \
Much of what practitioners do each day is trial and error in a messy real \
world environment. This chapter, while perhaps not yet a formal theory, may \
be the best if not the only way to approach the subject.",
 PageWidth->WindowWidth,
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{{3.5305415934258833`*^9, 3.5305416101958423`*^9}, 
   3.5390216353210807`*^9, 3.53903474584496*^9, {3.5405613458374677`*^9, 
   3.540561347940588*^9}, {3.540561433461479*^9, 
   3.540561434239524*^9}},ExpressionUUID->"275372aa-3a46-460d-97f1-\
8cab57942ceb"],

Cell[TextData[{
 "Our model is a dynamic model. This means it is dependent on time.  We argue \
that investors divide their time not only between real estate and other \
pursuits but divide their lifetimes into pre- and post-retirement periods. \
Dynamic models require differential equations, mathematical constructs that \
offer difficult challenges. Most differential equations have no solution.  It \
is interesting to note that one of the most famous results of finance, a \
Nobel Prize winning one, employs a differential equation. It happens that a \
physics equation describing the way heat diffuses has a solution that Fisher \
Black, Myron Scholes and Robert Merton used to create the widely known \
Black-Scholes Option Pricing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Model", 
    SuperscriptBox[".", 
     ButtonBox["1",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote1"]]}], TraditionalForm]],ExpressionUUID->
  "2e148135-5c4f-42d2-8acd-17c27aa233a7"],
 "  Our description of the labor component of real estate returns will also \
use differential equations. Unfortunately for us we will not be able to solve \
those equations in closed form. Rather, we will simulate them over a \
reasonable range and illustrate probable outcomes. Very often model builders \
must choose between mathematical tractability and reality. We have chosen the \
latter."
}], "Text",
 CellChangeTimes->{{3.5305415934258833`*^9, 3.5305415946139507`*^9}, {
  3.530541666894085*^9, 3.5305416681401567`*^9}, {3.530541855432869*^9, 
  3.530541855432869*^9}, {3.531616954737367*^9, 3.531616955911434*^9}, {
  3.539021635322081*^9, 3.5390216353240814`*^9}, {3.53903474584496*^9, 
  3.53903474584696*^9}},ExpressionUUID->"79cd8483-f081-4381-a059-\
0b86a7baf230"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.2. Foundation", "Section",
 CellChangeTimes->{3.531616985639135*^9, 3.5390216353240814`*^9, 
  3.53903474584696*^9},ExpressionUUID->"6d72b77f-c51b-4b52-a14e-88096201a5a8"],

Cell[TextData[StyleBox["The simple static model of labor supply \
(Killingsworth, 1983) holds that one chooses between work and recreation.  To \
the extent one works for an employer and receives wages, the static model \
assumes that one earns money, permitting one to purchase goods and services, \
all of which are consumed in the same period. If one chooses recreation \
rather than work, enjoying leisure, the implicit price of leisure is the \
forgone consumption goods one may have gained by working.  The theory claims \
that most people enjoy a mix of work (consumption goods) and recreation.",
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{3.5305424143898396`*^9, 3.5390216353240814`*^9, 
  3.53903474584696*^9},ExpressionUUID->"79784ad8-608b-4c39-a5a8-e3506e1380b6"],

Cell[TextData[StyleBox["Acknowledged in the simple static model is that fact \
that an agent may have or acquire along the way non-human assets, property in \
the form of bank accounts that pay interest or stock that pays dividends.  \
The agent's reservation wage (the wage below which he refuses to work)  is \
affected by the amount of property income.  The natural conclusion is that \
\"coupon clippers\" cannot be hired because their marginal substitution of \
wages for leisure is too high due to the fact that income from their \
non-human assets provides their creature comforts without the necessity of a \
job or an employer.",
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{{3.5305424143898396`*^9, 3.5305424385002184`*^9}, 
   3.5390216353240814`*^9, 
   3.53903474584696*^9},ExpressionUUID->"85064e0a-80f2-4f31-bf70-\
7854d3dcaad2"],

Cell[TextData[{
 StyleBox["Adding real estate introduces daunting complexity.  It is common \
for labor theorists to use financial assets as property, but when the source \
of property income is ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["real",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" property, interesting things can and do happen.   The important \
distinction is that the investor may impact the productivity of his \
investment in real assets.  Effort applied to the operation and management of \
the asset can change the income from the property and, therefore, the outcome \
of the ",
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   RowBox[{"investment", 
    SuperscriptBox[".", 
     ButtonBox["2",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote2"]]}], TraditionalForm]],ExpressionUUID->
  "13d8e521-8d06-4d45-afd5-3a8275ac4bda"]
}], "Text",
 CellChangeTimes->{{3.5305424143898396`*^9, 3.530542464457703*^9}, {
  3.5305426847773046`*^9, 3.5305426866424117`*^9}, {3.5305428021420174`*^9, 
  3.5305428021420174`*^9}, {3.539021635325081*^9, 3.539021635325081*^9}, {
  3.53903474584796*^9, 
  3.53903474584896*^9}},ExpressionUUID->"5597a20d-9b1c-460e-9e53-\
7c9152687fa9"],

Cell[TextData[{
 StyleBox["When the investor adds his labor to property he owns there are \
several new ",
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   RowBox[{"considerations", 
    SuperscriptBox[".", 
     ButtonBox["3",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote3"]]}], TraditionalForm]],ExpressionUUID->
  "d68bf6fa-1ad4-4e0a-ad3a-f18ad8134569"]
}], "Text",
 CellChangeTimes->{{3.5305424143898396`*^9, 3.5305424696089983`*^9}, {
  3.5305529617791157`*^9, 3.5305529640722466`*^9}, {3.5305531036382294`*^9, 
  3.5305531036382294`*^9}, {3.5390216353260813`*^9, 3.5390216353260813`*^9}, {
  3.5390347458499603`*^9, 
  3.5390347458509607`*^9}},ExpressionUUID->"5b81ae20-0a75-4483-9f7d-\
3e40e2e6febb"],

Cell[TextData[{
 "T",
 StyleBox["he time for that labor must come from somewhere.  In the simple \
model all time was devoted to work and leisure. Given a fixed amount of time \
available, real estate investment activity much take from one or the other.",
  CharacterEncoding -> "WindowsANSI"]
}], "Item1",
 CellChangeTimes->{3.5305424905781975`*^9, 3.5390216353260813`*^9, 
  3.5390347458509607`*^9},ExpressionUUID->"0aac8ddc-c22b-444f-ab41-\
85e7388b1a78"],

Cell[TextData[{
 "T",
 StyleBox["he election to work on property to improve its income introduces a \
third choice variable in the utility function.",
  CharacterEncoding -> "WindowsANSI"]
}], "Item1",
 CellChangeTimes->{
  3.5305424927303205`*^9, 3.5390216353260813`*^9, 3.5390347458509607`*^9, {
   3.5411870054937105`*^9, 
   3.5411870056597204`*^9}},ExpressionUUID->"20525edc-8b40-4759-a26e-\
e6b445f71a4a"],

Cell[TextData[{
 "T",
 StyleBox["he addition of the owner\[CloseCurlyQuote]s labor normally \
represents a positive value, increasing property income ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["over time.  ",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["Hence, the model has a time dimension.  This leads to the modeling \
difficulties common to a dynamic setting.",
  CharacterEncoding -> "WindowsANSI"]
}], "Item1",
 CellChangeTimes->{3.530542494734435*^9, 3.5390216353260813`*^9, 
  3.5390347458509607`*^9},ExpressionUUID->"e187528b-ff51-4d07-a619-\
e07f8037ee4d"],

Cell[TextData[{
 "A",
 StyleBox["ny model must provide for an efficiency factor to allow for \
differing skills among real property owners. Presumably, investors \
self-select into this market based on some real or imagined ability to \
successfully operate their acquisition.  Those with particularly good skills \
should enjoy improved results as a consequence of greater talent. Those \
misjudging their abilities or simply lacking what it takes should have \
marginally lower returns and be washed out of the market in sales to more \
efficient ",
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   RowBox[{"agents", 
    SuperscriptBox[".", 
     ButtonBox["4",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote4"]]}], TraditionalForm]],ExpressionUUID->
  "3f2b244b-134e-4746-ae8e-7a0dcc2cf2a1"]
}], "Item1",
 CellChangeTimes->{
  3.530542496481535*^9, {3.5305531355760565`*^9, 3.5305531369811363`*^9}, {
   3.530553228802388*^9, 3.530553228802388*^9}, {3.5390216353260813`*^9, 
   3.539021635327081*^9}, {3.53903474585196*^9, 
   3.5390347458529606`*^9}},ExpressionUUID->"3d2d52c2-2da7-423b-8eaf-\
3a01349fb23b"],

Cell[TextData[{
 StyleBox["A host of other, smaller, considerations must be incorporated.  \
The challenge is to make the model simple enough to be as elegant and \
universal as possible, yet include the vital, often complicating, factors \
necessary to make it realistic. It is reasonable to assume that the investor \
enters the real estate investment market only after amassing enough wealth to \
overcome the down payment barrier.  It is also assumed that the investor has \
a retirement goal measured by (a) accumulated dollars of capital to produce \
income; and (b) age. In fact, the argument here is that one of the reasons \
the investor chooses real estate is ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["to accelerate the date of retirement to an earlier point in life",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[". The choice of real estate evidences the individual\
\[CloseCurlyQuote]s belief that this acceleration is more likely or more \
rapid when that asset is held and over which some measure of control may be ",
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   RowBox[{"exercised", 
    SuperscriptBox[".", 
     ButtonBox["5",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote5"]]}], TraditionalForm]],ExpressionUUID->
  "d4e992a1-4391-4627-83a2-f4c3791fb73c"]
}], "Text",
 CellChangeTimes->{{3.5305428546080184`*^9, 3.5305428566551356`*^9}, {
  3.530542907574048*^9, 3.5305429299633284`*^9}, {3.530553274564006*^9, 
  3.530553333104354*^9}, {3.5305534937105403`*^9, 3.5305534937105403`*^9}, {
  3.531617052533961*^9, 3.5316170530679913`*^9}, {3.539021635327081*^9, 
  3.5390216353310814`*^9}, {3.5390347458529606`*^9, 
  3.539034745855961*^9}},ExpressionUUID->"95e8bd61-fe39-4c31-9ac3-\
244156a9f8bd"],

Cell[TextData[{
 StyleBox["These real world assumptions introduce more differences between \
ours and the traditional labor model.  In labor supply theory it is assumed \
that the length of economic life is measured by the time between the day the \
agent first enters the job market, perhaps after graduating from school, \
until death.  Our model assumes that  (1) ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["investment",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" economic life begins at the time real estate is purchased. This \
is presumably ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["after",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" some period of pre-investment wealth accumulation, time that \
begins upon entry into the labor force and ends when capital for a down \
payment has been ",
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"acquired", ";"}], 
    ButtonBox["6",
     BaseStyle->"Hyperlink",
     ButtonData->"endnote6"]], TraditionalForm]],ExpressionUUID->
  "32efc90b-3bd6-4c10-a42a-16a2476315c0"],
 StyleBox[" and (2) that some retirement date prior to death, a critical \
factor in the agent's plan, exists.  This retirement date is variable and \
based, in part, on the investor's efficient operation of his real estate.  \
This, of course, means that the time spent working for an employer and the \
time (retirement) following that working period are both variable but still \
sum to the whole of investment economic life as defined here.",
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{{3.5305428546080184`*^9, 3.530542858241226*^9}, {
   3.5305429464362707`*^9, 3.5305429487574034`*^9}, 3.5305519112220273`*^9, {
   3.530553528556534*^9, 3.530553531303691*^9}, {3.530553621309839*^9, 
   3.530553621309839*^9}, {3.5316170830447063`*^9, 3.531617088374011*^9}, {
   3.5390216353340816`*^9, 3.5390216353350816`*^9}, {3.539034745856961*^9, 
   3.539034745858961*^9}},ExpressionUUID->"b7a6274f-0806-46d7-99c1-\
2d5a4be603ec"],

Cell[TextData[StyleBox["The matter of bequests must be addressed.  One \
method, which might be quaintly referred to as \"the die broke scheme\", \
assumes bequests = 0.  That is, all wealth is consumed during one's lifetime. \
 The alternate extreme, for which competing monikers might be \"the live \
forever scheme\" or more likely \"the leave a rich wife scheme\", forbids any \
capital erosion.  In this second version a constraint on wealth is imposed \
such that only earnings are consumed after retirement while capital remains \
intact.  Neither of these extremes is terribly realistic and something in \
between is what we observe in practice. As always some simplifying \
assumptions are appropriate so we will concentrate our effort on the zero \
bequest and constant wealth cases.",
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{{3.5305428546080184`*^9, 3.530542858241226*^9}, {
   3.5305429464362707`*^9, 3.530542950341494*^9}, 3.5305519639560432`*^9, 
   3.5390216353350816`*^9, 
   3.539034745858961*^9},ExpressionUUID->"18945cbd-4d42-4b73-beff-\
02ecc2d00323"],

Cell[TextData[{
 StyleBox["Special note must be made of the efficiency factor.  This is the \
productivity of the investor's entrepreneurial effort (how good he is at it) \
applied to his rental property.  It produces a reward that acts like (but is \
not) a wage rate. Unlike wages sometimes behave, property returns are neither \
constant nor do they monotonically increase over time.  The vagaries of \
property ownership and income, like self employment, introduce uneven motion. \
There are economies of scale, discontinuities and variation, all differing \
over time, which affect how much the investor makes on any particular \
property over any specific holding period. A useful characterization, but \
still an oversimplification, would be to call the property return function \
the average rate at which the residual claim is rewarded over the holding \
period.  This reward is only in part for time spent. It is also a reward for \
bearing the ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["uncertainty",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" associated with the residual claim.",
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{{3.5305428546080184`*^9, 3.530542858241226*^9}, {
   3.5305429464362707`*^9, 3.530542950341494*^9}, {3.5305519639560432`*^9, 
   3.5305519868703537`*^9}, 3.5390216353350816`*^9, 
   3.539034745858961*^9},ExpressionUUID->"a96eae0c-c0c4-420a-9ace-\
cc04e387141d"],

Cell[TextData[{
 StyleBox["It is important to note that the efficiency factor does ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["not",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True},
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" represent property management ability but talent in the larger \
matters of strategy, timing and entity management. This is not to say that \
the investor might not also choose to do his own property management.  He may \
also choose to do his own plumbing. Presumably these decisions will be \
determined by any comparative advantages he may have in these areas.  No \
assumption is made that he MUST hire vendors for these tasks or that he is \
necessarily better able to perform them.  The primary purpose of the \
efficiency factor is to represent the payoff to the residual claim arising \
from the global coordination of the entire venture, of which property \
management, maintenance, etc. are all a part but do not, in the aggregate, \
represent the whole of what is required to own and successfully operate real \
property. ",
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{{3.5305428546080184`*^9, 3.530542858241226*^9}, {
   3.5305429464362707`*^9, 3.530542950341494*^9}, {3.5305519639560432`*^9, 
   3.530551989828523*^9}, 3.5390216353350816`*^9, 3.539034745858961*^9, {
   3.5405615957567625`*^9, 
   3.540561610949631*^9}},ExpressionUUID->"5fbacf7f-7fab-48b8-87b6-\
d4f85200086f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.3. Notation guide", "Section",
 CellChangeTimes->{{3.5316171137614627`*^9, 3.5316171159345875`*^9}, 
   3.5390216353350816`*^9, 
   3.539034745858961*^9},ExpressionUUID->"5d0a60df-ee26-4cd9-89b9-\
d504da008b9c"],

Cell[TextData[{
 "A considerable amount of notation is involved. This is brought about in \
part because of the complexity of a dynamic model and in part because of the \
way in which ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " processes symbols. Because ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has difficulties with subscripts in functions we use the subscripts in the \
narrative and we sometimes use similarly appearing, but not subscripted, \
characters in the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code."
}], "Text",
 CellChangeTimes->{{3.531617126033165*^9, 3.5316171264091864`*^9}, 
   3.5390216353350816`*^9, 3.539034745858961*^9, {3.5405616665478115`*^9, 
   3.5405616917182508`*^9}},ExpressionUUID->"b13366da-f384-48a9-a57d-\
aa41ba8c8f0c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"W0\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"wg\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"t\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"T\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"H\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"L\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"t\",FontSlant->\"Italic\"], \
StyleBox[\"W0\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"t\",FontSlant->\"Italic\"], \
StyleBox[\"w\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"t\",FontSlant->\"Italic\"], \
StyleBox[\"r\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"c\",FontSlant->\"Italic\"], \
StyleBox[\"w\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"c\",FontSlant->\"Italic\"], \
StyleBox[\"r\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"r\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"p\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"S\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\[Rho]\>\"", ",", "\"\<\[Alpha]\>\"", ",", "\"\<\[Beta]\>\"", 
          ",", "\"\<\[Gamma]\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"uf\",FontSlant->\"Italic\"]\)\>\""}], "}"}], 
        ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "19"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<initial wealth, assumed to be > 0 because of the down payment \
barrier imposed by real estate investing\>\"", ",", 
          "\"\<wage rate during time employed\>\"", ",", 
          "\"\<time \
(\!\(\*SubscriptBox[StyleBox[\"t\",FontSlant->\"Italic\"], \
StyleBox[\"0\",FontSlant->\"Italic\"]]\) is beginning of real estate \
investment period)\>\"", ",", 
          "\"\<total time working and retired \
(\!\(\*SubscriptBox[StyleBox[\"t\",FontSlant->\"Italic\"], \
StyleBox[\"w\",FontSlant->\"Italic\"]]\)+\!\(\*SubscriptBox[StyleBox[\"t\",\
FontSlant->\"Italic\"], StyleBox[\"r\",FontSlant->\"Italic\"]]\))\>\"", ",", 
          "\"\<exogenously determined portion of one's time devoted to \
working at a job\>\"", ",", 
          "\"\<leisure time, assumed to be > 0 (at least some time must be \
spent sleeping)\>\"", ",", "\"\<beginning point of working years\>\"", ",", 
          "\"\<working (pre-retirement) years\>\"", ",", 
          "\"\<retirement years\>\"", ",", 
          "\"\<consumption during time working\>\"", ",", 
          "\"\<consumption during retirement\>\"", ",", 
          "\"\<interest rate or rate of return over time\>\"", ",", 
          "\"\<exogenously given prices\>\"", ",", 
          "\"\<portion of time devoted to working on real property \
investments, the time remaining after \
\!\(\*StyleBox[\"H\",FontSlant->\"Italic\"]\) and \
\!\(\*StyleBox[\"L\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<efficiency of time spent working on real property investments, \
a measure of entrepreneurial ability\>\"", ",", 
          "\"\<preference for consumption over a base amount, assumed to be 0 \
< \[Alpha] < 1\>\"", ",", 
          "\"\<preference for leisure over a base amount, assumed to be 0 < \
\[Beta] < 1\>\"", ",", 
          "\"\<preference for time retired, assumed to be 0 < \[Gamma] < \
1\>\"", ",", 
          "\"\<utility function of the form \
\!\(\*StyleBox[\"u\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"(\",FontSlant->\
\"Italic\"]\)\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\",\"\
,FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"y\",FontSlant->\"Italic\"]\)\!\(\*\
StyleBox[\",\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"z\",FontSlant->\"\
Italic\"]\)\!\(\*StyleBox[\")\",FontSlant->\"Italic\"]\) = \
\!\(\*SuperscriptBox[StyleBox[\"x\",FontSlant->\"Italic\"], \"\[Alpha]\"]\)\!\
\(\*SuperscriptBox[StyleBox[\"y\",FontSlant->\"Italic\"], \
\"\[Beta]\"]\)\!\(\*SuperscriptBox[StyleBox[\"z\",FontSlant->\"Italic\"], \"\
\[Gamma]\"]\) with \[Alpha]+\[Beta]+\[Gamma]=1\>\""}], "}"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.533237314047065*^9, 3.5332379027867384`*^9}, 
   3.5390216353360815`*^9, 3.539034745858961*^9, 3.5390356165867634`*^9, {
   3.539042620559368*^9, 3.5390426213964157`*^9}, 
   3.540561758696082*^9},ExpressionUUID->"a4f5661c-fb32-4b48-9252-\
fc90ef57edf2"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"W0\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"initial wealth, assumed to be > 0 because of the down \
payment barrier imposed by real estate investing\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"wg\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"wage rate during time employed\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"time \
(\\!\\(\\*SubscriptBox[StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"], \
StyleBox[\\\"0\\\",FontSlant->\\\"Italic\\\"]]\\) is beginning of real estate \
investment period)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"T\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"total time working and retired \
(\\!\\(\\*SubscriptBox[StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"], \
StyleBox[\\\"w\\\",FontSlant->\\\"Italic\\\"]]\\)+\\!\\(\\*SubscriptBox[\
StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"], StyleBox[\\\"r\\\",FontSlant->\
\\\"Italic\\\"]]\\))\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"H\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"exogenously determined portion of one's time devoted to \
working at a job\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"L\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"leisure time, assumed to be > 0 (at least some time must be \
spent sleeping)\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"]\
, StyleBox[\\\"W0\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", \
"\<\"beginning point of working years\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"]\
, StyleBox[\\\"w\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", \
"\<\"working (pre-retirement) years\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"]\
, StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", \
"\<\"retirement years\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"c\\\",FontSlant->\\\"Italic\\\"]\
, StyleBox[\\\"w\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", \
"\<\"consumption during time working\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"c\\\",FontSlant->\\\"Italic\\\"]\
, StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", \
"\<\"consumption during retirement\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"interest rate or rate of return over time\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"p\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"exogenously given prices\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"S\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"portion of time devoted to working on real property \
investments, the time remaining after \\!\\(\\*StyleBox[\\\"H\\\",FontSlant->\
\\\"Italic\\\"]\\) and \\!\\(\\*StyleBox[\\\"L\\\",FontSlant->\\\"Italic\\\"]\
\\)\"\>"},
     {"\<\"\[Rho]\"\>", "\<\"=\"\>", "\<\"efficiency of time spent working on \
real property investments, a measure of entrepreneurial ability\"\>"},
     {"\<\"\[Alpha]\"\>", "\<\"=\"\>", "\<\"preference for consumption over a \
base amount, assumed to be 0 < \[Alpha] < 1\"\>"},
     {"\<\"\[Beta]\"\>", "\<\"=\"\>", "\<\"preference for leisure over a base \
amount, assumed to be 0 < \[Beta] < 1\"\>"},
     {"\<\"\[Gamma]\"\>", "\<\"=\"\>", "\<\"preference for time retired, \
assumed to be 0 < \[Gamma] < 1\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"uf\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"utility function of the form \
\\!\\(\\*StyleBox[\\\"u\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\
\"(\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\",\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\\
(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\",\\\
\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\"z\\\",FontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*StyleBox[\\\")\\\",FontSlant->\\\"Italic\\\"]\\) = \\!\
\\(\\*SuperscriptBox[StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"], \\\"\
\[Alpha]\\\"]\\)\\!\\(\\*SuperscriptBox[StyleBox[\\\"y\\\",FontSlant->\\\"\
Italic\\\"], \
\\\"\[Beta]\\\"]\\)\\!\\(\\*SuperscriptBox[StyleBox[\\\"z\\\",FontSlant->\\\"\
Italic\\\"], \\\"\[Gamma]\\\"]\\) with \[Alpha]+\[Beta]+\[Gamma]=1\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.54056176390738*^9, 3.541186520741985*^9, 
  3.541187154177215*^9, 3.5411879085793643`*^9, 3.541188032611459*^9, 
  3.541191064487872*^9, 3.541191162757493*^9, 3.5411912085731134`*^9, 
  3.541191242870075*^9, 3.541191301291416*^9, 3.541604147111719*^9, 
  3.6126968894680376`*^9, 3.6972339902219896`*^9, 3.697235485704302*^9, 
  3.6972358725145845`*^9, 3.697317851129978*^9, 3.6973235309241123`*^9, 
  3.698044389170043*^9, 3.6980448296493907`*^9, 
  3.731421553593405*^9},ExpressionUUID->"1276b329-2c44-4e2d-a0ed-\
3864ada459ff"]
}, Open  ]],

Cell[TextData[StyleBox["We assume that all wealth and excess earnings are \
invested in real estate in all time periods.",
 FontColor->GrayLevel[0]]], "Text",
 CellMargins->{{Inherited, 8.6875}, {Inherited, Inherited}},
 CellChangeTimes->{{3.530552145219411*^9, 3.5305524762753468`*^9}, {
   3.530552642938879*^9, 3.5305526984730554`*^9}, {3.5316171474993925`*^9, 
   3.5316171814183326`*^9}, {3.5331482213884706`*^9, 3.533148230874013*^9}, {
   3.5332387182883825`*^9, 3.5332387519063053`*^9}, {3.533238846663725*^9, 
   3.533238848107808*^9}, 3.5390216353360815`*^9, 
   3.5390347458599606`*^9},ExpressionUUID->"7226b059-5a40-4161-a471-\
ea596c0a4990"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*StyleBox[\"w0\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"ww\",FontSlant->\"Italic\"], \
StyleBox[\"1\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"w\",FontSlant->\"Italic\"], \
StyleBox[\"1\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[StyleBox[\"w\",FontSlant->\"Italic\"], \
StyleBox[\"2\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"wr1\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"tr1\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"st\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"scw\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"dv\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"\
(\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\)\!\(\
\*StyleBox[\")\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"ds\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"dtw\",FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"tws\",FontSlant->\"Italic\"]\)\>\""}], "}"}], 
        ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "12"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<boundary condition in the differential equation representing \
wealth accumulated at the point of retirement\>\"", ",", 
          "\"\<differential equation solved to produce \
\!\(\*SubscriptBox[StyleBox[\"w\",FontSlant->\"Italic\"], \
StyleBox[\"1\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<wealth accumulation function for pre-retirement years\>\"", 
          ",", "\"\<wealth accumulation function for retirement years\>\"", 
          ",", "\"\<the differential equation we solve to produce the \
function that accumulates \!\(\*StyleBox[\"w\",
FontVariations->{\"Underline\"->True}]\)ealth during \!\(\*StyleBox[\"r\",
FontVariations->{\"Underline\"->True}]\)etirement\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"t\",
FontVariations->{\"Underline\"->True}]\)otal \!\(\*StyleBox[\"r\",
FontVariations->{\"Underline\"->True}]\)etirement period, a variant of \
\!\(\*SubscriptBox[StyleBox[\"t\",FontSlant->\"Italic\"], \
StyleBox[\"r\",FontSlant->\"Italic\"]]\) needed to rearrange some terms\>\"", 
          ",", "\"\<\!\(\*StyleBox[\"s\",
FontVariations->{\"Underline\"->True}]\)olution of the retirement \
\!\(\*StyleBox[\"t\",
FontVariations->{\"Underline\"->True}]\)ime variable in terms of the other \
variables in the function produced by the differential equation\>\"", ",", 
          "\"\<\!\(\*StyleBox[\"s\",
FontVariations->{\"Underline\"->True}]\)olution of the \!\(\*StyleBox[\"c\",
FontVariations->{\"Underline\"->True}]\)onsumption while \!\(\*StyleBox[\"w\",
FontVariations->{\"Underline\"->True}]\)orking variable in terms of the other \
time variables\>\"", ",", "\"\<\!\(\*StyleBox[\"d\",
FontVariations->{\"Underline\"->True}]\)ata \!\(\*StyleBox[\(\*StyleBox[\"v\",
FontVariations->{\"Underline\"->True}]ersion\)]\)(\!\(\*StyleBox[\"x\",\
FontSlant->\"Italic\"]\)) necessary to create the graphic objects \
\!\(\*StyleBox[\"frho\",FontSlant->\"Italic\"]\) = the function of \
\!\(\*StyleBox[\"rho\",FontSlant->\"Italic\"]\) (\[Rho]) that employs the \
data, the utility function and its partial derivatives\>\"", ",", 
          "\"\<partial \!\(\*StyleBox[\"d\",
FontVariations->{\"Underline\"->True}]\)erivative of the utility function \
with respect to \!\(\*StyleBox[\"S\",FontSlant->\"Italic\",
FontVariations->{\"Underline\"->True}]\)\>\"", ",", 
          "\"\<partial \!\(\*StyleBox[\"d\",
FontVariations->{\"Underline\"->True}]\)erivative of the utility function \
with respect to \!\(\*StyleBox[\"t\",
FontVariations->{\"Underline\"->True}]\)ime \!\(\*StyleBox[\"w\",
FontVariations->{\"Underline\"->True}]\)orking\>\"", ",", 
          "\"\<a function used to produce a graphic object using the \
arguments \[Rho] and \!\(\*StyleBox[\"c\",FontSlant->\"Italic\"]\)\>\""}], 
         "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 ShowCellLabel->False,
 CellChangeTimes->{{3.533237314047065*^9, 3.5332379027867384`*^9}, {
   3.5332380523242917`*^9, 3.5332380532603455`*^9}, {3.533238083737088*^9, 
   3.5332384193862867`*^9}, {3.53323846140269*^9, 3.5332385677197704`*^9}, {
   3.5332386067920055`*^9, 3.533238701428418*^9}, 3.539021635337082*^9, 
   3.5390347458599606`*^9},ExpressionUUID->"43d1fa1e-f4e9-4896-a192-\
1382f522e371"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*StyleBox[\\\"w0\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"boundary condition in the differential equation representing \
wealth accumulated at the point of retirement\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"ww\\\",FontSlant->\\\"Italic\\\"\
], StyleBox[\\\"1\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", \
"\<\"differential equation solved to produce \
\\!\\(\\*SubscriptBox[StyleBox[\\\"w\\\",FontSlant->\\\"Italic\\\"], \
StyleBox[\\\"1\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"w\\\",FontSlant->\\\"Italic\\\"]\
, StyleBox[\\\"1\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", \
"\<\"wealth accumulation function for pre-retirement years\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[StyleBox[\\\"w\\\",FontSlant->\\\"Italic\\\"]\
, StyleBox[\\\"2\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>", "\<\"=\"\>", \
"\<\"wealth accumulation function for retirement years\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"wr1\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"the differential equation we solve to produce the function \
that accumulates \
\\!\\(\\*StyleBox[\\\"w\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
ealth during \
\\!\\(\\*StyleBox[\\\"r\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
etirement\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"tr1\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", \
"\<\"\\!\\(\\*StyleBox[\\\"t\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\
\\)otal \\!\\(\\*StyleBox[\\\"r\\\",\\nFontVariations->{\\\"Underline\\\"->\
True}]\\)etirement period, a variant of \
\\!\\(\\*SubscriptBox[StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"], \
StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]]\\) needed to rearrange some \
terms\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"st\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", \
"\<\"\\!\\(\\*StyleBox[\\\"s\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\
\\)olution of the retirement \\!\\(\\*StyleBox[\\\"t\\\",\\nFontVariations->{\
\\\"Underline\\\"->True}]\\)ime variable in terms of the other variables in \
the function produced by the differential equation\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"scw\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", \
"\<\"\\!\\(\\*StyleBox[\\\"s\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\
\\)olution of the \
\\!\\(\\*StyleBox[\\\"c\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
onsumption while \
\\!\\(\\*StyleBox[\\\"w\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
orking variable in terms of the other time variables\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"dv\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
StyleBox[\\\"(\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\"x\\\",\
FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\")\\\",FontSlant->\\\"\
Italic\\\"]\\)\"\>", "\<\"=\"\>", \
"\<\"\\!\\(\\*StyleBox[\\\"d\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\
\\)ata \\!\\(\\*StyleBox[\\(\\*StyleBox[\\\"v\\\",\\nFontVariations->{\\\"\
Underline\\\"->True}]ersion\\)]\\)(\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"\
Italic\\\"]\\)) necessary to create the graphic objects \
\\!\\(\\*StyleBox[\\\"frho\\\",FontSlant->\\\"Italic\\\"]\\) = the function \
of \\!\\(\\*StyleBox[\\\"rho\\\",FontSlant->\\\"Italic\\\"]\\) (\[Rho]) that \
employs the data, the utility function and its partial derivatives\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"ds\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"=\"\>", "\<\"partial \
\\!\\(\\*StyleBox[\\\"d\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
erivative of the utility function with respect to \
\\!\\(\\*StyleBox[\\\"S\\\",FontSlant->\\\"Italic\\\",\\nFontVariations->{\\\"\
Underline\\\"->True}]\\)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"dtw\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"partial \
\\!\\(\\*StyleBox[\\\"d\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
erivative of the utility function with respect to \
\\!\\(\\*StyleBox[\\\"t\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
ime \\!\\(\\*StyleBox[\\\"w\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\
\\)orking\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"tws\\\",FontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"=\"\>", "\<\"a function used to produce a graphic object using the \
arguments \[Rho] and \
\\!\\(\\*StyleBox[\\\"c\\\",FontSlant->\\\"Italic\\\"]\\)\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 ShowCellLabel->False,
 CellChangeTimes->{3.533238097590881*^9, 3.533238755070486*^9, 
  3.533240045361287*^9, 3.53368362765625*^9, 3.533735306489897*^9, 
  3.53375622709375*^9, 3.539021203275369*^9, 3.539021635337082*^9, 
  3.5390347458599606`*^9, 3.539988733391594*^9, 3.540127513836486*^9, 
  3.540561207538557*^9, 3.5411865214950275`*^9, 3.541187309483098*^9, 
  3.54118790867737*^9, 3.5411880326864634`*^9, 3.541191064577877*^9, 
  3.541191162849498*^9, 3.541191208657118*^9, 3.54119124295208*^9, 
  3.5411913013684206`*^9, 3.541604147599747*^9, 3.6126968897650547`*^9, 
  3.697233990244075*^9, 3.697235485722851*^9, 3.6972358725341363`*^9, 
  3.697317851218217*^9, 3.697323530941181*^9, 3.698044389206139*^9, 
  3.6980448296744576`*^9, 
  3.731421553661585*^9},ExpressionUUID->"19ed8b56-1521-48ab-b0e1-\
a5b4cb8ce712"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NameQ", "[", "\"\<\!\(\*SubscriptBox[\(ww\), \(1\)]\)\>\"", "]"}], 
  ";"}], "\n", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["w", "1"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["ww", "1"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["w", "2"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["W", "0"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["t", "w0"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["t", "r"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["t", "w"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["c", "w"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["c", "r"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\n", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["_", "_"],
   "NotationTemplateTag"], "]"}], "\n", 
 RowBox[{
  RowBox[{"Head", "[", 
   SubscriptBox["t", "w0"], "]"}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.41038871163925*^9, 3.410388798061125*^9}, 
   3.539021635337082*^9, 3.5390347458599606`*^9, {3.541187334606535*^9, 
   3.5411873499164104`*^9}},ExpressionUUID->"53ce0674-9937-4e38-b417-\
29b6cbad40de"],

Cell["\<\
The approach is to demonstrate the two extremes. First we work out the no \
bequests model, describing the daredevil who earns precisely enough money to \
enable him to retire for the exact remainder of his physical life.  Second we \
show the constant wealth model, representing the investor who, hoping to live \
forever, accumulates enough wealth to support an infinite life. \
\>", "Text",
 CellChangeTimes->{
  3.5305528314026585`*^9, {3.53161724519398*^9, 3.5316172552475557`*^9}, 
   3.5390216353380823`*^9, 3.539034745861961*^9, {3.5411873770539627`*^9, 
   3.541187394279948*^9}},ExpressionUUID->"269f6773-d627-4bc6-8076-\
f7a7432d4626"],

Cell["Clearly reality is somewhere in between...", "Text",
 CellChangeTimes->{{3.5305528314026585`*^9, 3.5305528329437466`*^9}, 
   3.5390216353380823`*^9, 
   3.539034745861961*^9},ExpressionUUID->"6c6dc738-fc68-4692-bf1b-\
701fb9183172"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.4. The no bequests model", "Section",
 CellChangeTimes->{
  3.531617225309843*^9, {3.5337355740552006`*^9, 3.533735578471453*^9}, 
   3.5390216353380823`*^9, 
   3.539034745861961*^9},ExpressionUUID->"914472c4-bdc1-4f15-a9e5-\
3cd3b7926f6c"],

Cell["\<\
Initially we assume that our investor only wishes to provide for himself \
during his lifetime and cares not about leaving a bequest to his heirs.\
\>", "Text",
 CellChangeTimes->{3.5390216353380823`*^9, 
  3.539034745861961*^9},ExpressionUUID->"714b7450-217b-4d13-add0-\
0ce46a885f21"],

Cell["8.4.1. Wealth accumulation prior to retirement", "Subsection",
 CellChangeTimes->{3.531617280901023*^9, 3.5337356084551682`*^9, 
  3.5390216353380823`*^9, 
  3.539034745861961*^9},ExpressionUUID->"595e1512-fd8e-4fed-a86e-\
5b2f0f6df653"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Equation 8.1 is the wealth accumulation function, ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox[
      StyleBox["w",
       FontWeight->"Plain"], 
      StyleBox["1",
       FontWeight->"Plain"]], "Input"], 
    StyleBox["(", "Input"], 
    SubscriptBox["t", "w"], ")"}], TraditionalForm]],ExpressionUUID->
  "481c99f5-3832-4a14-9110-02d5fd0e199b"],
 ",",
 StyleBox[" during working years, a continuous process beginning ",
  FontColor->GrayLevel[0]],
 "after our investor enters the work force, a time when sufficient wealth has \
been accumulated from other sources to meet the down payment requirement for \
a real estate investment.  Note that ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      SubscriptBox[
       StyleBox["w",
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"]], 
      StyleBox["(",
       FontWeight->"Plain"], 
      StyleBox[
       SubscriptBox["t", "w"],
       FontWeight->"Plain"], 
      StyleBox[")",
       FontWeight->"Plain"]}], " "}], "Input"], TraditionalForm]],
  ExpressionUUID->"e0d9c1d1-613d-494f-9679-c9f12d7bd9a0"],
 "is the solution to the differential equation ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox[
     StyleBox["ww",
      FontWeight->"Plain"], 
     StyleBox["1",
      FontWeight->"Plain"]], "Input",
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "1eb7827f-e20e-4c61-b296-02588feb12d6"],
 ", the instantaneous wealth production process.  In ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox[
     StyleBox["w",
      FontWeight->"Plain"], 
     StyleBox["1",
      FontWeight->"Plain"]], "Input"], TraditionalForm]],ExpressionUUID->
  "62f71c19-1a56-4622-a37a-15e261c6299f"],
 " you will note that time, ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", becomes a specific period of one's life, time working, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox[
     StyleBox["t",
      FontWeight->"Plain"], 
     StyleBox["w",
      FontWeight->"Plain"]], "Input"], TraditionalForm]],ExpressionUUID->
  "53bc6beb-15b8-4f4b-a37d-342da1654814"]
}], "Text",
 CellMargins->{{Inherited, 9.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5305537218875914`*^9, 3.5305537249177647`*^9}, {
   3.5305537948057623`*^9, 3.5305537951387815`*^9}, {3.5390216353380823`*^9, 
   3.539021635341082*^9}, {3.539034745861961*^9, 3.539034745864961*^9}, {
   3.539989572929612*^9, 3.5399896011132245`*^9}, 3.5405618072178574`*^9, 
   3.5405618700034485`*^9, 
   3.541187427097825*^9},ExpressionUUID->"3ba88d9d-148f-45d4-a6a9-\
7d3bc43d1a2c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["w", "1"], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["ww", "1"], "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["w", "1"], "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["w", "1"], "[", "t", "]"}], "\[Rho]", " ", 
           FractionBox["S", 
            RowBox[{"(", 
             RowBox[{"S", "+", "1"}], ")"}]]}], "+", 
          RowBox[{"wg", " ", "H"}], " ", "-", 
          RowBox[{
           SubscriptBox["c", "w"], " ", "p"}]}]}], "  ", ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["w", "1"], "[", "0", "]"}], "\[Equal]", "W0"}]}], 
       "}"}], ",", 
      RowBox[{
       SubscriptBox["w", "1"], "[", "t", "]"}], ",", "t"}], "]"}], "//", 
    "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["w", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ww", "1"], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "/.", 
    RowBox[{"t", "\[Rule]", 
     SubscriptBox["t", "w"]}]}]}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5332389156066685`*^9, 3.5332389170377502`*^9}, 
   3.539021635341082*^9, 3.539034745864961*^9, 
   3.540562315461927*^9},ExpressionUUID->"914448f3-5b1c-46b7-83c4-\
297c0befe85e"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], "(", 
     SubscriptBox["t", "w"], ")"}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["c", "w"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"S", " ", "t", " ", "\[Rho]"}], 
           RowBox[{"1", "+", "S"}]]]}], ")"}], " ", "p", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "S"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"S", " ", "t", " ", "\[Rho]"}], 
           RowBox[{"1", "+", "S"}]]]}], ")"}], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "S"}], ")"}], " ", "wg"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"S", " ", "t", " ", "\[Rho]"}], 
         RowBox[{"1", "+", "S"}]]], " ", "S", " ", "W0", " ", "\[Rho]"}]}], 
     RowBox[{"S", " ", "\[Rho]"}]]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.530553804279304*^9, 3.53055383637814*^9}, 
   3.539021635341082*^9, 
   3.539034745864961*^9},ExpressionUUID->"4b96748b-ebf0-4c9b-939b-\
b141bdd11a46"],

Cell[TextData[{
 "Although differential equations can appear daunting, a bit of decomposition \
can help understand it.  The first derivative of a function measures \
instantaneous change. A differential equation (and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s DSolve[ ] ) asks the question: Suppose I know what the derivative looks \
like, what is the function that, upon differentiation, would produce that \
derivative? "
}], "Text",
 CellChangeTimes->{3.530553892899373*^9, 3.539021635341082*^9, 
  3.539034745864961*^9},ExpressionUUID->"20ca46ba-af4d-4757-a1e4-\
7a870f8809ea"],

Cell[TextData[{
 "The derivative, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], "'"}], "[", 
    SubscriptBox["t", "w"], "]"}], TraditionalForm]],ExpressionUUID->
  "9b321424-2b3a-49ab-bb70-78ac448db39f"],
 ", of the wealth production function, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["w", "1"], "[", 
    SubscriptBox["t", "w"], "]"}], TraditionalForm]],ExpressionUUID->
  "d156807e-40df-4ba3-b728-7cec2da2fb46"],
 ", describes how wealth is accumulated instant-by-instant on a continuous \
basis. This derivative is composed of two parts"
}], "Text",
 CellChangeTimes->{{3.530553892899373*^9, 3.5305538941424437`*^9}, {
  3.531617336153183*^9, 3.531617352550121*^9}, {3.5390216353430824`*^9, 
  3.5390216353530827`*^9}, {3.539034745865961*^9, 3.5390347458669615`*^9}, {
  3.5399898046898685`*^9, 
  3.5399898784420867`*^9}},ExpressionUUID->"7bf43e75-b10f-4108-aa0e-\
abe2fac39c90"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["\[Delta]w", "1"], "(", 
      SubscriptBox["t", "w"], ")"}], "\[Delta]t"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["w", "1"], "[", "t", "]"}], "\[Rho]", " ", 
      FractionBox["S", 
       RowBox[{"(", 
        RowBox[{"S", "+", "1"}], ")"}]]}], "+", 
     RowBox[{"wg", " ", "H"}], " ", "-", 
     RowBox[{
      SubscriptBox["c", "w"], " ", "p", "  "}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5305539595951877`*^9, 3.530554010208082*^9}, 
   3.5390216353650837`*^9, 
   3.5390347458669615`*^9},ExpressionUUID->"2405a615-a7c5-45e1-9929-\
79856bdee840"],

Cell[TextData[{
 "The right side, ",
 StyleBox["wg ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"H", "-", 
    RowBox[{
     SubscriptBox["c", "w"], " ", "p"}]}], TraditionalForm]],ExpressionUUID->
  "71049fab-92f4-40af-a3f7-193d2ff21a54"],
 ", merely describes the daily accounting of going to work at a job and \
collecting wages (",
 StyleBox["wg H",
  FontSlant->"Italic"],
 ") which are then applied to paying bills ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["c", "w"], " ", "p"}]}], TraditionalForm]],ExpressionUUID->
  "43f632b8-4eba-4d9f-b0ea-1291c42aefc9"],
 "). If the net of these is positive wealth accumulates (saving), if it is \
negative wealth deteriorates (consumption)."
}], "Text",
 CellChangeTimes->{
  3.5305583940918264`*^9, {3.5390216353650837`*^9, 3.5390216353660836`*^9}, {
   3.5390347458669615`*^9, 3.5390347458689613`*^9}, {3.5399898918448534`*^9, 
   3.5399900005540714`*^9}},ExpressionUUID->"0f93b82f-04a2-4140-8e65-\
bd2309e36c57"],

Cell[TextData[{
 "The term ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], "[", "t", "]"}], " ", "\[Rho]", " ", 
    FractionBox["s", 
     RowBox[{"(", 
      RowBox[{"S", "+", "1"}], ")"}]]}], TraditionalForm]],ExpressionUUID->
  "3098017a-810e-4d7b-8b42-c6cb65ff7eb4"],
 ", is central to our story. It shows how the application of our investor's \
labor affects his real estate investments. Recall that ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    RowBox[{
     SubscriptBox["w", "1"], "[", "t", "]"}],
    FontFamily->"Times New Roman",
    FontSlant->"Italic"], " "}]],ExpressionUUID->
  "6db38da9-8a34-4338-a988-6beaad473e42"],
 "begins with, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], "[", "0", "]"}], "=", "W0"}], TraditionalForm]],
  ExpressionUUID->"a52eaeb6-354b-4021-afab-ebc957aa04cc"],
 ", a non-zero number by definition.  Thereafter we assume that the investor \
possesses not only sufficient funds for a down payment but aptitude for and \
ability to operate his property. This ability, which varies among different \
investors, is represented by a positive number, \[Rho], which is modified by \
the portion of one's time, ",
 StyleBox["S",
  FontSlant->"Italic"],
 ", devoted to real estate investment management. ",
 StyleBox["S",
  FontSlant->"Italic"],
 " appears in the equation in a functional form, ",
 Cell[BoxData[
  FormBox[
   FractionBox["s", 
    RowBox[{"(", 
     RowBox[{"S", "+", "1"}], ")"}]], TraditionalForm]],ExpressionUUID->
  "65b1b002-9bb3-4c8f-b837-99bf5e1f6134"],
 ", that represents marginally decreasing returns to added ",
 StyleBox["S",
  FontSlant->"Italic"],
 ". This is a common assumption in labor analysis and elsewhere.  People are \
less efficient as they exert more labor and become tired. Figure 8.1 \
illustrates three arbitrary values of \[Rho].  Applied to any given amount of \
wealth,",
 Cell[BoxData[
  RowBox[{" ", 
   StyleBox[
    RowBox[{
     SubscriptBox["w", "1"], "[", "t", "]"}],
    FontFamily->"Times New Roman",
    FontSlant->"Italic"]}]],ExpressionUUID->
  "ab0b8439-0f2d-4da8-8974-4a44cb2c313b"],
 ", these produce differing but positive results."
}], "Text",
 CellChangeTimes->{{3.5305583940918264`*^9, 3.530558396559967*^9}, {
  3.5305589258622417`*^9, 3.5305589343347263`*^9}, {3.530559033077374*^9, 
  3.5305590395737457`*^9}, {3.531617300243129*^9, 3.531617305134409*^9}, {
  3.5390216353670835`*^9, 3.539021635378084*^9}, {3.5390347458689613`*^9, 
  3.539034745880962*^9}, {3.5399900194711533`*^9, 
  3.5399902886035466`*^9}},ExpressionUUID->"b0019a2f-a69f-4008-8bc3-\
07f8d2d51fdc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhoplot", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Rho]", 
          FractionBox["S", 
           RowBox[{"S", "+", "1"}]]}], "/.", 
         RowBox[{"\[Rho]", "\[Rule]", "7"}]}], ",", 
        RowBox[{
         RowBox[{"\[Rho]", 
          FractionBox["S", 
           RowBox[{"S", "+", "1"}]]}], "/.", 
         RowBox[{"\[Rho]", "\[Rule]", "8.5"}]}], ",", 
        RowBox[{
         RowBox[{"\[Rho]", 
          FractionBox["S", 
           RowBox[{"S", "+", "1"}]]}], "/.", 
         RowBox[{"\[Rho]", "\[Rule]", "10"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"S", ",", "0", ",", "10"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".4", "]"}], ",", "Thick"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".6", "]"}], ",", "Thick"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".9", "]"}], ",", 
           RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", "Thick"}], 
          "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"S\",FontSlant->\"Italic\"]\)\>\"", ",", 
         "\"\<\[Rho] \!\(\*FractionBox[StyleBox[\"S\",FontSlant->\"Italic\"], \
RowBox[{StyleBox[\"S\",FontSlant->\"Italic\"], \"+\", \"1\"}]]\)\>\""}], 
        "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".4", "]"}], ",", "Thick"}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".6", "]"}], ",", "Thick"}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".9", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", "Thick"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\[Rho] = 7\>\"", ",", "\"\<\[Rho] = 8.5\>\"", ",", 
        "\"\<\[Rho] = 10\>\""}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.530558746188965*^9, 3.530558769718311*^9}, 
   3.539021635379084*^9, 3.539034745881962*^9, {3.541187464000936*^9, 
   3.5411874747655516`*^9}, {3.5411875063553586`*^9, 
   3.5411875470176845`*^9}, {3.5411875999567127`*^9, 
   3.5411876016728106`*^9}, {3.697234336439418*^9, 3.697234501466467*^9}, 
   3.6972345393512597`*^9},ExpressionUUID->"89d55fa0-d6d9-4f06-9a0e-\
341eb4be219c"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.4, 1, 1], 
          Thickness[Large]], 
         LineBox[CompressedData["
1:eJwV0nk81IkbB/BxFibXaMzkGr40QkqrFcnzIKsDbeSXLbnKEWGT6SBHJ5Yk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          "]]}, Annotation[#, "Charting`Private`Tag$2376#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.6, 1, 1], 
          Thickness[Large]], 
         LineBox[CompressedData["
1:eJwV0Xk01PsbwHEMWZMh68x8Dd8y2ZPTuSl8nhKhruz7UhJKVEplaRPhIkuy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          "]]}, Annotation[#, "Charting`Private`Tag$2376#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          Hue[0.9, 1, 1], 
          AbsoluteThickness[2], 
          Thickness[Large]], 
         LineBox[CompressedData["
1:eJwVzXk01Psfx3GMsiYzmKwz3+98aZD1dvyyxOddcpVwU0mXspUt2bpJIrko
tFzqiqHsLdSNdKhIJFFjN8oyKDX2JVwRY/vN/eN1nufx1wv3DDroJSIkJBQt
2H/NjPLcaHjymkVPm5tfFq3G4l0HZuuE+aE+Xa5S12/ZaL2+KhbDwpGsgmgr
saMYZb65Qd+AJaLOB6n3b2+sRqfNQwN+0tNRPvZ10e9hC+pY9k2ZoRciN5f6
pO7pfiTW+405RS9H6rbOVsfTJ1H3m9ehk6PlaCa9fwLzm0KPHrBqJ0oq0MCg
Kv56x3dkf8bebdyyEnH8MkUS26dRqkRF6ohPNdIyH+zsjphFlLsfRGa73qLf
V1/UqCf8QLkN2SETdDa65+316Dnw0Q9WmfaX62xk+3oWZWbz0a8+jTzOEhvt
/7Y9YXWVjyZJPx0rOhpQZdpcln75MjI2tzdNjG9CGYO+Zue1VlFb8YoIc7oV
/Vp52SDu33V0qUHHxtCtAzXuLtfKSRWBgpIXWx/f7kAUiay4B1UiwGHtJmk0
daDPT10/nR8WAXWfo5WKJh8Rufv4ZIwRCRpIcXpCcp+Qw0Zm7Y52ElDNeymt
9Z2I9JUREbYuCkXFib2n9bhonKsi98pEDMYp49dtPLiIdcqQX/S7GDDP2Vho
pnCRRbTmWlS4GOTslMrlLXGRw48Yu9KXYnCLfd3bua4X6brrxlwwEodzvKRZ
62P9yP1YpOtDTQnIlmqMJVsNoFr2hhX+giRYmEcci3YdQCE5ryb6KVLQF7jN
aDpsAJ2keaTl60mBIufacNOjAZTtK8Lt8pKCmyzbfQmyX1GyZszKKEcKYjVa
ZNZ7v6L6PzzEPj6UBh/Unj55hocckhj8KXMZEMpbqOi9xkP3bys8WneUAZao
al/DPR6yLdNX5QfIwAe2N62wk4dUQ9ebCjNlQPPwSp6X6SAamVFY+7ksA6O+
zH8+Cw8hd7+gCv/SzXDq1sWqtuRhVNxWWf72qiwEDmnxSovGkAxfhGzRSoYB
1x7xGvYY0nNVmcjpIcOh7gS95sExtOtUuyyfRwbjxpHwIeVxZEeyDU1aJAOp
5L4sNX4cdVPCFPfiFGBF4hZhbhNIXvchcyWYAjVySukmslNIW3Hv0zoJOZDE
45hfjGdQVqtFpS0hDx923tSPsppBY9OxR8jb5OHK0awdagdnkIFMyZfWX+RB
JPmltYv/DHIfVe413S0P/LVJn67MGWThqWPKdpeHiT7HglaRWfQsDkttvisP
TSym1pumWdRtHPN3nqwC/CXbqJ3rPocORA+GNI8qQPkOtTL7wDkUqd9sw55W
gEHXILQSMYdot/1qqhcUwOyJ3GGntDmU9+5mzl1RKozuO3ZxU8sccndw5lAx
KljGTrWGm/1ATenmlpQjVFic3xx6kDqP6vOPXrarooJn7+FqUtMCyqK3Oa5E
b4GQujjPICYfhfc1xtu1K0JJsPQhxX2ryM2oVof8WQlyI/zHDZyEIHmltCCA
qwwx2SsOPyaFgXMvKdigQAWEOgag8gIJDmnbJ/U5q8LWs97nD2tvgP5ChriB
mBoMzqcdkXq9EcZN4vWmU9XAZujUxVsh4nCHFZsoTNDAfjB5G40mCZInVBOG
smgwXusZ/eGJFERpsxUWxOigR+5Us3TbBO/M1jirQXSQRPMefXMyMOY7o/b9
Ax2sp5x/Mhxlwfy89bNqWQy6354UdtYhw/WMmoHXxhiUJbxzxebJ0K5y0NrG
BQPvDaEDLS0U8OryN5KNwuDEmYgy6Qw50DJ/kb7nLgb6PttabD3kQYesZrP4
AoNWio5UqIkCHBymt1A/YvCqKOaODokKVzd95BVNYhAhrH2gqZ8KxxPM8ss2
4CDZd2FvYOkWUNqpvP29Kg5DD/CU7EhFkMhvo1EMcUjRVBItd1SCRQ/uS64V
DskZ3u89MGX4GcBR2X4UB+eU4y3SI8pQcIDyh5UfDot77i9lV6mAu0MHv+cC
Dryh3effxqvCHn/h74FXccgzN1Rp9lADieErlEsZODy5HEr20aUBozqgs64A
h3jHE/tJ8zQI3EjEEc9xMOrLLYxvpkNuuGU0vxYHltadJ837McgLlgpyaMPh
0psbrP3lGAQ7Sdkr9+Ngp+J4v0Edh9N7WbuUxnDYFfjehZyIg9UW/hRnDods
VU/1pnkcDitN2/DXcFCvfZhq78KAY9O0PxfFGZCs+1abU8WAPX41UV4UBnjP
ibaztQn4vK/d2EyVAZ4l/2KJSQScXbOr2qzBgNMxh1ZsbhKwPJ0W/D+BQw+V
dkn/TYATnqJ6XOCE+dC/klMJGPAv9HgkcJHJ0nJaJgGGWWdy9mxlwFLNeueD
xwTcrfs0G8YU/HOkb7x7T8CzwrDvPVoMyMgP8L3CJmBL1XLPusD5Z1ss9zYS
MHjCs1pDmwHPqcn8xhYCAuz6w0IE7nOW8+34JPDXZ9ni2xjA5ClZfuMRoMDW
aDLSYYBB6QXavSEC8l1ij7gIbHq5d8lrhICYaS43WmBbZubTsXEC6oYvtjcK
fMYfo83OEmBz9dU5D10GRO78c+nZHAGpueT2KwJf3vTt49l5AqytAjT+EZhV
nH9tcZGAnO+mlQsC50WL+lTwCYhrL15T0WPAYwev3ZErBOxb1jfbJXApo17N
Yo0A357KEG+Bq+a2Lq2vEzDS7ZR3TeD/AyTEpIo=
          "]]}, Annotation[#, "Charting`Private`Tag$2376#3"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
       "\"\\!\\(\\*StyleBox[\\\"S\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        TraditionalForm], 
       FormBox[
       "\"\[Rho] \
\\!\\(\\*FractionBox[StyleBox[\\\"S\\\",FontSlant->\\\"Italic\\\"], \
RowBox[{StyleBox[\\\"S\\\",FontSlant->\\\"Italic\\\"], \\\"+\\\", \
\\\"1\\\"}]]\\)\"", TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 400, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 10}, {0., 9.09090907404284}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"\[Rho] = 7\"", "\"\[Rho] = 8.5\"", "\"\[Rho] = 10\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.4, 1, 1], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.4, 1, 1], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.6, 1, 1], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Hue[0.6, 1, 1], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.9, 1, 1], 
                    AbsoluteThickness[2], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.9, 1, 1], 
                    AbsoluteThickness[2], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.4], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    Hue[0.4000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.4`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.4, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.4], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.6], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.6, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.6`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.6, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.6], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.9, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.9`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.9], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], "}"}],
            ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}]}], "]"}]& ), Editable -> 
      True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.530558755947523*^9, 3.530558771944438*^9}, 
   3.5305723742204437`*^9, 3.5316178462403584`*^9, 3.531619480325823*^9, 
   3.531619757230661*^9, 3.5331481586928844`*^9, 3.533148201504333*^9, 
   3.53323643735192*^9, 3.5332400465013523`*^9, 3.533683629859375*^9, 
   3.5337353087310247`*^9, 3.533756229078125*^9, 3.539021206167535*^9, 
   3.539021635388085*^9, 3.5390347458909626`*^9, 3.5399887362757587`*^9, 
   3.5401275165116386`*^9, 3.540561213823917*^9, 3.5411865248242183`*^9, 
   3.541187476150631*^9, {3.5411875088585014`*^9, 3.541187548722782*^9}, 
   3.5411876036619244`*^9, 3.541187666268505*^9, 3.5411879098394365`*^9, 
   3.5411880339695363`*^9, 3.541191065764945*^9, 3.541191164070568*^9, 
   3.5411912104252195`*^9, 3.541191244339159*^9, 3.541191302558489*^9, 
   3.5416041523590193`*^9, 3.612696891802171*^9, 3.697233990666172*^9, 
   3.6972344584570417`*^9, 3.6972345030256157`*^9, 3.6972354862196727`*^9, 
   3.697235872993357*^9, 3.6973178517937455`*^9, 3.6973235312770777`*^9, 
   3.6980443897857065`*^9, 3.698044830084548*^9, 3.731421554089723*^9},
 TextAlignment->Center,ExpressionUUID->"e2d1b30a-1955-4214-92fb-da1c47d75565"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.1.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Labor-added efficiency at different levels",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{
  3.5285477921289577`*^9, 3.5300478264783916`*^9, {3.5300484582175255`*^9, 
   3.5300484678950787`*^9}, 3.530561498868409*^9, 3.530566557351738*^9, 
   3.539021635388085*^9, 3.5390347458909626`*^9, {3.540562567749357*^9, 
   3.540562568013372*^9}},
 TextAlignment->Center,ExpressionUUID->"75076e26-8eda-492b-b2e6-593fdc9495a5"],

Cell[TextData[{
 StyleBox["The notion that any and all effort applied to the operation of \
real estate always produces a positive result is doubtful. Our model applies \
primarily to those who have self-selected into real estate because of their ",
  FontColor->GrayLevel[0]],
 StyleBox["predilection ",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 10}, {Inherited, Inherited}},
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["for operating their investments.  It is not hard to imagine others \
who mistakenly choose real estate, discover they do not like it or learn they \
cannot do it and leave the market, probably selling to someone who fits our \
model. Departing investors are presumed to be short-term owners.  Our model \
is for the long-term real estate investor who resides in this market because \
he finds it profitable and to his liking. ",
  FontColor->GrayLevel[0]]
}], "Text",
 CellMargins->{{Inherited, 10}, {Inherited, Inherited}},
 CellChangeTimes->{
  3.539021635388085*^9, 3.5390347458909626`*^9, {3.5405626274807734`*^9, 
   3.5405626565394354`*^9}},ExpressionUUID->"a4e3f87a-04cb-4bdb-8b7f-\
2e1cea982bbc"],

Cell["8.4.2. Wealth accumulation after retirement", "Subsection",
 CellChangeTimes->{3.531617411493492*^9, 3.533735641721071*^9, 
  3.539021635388085*^9, 
  3.539034745891963*^9},ExpressionUUID->"d5de173b-f59f-4db0-ad64-\
4147d8b3ae87"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Another differential equation, 8.3",
  FontColor->GrayLevel[0]],
 ", is required",
 StyleBox[" for wealth following retirement. This is also a function of time \
and its derivative, Equation 8.4, is the instantaneous wealth production \
function, ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox[
      SubscriptBox[
       StyleBox["w",
        FontWeight->"Plain"], 
       StyleBox["2",
        FontWeight->"Plain"]], "Input"], "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "r"], ")"}]}], TraditionalForm]],
  FontColor->GrayLevel[0],ExpressionUUID->
  "18c9c3ad-48a8-494e-b41d-15d3249e3b3f"],
 StyleBox[", for retirement ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{"years", 
    SuperscriptBox[".", 
     ButtonBox["7",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote7"]]}], TraditionalForm]],ExpressionUUID->
  "4168e161-0a5b-4d9f-8853-74a8dc2940f8"]
}], "Text",
 CellChangeTimes->{
  3.5305590947849035`*^9, {3.5305592027820807`*^9, 3.5305592135006933`*^9}, {
   3.5305595366621776`*^9, 3.5305595577413836`*^9}, {3.539021635388085*^9, 
   3.5390216353900847`*^9}, {3.539034745891963*^9, 
   3.539034745893963*^9}},ExpressionUUID->"3f45682f-8951-4e4a-8f3e-\
28026c4fd535"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"wr1", "=", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["w", "2"], "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["w", "2"], "[", "t", "]"}], " ", "r"}], "-", 
         RowBox[{
          SubscriptBox["c", "r"], " ", "p"}]}]}], "  ", ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["w", "2"], "[", "0", "]"}], "\[Equal]", "w0"}]}], "}"}],
      ",", 
     RowBox[{
      SubscriptBox["w", "2"], "[", "t", "]"}], ",", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "tr1", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["w", "2"], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["w", "2"], "[", "t", "]"}], "/.", 
      RowBox[{"wr1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
     RowBox[{"t", "\[Rule]", "tr1"}]}], ")"}]}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.533239007801942*^9, 3.5332390147553396`*^9}, 
   3.5390216353900847`*^9, 
   3.539034745893963*^9},ExpressionUUID->"ac734b8d-9450-463f-815c-\
726eef9d5cc6"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], "(", 
     SubscriptBox["t", "r"], ")"}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       SubscriptBox["c", "r"], " ", "p"}], "-", 
      RowBox[{
       SubscriptBox["c", "r"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"r", " ", "tr1"}]], " ", "p"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"r", " ", "tr1"}]], " ", "r", " ", "w0"}]}], "r"]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.530559292973239*^9, 3.530559297624505*^9}, {
   3.530559343914153*^9, 3.530559354998787*^9}, {3.5305595060434265`*^9, 
   3.5305595120787716`*^9}, 3.5390216353910847`*^9, 
   3.539034745893963*^9},ExpressionUUID->"3625a094-3a52-4203-b3ed-\
82d2d95bda1d"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["\[Delta]w", "2"], "(", 
      SubscriptBox["t", "r"], ")"}], "\[Delta]t"], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["w", "2"], "(", 
      SubscriptBox["t", "r"], ")"}], "-", 
     RowBox[{
      SubscriptBox["c", "r"], " ", "p"}]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5305594124250717`*^9, 3.530559466511165*^9}, 
   3.5390216353910847`*^9, 
   3.539034745893963*^9},ExpressionUUID->"9b624807-203a-4132-b35d-\
b44fcbaa0eb5"],

Cell[TextData[{
 "Note that the right hand side of Equation 8.4, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], "[", 
     SubscriptBox["t", "r"], "]"}], "-", 
    RowBox[{
     SubscriptBox["c", "r"], "p"}]}], TraditionalForm]],ExpressionUUID->
  "ce125a51-ed89-4d57-b3f4-0dd5348bbd3d"],
 ", is again in two parts. The right side, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "r"], "p"}], TraditionalForm]],ExpressionUUID->
  "0a95c631-f6e3-435b-938d-ab6d771a8b82"],
 " is retirement consumption. In retirement there are no wages, thus no \
accumulation or savings aspect arising from labor at a job.  The remaining \
term,",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["w", "2"], "[", 
    SubscriptBox["t", "r"], "]"}], TraditionalForm]],ExpressionUUID->
  "3fe95a57-7432-449e-b8f1-cc175cae0917"],
 ", must produce all required income from wealth accumulated prior to \
retirement, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], "[", "0", "]"}], "=", "w0"}], TraditionalForm]],
  ExpressionUUID->"964addf9-bc34-4dd9-8c0b-0def077fab79"],
 ", adjusted by any post retirement return, ",
 StyleBox["r,",
  FontSlant->"Italic"],
 " on that wealth."
}], "Text",
 CellMargins->{{Inherited, 8}, {Inherited, Inherited}},
 CellChangeTimes->{{3.530559587270072*^9, 3.530559590544259*^9}, {
   3.531617437577984*^9, 3.5316175046478205`*^9}, {3.5390216353910847`*^9, 
   3.539021635394085*^9}, {3.539034745893963*^9, 3.5390347458959627`*^9}, {
   3.53999036069567*^9, 3.539990495339371*^9}, 
   3.5411876831624713`*^9},ExpressionUUID->"28e395c6-fe6d-4449-893d-\
35c027c05e3b"],

Cell[TextData[{
 "Substituting Equation 8.1 for the boundary condition in Equation 8.3, we \
then set the result to zero and solve for ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ". Thus we define ",
 StyleBox["st",
  FontSlant->"Italic"],
 ", the ",
 StyleBox["s",
  FontVariations->{"Underline"->True}],
 "olution for ",
 StyleBox["t",
  FontVariations->{"Underline"->True}],
 "ime in the implicit function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["w", "2"], "=", "0"}], TraditionalForm]],ExpressionUUID->
  "724b348b-9656-4cdb-a6e9-90b827115b57"],
 ". Note that the boundary condition, ",
 StyleBox["W0",
  FontSlant->"Italic"],
 ", is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "1"], TraditionalForm]],ExpressionUUID->
  "96b134da-0ee0-4aff-95c7-48fb91e03d5d"],
 ", the wealth accumulated prior to retirement.  We are interested in solving \
for",
 StyleBox[" the ",
  FontSlant->"Italic"],
 StyleBox["t",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox["ime ",
  FontSlant->"Italic"],
 StyleBox["r",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox["etired",
  FontSlant->"Italic"],
 ", ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ", in terms of all the other variables (Equation 8.5).  To meet the \"no \
bequests\" assumption this answers the question \"how long does it take for \
wealth to reach zero?\"  This occurs at ",
 StyleBox["T",
  FontSlant->"Italic"],
 ", the end of time and the conclusion of our investor's ",
 Cell[BoxData[
  FormBox[
   RowBox[{"life", 
    SuperscriptBox[".", 
     ButtonBox["8",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote8"]]}], TraditionalForm]],ExpressionUUID->
  "528c4601-5170-4b09-acff-9fbdef8f05f1"],
 " We name this solution, ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ", for future use as the length of retirement."
}], "Text",
 CellChangeTimes->{{3.539990720541252*^9, 
  3.5399908642364707`*^9}},ExpressionUUID->"54ee4f71-5063-48a0-a8a6-\
6612135e1a50"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"st", "=", 
   RowBox[{"Quiet", "[", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["w", "2"], "/.", 
          RowBox[{"w0", "\[Rule]", 
           SubscriptBox["w", "1"]}]}], ")"}], "\[Equal]", "0"}], ",", "tr1"}],
       "]"}], "//", "Simplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tr1", "=", 
   RowBox[{
    RowBox[{"st", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5332390737287126`*^9, 3.533239090423668*^9}, 
   3.539021635398085*^9, 
   3.5390347458999634`*^9},ExpressionUUID->"a9aa596e-888d-4d6d-9355-\
db785f89db77"],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"tr1", "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{
         RowBox[{
          SubscriptBox["c", "w"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"S", " ", 
               SubscriptBox["t", "w"], " ", "\[Rho]"}], 
              RowBox[{"1", "+", "S"}]]], "-", "1"}], ")"}], " ", "p", " ", 
          "r", " ", 
          RowBox[{"(", 
           RowBox[{"S", "+", "1"}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"S", " ", 
               SubscriptBox["t", "w"], " ", "\[Rho]"}], 
              RowBox[{"1", "+", "S"}]]], "-", "1"}], ")"}], " ", "H", " ", 
          "r", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "S"}], ")"}], " ", "wg"}], "+", 
         RowBox[{"S", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["c", "r"], " ", "p"}], "-", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"S", " ", 
                SubscriptBox["t", "w"], " ", "\[Rho]"}], 
               RowBox[{"1", "+", "S"}]]], " ", "r", " ", "W0"}]}], ")"}], " ",
           "\[Rho]"}]}], 
        RowBox[{
         SubscriptBox["c", "r"], " ", "p", " ", "S", " ", "\[Rho]"}]], "]"}], 
      "r"]}]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5305599400532503`*^9, 3.530559998131572*^9}, {
   3.530560069051628*^9, 3.5305600701946936`*^9}, 3.539021635398085*^9, 
   3.5390347458999634`*^9},ExpressionUUID->"70b8af88-53e6-4ea9-99e8-\
d942028f9c19"],

Cell[TextData[{
 "The length of retirement, ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ", is critical because the investor is presumed to derive utility from \
increased retirement time.  As suggested earlier, an important motive for \
choosing real property as an investment is the possibility of positively \
influencing the outcome.  This model accounts for that positive influence by \
reducing time working for an employer, therefore increasing retirement time.  \
Presuming that the agent has a disutility for working for an employer, the \
sooner retirement can occur, the better.  The investor\[CloseCurlyQuote]s \
problem is now one of maximizing the utility function in equation 8.6 where \
the variables follow the notation given earlier and the constants (900 \
minimum consumption and .25 minimum non-working time) represent base \
minimums. These constants may be viewed as subsistence in each case so that \
the agent values consumption and leisure only over the minimum required to \
sustain ",
 Cell[BoxData[
  FormBox[
   RowBox[{"life", 
    SuperscriptBox[".", 
     ButtonBox["9",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote9"]]}], TraditionalForm]],ExpressionUUID->
  "04088dec-c9a4-4834-ae03-fe42cabb8e4e"]
}], "Text",
 CellChangeTimes->{{3.530560307794284*^9, 3.5305603223871183`*^9}, {
  3.5305603752961445`*^9, 3.530560376034187*^9}, {3.530560481774235*^9, 
  3.530560481774235*^9}, {3.53161760692367*^9, 3.53161762248456*^9}, {
  3.539021635399085*^9, 3.5390216354020853`*^9}, {3.5390347458999634`*^9, 
  3.539034745902963*^9}},ExpressionUUID->"406f98ca-c02c-45c5-a6b5-\
c918c7de0a62"],

Cell[BoxData[
 FormBox[Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0003GH0@0006`00000000000000847003Q0000
00000000003=7P00^@<00215CDH00040f3D009T0000500000000000000000000`180080H003;0000
2P4000000000000000000<0I0`0[3@@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000G00005000015CDH[8T0400`0000000007T0900`000000000940100`000000000
<4020100000400000020?b501`0<0000000000A0000<0000000001H0000<0000600000X0000@0000
ooooo`0000090000400004@7003R0000DP00070100010000Y?ooo`00000000000000090100000000
14008T<0H@1/06T0HP1b06T000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
B;Hb0>2g<P1`Rbl2O;@b0?AO`f7P]c8080000=Bd<P3oooooa;Lb05be<P15n/aQe;@b0>2g<P0P0000
oooooo`2;@:jn/aQ0@000000001H0P009@0003L^T040008?1@820P@30PCo0P3Qoj`0@0T000000000
W`40000000130640K01Y0680LP0000000000000000000000000000Be<P2F@lIQ2P000?ooomm0]C80
4Vc4HEBe<P20/KQRK;Db0?`2;@8P0Rd2I7H02000000U000030000040000U000030000040000U0000
30000040000B000030000040000H000030000000009D0000E000004000000000=P0006l000010000
EEF7@=^fQd000000E`000040001<00001000000000000000A`L00>40001@0000800003H0000H0000
3000000000960000:00001`00017A4U30P000?koooooooooA0L00><000000000AP000?P:003/2P00
ADe6:bY0000T000060000000P3l000200000P000P3l0080o0000P2501@0<0000000000Q000ED2P00
B0X0008@`=/200000P00020:003GcLJJ00000000h1]P0`0900000956000100T000<@1@000P0W0@00
000500000P4100001@000042oooo00D0000^0AT0000500002`8000001@0000`2H0?P6a<0000V1Pl0
703ooooo001=01000030oooo[ooooj0K000?0`002`0002H63`0<04eQM6QDNG1U003000D000090P00
0085000050;D0Xh070000?/2g_j30000002@0@0000400P0@DgU]HVm/07M00000C1<:E1I3b7LO@lQg
8<3:M`00<0040000;@4000T0000b2P0000010000:7T000D0000D0]@2B`8L0000n`;NoX<000000901
00000@02011CNFeRKf`0Md00001`4`Yd5T?8Mam3b7LP`<Yg000`00@0000]0@4010000?0100090000
<PX000000@0002Ui0005000050;l0L0470000?/22OkS0000002@0@0000400P0@DgU]HVm/07M00000
C1<:EAI3b7LO@lQg8<3:M`00<0040000;@4000@0003`0@402@00038:00000040000XN@001@0001@2
o0782A`0003k0PWnh`000000T0400001008045=iKF9_K01g@000070C2WDF@lQg7d?8Mb30bWL00300
100002d10@040000l04000T0000b2P0000010000:GT000D0000D0_`1^`/L0000n`89o^<000000901
00000@02011CNFeRKf`0Md00001<4`YF5T?8Mam3b7LP`<Yg000`00@0000]0@0010000?010@090000
<PX000000@0002Qi0005000050;l0E<A70000?/22OkS0000002@0@0000400P0@DgU]HVm/07M00000
L1<:MQI3b7LO@lQg8<3:M`00<0040000;@4100@0003`0@002@00038:00000040000YN@001@0001@2
o0704Q`0003k0PWnh`000000T0400001008045=iKF9_K01g@00004`C2ULF@lQg7d?8Mb30bWL00300
100002d100040000l04100T0000b2P0000010000:7T000D0000D0_`1KaLL0000n`89o^<000000901
00000@02011CNFeRKf`0Md00001`4`Yg5T?8Mam3b7LP`<Yg000`00@0000]0@4010000?0100090000
<PX000000@0002Ui0005000050;l0N8H70000?/22OkS0000002@0@0000400P0@DgU]HVm/07M00000
C1<:F1I3b7LO@lQg8<3:M`00<0040000;@4000@0003`0@402@00038:00000040000XN@001@0001@2
o06;6Q`0003k0PWnh`000000T0400001008045=iKF9_K01g@000070C2WPF@lQg7d?8Mb30bWL00300
100002d10@040000l04000T0000b2P0000010000:GT000D0000D0/@2N04L0000n`8Ro`0000000901
00000002011DJFeULb1>IGLPDVm]HFh05T?8Mam3b7LP`<Yg000`00@0000]0@0010000?010@090000
<PX000000@0002ai_045000050;P0KX670000?/2P?h00000002@0@0000000P0@E6U]IG<PCVEg859_
KF5^01I3b7LO@lQg8<3:M`00<0040000;@4100@0003`0@004`00038:000000P0000/;3T`<2hb=G@1
d@K00<000PEP0<0000<5000050930P<670000?/28_l00000002@0@4000000P0@E6U]IG<PCVEg859_
KF5^01I3b7LO@lQg8<3:M`00<0040000;@4000@0003`0@403@00038:000000@0001gLWMb8@?J0nT<
_045000050;40^l070000?/28_l00000002@0@4000000P0@E6U]IG<PCVEg859_KF5^01I3b7LO@lQg
8<3:M`00<0040000;@4100@0003`0@002P00038:00000080001<Dlh0_045000050;P0D0070000?/2
P?h00000002@0@4000000P0@E6U]IG<PCVEg859_KF5^01I3b7LO@lQg8<3:M`00<0040000;@4000@0
003`0@406000038:000000/0001=HGQeIV=<M6=<M00n0L00f03008<1o@5L0J835`L:1P031@0001@2
nP3:4A`0003k0R;o00000000T0410001008045=iKF9_K01g@000070C2W/F@lQg7d?8Mb30bWL00300
100002d10@040000l04000`0000b2P0000030000HF9WFc063`>l0@D0000D0^01V`XL0000n`:0oP00
0000090100000@02011CNFeRKf`0Md00001<4`YL5T?8Mam3b7LP`<Yg000`00@0000]0@0010000?01
0@0<0000<PX000000`0003d];G]L0hh600<W0@009PH?04@2CF5dJ5AiL6EEECP21@401@14DdeD=@01
4eMYKT5/K49QLfUS@fmTIE1QIfEc0145E6U]IG<PCVEg859_KF5^0143DgU]HVm/0145@fmeLVUULR1>
IGL04@A=E215N7AbH@0B00PQ;dF?A2m1D?@@3dMO@E3b7ai1D?@E3d40m4Gd9OB?@Um10?@@3d=O@@3d
SdGd:Um8m8m10?@@3d3dSd5oB?@@3d4ZGdAOAOAOAOAO@@l<0@0100420P8200800@4100<00@04000:
0@0301L@00400P23C@0208=Q0080PgP000/100<00@<00@0208=<0080PR`00P23D`000P2F:00209HY
00000@402P80V0;_0P23M@0208=V00<00@<00@0208=S00<06`002`400P23M`000@402P80PR`00P23
C002088/0080Pg@00`0K000;0@0208=b00010@002P80URP00P2F:@000PB6?@0m0`010`010080Pf<0
0`0K000;0@0208=g00010@0:0PB64R8]0P28>@0208P`0080R3000080URP00P2F:@000`0L000;0@41
0084Q;43H@002P<00@<00@0208=<0084QQ8R;@80PRh00P28<P0208Pe000209HX0080URT000<07000
2`410@0218Bb0f8000X3004300400P23M00301/000/10080Pg800041000:0P2F:00209HY000301`0
00/10@400PB4/`=W000000/0000V1Pl0303ooooo0@000000000L0000n`8@00L000000;`200000042
0R9CNG=dIFd000002P0Q08X100000040002liQ80:D;8M`@0000]0@4010000?01000300000008@048
900001P000024<3K0@0000<00000000000000000000K@000@00003@0000100000P00000000000000
003OA@00F4@300000010_oooociBMNQ4oooo?P00@;mCEF938@0000P0001R000030000040000:0000
40000000000000008@0000P0001R000030000040000A0000300000P0000:00004000000000000000
2@000100003P6`00H0<000`0000@000000000000000;0000400004D7003R00008@0000P0000U0000
300000L0080U000030000000080F000030000000000H000030000000000I000030000?ooo`0D0000
300000d0001B0000L0400080002Toooo0000000000000000T04000000007@00R@`1Q06`0J@1R0780
J@0000000000000000000000000000000000000000000000000000000000000000000000FGD00000
0000000000000000000000000000000000000?ooool0000000000000000000000000000000000000
00000000000000000000000000010000ooooo`000000000000000>2@O0D0P810`AhQ[a00T0400000
000b0;QjE`<^?G=[B:8b0=`kLf^8XS801000000000000?0o00000000000000000000000000000?0o
00000000ND0000000820@0000000000000000000001/heeg=3hmN000002L0Fd0001]02QS?`VXmW@5
B@0/0500001TMP08000002D0000<00000P000180000<00000@0001T0000<0000oooo01H0000<0000
6@0000X0000@0000000000000009000040000>0K001P0`00600000`0000000006`000100002>0000
e0800580001`0@000`000=knoon3000000000000002@0@0000000PL2011C07T0K@1R06l0K0000000
0000000000000000000000000000000000000000000000000000000000000000000b068nFGD20000
`AhQ[aT0/06L?5Ue000C000hC`P10000A:Lb0=XaaV4:000003Q?2040000@XC80P05MM@iLF7GPFeQe
4:4b06@1000000000000063@M@D4000000000?PG2UbhXS80HeaHM@00002Toooo00000000000007`5
00000<4N8Joh5`YL0P000:Coool0000000000000002@0@00000000M002930640K01Y0680LP1Y0000
0000000000000000000000000000000000000000000000000000000000000000001IM@0000000000
000006Af00P000009@0000`000030000E00005@0000U0000L@0003H0003<00000@000:`/SCmBohdo
0000000000010000C00000000000000000000?ooooooooooD00002S`000000006`000100001;0P00
e0800580001`0@0010000=knoon3000000000000002@0@0000000PL2011C07T0K@1R06l0K0000000
00000000000000000000000000000000000000000000000000000000000000000000000000000380
HSiIM@8000317R6_6@2`0I`lFGD001<003Q?20400014Yc80fS76H@X00000>4l8000002X000317R6_
V9Ag0>80E@RHU7L0000002S`001/heegI3dmN000002D0Fd0001]0;RR<P1SG5Qe0P1^0=d000000000
00000000O0D000000`0J0=d000020000Y?oook20K@0000001000090100000000V3Qc0:1mK@2dOVd0
001g0321K@000000o:0b0000000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000e01E2000000005Ue
000006Af00P000009@0000`000040000:00000`000030000E00005@0002I0000L@000:T0003<0000
0@000:`/SCmBohdo0000000000010000C00000000000000000000?ooooooooooD00002W`04000000
6`00010000301000o0400580001`0@000`0000WnoooS000000000000002@0@0000000PL2011C07T0
K@1R06l0K00000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000<P1R?UUe0P000<4N8JlI0;01W3aIM@004`00>4l80@0004BW<P3J<LIQ
000002X000317R6_V9Ag04H1E@RHU7L0000002W`M`1/heegI3dmN000002D0Fd0001]09@1K@0006d0
0P1^0=h0000006h0g@000000000000000`0J0=h0000301X0g@000;20K@000000100002QTO@D00000
V3Qc0:1mK@2dOVd0001g0321K@0007L0o:0b0040000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000
>05E2000000006d0000006Af00P000009@0000`000030000:00000`000040000E00005@0000m0@00
0@0005`1002Q00000@000:`/SCmBohdo0000000000010000C00000000000000000000?oooooooooo
D00002S`000000006`00010000382@00o0400580001`0@00100000WnoooS000000000000002@0@00
00000PL2011C07T0K@1R06l0K0000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000b068nFGD20000`AhQ[aT0/06L?5Ue
000C000hC`P10000000002X000317R6_V9Ag0:X1E@RHU7L0000002S`M`1/heegI3dmN000002D0Fd0
001]09@1K@0006d00P1^0=l0000006h0gP000000KP3M00000`0J0=l0000301X0gP000;20K@000000
100004QTO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0o:0b0040000`XS80cAiRMja>DPonoooo
K>=MMm;PGGL00000W05E2000000006d0000006Af00P000009@0000`000040000:00000`000030000
E00005@0002=0P000@000:T2002Q00000@000:`/SCmBohdo0000000000010000C000000000000000
00000?ooooooooooD00002W`000000006`000100002k2`00o0400580001`0@000`0000WnoooS0000
00000000002@0@0000000PL2011C07T0K@1R06l0K000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000380
HSiIM@8000317R6_6@2`0I`lFGD001<0000002X000317R6_V9Ag00h2E@RHU7L0000002W`M`1/heeg
I3dmN000002D0Fd0001]09@1K@0006d00P1^0>00000006h0g`000000KP3N00000`0J0>00000301X0
g`000;20K@000000100002QTO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0o:0b0040000`XS80
cAiRMja>DPonooooK>=MMm;PGGL00000009E2000000006d0000006Af00P000009@0000`000030000
:00000`000040000E00005@0000?0`000@0002h3002Q00000@000:`/SCmBohdo0000000000010000
C00000000000000000000?ooooooooooD00002S`000000006`000100001C4@00o0400580001`0@00
100000WnoooS000000000000002@0@0000000PL2011C07T0K@1R06l0K00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000<P1R?UUe0P000<4N8JlI0;01000002X000317R6_V9Ag0782E@RHU7L0
000002S`M`1/heegI3dmN000002D0Fd0001]09@1K@0006d00P1^0>40000006h0h0000000KP3O0000
0`0J0>40000301X0h0000;20K@000000100004QTO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0
o:0b0040000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000I09E2000000006d0000006Af00P00000
9@0000`000040000:00000`000030000E00005@0002510000@000:44002Q00000@000:`/SCmBohdo
0000000000010000C00000000000000000000?ooooooooooD00002W`000000006`00010000304P00
o0400580001`0@000`0000WnoooS000000000000002@0@0000000PL2011C07T0K@1R06l0K0000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000b068nFGD20000000002X000317R6_
V9Ag0=H2E@RHU7L0000002W`M`1/heegI3dmN000002D0Fd0001]09@1K@0006d00P1^0>80000006h0
h@000000KP3P00000`0J0>80000301X0h@000;20K@000000100002QTO@D00000V3Qc0:1mK@2dOVd0
001g0321K@0007L0o:0b0040000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000b09E2000000006d0
000006Af00P000009@0000`000030000:00000`000040000E00005@0003T10000@0000<5002Q0000
0@000:`/SCmBohdo0000000000010000C00000000000000000000?ooooooooooD00002S`00000000
6`000100001_5`00o0400580001`0@00100000WnoooS000000000000002@0@0000000PL2011C07T0
K@1R06l0K00000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000380
000002X000317R6_V9Ag03X3E@RHU7L0000002S`M`1/heegI3dmN000002D0Fd0001]09@1K@0006d0
0P1^0><0000006h0hP000000KP3Q00000`0J0><0000301X0hP000;20K@000000100004QTO@D00000
V3Qc0:1mK@2dOVd0001g0321K@0007L0o:0b0040000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000
;0=E2000000006d0000006Af00P000009@0000`000040000:00000`000030000E00005@0000M1P00
0@0003T6002Q00000@000:`/SCmBohdo0000000000010000C00000000000000000000?oooooooooo
D00002W`000000006`000100003R6000o0400580001`0@000`0000WnoooS000000000000002@0@00
00000PL2011C07T0K@1R06l0K0000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000002X000317R6_V9Ag09h3E@RHU7L0000002W`M`1/heegI3dmN000002D0Fd0
001]09@1K@0006d00P1^0>@0000006h0h`000000KP3R00000`0J0>@0000301X0h`000;20K@000000
100002QTO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0o:0b0040000`XS80cAiRMja>DPonoooo
K>=MMm;PGGL00000T0=E2000000006d0000006Af00P000009@0000`000030000:00000`000040000
E00005@0001m1P000@0009`6002Q00000@000:`/SCmBohdo0000000000010000C000000000000000
00000?ooooooooooD00002S`000000006`000100002;6P00o0400580001`0@00100000WnoooS0000
00000000002@0@0000000PL2011C07T0K@1R06l0K000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000002X000317R6_V9Ag0084E@RHU7L0000002S`M`1/heeg
I3dmN000002D0Fd0001]09@1K@0006d00P1^0>D0000006h0i0000000KP3S00000`0J0>D0000301X0
i0000;20K@000000100004QTO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0o:0b0040000`XS80
cAiRMja>DPonooooK>=MMm;PGGL00000m0=E2000000006d0000006Af00P000009@0000`000040000
:00000`000030000E00005@0003/1P000@0000P7002Q00000@000:`/SCmBohdo0000000000010000
C00000000000000000000?ooooooooooD00002W`0B8000006`000100001h0@00a0800580001`0@00
0`0002;oool0000000000000002@0@00000000L2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000002X000317R6_V9Ag06H4E@RHU7L0
000002W`M`1/heegI3dmN000002D0Fd0001]09@1K@0006d00P1^0>H0000006h0i@000000KP3T0000
0`0J0>H0000301X0i@000;20K@000000100002QTO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0
o:0b0040000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000F0AE2000000006d0000006Af00P00000
9@0000`000030000:00000`000040000E00005@0001R0000Q0000=D0003600000@000:`/SCmBohdo
0000000000010000C00000000000000000000?ooooooooooD00002`0J@2l0@006`000100002j1P00
h0400580001`0@001000083nool0000000000000002@0@00000000L2011D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>@400317R6_
V9Ag0<X4E@RHU7L0000002`0M`1/heegI3dmN000002D0Fd0001]09@1K@0006d00P1^0>L0000006h0
iP000000KP3U00000`0J0>L0000301X0iP000;20K@000000100004QTO@D00000V3Qc0:1mK@2dOVd0
001g0321K@0007L0o:0b0040000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000_0AE2000000006d0
000006Af00P000009@0000`000040000:00000`000030000E00007`000310@0090000:h6002E0000
0@000:`/SCmBohdo0000000000080000C00000000000000000000?ooooooooooG00002`0;00i0300
<00^0380=@1d0@00d@H00<00003000000PD006000030000000<001/0000@00000`H004<2001B0000
L04000<0000Roooo0000000000000000T040004000070P0@E01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003T1000`AhQ[cR/?PT^1ED8
>:`n2@00000/02`0>@0`0300;P0b03D0[05]0000K@2D0Fd0001]0180bP0R0000001^0>L0000006h0
iP0001<0c`0R00000`0J0>L0003Pj6d000000200000XI7d50P0002QKN`FPOFd0`7i]0000?PVHjVd0
001g0?bP<P010000<:8b0<dNHWN/CU8?o_ooofcSGGOBh5eg00000205E@P00000001]0000001TMP08
000002D0000<00000`0002P0000<0000100005@0001T0000T@4006<0000d1`00Y0000040002/;8do
D_n=?`0000000000100004`00000000000000000003ooooooooooe@0001g0780M`1b0243003J0`00
j@`00;`1000K000040000>l000340P00DP000701000400008_ooo`00000000000000090100010000
1`8045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000i0@00<4N8JlXHgH5YPEE22QSMPD00000M`1b07L0LP1T?Ceh000009`1K@0006d0
[05]0000K@1802T0D0000000bP0R0000001^0>L0001902`0D00001<0c`0R0000/81]0000000@0000
B6Am1@00002PNS`9X7e]0;QnK@0007H5V85]0000?PWlX3800@00032R<P3=7V9g[4iB3okooom/heeg
d^1MM`00002H1ED800000000K@000000I7H02000000U0000300000@0000X0000300000<0001D0000
F00003`000250000i`000<H000010000[2b=?e;oSCl0000000000080001<00000000000000000000
oooooooooom@0000C01C0<h0002l0@006`00010000100000h0400580001`0@000`00083nool00000
00000000002@0@000@0000L2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000>@400317R6_V9Ag0186E@RHU7L0000004`0D`1/heeg
I3dmN000002D0Fd0001]09`1K@0006d00P1^0>P0000002T0D0000000bP0R00000`0J0>P0001902`0
D0000;20K@000000200002QTO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007H5o:0b0040000`XS80
cAiRMja>DPonooooK>=MMm;PGGL0000010IE2000000006d0000006Af00P000009@0000`000030000
:00000`000040000E0000900000@0000900006`7002E00000@000:`/SCmBohdo00000000000;0000
C00000000000000000000?ooooooooooI00004d0H@1h07D0IP1S04`0M01S04`0M00003h100300000
f0000<0000230@00o@4005`1002R0`005`L000X600000`006`000100003:4@00nP000580001`0@00
100002;oool0000000000000002@0@000@000PL2011C07T0K@1R06l0K00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>@400317R6_j:hn2GP6E@SX[Sh9
000004d0H@1h07D0IP1S04`0M01S04`0M01]09@1K@0006d0@P0/00P0000006h0j0000000:@1@0000
@`0U00P0000301X0j0000;20K@000000;00004QTO@D0000087/l2J1mK@38OVd0000n2CR3K@0007L0
o:0b0040000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000JPIE2000000006d0000006Af00P00000
9@0000`000040000:00000`000030000E0000600002T10001`000847001=00000@000:`/SCmBohdo
0000000000030000C00000000000000000000?ooooooooooE000067`H_1Wl300<0H000l3002l0@00
6`000100002K2P00h0400580001`0@000`00083nool0000000000000002@0@0000000PL2011C07T0
K@1R06l0K00000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000002X000317R6_:6=f1OX6E@PXHgH50000067`H_1Wl5egI3dmN000002L0Fd0001]06<0C01d06d0
B00Y0540000002`020000000KP3X0000B@0/0540001302D020000;20K@000000300002QTO@D00000
X7Xl2J1mK@2hOVd0001f1IR1K@0003h9o:0b0040000`XS80cAiRMja>DPonooooK>=MMm;PGGL00000
k0IE2000000006d0000006Af00P000009@0000`000030000:00000`000040000E000060000340P00
6P000286002C00000@000:`/SCmBohdo0000000000030000C00000000000000000000?oooooooooo
E00003g`;O0]l000G0<008h600000`00DP00070100040000400000L00000000000000;`200000000
1`828U<0N@1c07@0I@1]000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000:P000<4N8JlXHgH5I0ME22QSMPD00000?O0]l2g`GGMT?Ceh000009`1K@0006d0
W05]0000K@1802T0DP000000:@1A0000000/00P0001902`0DP0004T0;01A0000/81]0000000<0000
B6Am1@00002PNS`9X7e]0;QnK@0007H5V85]0000MPGlX3800@00032R<P3=7V9g[4iB3okooom/heeg
d^1MM`00001F1eD800000000K@000000I7H02000000U0000300000@0000X0000300000<0000U0000
300000L0080U000030000000080`0000300000l0080U000030000040001;00004000000000050000
:00000`0000400009@0000`0000000209@0000`0000700208P0000`0003ooooo9@0000`0000=0020
:00000`0000200008P0000`0003ooooo8P0000`0003oooooAP000700001T0000ADe6:ba0000T0000
600009QkQCh000200000P<3CQCh0042ooooo?RY0000T000060000000P3l000200000P000P3l0080o
0000P2501`0<0000000000A0000<0000000004H0000D0000200004M4BD<300009@0000`0000>0020
9@0000`0000>0020AP0003@0000X0000ADe6:bY0000T000060000000P3l000200000P000P3l0080o
0000P24000080000HP0000`0000100002P00010000000000000004`0001T00000000000000141`00
h@00000000000000A@L00>80000Y0:X0000000000000080o000000000000080o0000000000000000
000000000000000000000000000R000030000?oooom60000700001000015CDH[0T0000`000000000
3P0001@000000000400001@0
\>"], "Graphics",
   GeneratedCell->False,
   CellAutoOverwrite->False,
   ImageSize->{213.33333333333331`, 25.77181208053692},
   ImageMargins->{{84.66666666666666, 0.}, {0., -4.666666666666666}},
   ExpressionUUID->"da67a891-26bd-4c16-8226-f7ed174fb65c"], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5305603528128586`*^9, 3.5305603648505473`*^9}, 
   3.5390216354030857`*^9, 3.539034745903963*^9, {3.5390860430309916`*^9, 
   3.5390860530925665`*^9}},ExpressionUUID->"41382b5c-8fec-4f10-ae84-\
caaf6b9493c0"],

Cell[TextData[{
 "Using ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 " as ",
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["r",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 " we are now in a position to conduct some simulations to explore how well \
our model fits reality."
}], "Text",
 CellChangeTimes->{
  3.530560512777008*^9, {3.5332396906209965`*^9, 3.533239691129026*^9}, 
   3.5390216354030857`*^9, 
   3.539034745903963*^9},ExpressionUUID->"5838389c-0206-4b05-9aa2-\
d1636775b51a"],

Cell[TextData[{
 "As expected, a model composed of differential equations and many variables \
admits no closed form analytical solution. Instead, we employ bounded ",
 StyleBox["numerical",
  FontSlant->"Italic"],
 " solutions and create graphics of reasonable dimensions to simulate how the \
model behaves. This is in lieu of the conventional comparative statics (as we \
used in Chapter 2) permitted by analytic methods.  Simulation, while \
suboptimal in meeting the usual standard for theory, becomes the best one may \
do in this case.  Graphics produced by simulation allow no more than three \
variables. To accomplish this we assume plausible but fixed values for a \
number of parameters. The result is a graphic showing how different \
combinations of three of the most critical variables produce different \
optimum utility. The variables chosen for the graphic are not the choice \
variables and the graphic is not a conventional optimization exercise. \
Rather, it depicts ranges of optimal utility that may be achieved under \
different conditions. The three important variables used in the simulations \
below are the efficiency factor (\[Rho]), working years (",
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["w",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 ") and the portion of one\[CloseCurlyQuote]s time devoted to real estate \
ownership activities (",
 StyleBox["S",
  FontSlant->"Italic"],
 ")",
 StyleBox[", ",
  FontFamily->"Times New Roman Greek"],
 StyleBox["the latter two both being functions of ",
  FontFamily->"Times New Roman"],
 StyleBox["\[Rho]",
  FontFamily->"Times New Roman Greek"],
 ".  The intuition is that persons of varying skill levels devote different \
amounts of time to maximizing their real property investments while also \
working for an employer with the result that they retire from employment at \
different times in their lives."
}], "Text",
 CellChangeTimes->{{3.530560674570262*^9, 3.5305606814846573`*^9}, {
   3.5305607436812153`*^9, 3.5305607680956116`*^9}, {3.5316176542173753`*^9, 
   3.5316176691242275`*^9}, 3.5390216354030857`*^9, 
   3.539034745903963*^9},ExpressionUUID->"d0342836-8929-4709-aa8a-\
cec218a19efb"],

Cell["8.4.3. Simulation #1", "Subsection",
 CellChangeTimes->{3.5316176896674027`*^9, 3.5390216354030857`*^9, 
  3.539034745903963*^9},ExpressionUUID->"3b1864af-a7ea-4405-8c1c-\
53c7d7d89508"],

Cell[TextData[{
 "The first set, ",
 StyleBox["dv1",
  FontFamily->"Courier New",
  FontWeight->"Bold"],
 ", of ",
 StyleBox["d",
  FontVariations->{"Underline"->True}],
 "ata ",
 StyleBox["v",
  FontVariations->{"Underline"->True}],
 "alues, shown in ",
 StyleBox["Table 8.1", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 ", is provided for the first simulation."
}], "Text",
 CellChangeTimes->{{3.530561275585638*^9, 3.5305612771847296`*^9}, {
   3.5305613164139733`*^9, 3.5305613209242315`*^9}, {3.5316177145918283`*^9, 
   3.5316177635616293`*^9}, 3.5390216354030857`*^9, 
   3.539034745903963*^9},ExpressionUUID->"61216ad9-c71c-4bbf-bdc1-\
0f2718e44adf"],

Cell[TextData[{
 "The first simulation demonstrates how different combinations of time \
working ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "w"], TraditionalForm]],ExpressionUUID->
  "17e78ca2-f61c-4adf-a0de-75467f1207b8"],
 ", rental owner efficiency, \[Rho], and time spent operating rentals, ",
 StyleBox["S",
  FontSlant->"Italic"],
 ", produce different optimal utility. We need a function of \[Rho], which \
will be named \[OpenCurlyDoubleQuote]",
 StyleBox["frho",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]. This is created in several steps."
}], "Text",
 CellMargins->{{Inherited, 9.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.530560817114415*^9, 3.5305608179054604`*^9}, {
  3.5390216354030857`*^9, 3.5390216354050856`*^9}, {3.539034745903963*^9, 
  3.5390347459049635`*^9}, {3.5399909571567855`*^9, 
  3.539991027590814*^9}},ExpressionUUID->"684f047d-e3eb-4551-bdcc-\
60c1696c2026"],

Cell[TextData[{
 "Define the value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "r"], TraditionalForm]],ExpressionUUID->
  "ffb0924a-6ea4-4b8f-bcbd-1b708825995b"],
 " as ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ", using the data in ",
 StyleBox["dv1", "Input"],
 " as fixed inputs."
}], "Item1Numbered",
 CellChangeTimes->{
  3.5305608037086487`*^9, {3.5390216354050856`*^9, 3.539021635406086*^9}, {
   3.539034745905964*^9, 3.539034745905964*^9}, {3.539991041293598*^9, 
   3.539991063512869*^9}},ExpressionUUID->"c658d07b-c834-44f7-8857-\
2b6d26a92628"],

Cell[TextData[{
 "Using the fact that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "w"], TraditionalForm]],ExpressionUUID->
  "f2c816e4-4fff-4404-b3e9-3a1992f05621"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "r"], TraditionalForm]],ExpressionUUID->
  "a4f842fa-108a-4c8a-b20b-965b8980d6a8"],
 " total ",
 StyleBox["T",
  FontSlant->"Italic"],
 ", solve for consumption in working years, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "w"], TraditionalForm]],ExpressionUUID->
  "f532a064-6232-47ec-81e7-1191021f5ee2"],
 ", in terms of ",
 StyleBox["S, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "w"], TraditionalForm]],ExpressionUUID->
  "25d70910-8319-45bb-bf3b-831e328a41b1"],
 ", \[Rho] and the parameters fixed by ",
 StyleBox["dv1", "Input"],
 ".  That function is then named ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "w"], TraditionalForm]],ExpressionUUID->
  "d41ce86c-5dc6-4b67-9aa9-bd9199d96204"],
 "."
}], "Item1Numbered",
 CellChangeTimes->{
  3.530560805276738*^9, {3.539021635406086*^9, 3.539021635408086*^9}, {
   3.5390347459069633`*^9, 3.5390347459089637`*^9}, {3.539991069520212*^9, 
   3.539991177560392*^9}},ExpressionUUID->"61ac7491-fa43-432d-afa9-\
19b8b06eccc2"],

Cell[TextData[{
 "Define leisure, ",
 StyleBox["L",
  FontSlant->"Italic"],
 ", as the portion of waking time (itself a fraction of total time) left \
after working for an employer, ",
 StyleBox["H",
  FontSlant->"Italic"],
 ", and working on real estate, ",
 StyleBox["S",
  FontSlant->"Italic"],
 "."
}], "Item1Numbered",
 CellChangeTimes->{
  3.5305608066998196`*^9, 3.539021635408086*^9, 3.5390347459089637`*^9, {
   3.5399911816036234`*^9, 
   3.539991202086795*^9}},ExpressionUUID->"f4a059aa-510f-4e16-9934-\
81b6a6e8069c"],

Cell[TextData[{
 "Assume the agent derives utility from (a) consumption in working years \
(recall that consumption during retirement is part of ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ") over a fixed level of subsistence; (b) leisure over a fixed minimum; and \
(c) years in retirement, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "r"], TraditionalForm]],ExpressionUUID->
  "5a0d87fc-6375-4108-99e0-30f98594943a"],
 ". "
}], "Item1Numbered",
 CellChangeTimes->{
  3.5305608084289184`*^9, 3.531617776219353*^9, {3.539021635409086*^9, 
   3.539021635409086*^9}, {3.5390347459089637`*^9, 3.5390347459099636`*^9}, {
   3.539991215532564*^9, 
   3.539991237806838*^9}},ExpressionUUID->"0a1d0382-9cdf-44ae-ad22-\
6be989800528"],

Cell[TextData[{
 "Define a utility function, ",
 StyleBox["uf",
  FontSlant->"Italic"],
 ", with those variables in the form ",
 StyleBox["u(xyz)",
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],
 StyleBox[" = ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     FormBox[
      SuperscriptBox["x", 
       StyleBox["\[Alpha]",
        FontSlant->"Plain"]],
      TraditionalForm], 
     SuperscriptBox["y", 
      StyleBox["\[Beta]",
       FontSlant->"Plain"]], 
     SuperscriptBox["z", 
      StyleBox["\[Gamma]",
       FontSlant->"Plain"]]}],
    FontSlant->"Italic",
    FontColor->GrayLevel[0]], TraditionalForm]],ExpressionUUID->
  "c7aec54a-4180-4d1d-990a-43f2a765f2f1"],
 " where ",
 StyleBox["x",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    SubscriptBox["c", "w"]}], TraditionalForm]],ExpressionUUID->
  "05e020fe-a2d0-4e0a-833f-bc2f8ff3f03f"],
 "-900; ",
 StyleBox["y",
  FontSlant->"Italic"],
 " =",
 StyleBox["L",
  FontSlant->"Italic"],
 "-.25; and z ",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    SubscriptBox["t", "r"]}], TraditionalForm]],ExpressionUUID->
  "9945c254-e8bf-487f-a711-1f4a7c3591e4"],
 ".  Exponents represent relative preferences, and are assumed to be, each, \
\[Subset] (0,1), exhibiting diminishing marginal returns. Also, \[Alpha]",
 StyleBox[" + ",
  FontSlant->"Italic"],
 "\[Beta]",
 StyleBox[" + ",
  FontSlant->"Italic"],
 "\[Gamma] = 1."
}], "Item1Numbered",
 CellChangeTimes->{
  3.530560810242022*^9, {3.5390216354100857`*^9, 3.539021635412086*^9}, {
   3.5390347459099636`*^9, 3.5390347459119635`*^9}, {3.539991243470162*^9, 
   3.5399913129971385`*^9}},ExpressionUUID->"a5740faf-838e-48f3-9a48-\
14d1cd508d13"],

Cell[TextData[{
 "Find partial derivatives of the utility function with respect to ",
 StyleBox["S",
  FontSlant->"Italic"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "w"], TraditionalForm]],ExpressionUUID->
  "79769056-e183-4c76-bc7f-0b93f25b1a3f"],
 " naming them, respectively, ",
 StyleBox["ds",
  FontSlant->"Italic"],
 " and ",
 StyleBox["dtw",
  FontSlant->"Italic"],
 "."
}], "Item1Numbered",
 CellChangeTimes->{
  3.53056081248215*^9, {3.539021635412086*^9, 3.539021635413086*^9}, {
   3.5390347459119635`*^9, 3.539034745912964*^9}, {3.5399913308551598`*^9, 
   3.539991352251384*^9}},ExpressionUUID->"c0ad316c-d881-47f5-b037-\
ec671b3bd6bc"],

Cell[CellGroupData[{

Cell[TextData[{
 "Note in Table 8.1 a value for ",
 StyleBox["T",
  FontSlant->"Italic"],
 ". This represents the maximum time capital will last. This is not a natural \
lifespan. Rather it is an individual's investment lifespan. Assuming one does \
not enter the workforce and begin investing in real estate until one is at \
least 20, when ",
 StyleBox["T",
  FontSlant->"Italic"],
 " = 60 natural age is 80."
}], "Text",
 CellMargins->{{Inherited, 9.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.530561150521485*^9, 3.5305611835763755`*^9}, {
   3.5316177878870206`*^9, 3.5316178108933363`*^9}, 3.539021635413086*^9, 
   3.539034745912964*^9, {3.5399913663051877`*^9, 
   3.539991378443882*^9}},ExpressionUUID->"b34e02d1-fe20-4c98-8116-\
483b00b9ec3d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
    SubscriptBox["c", "w"], ",", 
    SubscriptBox["t", "w0"], ",", "S", ",", 
    SubscriptBox["c", "r"]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dv1", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"T", "=", "60"}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "\[Rule]", "0.1"}], ",", 
       StyleBox[
        RowBox[{"\[Beta]", "\[Rule]", "0.4"}],
        Background->None], ",", 
       RowBox[{"\[Gamma]", "\[Rule]", "0.5"}], ",", 
       RowBox[{
        SubscriptBox["c", "r"], "\[Rule]", "1200"}], ",", 
       RowBox[{"p", "\[Rule]", "20"}], ",", 
       RowBox[{"r", "\[Rule]", "0.07"}], ",", 
       RowBox[{"wg", "\[Rule]", "120000."}], ",", 
       RowBox[{"H", "\[Rule]", "0.25"}], ",", 
       RowBox[{"W0", "\[Rule]", "50000."}]}], "}"}]}], ")"}]}], ";"}], "\n", 
 RowBox[{"frho", "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", "r"], "=", 
     RowBox[{"tr1", "/.", "dv1"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"scw", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["t", "r"], "+", 
         SubscriptBox["t", "w"]}], "\[Equal]", "T"}], ",", 
       SubscriptBox["c", "w"]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["c", "w"], "=", 
     RowBox[{
      SubscriptBox["c", "w"], "/.", 
      RowBox[{"scw", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"L", "=", 
     RowBox[{"1", "-", "H", "-", "S"}]}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{"uf", "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["c", "w"], "-", "900"}], ")"}], "\[Alpha]"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"L", "-", ".25"}], ")"}], "\[Beta]"], 
       SuperscriptBox[
        SubscriptBox["t", "r"], "\[Gamma]"]}], "/.", "dv1"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"ds", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", "S"], " ", "uf"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"dtw", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       SubscriptBox["t", "w"]], " ", "uf"}]}], ";"}], "\[IndentingNewLine]", 
   ")"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.533239773431733*^9, 3.539021635413086*^9, 
  3.539034745912964*^9},ExpressionUUID->"21575059-11fb-4c9d-a008-\
f0fa77143464"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", "60", "}"}], ",", 
    RowBox[{"dv1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", "\"\<T\>\"", "}"}], ",", 
     RowBox[{"dv1", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}]}], "]"}], "/.", 
   RowBox[{
    SubscriptBox["c", "r"], "\[Rule]", 
    "\"\<\!\(\*SubscriptBox[\(c\), \(r\)]\)\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "%%"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.531617833243615*^9, 3.5316179604478903`*^9}, {
   3.5316179953398867`*^9, 3.531618081400809*^9}, {3.5316181307886333`*^9, 
   3.5316181317316875`*^9}, 3.5390216354140863`*^9, 
   3.5390347459139643`*^9},ExpressionUUID->"c60b86d5-1fc1-4075-89ff-\
d2e23e9c11f0"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"T\"\>", "\[Alpha]", "\[Beta]", 
     "\[Gamma]", "\<\"\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\)\"\>", "p", 
     "r", "wg", "H", "W0"},
    {"60", "0.1`", "0.4`", "0.5`", "1200", "20", "0.07`", "120000.`", "0.25`",
      "50000.`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.531617847467428*^9, 3.53161787616807*^9}, 
   3.5316179240968113`*^9, 3.531617960762909*^9, {3.5316180205363274`*^9, 
   3.5316180360382137`*^9}, 3.531618082176853*^9, 3.531618133484788*^9, 
   3.5316194808088503`*^9, 3.5316197576956873`*^9, 3.5331482022403755`*^9, 
   3.533236439647052*^9, 3.5332400469673786`*^9, 3.533683630546875*^9, 
   3.5337353098800907`*^9, 3.533756229671875*^9, 3.5390212077016225`*^9, 
   3.5390216354140863`*^9, 3.5390347459139643`*^9, 3.539988737980856*^9, 
   3.5401275181427317`*^9, 3.5405612158750343`*^9, 3.541186526966341*^9, 
   3.5411879104024687`*^9, 3.5411880344625645`*^9, 3.5411910663129764`*^9, 
   3.541191164575597*^9, 3.5411912111782627`*^9, 3.5411912449651947`*^9, 
   3.5411913030715184`*^9, 3.541604154097119*^9, 3.6126968929532375`*^9, 
   3.6972339908626947`*^9, 3.697235486471341*^9, 3.6972358732300463`*^9, 
   3.6973178522660007`*^9, 3.6973235314485083`*^9, 3.698044389984208*^9, 
   3.698044830272046*^9, 3.7314215543654575`*^9},
 TextAlignment->Center,ExpressionUUID->"bec6a76b-c014-4d34-a473-40b34e3ec7fc"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table 8.1",
  FontWeight->"Bold"],
 " Fixed parameter values for simulation #1"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{57, 0}, {1, 7}},
 CellChangeTimes->{{3.530561082895617*^9, 3.5305610961973777`*^9}, 
   3.5390216354140863`*^9, 3.5390347459139643`*^9},
 TextAlignment->Center,ExpressionUUID->"7bde0bcc-979c-4053-a59d-4cb529924aec"],

Cell[TextData[{
 "Inserting values from ",
 StyleBox["Table 8.1",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 "into equation (8.",
 StyleBox["5",
  FontFamily->"Times New Roman"],
 ") we reduce the number of variables in ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ". Using the fact that ",
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["w",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 " + ",
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["r",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 " = ",
 StyleBox["T",
  FontSlant->"Italic"],
 " we can solve for ",
 StyleBox["c",
  FontSlant->"Italic"],
 StyleBox["r",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 " in terms of variables already in ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ". Knowing that ",
 StyleBox["L",
  FontSlant->"Italic"],
 " = 1 - ",
 StyleBox["H",
  FontSlant->"Italic"],
 " - ",
 StyleBox["S",
  FontSlant->"Italic"],
 " completes what we need for the utility function, ",
 StyleBox["uf",
  FontSlant->"Italic"],
 ". ",
 StyleBox["Table 8.1",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 "specifies values for \[Alpha], \[Beta] and ",
 StyleBox["\[Gamma]",
  FontFamily->"Times New Roman Greek"],
 " so we are now ready to make the calculations needed for simulation.  We \
take the first partial derivatives of the utility function with respect to ",
 StyleBox["S",
  FontSlant->"Italic"],
 " and ",
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["w",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 ", set them equal to zero and solve for optimal utility using a number of \
different values of \[Rho], ",
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["w",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 ", and ",
 StyleBox["S",
  FontSlant->"Italic"],
 ". ",
 StyleBox["Figure 8.2",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 "reflects the graph of optimal utility, given the data in ",
 StyleBox["Table 8.1",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 ", showing how optimal utility changes with changes in the critical \
variables.  Note that time working prior to retirement, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "w"], "(", "\[Rho]", ")"}], TraditionalForm]],
  ExpressionUUID->"9048e4ed-956a-4481-a3d9-cf0f91796ef6"],
 ", decreases with higher values of \[Rho] and/or ",
 StyleBox["S",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.5305616819898834`*^9, 3.5305618260911255`*^9}, {
   3.530561860210077*^9, 3.530561867450491*^9}, {3.530561938189537*^9, 
   3.5305619450239277`*^9}, {3.5316182664803944`*^9, 3.531618314637149*^9}, {
   3.5390216354140863`*^9, 3.539021635416086*^9}, {3.5390347459139643`*^9, 
   3.539034745915964*^9}, {3.539991454838251*^9, 3.5399914920373793`*^9}, 
   3.697234160549466*^9},ExpressionUUID->"47c17fcd-9a0f-4a77-a6f0-\
7951f24077bd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tws", ",", "S", ",", 
    SubscriptBox["t", "w"]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ds1", "[", "\[Rho]_", "]"}], "=", "ds"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dtw1", "[", "\[Rho]_", "]"}], "=", "dtw"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tws", "[", "\[Rho]_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Rho]", ",", 
      SubscriptBox["t", "w"], ",", "S"}], "}"}], "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ds1", "[", "\[Rho]", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"dtw1", "[", "\[Rho]", "]"}], "\[Equal]", "0"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"S", ",", ".2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["t", "w"], ",", "40"}], "}"}], ",", 
      RowBox[{"MaxIterations", "\[Rule]", "20"}], ",", 
      RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tv1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tws", "[", "\[Rho]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".375", ",", ".7", ",", ".025"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ftv1", "=", 
   RowBox[{"ListInterpolation", "[", 
    RowBox[{"tv1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{".375", ",", ".7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"pp1", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ftv1", "[", 
       RowBox[{"\[Rho]", ",", "3"}], "]"}], ",", 
      RowBox[{"ftv1", "[", 
       RowBox[{"\[Rho]", ",", "2"}], "]"}], ",", "\[Rho]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Rho]", ",", ".375", ",", ".7"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", ".5", "]"}], ",", "Thick"}], 
      StyleBox["}",
       FontFamily->"Courier New",
       CharacterEncoding -> "WindowsANSI"]}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<    S(\[Rho])      \>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])\>\"", ",", 
       "\"\<   \[Rho]\>\""}], "}"}]}], ",", 
    RowBox[{"FaceGrids", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}], "}"}]}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"2.589", ",", 
       RowBox[{"-", "0.864"}], ",", "2.000"}], "}"}]}]}], "]"}]}]}], "Input",
 CellMargins->{{Inherited, 9.375}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.4101996949375*^9, 3.410199706390625*^9}, 
   3.41021691346875*^9, {3.41021731125*^9, 3.4102173118125*^9}, 
   3.410276248390625*^9, {3.4102764939462757`*^9, 3.410276497087845*^9}, {
   3.4102766385991488`*^9, 3.4102766418657565`*^9}, {3.4102768587747326`*^9, 
   3.410276860947261*^9}, 3.410277160162238*^9, {3.4102772021592417`*^9, 
   3.4102772298081813`*^9}, 3.41027759274314*^9, 3.4102776329716716`*^9, 
   3.4102777144602346`*^9, {3.4102779425000553`*^9, 3.41027796275498*^9}, 
   3.410373565858*^9, {3.410373608967375*^9, 3.4103736457955*^9}, 
   3.5305613851509047`*^9, 3.5390216354170866`*^9, 3.539034745915964*^9, {
   3.541187973735091*^9, 3.54118801497945*^9}, {3.541191037267315*^9, 
   3.541191046056818*^9}},ExpressionUUID->"876decd4-06a5-4cd1-a23f-\
082f3a7ff68d"],

Cell[BoxData[
 Graphics3DBox[{{}, {}, 
   TagBox[
    {Hue[0.5, 1, 1], Thickness[Large], Line3DBox[CompressedData["
1:eJwN0Xs81Pkex/EhxbajWjSkkJJc4zeXFPH55lI4wuqySaodt6jIsWUQlRCV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      "]]},
    Annotation[#, "Charting`Private`Tag$2583#1"]& ]},
  Axes->True,
  AxesLabel->{
    FormBox["\"    S(\[Rho])      \"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(w\\)]\\)(\[Rho])\"", 
     TraditionalForm], 
    FormBox["\"   \[Rho]\"", TraditionalForm]},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  FaceGrids->{{0, 0, -1}},
  FaceGridsStyle->Automatic,
  ImageSize->300,
  Method->{},
  PlotRange->{{0.09611178375039214, 0.11274289272768775`}, {17.20494454479574,
    21.24328657623363}, {0.37500000663265304`, 0.6999999933673469}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{2.589, -0.864, 2.}]], "Output",
 CellChangeTimes->{
  3.541191066565991*^9, 3.5411911648526125`*^9, {3.5411912174266195`*^9, 
   3.541191245246211*^9}, 3.541191303339534*^9, 3.541604155988227*^9, 
   3.6126968951083603`*^9, 3.697233991271784*^9, 3.6972354867621484`*^9, 
   3.6972358739148684`*^9, 3.697317852926759*^9, 3.697323531679134*^9, 
   3.6980443905537243`*^9, 3.6980448305478115`*^9, 3.731421555218727*^9},
 TextAlignment->Center,ExpressionUUID->"08dfd344-7928-43e4-8a42-b95cb645b303"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.2.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Simulation #1 - Optimal utility under different values of \[Rho],",
  FontFamily->"Times New Roman",
  FontSize->12],
 StyleBox[" t",
  FontFamily->"Times New Roman",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox["w",
  FontFamily->"Times New Roman",
  FontSize->12,
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox["(\[Rho]) and ",
  FontFamily->"Times New Roman",
  FontSize->12],
 StyleBox["S",
  FontFamily->"Times New Roman",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox["(\[Rho])",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{
  3.5285477921289577`*^9, 3.5300478264783916`*^9, {3.5300484582175255`*^9, 
   3.5300484678950787`*^9}, 3.5305630958357506`*^9, {3.530566506437826*^9, 
   3.5305665085119443`*^9}, 3.539021635420087*^9, 3.5390347459189644`*^9},
 TextAlignment->Center,ExpressionUUID->"a3801237-220a-493c-8fa0-96c056a4af3f"],

Cell[TextData[{
 StyleBox["To review, Figure 8.2 plots the values of ",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox["S", "Input",
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox[", and ",
  FontColor->GrayLevel[0],
  Background->None],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "w"], TraditionalForm]],ExpressionUUID->
  "510ba64f-0efe-4f3f-bbee-14585a91ee00"],
 StyleBox[",",
  FontColor->GrayLevel[0],
  Background->None],
 " each",
 StyleBox[" as a function of \[Rho]",
  FontColor->GrayLevel[0]],
 StyleBox[" which yield",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1],
  Background->None],
 StyleBox["optimal",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1],
  Background->None],
 StyleBox["utility when all other parameters are fixed by ",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox["dv1", "Input",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox[" in Table 8.1", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox[".  Optimal utility occurs when the first derivative of the utility \
function is set to zero. Note that, given these fixed parameters, optimal \
utility increases with smaller amounts of time working, ",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["w",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox[", ",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox["presumed to be the agent's goal.",
  FontColor->GrayLevel[0]],
 StyleBox[" This occurs, as hoped, when \[Rho], ",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox["S(",
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox["\[Rho]) or combinations of them increase.",
  FontColor->GrayLevel[0],
  Background->None]
}], "Text",
 CellMargins->{{Inherited, 8.625}, {Inherited, Inherited}},
 CellChangeTimes->{
  3.5305616206123724`*^9, {3.5305620684069853`*^9, 3.530562088927159*^9}, {
   3.5316183461039486`*^9, 3.5316183496411514`*^9}, {3.539021635420087*^9, 
   3.539021635423087*^9}, {3.5390347459189644`*^9, 3.5390347459209642`*^9}, {
   3.5399915249512615`*^9, 
   3.5399916215957894`*^9}},ExpressionUUID->"85776d96-c1c9-490e-881a-\
109a559b45b3"],

Cell[TextData[{
 StyleBox["Table 8.2 displays values used to create Figure 8.2",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox[".",
  FontColor->GrayLevel[0]],
 StyleBox[" Note that the points for the lower right hand rear corner of the \
graph are on the first line in the table and the last line shows the points \
for the upper left forward corner. ",
  FontColor->GrayLevel[0],
  Background->None]
}], "Text",
 CellMargins->{{Inherited, 8.625}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5305616206123724`*^9, 3.530561621896446*^9}, {
   3.530562171955908*^9, 3.530562175806128*^9}, {3.5305625316394806`*^9, 
   3.5305625436691685`*^9}, 3.539021635423087*^9, 3.5390347459209642`*^9, 
   3.541188058665949*^9},ExpressionUUID->"6a0d1099-d9a6-483d-9351-\
808c6ed5d4a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{"tv1", ",", 
     RowBox[{"TableHeadings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Rho]\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])\>\"", ",", 
          "\"\<S(\[Rho])\>\""}], "}"}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5305623855941267`*^9, 3.530562470718996*^9}, {
   3.5332399734141717`*^9, 3.5332400001797028`*^9}, 3.539021635423087*^9, 
   3.5390347459209642`*^9},ExpressionUUID->"010a1b96-71fe-4694-8ed4-\
7a3f83e81f79"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"\[Rho]\"\>",
        HoldForm], 
       TagBox["\<\"\\!\\(\\*SubscriptBox[\\(t\\), \\(w\\)]\\)(\[Rho])\"\>",
        HoldForm], 
       TagBox["\<\"S(\[Rho])\"\>",
        HoldForm]},
      {"0.375`", "21.243286690380696`", "0.09611178300233925`"},
      {"0.4`", "20.825964516690462`", "0.09872247645049205`"},
      {"0.425`", "20.432910337450593`", "0.10095856062375713`"},
      {"0.45`", "20.06175274268444`", "0.10288479347109206`"},
      {"0.475`", "19.710433011442724`", "0.10455241926893101`"},
      {"0.5`", "19.37715514103298`", "0.10600245586033877`"},
      {"0.525`", "19.060344908677152`", "0.10726807645756022`"},
      {"0.55`", "18.758616229591354`", "0.10837636232325114`"},
      {"0.575`", "18.47074340077513`", "0.10934961073515735`"},
      {"0.6`", "18.195638098244533`", "0.11020632363480756`"},
      {"0.625`", "17.932330223820596`", "0.11096196370700989`"},
      {"0.65`", "17.67995188092456`", "0.11162953884241544`"},
      {"0.675`", "17.43772390437766`", "0.11222005842981644`"},
      {"0.7`", "17.204944484229248`", "0.11274289285824897`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {
      None, {
       "\[Rho]", "\!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])", 
        "S(\[Rho])"}}]]],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{
  3.5332400012637644`*^9, 3.533240047306398*^9, 3.533683631203125*^9, 
   3.5337353109971547`*^9, 3.53375623034375*^9, 3.5390212101177607`*^9, 
   3.539021635423087*^9, 3.5390347459209642`*^9, 3.5399887404729986`*^9, 
   3.5401275203788595`*^9, 3.540561219412236*^9, 3.541186530046517*^9, 
   3.5411879107534885`*^9, 3.5411880348205853`*^9, 3.5411910666949987`*^9, 
   3.541191164993621*^9, {3.541191217708636*^9, 3.541191245381219*^9}, 
   3.541191303477542*^9, 3.5416041567322693`*^9, 3.612696895528384*^9, 
   3.697233991409148*^9, 3.6972354869005156`*^9, 3.697235874157013*^9, 
   3.697317853019004*^9, 3.697323531693161*^9, 3.69804439076328*^9, 
   3.6980448305688353`*^9, 3.73142155534005*^9},
 TextAlignment->Center,ExpressionUUID->"8b8a99d6-11b4-43ac-ac4b-55c9be242632"]
}, Open  ]],

Cell["Table 8.2 Selected points from Figure 8.2", "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{24.666666666666657`, 10.}, {1., 7.}},
 CellChangeTimes->{{3.530562220451681*^9, 3.530562222276786*^9}, {
   3.5305624955614166`*^9, 3.5305625064820414`*^9}, 3.539021635423087*^9, 
   3.5390347459209642`*^9},
 TextAlignment->Center,ExpressionUUID->"0710262b-f5dd-4e8a-bbb0-7b13c876fc53"],

Cell["8.4.4. Simulation #2", "Subsection",
 CellChangeTimes->{3.5316183816999846`*^9, 3.539021635423087*^9, 
  3.5390347459209642`*^9},ExpressionUUID->"01925821-3fc6-4fc8-be3b-\
2d24f8989b4d"],

Cell[TextData[{
 StyleBox["Using a slightly different dataset, ",
  FontColor->GrayLevel[0]],
 StyleBox["dv2", "Input",
  FontColor->GrayLevel[0]],
 StyleBox[", for fixed parameters, the value of two of the variables is \
changed to see how the plot changes.  For the present ",
  FontColor->GrayLevel[0]],
 StyleBox["H", "Input",
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],
 StyleBox[" remains fixed at .25, the change is in one of the exponents in \
the utility function. Increasing ",
  FontColor->GrayLevel[0]],
 StyleBox["\[Gamma]", "Input",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 StyleBox[" indicates a greater preference for retirement time, suggesting \
the investor gains utility by retiring earlier in life (expressed by shorter \
time working, ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "w"], TraditionalForm]],ExpressionUUID->
  "754ff2f4-8aaf-4407-82e2-74f973668cc3"],
 "). Because \[Alpha] ",
 StyleBox["+ \[Beta] + \[Gamma] = 1 increasing \[Gamma] means decreasing \
something else. We choose \[Beta]. ",
  FontColor->GrayLevel[0]]
}], "Text",
 CellMargins->{{Inherited, 9.3125}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5305631650947123`*^9, 3.530563181506651*^9}, {
   3.5316184221462984`*^9, 3.531618508303226*^9}, 3.5390213986205425`*^9, {
   3.539021635423087*^9, 3.539021635425087*^9}, {3.5390347459209642`*^9, 
   3.539034745922964*^9}},ExpressionUUID->"de58392d-e0b2-46d6-b2f8-\
56af25574efc"],

Cell[CellGroupData[{

Cell[TextData[{
 "The procedure for creating ",
 StyleBox["frho",
  FontSlant->"Italic"],
 " is the same except the new data, ",
 StyleBox["dv2", "Input"],
 StyleBox[" ", "Input",
  FontFamily->"Times New Roman"],
 StyleBox["from Table 8.3", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 ", are employed. "
}], "Text",
 CellChangeTimes->{{3.530562929691248*^9, 3.530562934905546*^9}, 
   3.5305629788900614`*^9, {3.5390214149214745`*^9, 3.539021415509508*^9}, 
   3.539021635425087*^9, 
   3.539034745922964*^9},ExpressionUUID->"4e0f4e7a-52e7-40c2-83ee-\
2c560458c230"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
    SubscriptBox["c", "w"], ",", 
    SubscriptBox["t", "w"], ",", "S", ",", "T"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dv2", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"T", "=", "60"}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "\[Rule]", "0.1"}], ",", 
       RowBox[{"\[Beta]", "\[Rule]", "0.2"}], ",", 
       RowBox[{"\[Gamma]", "\[Rule]", "0.7"}], ",", 
       RowBox[{
        SubscriptBox["c", "r"], "\[Rule]", "1200"}], ",", 
       RowBox[{"p", "\[Rule]", "20"}], ",", 
       RowBox[{"r", "\[Rule]", "0.07"}], ",", 
       RowBox[{"wg", "\[Rule]", "120000."}], ",", 
       RowBox[{"H", "\[Rule]", "0.25"}], ",", 
       RowBox[{"W0", "\[Rule]", "50000."}]}], "}"}]}], ")"}]}], ";"}], "\n", 
 RowBox[{"frho", "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", "r"], "=", 
     RowBox[{"tr1", "/.", "dv2"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"scw", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["t", "r"], "+", 
         SubscriptBox["t", "w"]}], "\[Equal]", "T"}], ",", 
       SubscriptBox["c", "w"]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["c", "w"], "=", 
     RowBox[{
      SubscriptBox["c", "w"], "/.", 
      RowBox[{"scw", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"L", "=", 
     RowBox[{"1", "-", "H", "-", "S"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"uf", "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["c", "w"], "-", "900"}], ")"}], "\[Alpha]"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"L", "-", ".25"}], ")"}], "\[Beta]"], 
       SuperscriptBox[
        SubscriptBox["t", "r"], "\[Gamma]"]}], "/.", "dv2"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"ds", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", "S"], " ", "uf"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"dtw", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       SubscriptBox["t", "w"]], " ", "uf"}]}], ";"}], "\[IndentingNewLine]", 
   ")"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.5332401151492786`*^9, 3.539021635425087*^9, 
  3.539034745922964*^9},ExpressionUUID->"f2c6d4af-dfac-403f-8bdb-\
c7e844645201"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<T\>\"", ",", "\[Alpha]", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\[Beta]", ",", "Red"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\[Gamma]", ",", "Red"}], "]"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(c\), \(r\)]\)\>\"", ",", "p", ",", "r", ",", 
       "wg", ",", "H", ",", "W0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", "0.1", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"0.2", ",", "Red"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"0.7", ",", "Red"}], "]"}], ",", "1200", ",", "20", ",", 
       "0.07", ",", "120000.", ",", "0.25", ",", "50000."}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.53161856623954*^9, 3.531618577677194*^9}, {
   3.531618645805091*^9, 3.531618799763897*^9}, 3.539021635425087*^9, 
   3.539034745922964*^9},ExpressionUUID->"a03124c3-b351-4156-9af4-\
a8b99692105c"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"T\"\>", "\[Alpha]", 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox["\[Gamma]",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[
       1, 0, 0]], "\<\"\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\)\"\>", "p", 
     "r", "wg", "H", "W0"},
    {"60", "0.1`", 
     StyleBox["0.2`",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox["0.7`",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "1200", "20", "0.07`", "120000.`", 
     "0.25`", "50000.`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.531618587447753*^9, 3.5316186577567744`*^9, {3.5316186958809547`*^9, 
   3.531618800603945*^9}, 3.531619481435886*^9, 3.531619758359725*^9, 
   3.5331482040684795`*^9, 3.533236441830177*^9, 3.533240047417404*^9, 
   3.533683631359375*^9, 3.5337353116671925`*^9, 3.5337562305*^9, 
   3.5390212108368015`*^9, 3.539021635425087*^9, 3.539034745922964*^9, 
   3.539988741305046*^9, 3.540127521170905*^9, 3.5405612206403065`*^9, 
   3.541186531047574*^9, 3.5411879109294987`*^9, 3.5411880349115906`*^9, 
   3.5411910667860036`*^9, 3.5411911651066275`*^9, {3.5411912179796515`*^9, 
   3.5411912456072316`*^9}, 3.541191303573547*^9, 3.5416041575723176`*^9, 
   3.612696896064415*^9, 3.697233991459283*^9, 3.697235486967161*^9, 
   3.697235874275361*^9, 3.697317853149351*^9, 3.6973235317363005`*^9, 
   3.6980443908274508`*^9, 3.6980448307803984`*^9, 3.7314215554002094`*^9},
 TextAlignment->Center,ExpressionUUID->"f9cacea5-c508-4618-9b46-18e8c63a7887"]
}, Open  ]],

Cell["Table 8.3 Fixed parameter values for simulation #2", "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{74.66666666666666, 10.}, {1., 7.}},
 CellChangeTimes->{{3.530561082895617*^9, 3.5305610961973777`*^9}, {
   3.5305628115044875`*^9, 3.5305628144376554`*^9}, 3.539021635425087*^9, 
   3.539034745922964*^9},
 TextAlignment->Center,ExpressionUUID->"a8035b74-1d2e-4765-a12a-38534fc4c5ce"],

Cell[TextData[{
 StyleBox["Note that for Simulation #2 it is necessary to increase \
MaxIterations for FindRoot to get good solutions for all values of ",
  Background->None],
 StyleBox["\[Rho]", "Input",
  Background->None],
 StyleBox[" using ",
  Background->None],
 StyleBox["dv2", "Input",
  Background->None],
 StyleBox[". ",
  Background->None]
}], "Text",
 CellOpen->False,
 CellChangeTimes->{{3.5305629982131667`*^9, 3.530563001159335*^9}, 
   3.539021635425087*^9, 
   3.539034745922964*^9},ExpressionUUID->"dc595fd5-2685-4314-8f2e-\
5867fa94da1d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tws", ",", "S", ",", 
    SubscriptBox["t", "w"]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ds1", "[", "\[Rho]_", "]"}], "=", "ds"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dtw1", "[", "\[Rho]_", "]"}], "=", "dtw"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tws", "[", "\[Rho]_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Rho]", ",", 
      SubscriptBox["t", "w"], ",", "S"}], "}"}], "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ds1", "[", "\[Rho]", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"dtw1", "[", "\[Rho]", "]"}], "\[Equal]", "0"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"S", ",", ".2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["t", "w"], ",", "40"}], "}"}], ",", 
      RowBox[{"MaxIterations", "\[Rule]", "40"}], ",", 
      RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tv2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tws", "[", "\[Rho]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".375", ",", ".7", ",", ".025"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ftv2", "=", 
   RowBox[{"ListInterpolation", "[", 
    RowBox[{"tv2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{".375", ",", ".7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"pp2", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ftv2", "[", 
       RowBox[{"\[Rho]", ",", "3"}], "]"}], ",", 
      RowBox[{"ftv2", "[", 
       RowBox[{"\[Rho]", ",", "2"}], "]"}], ",", "\[Rho]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Rho]", ",", ".375", ",", ".7"}], "}"}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", ".2", "]"}], ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<   S(\[Rho])     \>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])\>\"", ",", 
       "\"\<   \[Rho]\>\""}], "}"}]}], ",", 
    RowBox[{"FaceGrids", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}], "}"}]}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"2.589", ",", 
       RowBox[{"-", "0.864"}], ",", "2.000"}], "}"}]}]}], "]"}]}]}], "Input",
 CellMargins->{{Inherited, 9.3125}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{
  3.410358684498625*^9, 3.410358727186125*^9, {3.410358830967375*^9, 
   3.41035887607675*^9}, {3.410359110529875*^9, 3.410359137654875*^9}, {
   3.41035920913925*^9, 3.410359215998625*^9}, {3.410359329561125*^9, 
   3.410359341904875*^9}, {3.4103594717955*^9, 3.410359472358*^9}, {
   3.4103737256705*^9, 3.41037377551425*^9}, 3.5305626727815533`*^9, 
   3.539021635426087*^9, 3.5390347459239645`*^9, 
   3.5411911088594103`*^9},ExpressionUUID->"86ca7d0b-08e4-41b2-90f8-\
8d5e55f48390"],

Cell[BoxData[
 Graphics3DBox[{{}, {}, 
   TagBox[
    {Hue[0.2, 1, 1], AbsoluteThickness[2], Line3DBox[CompressedData["
1:eJwV1Xk8VN8bB3BEKyqJ0GoJdwyDb1QTzwmVLN98VUg/ErIlUQqRtUJFmSRS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      "]]},
    Annotation[#, "Charting`Private`Tag$2611#1"]& ]},
  Axes->True,
  AxesLabel->{
    FormBox["\"   S(\[Rho])     \"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(w\\)]\\)(\[Rho])\"", 
     TraditionalForm], 
    FormBox["\"   \[Rho]\"", TraditionalForm]},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  FaceGrids->{{0, 0, -1}},
  FaceGridsStyle->Automatic,
  ImageSize->300,
  Method->{},
  PlotRange->{{0.19453983600557873`, 0.20011988439444292`}, {
   13.23465037170585, 16.88424433251741}, {0.37500000663265304`, 
   0.6999999933673469}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{2.589, -0.864, 2.}]], "Output",
 CellChangeTimes->{
  3.530562673652603*^9, 3.5305723755545197`*^9, 3.5316178502635884`*^9, 
   3.5316194817039013`*^9, 3.5316197586317406`*^9, 3.5331482047005157`*^9, 
   3.5332364425102158`*^9, 3.5332400476654186`*^9, 3.533683631875*^9, 
   3.533735312472239*^9, 3.533756231015625*^9, 3.5390212118798614`*^9, 
   3.539021635428087*^9, 3.5390347459259644`*^9, 3.5399887421140924`*^9, 
   3.540127522266968*^9, 3.5405612217163687`*^9, 3.541186532212641*^9, 
   3.5411879112525177`*^9, 3.541188035168605*^9, 3.541191067040018*^9, 
   3.541191130445645*^9, 3.541191165390643*^9, {3.541191223915991*^9, 
   3.541191245863246*^9}, 3.5411913038395624`*^9, 3.5416041584663687`*^9, 
   3.612696897134476*^9, 3.697233991730001*^9, 3.697235487272473*^9, 
   3.6972358745986876`*^9, 3.697317853438119*^9, 3.6973235319959955`*^9, 
   3.6980443910701303`*^9, 3.6980448310230727`*^9, 3.7314215557070246`*^9},
 TextAlignment->Center,ExpressionUUID->"515c2646-a0dd-4dcb-b1a2-c961a1981d29"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.3.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Simulation #2 with \[Beta] = .2 and \[Gamma] = .7",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.530566474307988*^9, 3.530566484530573*^9}, 3.539021635428087*^9, 
   3.5390347459259644`*^9},
 TextAlignment->Center,ExpressionUUID->"63ce085d-985d-4973-9da8-2d4abf1f18ce"],

Cell[TextData[{
 StyleBox["Figure 8.3",
  FontFamily->"Times New Roman"],
 " is the plot of our second simulation",
 StyleBox[". ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["It looks nearly identical to Figure 8.2 and it is except for the \
range on the axes.",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["The exponents representing relative preference, \[Alpha], \[Beta], \
and \[Gamma], are highly abstract. ",
  FontColor->GrayLevel[0]],
 StyleBox["W",
  FontFamily->"Times New Roman"],
 "hen \[Gamma] increases at the expense of \[Beta] optimum utility occurs \
along the same range of \[Rho] but along a broader range of ",
 StyleBox["S",
  FontSlant->"Italic"],
 ", with working years consistently lower.  Hence, when one prefers greater \
retirement time (as evidenced by a higher \[Gamma]) and takes from leisure \
time (by lowering \[Beta]) he can reduce time working over the relevant \
ranges of ",
 StyleBox["S",
  FontSlant->"Italic"],
 " and \[Rho]. Those who might refer to such a person as a \"workaholic\" may \
wish to rethink this accusation. Such investors just prefer to organize life \
in a way that concentrates larger effort in early years to allow for less \
effort in later years. Thus, like the fable of the ant and the grasshopper, \
the investor willing to forgo some leisure early in life is able to retire \
sooner."
}], "Text",
 CellChangeTimes->{{3.530563269871705*^9, 3.5305633046096916`*^9}, 
   3.530563395544893*^9, 3.530564524509466*^9, {3.5316189278592234`*^9, 
   3.531618957411914*^9}, 3.53324015014028*^9, 3.539021635428087*^9, 
   3.5390347459259644`*^9, {3.5399893470196915`*^9, 3.539989349936858*^9}, 
   3.5399893854428887`*^9, {3.539991683709342*^9, 3.53999172370463*^9}, {
   3.540565299990632*^9, 
   3.540565314684473*^9}},ExpressionUUID->"25900c8a-05a7-4ad1-aebd-\
d375b33a1893"],

Cell[TextData[{
 StyleBox["Table 8.4 displays values used to create Figure 8.3",
  FontColor->GrayLevel[0],
  Background->None],
 StyleBox[".",
  FontColor->GrayLevel[0]],
 StyleBox[" Again, the points for the lower right hand rear corner of the \
graph are on the first line in the table and the last line shows the points \
for the upper left forward corner. ",
  FontColor->GrayLevel[0],
  Background->None]
}], "Text",
 CellMargins->{{Inherited, 8.625}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5305616206123724`*^9, 3.530561621896446*^9}, {
   3.530562171955908*^9, 3.530562175806128*^9}, {3.5305625316394806`*^9, 
   3.5305625436691685`*^9}, {3.530563430377885*^9, 3.530563453551211*^9}, 
   3.539021635428087*^9, 3.5390347459259644`*^9, 
   3.541188091452824*^9},ExpressionUUID->"4376a32b-e128-469c-a90e-\
315313fba703"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{"tv2", ",", 
     RowBox[{"TableHeadings", "->", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<   \[Rho]\>\"", ",", 
          "\"\<  \!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])\>\"", ",", 
          "\"\<  S(\[Rho])\>\""}], "}"}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellMargins->{{Inherited, 10}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.530563027388836*^9, 3.530563046282916*^9}, {
   3.5332401747856894`*^9, 3.533240187119395*^9}, 3.539021635428087*^9, 
   3.5390347459259644`*^9},ExpressionUUID->"fe1a56ed-1604-444a-8145-\
47de0691e589"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"   \[Rho]\"\>",
        HoldForm], 
       TagBox["\<\"  \\!\\(\\*SubscriptBox[\\(t\\), \\(w\\)]\\)(\[Rho])\"\>",
        HoldForm], 
       TagBox["\<\"  S(\[Rho])\"\>",
        HoldForm]},
      {"0.375`", "16.884244437714095`", "0.19453983563817748`"},
      {"0.4`", "16.50037148211796`", "0.1957894823059978`"},
      {"0.425`", "16.140178497043273`", "0.19679854280095002`"},
      {"0.45`", "15.801272578882537`", "0.19761165830479852`"},
      {"0.475`", "15.48158778247776`", "0.19826382486929972`"},
      {"0.5`", "15.179330182017738`", "0.19878279687475592`"},
      {"0.525`", "14.892933664812828`", "0.19919081496622318`"},
      {"0.55`", "14.621024112236032`", "0.19950586849373075`"},
      {"0.575`", "14.362390178447077`", "0.19974263135725653`"},
      {"0.6`", "14.115959294681605`", "0.19991316494988048`"},
      {"0.625`", "13.880777840414554`", "0.20002745253849297`"},
      {"0.65`", "13.655994659320696`", "0.20009380998882548`"},
      {"0.675`", "13.440847277460016`", "0.20011920464828684`"},
      {"0.7`", "13.234650318127223`", "0.20010950523442234`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {
      None, {
       "   \[Rho]", "  \!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])", 
        "  S(\[Rho])"}}]]],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{
  3.410468877529875*^9, 3.410504963640625*^9, 3.530360977599249*^9, {
   3.5305630225085564`*^9, 3.5305630468709497`*^9}, 3.530563460446605*^9, 
   3.5305723756085234`*^9, 3.5316178506866126`*^9, 3.531619481766905*^9, 
   3.5316197587077456`*^9, 3.5331482050915384`*^9, 3.533236443251258*^9, 
   3.533240047770425*^9, 3.5332401880564485`*^9, 3.5336836319375*^9, 
   3.5337353131392775`*^9, 3.533756231109375*^9, 3.5390212127219095`*^9, 
   3.539021635428087*^9, 3.5390347459259644`*^9, 3.5399887429361396`*^9, 
   3.5401275231490183`*^9, 3.5405612225994186`*^9, 3.5411865333967085`*^9, 
   3.541187911332522*^9, 3.5411880353126135`*^9, 3.541191067201027*^9, 
   3.541191165603656*^9, {3.5411912241030016`*^9, 3.5411912459612517`*^9}, 
   3.541191304006572*^9, 3.541604159350419*^9, 3.6126968975464997`*^9, 
   3.6972339917430377`*^9, 3.69723548728952*^9, 3.6972358746142287`*^9, 
   3.697317853504303*^9, 3.697323532123329*^9, 3.6980443910891466`*^9, 
   3.698044831060142*^9, 3.7314215557310886`*^9},
 TextAlignment->Center,ExpressionUUID->"7fea851f-6dcb-48d2-8281-dd524882d7a2"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Table 8.4",
  FontWeight->"Bold"],
 " Selected points from Figure 8.3"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{65.66666666666663, 10.}, {1., 7.}},
 CellChangeTimes->{{3.530562220451681*^9, 3.530562222276786*^9}, {
   3.5305624955614166`*^9, 3.5305625064820414`*^9}, {3.5305643573699064`*^9, 
   3.530564360298074*^9}, 3.539021635428087*^9, 3.5390347459259644`*^9},
 TextAlignment->Center,ExpressionUUID->"765f0885-06da-4f24-9236-49afb0609682"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Beneath this cell is a test to determine if good solutions are \
found, i.e., are the values of ",
  Background->None],
 StyleBox["ds ", "Input",
  Background->None],
 StyleBox["and ",
  Background->None],
 StyleBox["dtw", "Input",
  Background->None],
 StyleBox[" very near zero (where optimal utility is presumed to take place) \
when evaluated at the values of ",
  Background->None],
 StyleBox["\[Rho]", "Input",
  Background->None],
 StyleBox[", ",
  Background->None],
 StyleBox["s", "Input",
  Background->None],
 StyleBox[", ",
  Background->None],
 StyleBox["tw", "Input",
  Background->None],
 StyleBox["? Indeed they are. ",
  Background->None]
}], "Text",
 CellMargins->{{Inherited, 8}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.5305643743548775`*^9, 3.5305643756919537`*^9}, {
   3.531618983945431*^9, 3.531618985092497*^9}, 3.539021635428087*^9, 
   3.5390347459259644`*^9},ExpressionUUID->"f1a607c7-ebc5-4d24-9d9e-\
8f9c09964256"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Rho]", ",", "ds", ",", "dtw"}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Rho]", "\[Rule]", 
         RowBox[{"tv2", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
        RowBox[{"S", "\[Rule]", 
         RowBox[{"tv2", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "3"}], "]"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["t", "w"], "\[Rule]", 
         RowBox[{"tv2", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "14"}], "}"}]}], "]"}], ",", 
   RowBox[{"TableHeadings", "->", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<   \[Rho]\>\"", ",", 
        "\"\<   \!\(\*SubscriptBox[\(\[PartialD]\), \(S\)]\)\>\"", ",", 
        "\"\<   \!\(\*SubscriptBox[\(\[PartialD]\), SubscriptBox[\(t\), \
\(w\)]]\)\>\""}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellMargins->{{Inherited, 9.3125}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{3.539021635429087*^9, 
  3.5390347459259644`*^9},ExpressionUUID->"22c974c1-febf-4ec5-aed1-\
75937b039c67"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"   \[Rho]\"\>",
       HoldForm], 
      TagBox["\<\"   \\!\\(\\*SubscriptBox[\\(\[PartialD]\\), \\(S\\)]\\)\"\>",
       HoldForm], 
      TagBox["\<\"   \\!\\(\\*SubscriptBox[\\(\[PartialD]\\), \
SubscriptBox[\\(t\\), \\(w\\)]]\\)\"\>",
       HoldForm]},
     {"1", "0.375`", 
      RowBox[{"-", "6.554756737386924`*^-13"}], 
      RowBox[{"-", "6.661338147750939`*^-15"}]},
     {"2", "0.4`", "5.293543381412746`*^-13", "1.0602629885170245`*^-14"},
     {"3", "0.425`", 
      RowBox[{"-", "1.4210854715202004`*^-12"}], 
      RowBox[{"-", "1.326716514427062`*^-14"}]},
     {"4", "0.45`", "6.892264536872972`*^-13", "1.2934098236883074`*^-14"},
     {"5", "0.475`", 
      RowBox[{"-", "8.348877145181177`*^-13"}], "2.609024107869118`*^-15"},
     {"6", "0.5`", 
      RowBox[{"-", "7.691625114603085`*^-13"}], "1.9984014443252818`*^-15"},
     {"7", "0.525`", "4.654054919228656`*^-13", "8.881784197001252`*^-16"},
     {"8", "0.55`", "9.059419880941277`*^-14", "1.8318679906315083`*^-14"},
     {"9", "0.575`", "1.0391687510491465`*^-12", "2.503552920529728`*^-14"},
     {"10", "0.6`", "3.232969447708456`*^-13", "2.425837308805967`*^-14"},
     {"11", "0.625`", 
      RowBox[{"-", "1.056932319443149`*^-12"}], 
      RowBox[{"-", "1.5265566588595902`*^-14"}]},
     {"12", "0.65`", 
      RowBox[{"-", "9.14823772291129`*^-13"}], 
      RowBox[{"-", "1.0602629885170245`*^-14"}]},
     {"13", "0.675`", "6.767919558114954`*^-13", "3.4583447217073626`*^-14"},
     {"14", "0.7`", 
      RowBox[{"-", "1.2807532812075806`*^-12"}], 
      RowBox[{"-", "1.6209256159527285`*^-14"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     Automatic, {
      "   \[Rho]", "   \!\(\*SubscriptBox[\(\[PartialD]\), \(S\)]\)", 
       "   \!\(\*SubscriptBox[\(\[PartialD]\), SubscriptBox[\(t\), \
\(w\)]]\)"}}]]]], "Output",
 CellChangeTimes->{3.5411912460802584`*^9, 3.5411913040715756`*^9, 
  3.5416041601024623`*^9, 3.6126968979975257`*^9, 3.697233991769105*^9, 
  3.697235487337145*^9, 3.6972358747370567`*^9, 3.697317853589522*^9, 
  3.69732353215639*^9, 3.698044391193424*^9, 3.6980448311333694`*^9, 
  3.731421555782225*^9},ExpressionUUID->"838c247b-8c65-40c5-a9c9-\
dee066be1128"]
}, Open  ]]
}, Closed]],

Cell["\<\
 Figure 8.4 displays plots of optimal utility for both datasets on the same \
graph for comparison purposes.  \
\>", "Text",
 CellChangeTimes->{{3.530564577046471*^9, 3.5305646251992254`*^9}, 
   3.5390214220868845`*^9, 3.539021635429087*^9, 
   3.5390347459269648`*^9},ExpressionUUID->"2fe10581-3095-45d6-8a10-\
4623e77d136d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"s2", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"pp1", ",", "pp2", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2.589", ",", 
        RowBox[{"-", "0.864"}], ",", "2.000"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"SL2a", "=", 
  RowBox[{"Legended", "[", "\n", " ", 
   RowBox[{"s2", ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".5", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".2", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Simulation #1\>\"", ",", "\"\<Simulation #2\>\""}], 
       "}"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4103597924205*^9, 3.410359792983*^9}, 
   3.410359858561125*^9, {3.410359896873625*^9, 3.41035991845175*^9}, {
   3.410360419654875*^9, 3.410360437233*^9}, {3.410360475842375*^9, 
   3.410360477873625*^9}, 3.530564431274133*^9, 3.539021635429087*^9, 
   3.5390347459269648`*^9, {3.5411911466095695`*^9, 3.541191148824696*^9}, {
   3.6972347496898603`*^9, 3.697234775492506*^9}, {3.6972348144962845`*^9, 
   3.697234885038958*^9}},ExpressionUUID->"abdfcef4-8f68-4ed0-ad9f-\
47a0bd073ef4"],

Cell[BoxData[
 TemplateBox[{Graphics3DBox[{{{{}, {}, 
       TagBox[{
         AbsoluteThickness[2], 
         Hue[0.5, 1, 1], 
         Thickness[Large], 
         Line3DBox[CompressedData["
1:eJwN0Xs81Pkex/EhxbajWjSkkJJc4zeXFPH55lI4wuqySaodt6jIsWUQlRCV
HiEWieTSxUasy1x+O1qhyeJ0FGbcGX7MqHRxC0fn98frn+fj/d9bnx3mFaBI
oVAOkK0g2yOZ2y7K5cLz6PPKznYsFGmqp0yhiGHff8KrE+5x4fHVhfxuWxba
Er9d+6GCGBpffNqyN48LTnX5tkGkt4otzB1XiMG9aG0p7z4XAjcw7iTtIfdJ
6GDyKjHIGzycnjzgwmJJ1I0maxZqH/q1YJ2qGN64t07Gl3LBbt+HDkcrFjLI
KrbS1xbD62cH5vWquJDyX1m5syULdVBMTtszxaBmZkJVfM0F/6SfwgK2sJBZ
F/N1wmkxtHAcNWjfuKDmbdL2SImFQqeTzd9JxGB0n/PEwIAHsaG7Kw7LmOjO
8G23QgcJVGjEra1x40Ggl/HETDsTtRpv1vUpk4D469q+zxd50Dd4tKC1ioky
x6bSBjf2wJvIZVdRHg+sv5ue+ZDNRHbnw18MJ/SA7KmOpWEjD+pFkpUHY5no
t1AsrXy2B9pT1vvZyXgwEJZ1t5TNRC9fXdI4HdgLN1Zcfnx9NR9mDjY1b3Vl
oi9TUV4F7b0gnzglsjHnw6ezz9qmLZio/GYNvRD6oGuA3s5248PKzxmiQU0m
cp192Lb5SR8MuVzd0xnMh7TTJWrZFCai4Bs3pq7rh1iqWVduMh+afG82V44z
kMNMx+rGK/2QaR/aBsV8+HlRJ63lDQMF/s+mhiPrh4E1cyHaf/MB3VKWe3IZ
iBYlVZg/NgCl0u63p/r4IMnbISl8wECDHjQF/5YBiC6uKyGm+RDSxbkuvsFA
yTML/AP0QXA+yzt/Y40Aqvsr76ZEMJBwja6mYtEgCL8rsu5vE0BDsTxG/QQD
hcR8o2mvGoL38+uicFsBTJxU7dXfz0A2xtcitGAIfvL9WH7rkADaj8Sx5ZYM
lJPgZawaOQQa2WlsWrAAxhgZxRc2MVDQq2gclQ2BmZbcKzNOAFO1Rw6lrWKg
JYeGBxLpEHgqJi3MpAnguU61mv8XOlJ4zGZXag2DUCXx5sFiAQhmZayeATrK
4DnHXnYbBm15lk56nQB+zyoTTb6mo0kld1lVwjD4KjQkvRcJYNBG6URhLR39
afUHfRtvGH5/WO+r1SuALIqH02IhHe0tNm5b+jwM346bxHu8F0AFopybS6Wj
48L3L1qMR8Dw0c/KnYsCGDehChNj6Gi8XiW923cELN31YjZRcUhsmdzfEERH
uxcdql2yRqCcZqHZpo2D1uFjT64fpqNFHfGfCy0jUO/wg7nQCAdJxMGaPgc6
cv1YSX24PAI7NLTOnrLC4ZOZRp7Mko5Ozj+tLd8pBcoX+9EsRxyYqz38wvTo
aFS2ZLsQIgVL9RP7w71wqNF+Jamm0pHF+lBaWZEUSnQ5z7+ewEFHM9ryzCKG
5Nt3teaKpVC36y6tMwQHBexVwCM5hugT+3uvUEfBLJLT4x6JQ7fz8UdlYgzt
Hblo0+o4CrPBPmsy4nFwudNeoCbC0IuXy5wjUaPwSWqywu82DsdR548utRha
OViivK9qFKbU/4jKycFB2pDfp1SCoe5H6VOm8lFI7zrnyS/CYdet6Nr1mRja
cFRc7ak7Bt4Dc1U+5TiUJhHU5WsY0re3/afnyBgkeFk/na3D4YxJYzbzNwzl
qC8Ki26OQbrAyUfzbxx2Zq4RjPhjKD99+Ue/+jE4xL7GLW/BIcMsoiXsEIZC
/qX/9PrcGLid5/7l/RaHU5oqiuCEodLJvG2TpgQ0F/8gvkx6TNedxEVHDFm/
TVPrNCNgR7PBhxLSUz1pVC7p7fyk70JzAgY5uPIX0sP9aFsw0mdTzkvSLQhg
295cTnlH/psoDd/qgKF9Ro6p1gwCPkLEV24nDt+EFx6o7MXQuP/kdIo1Abrq
nRR1MQ6VTrlWnXswZDSwu9HIhYCAVuOLu0inZrO000nHm3ZUqrkS4CUIIHxJ
19Jo+u5OuuezrflLpFtIs+oek64XWf9WZIMhziVVzhs3AvIX5jbZSXBoCNYu
wK0xJNIeNuV4EuDmFD8d1INDhIr5y+JdGAr+JTnj1S8E3DLmaqWSbtApf/cr
6ct2sVcqjxLQNi61qiJ9ND5bpkt6uuG/z93zJiDw3uagJdKDwxo25lhhiD/j
sz/Mh4DMOOeUO704sFVdilJ3Ymj1XYtF2kkCLnbsS6wh/axfXKsr6fkxBhOU
UwQkedlf6iGdebFwXpl0ut+GTjnpTleYPgZ9OHTUV3jHszB0jL6iQsgm4Kqi
uYML6XfP5d4G0j9umL/32I8AhWOGhqGkTzaFNy8xMRSv8CE53Z8Aari+Ugbp
bgksBT7pNNnwhUsBBBCYXn8d6eb+Y3aRpD9908UODCTg/7O3dtc=
          "]]}, Annotation[#, "Charting`Private`Tag$2583#1"]& ]}}, {{{}, {}, 
       TagBox[{
         Hue[0.2, 1, 1], 
         AbsoluteThickness[2], 
         Line3DBox[CompressedData["
1:eJwV1Xk8VN8bB3BEKyqJ0GoJdwyDb1QTzwmVLN98VUg/ErIlUQqRtUJFmSRS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          "]]}, Annotation[#, "Charting`Private`Tag$2611#1"]& ]}}}, {
    PlotRange -> All, ViewPoint -> {2.589, -0.864, 2.}, ImageSize -> 300, 
     DisplayFunction -> Identity, Axes -> True, AxesLabel -> {
       FormBox["\"    S(\[Rho])      \"", TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(w\\)]\\)(\[Rho])\"", 
        TraditionalForm], 
       FormBox["\"   \[Rho]\"", TraditionalForm]}, BoxRatios -> {1, 1, 1}, 
     DisplayFunction :> Identity, FaceGrids -> {{0, 0, -1}}, FaceGridsStyle -> 
     Automatic, ImageSize -> 300, Method -> {}, 
     PlotRange -> {{0.09611178375039214, 0.11274289272768775`}, {
      17.20494454479574, 21.24328657623363}, {0.37500000663265304`, 
      0.6999999933673469}}, PlotRangePadding -> {
       Scaled[0.02], 
       Scaled[0.02], 
       Scaled[0.02]}, Ticks -> {Automatic, Automatic, Automatic}, 
     ViewPoint -> {2.589, -0.864, 2.}}],FormBox[
    FormBox[
     TemplateBox[{"\"Simulation #1\"", "\"Simulation #2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.5, 1, 1], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.5, 1, 1], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.2, 1, 1], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.2, 1, 1], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.5, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.5`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.5, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.5], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    Hue[0.20000000000000004`, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.2`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.2, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.2], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& ), Editable -> True], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.410468877717375*^9, 3.410504963734375*^9, 3.5303609782632866`*^9, 
   3.530564434430314*^9, 3.5305723757385306`*^9, 3.5316178515686626`*^9, 
   3.531619481873911*^9, 3.5316197588167515`*^9, 3.533148206154599*^9, 
   3.533236444406324*^9, 3.533240047877431*^9, 3.533683632140625*^9, 
   3.533735314092332*^9, 3.533756231375*^9, 3.539021213895977*^9, 
   3.5390216354400873`*^9, 3.5390347459359655`*^9, 3.53998874522727*^9, 
   3.5401275243810883`*^9, 3.5405612245385294`*^9, 3.54118653481479*^9, 
   3.541187911453529*^9, 3.54118803542862*^9, 3.541191067318034*^9, 
   3.541191165716662*^9, 3.5411912461372623`*^9, 3.541191304132579*^9, 
   3.5416041606554937`*^9, 3.6126968983265443`*^9, 3.6972339917841454`*^9, {
   3.6972348735343657`*^9, 3.6972348913547544`*^9}, 3.6972354873927994`*^9, 
   3.6972358748192744`*^9, 3.6973178536907916`*^9, 3.697323532214545*^9, 
   3.698044391272661*^9, 3.6980448312025476`*^9, 3.731421555849405*^9},
 TextAlignment->Center,ExpressionUUID->"9b9c4eed-6a5a-462c-b7e9-5975c24ffeab"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.4.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Simulations 1 and 2",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.5305644553435097`*^9, 3.530564458907714*^9}, 3.5390216354400873`*^9, 
   3.5390347459359655`*^9},
 TextAlignment->Center,ExpressionUUID->"ea932c9b-44b4-4209-9602-0fa63e7bcdcc"],

Cell["8.4.5. Simulation #3", "Subsection",
 CellChangeTimes->{3.5316190095878983`*^9, 3.5390216354400873`*^9, 
  3.5390347459359655`*^9},ExpressionUUID->"c038a0e6-288b-4b9a-8737-\
f9d3b41990d8"],

Cell[TextData[{
 "Returning to the original values for ",
 StyleBox["\[Beta]", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["\[Gamma]", "Input",
  FontWeight->"Plain"],
 " in ",
 StyleBox["dv1", "Input"],
 ", in ",
 StyleBox["dv3", "Input"],
 " we change the assumption of fixed (25%) percentage of work time to a \
different fixed percentage, 15%. This could be the result of semi-retirement \
from one's job or changing to part-time employment. The procedure for \
creating ",
 StyleBox["frho",
  FontSlant->"Italic"],
 " is repeated using the new data, ",
 StyleBox["dv3 ", "Input"],
 StyleBox["in Table 8.5", "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 "."
}], "Text",
 CellChangeTimes->{{3.5305646485675616`*^9, 3.5305646493086042`*^9}, {
   3.531619177389496*^9, 3.531619180886696*^9}, {3.5332402589915056`*^9, 
   3.5332402732723227`*^9}, 3.5390216354400873`*^9, 3.5390347459359655`*^9, {
   3.5399917675031347`*^9, 
   3.539991774216519*^9}},ExpressionUUID->"408939ab-2f9d-4d6c-bdc2-\
4747d1653607"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"cw", ",", 
    SubscriptBox["c", "w"], ",", "tw", ",", 
    SubscriptBox["t", "w"], ",", "s", ",", "S", ",", "T"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dv3", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"T", "=", "60"}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "\[Rule]", "0.1"}], ",", 
       RowBox[{"\[Beta]", "\[Rule]", "0.4"}], ",", 
       RowBox[{"\[Gamma]", "\[Rule]", "0.5"}], ",", 
       RowBox[{
        SubscriptBox["c", "r"], "\[Rule]", "1200"}], ",", 
       RowBox[{"p", "\[Rule]", "20"}], ",", 
       RowBox[{"r", "\[Rule]", "0.07"}], ",", 
       RowBox[{"wg", "\[Rule]", "120000."}], ",", 
       RowBox[{"H", "\[Rule]", "0.15"}], ",", 
       RowBox[{"W0", "\[Rule]", "50000."}]}], "}"}]}], ")"}]}], ";"}], "\n", 
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<T\>\"", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", 
       "\"\<\!\(\*SubscriptBox[\(c\), \(r\)]\)\>\"", ",", "p", ",", "r", ",", 
       "wg", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"H", ",", "Red"}], "]"}], ",", "W0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "60", ",", "0.1", ",", "0.4", ",", "0.5", ",", "1200", ",", "20", ",", 
       "0.07", ",", "120000.", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"0.25", ",", "Red"}], "]"}], ",", "50000."}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.530564689595908*^9, 3.530564727533078*^9}, {
   3.531619147590791*^9, 3.5316191594444695`*^9}, {3.531619624888091*^9, 
   3.531619628038271*^9}, 3.5390216354400873`*^9, 
   3.5390347459359655`*^9},ExpressionUUID->"aecbe69b-bb98-40e4-aa40-\
6ff0797657f3"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"T\"\>", "\[Alpha]", "\[Beta]", 
     "\[Gamma]", "\<\"\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\)\"\>", "p", 
     "r", "wg", 
     StyleBox["H",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "W0"},
    {"60", "0.1`", "0.4`", "0.5`", "1200", "20", "0.07`", "120000.`", 
     StyleBox["0.25`",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "50000.`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.531618587447753*^9, 3.5316186577567744`*^9, {3.5316186958809547`*^9, 
   3.531618800603945*^9}, {3.531619085032213*^9, 3.531619132623935*^9}, 
   3.5316194819399147`*^9, 3.5316196577069683`*^9, 3.5316197589067564`*^9, 
   3.533148206748633*^9, 3.5332364449053526`*^9, 3.5332400479314337`*^9, 
   3.5336836323125*^9, 3.533735314520356*^9, 3.533756231484375*^9, 
   3.5390212144880104`*^9, 3.5390216354400873`*^9, 3.5390347459359655`*^9, 
   3.539988745886308*^9, 3.540127525052127*^9, 3.540561225455582*^9, 
   3.5411865358098464`*^9, 3.541187911564535*^9, 3.541188035539626*^9, 
   3.5411910674830437`*^9, 3.541191165829668*^9, 3.5411912462532682`*^9, 
   3.5411913042675867`*^9, 3.5416041612255263`*^9, 3.612696898747568*^9, 
   3.6972339918032227`*^9, 3.697235487414853*^9, 3.6972358748528647`*^9, 
   3.6973178537659917`*^9, 3.6973235322356014`*^9, 3.6980443913007097`*^9, 
   3.698044831243637*^9, 3.731421555880488*^9},
 TextAlignment->Center,ExpressionUUID->"d61b89a6-dceb-468b-a425-f0ae92f79366"]
}, Open  ]],

Cell["Table 8.5 Fixed parameter values for simulation #3", "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{131.33333333333331`, 10.}, {1., 7.}},
 CellChangeTimes->{{3.530561082895617*^9, 3.5305610961973777`*^9}, {
   3.5305628115044875`*^9, 3.5305628144376554`*^9}, {3.5305647582438345`*^9, 
   3.5305647612080045`*^9}, 3.5390216354400873`*^9, 3.5390347459359655`*^9},
 TextAlignment->Center,ExpressionUUID->"aca1e518-3289-42f9-9c41-ad48865c24d7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"frho", "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", "r"], "=", 
     RowBox[{"tr1", "/.", "dv3"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"scw", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["t", "r"], "+", 
         SubscriptBox["t", "w"]}], "\[Equal]", "T"}], ",", 
       SubscriptBox["c", "w"]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["c", "w"], "=", 
     RowBox[{
      SubscriptBox["c", "w"], "/.", 
      RowBox[{"scw", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"L", "=", 
     RowBox[{"1", "-", "H", "-", "S"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"uf", "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["c", "w"], "-", "900"}], ")"}], "\[Alpha]"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"L", "-", ".25"}], ")"}], "\[Beta]"], 
       SuperscriptBox[
        SubscriptBox["t", "r"], "\[Gamma]"]}], "/.", "dv3"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"ds", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", "S"], " ", "uf"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"dtw", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       SubscriptBox["t", "w"]], " ", "uf"}]}], ";"}], "\[IndentingNewLine]", 
   ")"}]}], "\n", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tws", ",", "S", ",", 
    SubscriptBox["t", "w"]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ds1", "[", "\[Rho]_", "]"}], "=", "ds"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dtw1", "[", "\[Rho]_", "]"}], "=", "dtw"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tws", "[", "\[Rho]_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Rho]", ",", 
      SubscriptBox["t", "w"], ",", "S"}], "}"}], "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ds1", "[", "\[Rho]", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"dtw1", "[", "\[Rho]", "]"}], "\[Equal]", "0"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"S", ",", ".2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["t", "w"], ",", "40"}], "}"}], ",", 
      RowBox[{"MaxIterations", "\[Rule]", "200"}], ",", 
      RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tv3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tws", "[", "\[Rho]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".375", ",", ".7", ",", ".025"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ftv3", "=", 
   RowBox[{"ListInterpolation", "[", 
    RowBox[{"tv3", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{".375", ",", ".7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"pp3", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ftv3", "[", 
       RowBox[{"\[Rho]", ",", "3"}], "]"}], ",", 
      RowBox[{"ftv3", "[", 
       RowBox[{"\[Rho]", ",", "2"}], "]"}], ",", "\[Rho]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Rho]", ",", ".375", ",", ".7"}], "}"}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", ".9", "]"}], ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<S(\[Rho])      \>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])\>\"", ",", 
       "\"\<   \[Rho]\>\""}], "}"}]}], ",", 
    RowBox[{"FaceGrids", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}], "}"}]}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"2.589", ",", 
       RowBox[{"-", "0.864"}], ",", "2.000"}], "}"}]}]}], "]"}]}]}], "Input",
 CellMargins->{{66, 0}, {5, 10}},
 CellOpen->False,
 CellChangeTimes->{3.530564849822073*^9, 3.5390216354410877`*^9, 
  3.539034745936965*^9, 
  3.5411911990995717`*^9},ExpressionUUID->"6a3a7d32-4346-4a04-b689-\
a7330bdc05f6"],

Cell[BoxData[
 Graphics3DBox[{{}, {}, 
   TagBox[
    {Hue[0.9, 1, 1], AbsoluteThickness[2], Line3DBox[CompressedData["
1:eJwN0Xs0lPsaB/DRJF3oVDSFo6HcplHZ3rmYmXh+SIW07aKIdp1xPbRj7yiV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      "]]},
    Annotation[#, "Charting`Private`Tag$2657#1"]& ]},
  Axes->True,
  AxesLabel->{
    FormBox["\"S(\[Rho])      \"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(w\\)]\\)(\[Rho])\"", 
     TraditionalForm], 
    FormBox["\"   \[Rho]\"", TraditionalForm]},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  FaceGrids->{{0, 0, -1}},
  FaceGridsStyle->Automatic,
  ImageSize->300,
  Method->{},
  PlotRange->{{0.23837920395533968`, 0.28764735227615185`}, {
   19.14774326568978, 27.085229232615077`}, {0.37500000663265304`, 
   0.6999999933673469}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{2.589, -0.864, 2.}]], "Output",
 CellChangeTimes->{3.5305647912907248`*^9, 3.530572376039548*^9, 
  3.531617852760731*^9, 3.5316194822239313`*^9, 3.531619759193773*^9, 
  3.5331482073276663`*^9, 3.533236445504387*^9, 3.5332400482064495`*^9, 
  3.533683632859375*^9, 3.5337353151153903`*^9, 3.533756232046875*^9, 
  3.539021215374061*^9, 3.539021635443088*^9, 3.5390347459379654`*^9, 
  3.539988746896366*^9, 3.5401275260321827`*^9, 3.5405612692410865`*^9, 
  3.5411865368609066`*^9, 3.5411879118615522`*^9, 3.541188035828643*^9, 
  3.54119106777106*^9, 3.541191166119685*^9, 3.5411912071250305`*^9, 
  3.5411912465502853`*^9, 3.5411913045656037`*^9, 3.5416041620675745`*^9, 
  3.6126968997766275`*^9, 3.6972339921701994`*^9, 3.697235487741722*^9, 
  3.6972358751692057`*^9, 3.697317854065789*^9, 3.6973235324983273`*^9, 
  3.6980443915714645`*^9, 3.6980448315173583`*^9, 3.7314215561983323`*^9},
 TextAlignment->Center,ExpressionUUID->"a8b88f17-5d70-48e8-8d40-3acdb668bbac"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.5.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Simulation #3 with H = 15%",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
   3.5305648276488047`*^9}, {3.5305664300914593`*^9, 3.5305664344907107`*^9}, 
   3.539021635443088*^9, 3.5390347459379654`*^9},
 TextAlignment->Center,ExpressionUUID->"577788a2-7c12-4160-9d99-91a3a3c1fa7d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{"tv3", ",", 
     RowBox[{"TableHeadings", "->", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<   \[Rho]\>\"", ",", 
          "\"\<   \!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])\>\"", ",", 
          "\"\<   S(\[Rho])\>\""}], "}"}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellMargins->{{Inherited, 8}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.5332402897572656`*^9, 3.5332403017289505`*^9}, 
   3.539021635443088*^9, 
   3.539034745938965*^9},ExpressionUUID->"0dc04b2c-075e-434d-9be1-\
344873c2bae8"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"   \[Rho]\"\>",
        HoldForm], 
       TagBox["\<\"   \\!\\(\\*SubscriptBox[\\(t\\), \\(w\\)]\\)(\[Rho])\"\>",
        HoldForm], 
       TagBox["\<\"   S(\[Rho])\"\>",
        HoldForm]},
      {"0.375`", "27.085229495903263`", "0.28764735383403334`"},
      {"0.4`", "26.13968031846485`", "0.28201325042883696`"},
      {"0.425`", "25.279795898007382`", "0.2768218738652091`"},
      {"0.45`", "24.493539042219126`", "0.27202357974335467`"},
      {"0.475`", "23.771079459683357`", "0.2675748707416368`"},
      {"0.5`", "23.104308735544723`", "0.2634378693176796`"},
      {"0.525`", "22.486476659079916`", "0.2595796586533017`"},
      {"0.55`", "21.911915587116383`", "0.25597162328520856`"},
      {"0.575`", "21.37582925983609`", "0.2525888439568014`"},
      {"0.6`", "20.874129286938118`", "0.24940956486887933`"},
      {"0.625`", "20.40330726403446`", "0.2464147348057342`"},
      {"0.65`", "19.960333798323152`", "0.2435876164784152`"},
      {"0.675`", "19.5425780628985`", "0.2409134559062023`"},
      {"0.7`", "19.147743163775054`", "0.23837920330039208`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {
      None, {
       "   \[Rho]", "   \!\(\*SubscriptBox[\(t\), \(w\)]\)(\[Rho])", 
        "   S(\[Rho])"}}]]],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+I9JZcZv2S8dGRoaFrAmvnSUWJzkdBC31eOIqEH17H4
vXKM+8fkzQGkQ7uXH2cLeOXI8dZjMjuQDtJ/sRVEc4n9YP0U9MrxQ/5+adng
V453TDjuyQHpBzXn/4JohgbZsu9A+ot0wSaBEBCf5aUUkL7RyLhFNe6V4w/T
vBcgmoHHzl8HSJcZlSr+i3/leCX82hPHhFeOF66vXiea+Mpx9Vrjv25JrxxT
gv6tcAfSFjq1O0C09bxqY08gfSf5mD2IPpZ23RNELyoVDQTR6xdEvBBKfuW4
Q7xZY80roL3ubJyvul87zrb/cRhEM+1P+wLmex75LdTz2tErd8JBUSCd4fZl
T2nva0cepY+fQTTr3zY9+bOvHQEM5JV/
  "],
 TextAlignment->Center,ExpressionUUID->"b40ecbeb-4513-4c02-83e6-7d9bcda02798"]
}, Open  ]],

Cell["Table 8.6 Selected points from Figure 8.5", "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{77.66666666666663, 10.}, {1., 7.}},
 CellChangeTimes->{{3.530562220451681*^9, 3.530562222276786*^9}, {
   3.5305624955614166`*^9, 3.5305625064820414`*^9}, {3.5305643573699064`*^9, 
   3.530564360298074*^9}, {3.530564968711873*^9, 3.530564975622268*^9}, 
   3.539021635444088*^9, 3.539034745938965*^9},
 TextAlignment->Center,ExpressionUUID->"dde15d06-6a06-4270-8372-994049129284"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Beneath this cell again is the test to determine if good solutions \
are found, i.e., are the values of ",
  Background->None],
 StyleBox["ds", "Input",
  Background->None],
 StyleBox[" and ",
  Background->None],
 StyleBox["dtw", "Input",
  Background->None],
 StyleBox[" very near zero when evaluated at the values of ",
  Background->None],
 StyleBox["\[Rho]", "Input",
  Background->None],
 StyleBox[", ",
  Background->None],
 StyleBox["s", "Input",
  Background->None],
 StyleBox[", ",
  Background->None],
 StyleBox["tw", "Input",
  Background->None],
 StyleBox["? They are.",
  Background->None]
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, -138}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.530565032441518*^9, 3.530565046763337*^9}, {
   3.531619221124997*^9, 3.531619222255062*^9}, {3.5332403331637483`*^9, 
   3.53324033493985*^9}, 3.539021635444088*^9, 3.539034745938965*^9},
 TextJustification->0.,ExpressionUUID->"bd2835b8-b670-4860-8e31-8a19e408086d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Rho]", ",", "ds", ",", "dtw"}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Rho]", "\[Rule]", 
         RowBox[{"tv3", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
        RowBox[{"S", "\[Rule]", 
         RowBox[{"tv3", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "3"}], "]"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["t", "w"], "\[Rule]", 
         RowBox[{"tv3", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "14"}], "}"}]}], "]"}], ",", 
   RowBox[{"TableHeadings", "->", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<   \[Rho]\>\"", ",", 
        "\"\<   \!\(\*SubscriptBox[\(\[PartialD]\), \(S\)]\)\>\"", ",", 
        "\"\<   \!\(\*SubscriptBox[\(\[PartialD]\), SubscriptBox[\(t\), \
\(w\)]]\)\>\""}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.539021635444088*^9, 
  3.539034745938965*^9},ExpressionUUID->"1de94bf0-1cae-4000-9162-\
a32c7029dfe2"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"   \[Rho]\"\>",
       HoldForm], 
      TagBox["\<\"   \\!\\(\\*SubscriptBox[\\(\[PartialD]\\), \\(S\\)]\\)\"\>",
       HoldForm], 
      TagBox["\<\"   \\!\\(\\*SubscriptBox[\\(\[PartialD]\\), \
SubscriptBox[\\(t\\), \\(w\\)]]\\)\"\>",
       HoldForm]},
     {"0.375`", "2.842170943040401`*^-14", 
      RowBox[{"-", "2.3037127760972`*^-15"}]},
     {"0.4`", "5.773159728050814`*^-14", 
      RowBox[{"-", "6.106226635438361`*^-16"}]},
     {"0.425`", "1.1368683772161603`*^-13", "1.970645868709653`*^-15"},
     {"0.45`", "0.`", 
      RowBox[{"-", "2.040034807748725`*^-15"}]},
     {"0.475`", "1.6697754290362354`*^-13", 
      RowBox[{"-", "8.604228440844963`*^-16"}]},
     {"0.5`", "1.4832579608992091`*^-13", 
      RowBox[{"-", "5.134781488891349`*^-16"}]},
     {"0.525`", 
      RowBox[{"-", "1.4210854715202004`*^-14"}], 
      RowBox[{"-", "6.50868248186498`*^-15"}]},
     {"0.55`", 
      RowBox[{"-", "1.687538997430238`*^-14"}], "4.6351811278100286`*^-15"},
     {"0.575`", "7.638334409421077`*^-14", 
      RowBox[{"-", "1.942890293094024`*^-15"}]},
     {"0.6`", "1.8562928971732617`*^-13", 
      RowBox[{"-", "1.762479051592436`*^-15"}]},
     {"0.625`", "6.377121053446899`*^-13", "6.161737786669619`*^-15"},
     {"0.65`", 
      RowBox[{"-", "6.297184995673888`*^-13"}], 
      RowBox[{"-", "4.038436252074007`*^-15"}]},
     {"0.675`", 
      RowBox[{"-", "3.268496584496461`*^-13"}], "1.27675647831893`*^-15"},
     {"0.7`", "8.757439218243235`*^-13", 
      RowBox[{"-", "1.8318679906315083`*^-15"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"   \[Rho]", "   \!\(\*SubscriptBox[\(\[PartialD]\), \(S\)]\)", 
       "   \!\(\*SubscriptBox[\(\[PartialD]\), SubscriptBox[\(t\), \
\(w\)]]\)"}}]]]], "Output",
 CellOpen->False,
 CellChangeTimes->{3.410468878717375*^9, 3.410504964109375*^9, 
  3.53036097989938*^9, 3.5305650623272276`*^9, 3.5305723761435537`*^9, 
  3.5316178537187862`*^9, 3.5316194823219366`*^9, 3.53161975931678*^9, 
  3.5331482081597137`*^9, 3.533236447395495*^9, 3.533240048305455*^9, 
  3.53368363303125*^9, 3.533735315936437*^9, 3.53375623225*^9, 
  3.5390212168661466`*^9, 3.539021635444088*^9, 3.539034745938965*^9, 
  3.5399887483404484`*^9, 3.540127527361259*^9, 3.5405612694180965`*^9, 
  3.5411865383729935`*^9, 3.5411879120775647`*^9, 3.5411880359756513`*^9, 
  3.5411910679190683`*^9, 3.541191166256693*^9, 3.541191246789299*^9, 
  3.5411913047366133`*^9, 3.541604163630664*^9, 3.612696900508669*^9, 
  3.6972339922283535`*^9, 3.6972354878149157`*^9, 3.6972358752885227`*^9, 
  3.6973178542191973`*^9, 3.6973235325434203`*^9, 3.6980443917268424`*^9, 
  3.6980448315644836`*^9, 
  3.7314215562655115`*^9},ExpressionUUID->"7a2fcccc-f9d8-4b18-8999-\
c06464d586bf"]
}, Open  ]]
}, Closed]],

Cell[TextData[{
 "Again, combining the plots is instructive.  The last plot indicates that, \
because more time is devoted to leisure as ",
 StyleBox["H",
  FontSlant->"Italic"],
 " declines (because ",
 StyleBox["L",
  FontSlant->"Italic"],
 " = 1 - ",
 StyleBox["H",
  FontSlant->"Italic"],
 " - ",
 StyleBox["S",
  FontSlant->"Italic"],
 "), ",
 StyleBox["ceteris paribus",
  FontSlant->"Italic"],
 ", years spent working prior to retirement increase. Beyond lowering the \
percentage share of time that goes to working, the model does not ",
 StyleBox["distinguish ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 " years spent working less than full time."
}], "Text",
 CellChangeTimes->{
  3.539021635444088*^9, 3.539034745938965*^9, 3.539091956483221*^9, {
   3.5399917868542414`*^9, 3.5399918181440315`*^9}, 
   3.69723419427419*^9},ExpressionUUID->"9d86eea6-dbc7-48b6-af45-\
91b055865a0e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"s3", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"pp1", ",", "pp2", ",", "pp3", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2.589", ",", 
        RowBox[{"-", "0.864"}], ",", "2.000"}], "}"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"SL3a", "=", 
  RowBox[{"Legended", "[", "\n", " ", 
   RowBox[{"s3", ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".5", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".2", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".9", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Simulation #1\>\"", ",", "\"\<Simulation #2\>\"", ",", 
        "\"\<Simulation #3\>\""}], "}"}]}], "]"}]}], "\n", " ", 
   "]"}]}]}], "Input",
 CellMargins->{{Inherited, 8}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.41037490370175*^9, 3.410374941983*^9}, 
   3.41037513957675*^9, 3.530565079197192*^9, 3.539021635444088*^9, 
   3.5390347459399652`*^9, {3.540565353345684*^9, 3.540565374044868*^9}, {
   3.6972349977628503`*^9, 
   3.6972350924497623`*^9}},ExpressionUUID->"e60e2e1f-7b0a-471f-be00-\
a18858dd175c"],

Cell[BoxData[
 TemplateBox[{Graphics3DBox[{{{{}, {}, 
       TagBox[{
         AbsoluteThickness[2], 
         Hue[0.5, 1, 1], 
         Thickness[Large], 
         Line3DBox[CompressedData["
1:eJwN0Xs81Pkex/EhxbajWjSkkJJc4zeXFPH55lI4wuqySaodt6jIsWUQlRCV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          "]]}, Annotation[#, "Charting`Private`Tag$2583#1"]& ]}}, {{{}, {}, 
       TagBox[{
         Hue[0.2, 1, 1], 
         AbsoluteThickness[2], 
         Line3DBox[CompressedData["
1:eJwV1Xk8VN8bB3BEKyqJ0GoJdwyDb1QTzwmVLN98VUg/ErIlUQqRtUJFmSRS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          "]]}, Annotation[#, "Charting`Private`Tag$2611#1"]& ]}}, {{{}, {}, 
       TagBox[{
         Hue[0.9, 1, 1], 
         AbsoluteThickness[2], 
         Line3DBox[CompressedData["
1:eJwN0Xs0lPsaB/DRJF3oVDSFo6HcplHZ3rmYmXh+SIW07aKIdp1xPbRj7yiV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          "]]}, Annotation[#, "Charting`Private`Tag$2657#1"]& ]}}}, {
    PlotRange -> All, ViewPoint -> {2.589, -0.864, 2.}, DisplayFunction -> 
     Identity, Axes -> True, AxesLabel -> {
       FormBox["\"    S(\[Rho])      \"", TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(w\\)]\\)(\[Rho])\"", 
        TraditionalForm], 
       FormBox["\"   \[Rho]\"", TraditionalForm]}, BoxRatios -> {1, 1, 1}, 
     DisplayFunction :> Identity, FaceGrids -> {{0, 0, -1}}, FaceGridsStyle -> 
     Automatic, ImageSize -> 300, Method -> {}, 
     PlotRange -> {{0.09611178375039214, 0.11274289272768775`}, {
      17.20494454479574, 21.24328657623363}, {0.37500000663265304`, 
      0.6999999933673469}}, PlotRangePadding -> {
       Scaled[0.02], 
       Scaled[0.02], 
       Scaled[0.02]}, Ticks -> {Automatic, Automatic, Automatic}, 
     ViewPoint -> {2.589, -0.864, 2.}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"Simulation #1\"", "\"Simulation #2\"", "\"Simulation #3\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.5, 1, 1], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.5, 1, 1], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.2, 1, 1], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.2, 1, 1], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.9, 1, 1], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.9, 1, 1], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.5, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.5`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.5, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.5], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    Hue[0.20000000000000004`, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.2`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.2, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.2], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.9, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.9`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.9], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}]}], "]"}]& ), Editable -> 
      True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.410468878842375*^9, 3.41050496415625*^9, 3.530360980351406*^9, 
   3.5305650827153935`*^9, 3.5305723761995573`*^9, 3.5316178540618057`*^9, 
   3.5316194823669395`*^9, 3.5316197594107857`*^9, 3.533148208481732*^9, 
   3.5332364478235197`*^9, 3.533240048362458*^9, 3.533683633140625*^9, 
   3.5337353162804565`*^9, 3.53375623240625*^9, 3.5390212177942*^9, 
   3.5390216354550886`*^9, 3.539034745948966*^9, 3.539988748904481*^9, 
   3.5401275278372865`*^9, 3.5405612694730997`*^9, {3.5405653541427298`*^9, 
   3.540565374377887*^9}, 3.5411865389900284`*^9, 3.5411879121435685`*^9, 
   3.541188036037655*^9, 3.541191067981072*^9, 3.5411911663186965`*^9, 
   3.541191246851303*^9, 3.5411913048066177`*^9, 3.541604164105691*^9, 
   3.61269690087169*^9, 3.6972339922443705`*^9, 3.6972350837325706`*^9, 
   3.6972354879111853`*^9, 3.6972358753491845`*^9, 3.6973178543144507`*^9, 
   3.697323532606615*^9, 3.698044391829115*^9, 3.69804483168182*^9, 
   3.731421556359761*^9},
 TextAlignment->Center,ExpressionUUID->"6321961c-e688-4828-b754-ab8999268d6a"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.6.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Simulations 1, 2 and 3",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
   3.5305648276488047`*^9}, {3.530565115734282*^9, 3.530565120441551*^9}, 
   3.5390216354550886`*^9, 3.539034745948966*^9},
 TextAlignment->Center,ExpressionUUID->"7124fc55-345e-4310-841a-c81b12d919d9"],

Cell[TextData[{
 "As ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "w"], TraditionalForm]],ExpressionUUID->
  "ed6e1fee-f1fb-4ae3-b60a-6fe90912dc00"],
 " and ",
 StyleBox["s",
  FontSlant->"Italic"],
 " are functions of \[Rho] Figure 8.7 shows how these change with \[Rho]",
 StyleBox[" ", "Input"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["t", "w"]}], TraditionalForm]],ExpressionUUID->
  "ca642bd9-8502-48d5-821a-e1f7e22ae916"],
 " is divided by 100 to permit it to scale closer to the plot of ",
 StyleBox["S(\[Rho]",
  FontSlant->"Italic"],
 ") ",
 StyleBox[")", "Input",
  FontWeight->"Plain"],
 StyleBox[".", "Input"],
 " As one might expect, with an increase in management efficiency, \[Rho], \
less time, ",
 StyleBox["S",
  FontSlant->"Italic"],
 ", is required to attend to real estate duties. Time ",
 Cell[BoxData[
  FormBox[
   RowBox[{"working", ",", 
    SubscriptBox["t", "w"]}], TraditionalForm]],ExpressionUUID->
  "408b1463-13ad-42c7-8363-b9843c4bcb76"],
 ", also declines with increased management efficiency.  The intuition is \
straightforward: the better one is at operating one's rentals the less time \
it takes and the earlier one retires."
}], "Text",
 CellChangeTimes->{{3.530570873311597*^9, 3.53057088630534*^9}, {
   3.531619241945188*^9, 3.531619255844983*^9}, {3.5390216354560885`*^9, 
   3.539021635459089*^9}, {3.539034745949966*^9, 3.5390347459519663`*^9}, {
   3.5399918274915657`*^9, 3.5399919685466337`*^9}, 
   3.5411881327351856`*^9},ExpressionUUID->"e7ab2f93-cf65-4945-b906-\
458e3a58992d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotchanges", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ftv3", "[", 
          RowBox[{"i", ",", "2"}], "]"}], "/", "100"}], ",", 
        RowBox[{"ftv3", "[", 
         RowBox[{"i", ",", "3"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", ".375", ",", ".7"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".4", "]"}], ",", 
           RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", ".9", "]"}], ",", 
           RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], "}"}]}], 
      ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[Rho]\>\"", ",", 
         "\"\<\!\(\*FractionBox[\(\([t, w]\) \((\[Rho])\)\), \(100\)]\) or S(\
\[Rho])\>\""}], "}"}]}]}], "]"}], ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".4", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", ".9", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*FractionBox[\(\([t, w]\) \((\[Rho])\)\), \(100\)]\)\>\"", 
        ",", "\"\<S(\[Rho])\>\""}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.41037580763925*^9, 3.410375817092375*^9}, 
   3.410375859858*^9, 3.410375897561125*^9, 3.5305651689903283`*^9, 
   3.539021635459089*^9, 3.5390347459529657`*^9, {3.6972351497221346`*^9, 
   3.6972351835010014`*^9}, {3.6972352641341763`*^9, 
   3.6972353430142393`*^9}},ExpressionUUID->"e5cd0fc3-8193-4436-90cd-\
366e489b7b7c"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          Hue[0.4, 1, 1], 
          AbsoluteThickness[2]], 
         LineBox[CompressedData["
1:eJwVzXk41AkAxvGhorV4qFYaNdLmnPA0G8Kj10RsoZ2dmhRtbsmmbCfiyTG1
rg6j2kqppFNphfbRauj0m9MMpZkpx4zxy1Vqn9A6pp39432+z+ev1y52NzvB
kEKhhOn3fw/SbY0pFAWen01QVXLkWJLrSK0wUMCNUvRet1EOscLdNXCGAvFF
kZZb9F5y1H9DvpECjbdGC802yCHtiblkYaZAX1j7moMsOZaeqfSyoypgt2eb
IixEjjaKS9LqFQqUUI1ijZlyLOtYIeAmKfA6xYVXtUyOXZ/zXV8q9R6uqI4z
kOOk+njolQAl/Czs2wxVMoidF9Miq5RQsCy3hNfJcLpvpKTbRgUvTaNHVrEM
q1J/a1ZzVahglwk8kmTYt2t5SfWYCnNlS64rmTI8bcmcl5T4BmnB8wMXLpLh
n5F09iXpG9BasvKY462oLqpnXMFbRIdkqFh/tmLdWIVk8a23YDZNp5zf3QpK
o43NMYtOmHDTt+Utb0XAaJvJs+xOzJXcirgwIkXitG992kAnEny7ePtqpbBK
7zX4EtGF9YaOOTf2StH9k5VBvLALZ1077aM8pcgfnXgYxuiGsNjFOlEnAd+c
Nt/wajcGLZVtI08kSD70rxXVqAf7c1IfnSyWwNc5b681euA4q9W7nS3BOS7b
2exgDyK7U+hhNhJsb8lo9K/qgXVrQUNuvxhTAU8uK3t7wMyuHjl8XwyDm7Gx
NdZqjNf+2mGcI0Zpw49Zh0PV0C2O2rnjZzGGZq4fuM9V4+tj2nAdTYxarzsM
+wY1OJ/q1/h/FIFZ6SyZ+qRGsPfdahlfhK384WahswYxnZaf3E6I8K5pNu/1
Lxp0fPQsLogTwXsyoG7tGQ04FIflRh4iTC5S1E4INdC+iL4TaSLCug81phU6
DbbLX4WvVAsR9eX2g2rPXlhOh2zdWC+EdmDKbyK5F0JbRrD5MSHcv9tlVXW1
F2xtqY1trBCDjivF5xW9cDmRk1XjIwSjP/hNtqkWE8nWiyrnCcHUHPAVB2rx
LNjBfNawAM1PdWmb0rXwcZjdVv9CgFnd14yD7mvREdrsM1QuwOsbvBH6oBYe
NK/ujDQBFmxW1LFofbDSCtzpHAHsVvuJVJv6wPB4dO+AuwDn5k7yrxb1od3p
b7nIVIBynu7buKY+7H18Lih0iEByiN3t38f7cOi0W2pmC4HrQxfsh+gkLrMv
zT9+nYBPe8mcV8tItKjo1lPXCEgfHv3KdyVh4yazS9Z7rCBVyXMnIW2IZAVV
EghyCjzm8wMJ+fQ26tcrBN7FD30u8CHRNEmN2XORgFOX9zOntSS2Dh2viTpF
oPG5W82cdSTWFva3SUsJsO5+Xz6lN9vCc9pP77RMszRZKAlfzs2dC3kECKqa
nsbS/0UIHyhPENgRnl/aEk6Ca/3NOKeIgG5VVnbNZhJTJdQbzwsJ8Bz2pJRt
IVFIMY/20PvhaGTw7kgSUf5nhucVEDA55T5pFaV3r2nqy6MEyg8t7adEkxi4
aL49UG9G3IJXg3rnbRxIrDtCIIIx4x4/lkSMt33OKS6BDwu+lN2MI5HgzC2b
qXeuwft8XjyJ8bN/8fflEbAaUO/PTCAxlsQf1OYSuC3riE1MJMHM+MOWo/d/
cABq2Q==
          "]]}, Annotation[#, "Charting`Private`Tag$2718#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          Hue[0.9, 1, 1], 
          AbsoluteThickness[2]], 
         LineBox[CompressedData["
1:eJwV0H0w1AkYB/B1e6VEY7i2cCqOakM6hXD5emm9RTlceWvqvB93qLhUmmvi
tKU1tSltmhwqvRfhLmesSR1p++3vt6nWRnbt7i9vpai8rLb79cczz3zmO/M8
8zw2CVkRyV+xWKwwpr70PQ5LDFksOV5fupNNpslge2i5ZZWBHD1lUX6ZjCVy
Z6cNbDk2ceO/Nf6SF/lE8mfLMe+f8sHAVBkI5c8VpiZy+IfdHxAny2B3+oK7
jaUcPNFUXm2CDDLWyjS/tXLES2jF2XgZHJ+tfViYJkc4Lz6nKFyGzPd8p65u
OcIkGVseuMlwXFUSWunfjaeqUB+fJcx+7tLFcde6sZualXp9jgyntKMn+qwU
6F2eW1L/loJ39s5WVaECh7t1jqSCQk7m9yduflRA+G5hSlkbhbb2/G/SUl7A
qLn0UtANCmOjeyMqiBdYfbfGlz5D4WZxg0slerDydrUFCiiEfKx6vPRKD3YV
XUjamUWB1WxlJTDtxTJ7HVLiKfh/kBndP9iL/JYFHLsgCimfvBryBnvB6197
rNyVAmev2mAy9iUmRrUVAzYU+jZzDJI6X0LsPWY9Pp8C/8N0U5hLH7K20WdE
n0i0zF+88KvqPlyMnBtnO0wiff8Ux3K2EiNC0mSdgoQXt2D3IijBXkKoPTpI
iAojuCZ7lPAaGRjWNJJIbd/X7HNNiUcJpY3sGhIz/vf+6lYrIXA1DbM8TcLg
ckJC7SIVHI8oeWVFJE7eDTrwR6gK5h28Y9V7SAx/vWmwrlCFpoeTq+tSSdxx
v+5if1cFsccsC7MYEr4XuI9n3qkwPlLZlR9MIr5lpLWT24/YoUifHE8Sr8Rz
hM+39cMw94fjVxxJeOj864NP9yNxfNOTMWsSOmv5nenOfrAy7lFZpiRC3tQa
V+n70Rqe4Z/MJrF98mrjTTc1jNmuMaNDUmgGZ9ZPp6tB2yqLYigpnBdkcq5V
q8FruO1u3CjF0PJ1krNyNcQjPMH4OSlcBgJfHDTWYDjwxvWGQil8+3/3kmzQ
IDznqJ00XYrWNn3elr0auHUZvv0cIcWsvouGAXUacPV+klMeUjyvEY46DGng
VTF9hm0jhUW0vD58sRZlbsvafjWSwsZv/SPFFi2Ize4OwWMEROa6lupiLQQc
V655D4HzQv28RLEWvpJ9VqL/CKRvtLl6eEKLH9cs8K64ReDS8Dn7YQcaq9b/
/WrfWQKeT06YPXWk0cn9186aMdFU9LnFiUayKDJVLCLw8Uh2t9CZxqJcfGIz
DlixQeC5hoY44F2GoIzAq6Th90c8adSfWhVVWUpgxUuP+yuCafhMiDY+LiHQ
/GBVrVkIDbXLmEc24/Ab352fYRwl6HQyZ5yXb5JHhtKwMpuyjxEQ6LBUOeSF
0zhe4BWtLSbwy1b+yfatNBqD2tv0fAJ67wMHa6NpHJrqmlvFWLhs12/lMTTY
ZdE/8Rg3fYgLzIqjUTFPPFN8mIBRqbOOs52Zx544ZlHE/Ge/3QBrB41Yvyp9
858EXBItng4xlkS15O5gHOvCvtWSQMM+LSCnppDAG4vJ8suJNDpsa3UhjA8Z
vOYLk2iU2B3lvykgwBlU5eYnM/d0kpZCxlfJZwkpKTSmswvrXBn/D1PZciQ=

          "]]}, Annotation[#, "Charting`Private`Tag$2718#2"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0.375, 0.1914774326568978}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"\[Rho]\"", TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*FractionBox[\\(\\([t, w]\\) \\((\[Rho])\\)\\), \
\\(100\\)]\\) or S(\[Rho])\"", TraditionalForm]}, 
     AxesOrigin -> {0.375, 0.1914774326568978}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.375, 0.7}, {0.1914774326568978, 0.28764735227615185`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*FractionBox[\\(\\([t, w]\\) \\((\[Rho])\\)\\), \
\\(100\\)]\\)\"", "\"S(\[Rho])\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.4, 1, 1], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.4, 1, 1], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.9, 1, 1], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.9, 1, 1], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.4], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    Hue[0.4000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.4`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.4, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.4], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.9, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.9`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.9], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& ), Editable -> True], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.530565170686425*^9, 3.53057237729762*^9, 3.5316178552298727`*^9, 
   3.5316194831699853`*^9, 3.5316197602008305`*^9, 3.5331482096187973`*^9, 
   3.53323645045767*^9, 3.533240049285511*^9, 3.53368363446875*^9, 
   3.5337353176355343`*^9, 3.53375623375*^9, 3.5390212192222815`*^9, 
   3.5390216354690895`*^9, 3.5390347459619665`*^9, 3.5399887502475576`*^9, 
   3.540127529420377*^9, 3.540561270406153*^9, 3.5411865408161325`*^9, 
   3.5411879132126293`*^9, 3.5411880371167164`*^9, 3.5411910691421385`*^9, 
   3.541191167393758*^9, 3.5411912479353647`*^9, 3.5411913058976803`*^9, 
   3.5416041654427676`*^9, 3.612696902076759*^9, 3.6972339922975116`*^9, {
   3.6972353314754257`*^9, 3.6972353445470448`*^9}, 3.69723548802297*^9, 
   3.697235875469003*^9, 3.697317854476883*^9, 3.6973235327118998`*^9, 
   3.69804439195545*^9, 3.6980448318592668`*^9, 3.7314215564690523`*^9},
 TextAlignment->Center,ExpressionUUID->"d179ce96-48ce-4a4f-9af6-31d536c54095"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.7.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Efficiency measures on \[Rho] - Changes in S(\[Rho]) and t",
  FontFamily->"Times New Roman",
  FontSize->12],
 StyleBox["w",
  FontFamily->"Times New Roman",
  FontSize->12,
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox["(\[Rho]) with changes in \[Rho]",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
   3.5305648276488047`*^9}, {3.530565115734282*^9, 3.530565120441551*^9}, {
   3.5305652681770015`*^9, 3.530565281904786*^9}, {3.53056638604994*^9, 
   3.5305663913232417`*^9}, 3.5390216354690895`*^9, 3.5390347459619665`*^9},
 TextAlignment->Center,ExpressionUUID->"2727a463-7463-4fb4-9c1f-c6a7fe72955a"],

Cell["8.4.6. Simulation #4", "Subsection",
 CellChangeTimes->{3.5316192834475617`*^9, 3.5390216354690895`*^9, 
  3.5390347459619665`*^9},ExpressionUUID->"ac9c072d-31c4-4262-ae73-\
f1e9528c8044"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["One can easily claim that retirement time is dependent on \
maintaining a frugal post-retirement lifestyle. To illustrate this we take a \
different approach that fixes \[Rho], then calculates ", "Text",
  FontWeight->"Plain"],
 StyleBox["S", "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[", ", "Text",
  FontWeight->"Plain"],
 StyleBox[Cell[BoxData[
  FormBox[
   SubscriptBox["t", "w"], TraditionalForm]], "Input",
  FontWeight->"Plain",ExpressionUUID->"e4b77e3f-697b-4628-81af-7e2db7c0038c"],
   "Text"],
 StyleBox[", as functions of ", "Text",
  FontWeight->"Plain"],
 StyleBox[Cell[BoxData[
  FormBox[
   SubscriptBox["c", "r"], TraditionalForm]], "Input",
  FontWeight->"Plain",ExpressionUUID->"2def0bfa-6b95-49e1-a39b-33bef596fe5c"],
   "Text"],
 StyleBox[".", "Text",
  FontWeight->"Plain"]
}], "Text",
 CellChangeTimes->{
  3.5332404203407345`*^9, {3.5390216354690895`*^9, 3.5390216354700894`*^9}, {
   3.5390347459619665`*^9, 3.539034745962967*^9}, {3.539991984001518*^9, 
   3.5399919904288855`*^9}},ExpressionUUID->"652e3398-4257-44f8-891d-\
393bb8537d89"],

Cell[TextData[{
 StyleBox[" (Defining a function in ", "Text",
  FontWeight->"Plain"],
 StyleBox["Mathematica", "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" using a subscripted variable is complicated so ", "Text",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "r"], TraditionalForm]], "Input",ExpressionUUID->
  "4239b2d5-b799-4773-b7e7-67a27e473eb8"],
 " becomes ",
 StyleBox["cr", "Input"],
 " for the simulation below)",
 StyleBox[".", "Text",
  FontWeight->"Plain"]
}], "Text",
 CellOpen->False,
 CellChangeTimes->{{3.5390216354700894`*^9, 3.5390216354710894`*^9}, {
  3.539034745962967*^9, 
  3.539034745963967*^9}},ExpressionUUID->"070dfb63-f4a9-411e-8247-\
76b23ca556bf"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"cw", ",", 
    SubscriptBox["c", "w"], ",", 
    SubscriptBox["c", "r"], ",", "tw", ",", 
    SubscriptBox["t", "w"], ",", "s", ",", "S", ",", "T"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dv4", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"T", "=", "60"}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "\[Rule]", "0.1"}], ",", 
       RowBox[{"\[Beta]", "\[Rule]", "0.4"}], ",", 
       RowBox[{"\[Gamma]", "\[Rule]", "0.5"}], ",", 
       RowBox[{"\[Rho]", "\[Rule]", ".7"}], ",", 
       RowBox[{"p", "\[Rule]", "20"}], ",", 
       RowBox[{"r", "\[Rule]", "0.07"}], ",", 
       RowBox[{"wg", "\[Rule]", "120000."}], ",", 
       RowBox[{"H", "\[Rule]", "0.25"}], ",", 
       RowBox[{"W0", "\[Rule]", "50000."}]}], "}"}]}], ")"}]}], ";"}], "\n", 
 RowBox[{"frho", "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", "r"], "=", 
     RowBox[{"tr1", "/.", "dv4"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"scw", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["t", "r"], "+", 
         SubscriptBox["t", "w"]}], "\[Equal]", "T"}], ",", 
       SubscriptBox["c", "w"]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["c", "w"], "=", 
     RowBox[{
      SubscriptBox["c", "w"], "/.", 
      RowBox[{"scw", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"L", "=", 
     RowBox[{"1", "-", "H", "-", "S"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"uf", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["c", "w"], "-", "900"}], ")"}], "\[Alpha]"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"L", "-", ".25"}], ")"}], "\[Beta]"], 
         SuperscriptBox[
          SubscriptBox["t", "r"], "\[Gamma]"]}], "/.", "dv4"}], ")"}], "/.", 
      RowBox[{
       SubscriptBox["c", "r"], "\[Rule]", "cr"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"ds", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", "S"], " ", "uf"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"dtw", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       SubscriptBox["t", "w"]], " ", "uf"}]}], ";"}], "\[IndentingNewLine]", 
   ")"}]}], "\n", 
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<T\>\"", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\[Rho]\>\"", ",", "Red"}], "]"}], ",", "p", ",", "r", 
       ",", "wg", ",", "H", ",", "W0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", "0.1", ",", "0.4", ",", "0.5", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"0.7", ",", "Red"}], "]"}], ",", "20", ",", "0.07", ",", 
       "120000.", ",", "0.25", ",", "50000."}], "}"}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellMargins->{{Inherited, 12.6875}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.530565335669862*^9, 3.5305653720389423`*^9}, {
   3.5316193220577703`*^9, 3.5316194149730844`*^9}, {3.5316194481029797`*^9, 
   3.5316194529642577`*^9}, 3.5316195512878814`*^9, 3.53161969533712*^9, 
   3.531619772730547*^9, 3.53902163547209*^9, 
   3.539034745964967*^9},ExpressionUUID->"1e7d366c-0461-42fe-bc8a-\
4e8ecfb155eb"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"T\"\>", "\[Alpha]", "\[Beta]", "\[Gamma]", 
     StyleBox["\<\"\[Rho]\"\>",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "p", "r", "wg", "H", "W0"},
    {"60", "0.1`", "0.4`", "0.5`", 
     StyleBox["0.7`",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "20", "0.07`", "120000.`", "0.25`", 
     "50000.`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.53161941594814*^9, {3.5316194547553596`*^9, 3.531619483222988*^9}, {
   3.531619557170218*^9, 3.531619583116702*^9}, 3.5316197051866837`*^9, 
   3.5316197602888355`*^9, 3.533148210073823*^9, 3.5332364510017014`*^9, 
   3.533240049461521*^9, 3.53368363465625*^9, 3.533735318130563*^9, 
   3.533756233984375*^9, 3.539021219817315*^9, 3.53902163547209*^9, 
   3.539034745964967*^9, 3.5399887509115953`*^9, 3.5401275303024273`*^9, 
   3.5405612705151596`*^9, 3.5411865417301855`*^9, 3.54118791339464*^9, 
   3.5411880372937264`*^9, 3.541191069333149*^9, 3.541191167593769*^9, 
   3.5411912481263757`*^9, 3.5411913061026917`*^9, 3.5416041661208067`*^9, 
   3.612696902531785*^9, 3.697233992370706*^9, 3.69723548806859*^9, 
   3.697235875535189*^9, 3.6973178546102448`*^9, 3.6973235327560167`*^9, 
   3.698044391996608*^9, 3.6980448319344683`*^9, 3.7314215565552826`*^9},
 TextAlignment->Center,ExpressionUUID->"0b29ebab-4012-4ce4-8e95-0720b0d3f3a8"]
}, Open  ]]
}, Open  ]],

Cell["Table 8.7 Fixed parameter values for simulation #4", "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{82, 10}, {1, 7}},
 CellChangeTimes->{{3.530561082895617*^9, 3.5305610961973777`*^9}, {
   3.5305628115044875`*^9, 3.5305628144376554`*^9}, {3.5305647582438345`*^9, 
   3.5305647612080045`*^9}, {3.530565539202503*^9, 3.530565542171673*^9}, 
   3.53902163547209*^9, 3.539034745964967*^9},
 TextAlignment->Center,ExpressionUUID->"3a031926-04eb-49ab-9fd8-617c4f0cc26f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tws", ",", "S", ",", 
    SubscriptBox["t", "w"]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ds1", "[", "cr_", "]"}], "=", "ds"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dtw1", "[", "cr_", "]"}], "=", "dtw"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"twsa", "[", "cr_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cr", ",", 
      SubscriptBox["t", "w"], ",", "S"}], "}"}], "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ds1", "[", "cr", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"dtw1", "[", "cr", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"S", ",", 
          RowBox[{".2", "+", 
           RowBox[{"0.1", "I"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["t", "w"], ",", 
          RowBox[{"40", "+", "I"}]}], "}"}]}], "}"}], ",", 
      RowBox[{"MaxIterations", "\[Rule]", "200"}], ",", 
      RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tv4a", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"twsa", "[", "cr", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"cr", ",", "900", ",", "1800", ",", "100"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ftv4a", "=", 
   RowBox[{"ListInterpolation", "[", 
    RowBox[{
     RowBox[{"Chop", "[", "tv4a", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"800", ",", "1800"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"pp4", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ftv4a", "[", 
       RowBox[{"cr", ",", "3"}], "]"}], ",", 
      RowBox[{"ftv4a", "[", 
       RowBox[{"cr", ",", "2"}], "]"}], ",", "cr"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"cr", ",", "800", ",", "1800"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", ".7", "]"}], ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<S(\!\(\*SubscriptBox[\(c\), \(r\)]\))   \>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(t\), \(w\)]\)(\!\(\*SubscriptBox[\(c\), \
\(r\)]\))\>\"", ",", "\"\<   \!\(\*SubscriptBox[\(c\), \(r\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"FaceGrids", "->", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}], "}"}]}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"2.589", ",", 
       RowBox[{"-", "0.864"}], ",", "2.000"}], "}"}]}]}], "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.6974215041142282`*^9, {3.697421547890334*^9, 3.6974216180811796`*^9}, 
   3.6974217097509737`*^9, 3.69742184388888*^9, {3.69748107765895*^9, 
   3.697481130544119*^9}, {3.6974812229231186`*^9, 3.697481265643284*^9}, {
   3.6974817196745043`*^9, 3.697481724681978*^9}, {3.697481761418448*^9, 
   3.6974818391363597`*^9}, 3.69748219789839*^9, 3.6974822697593994`*^9, {
   3.697482355473422*^9, 3.6974823741141825`*^9}, {3.6974830517629967`*^9, 
   3.697483067754404*^9}, 3.697565141483163*^9, {3.697565196986326*^9, 
   3.697565212293769*^9}},
 FontColor->GrayLevel[
  0],ExpressionUUID->"bc8692a4-996d-4cac-a6b7-d6d58e5ed7c9"],

Cell[BoxData[
 Graphics3DBox[{{}, {}, 
   TagBox[
    {Hue[0.7, 1, 1], AbsoluteThickness[2], Line3DBox[CompressedData["
1:eJwNz3k81Psex3HJILI1lSLOsVMaM/PLVvT92E+2VGTnIklZjpN0s+VhyyCM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      "]]},
    Annotation[#, "Charting`Private`Tag$2773#1"]& ]},
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"S(\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\))   \"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(t\\), \
\\(w\\)]\\)(\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\))\"", TraditionalForm], 
    FormBox[
    "\"   \\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\)\"", TraditionalForm]},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  FaceGrids->{{0, 0, -1}},
  FaceGridsStyle->Automatic,
  ImageSize->300,
  Method->{},
  PlotRange->{{0.09169430820533693, 0.13842666265127795`}, {15.42049569720624,
    19.571647561036297`}, {800.0000204081632, 1799.9999795918368`}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{2.589, -0.864, 2.}]], "Output",
 CellChangeTimes->{3.6980443921860733`*^9, 3.698044832108963*^9, 
  3.7314215567788754`*^9},
 TextAlignment->Center,ExpressionUUID->"0a72f5e5-bb9d-4f69-b00f-84fa6810ba15"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.8.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Simulation #4 - t",
  FontFamily->"Times New Roman",
  FontSize->12],
 StyleBox["w",
  FontFamily->"Times New Roman",
  FontSize->12,
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox[" and S as functions of c",
  FontFamily->"Times New Roman",
  FontSize->12],
 StyleBox["r",
  FontFamily->"Times New Roman",
  FontSize->12,
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox[" assuming fixed \[Rho]",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
   3.5305648276488047`*^9}, {3.530565115734282*^9, 3.530565120441551*^9}, {
   3.530565584010066*^9, 3.530565587296254*^9}, {3.5305663222572913`*^9, 
   3.530566342809467*^9}, 3.5390216354750896`*^9, 3.5390347459669666`*^9},
 TextAlignment->Center,ExpressionUUID->"96da8de0-62d1-4e47-be3c-7df5095dfbb2"],

Cell[TextData[{
 "Figure 8.8 describes a person with a given, constant level of wealth \
management efficiency.  He may increase consumption during retirement by \
either working longer at his job (delaying retirement) or by spending more \
time working on his rentals. The factor of interest here is the relative \
efficiency or the productivity of spending effort at one's job vs. working on \
one's real estate.",
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 " Neither this model nor its graphic depiction above addresses this, but one \
can see that there are many different ways to approach the problem."
}], "Text",
 CellChangeTimes->{{3.5305657424101257`*^9, 3.530565745841322*^9}, 
   3.5390216354750896`*^9, 
   3.5390347459669666`*^9},ExpressionUUID->"0d73b6cd-aee6-4d60-9ba4-\
8491544aa0ad"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tws", ",", "S", ",", 
    SubscriptBox["t", "w"]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ds1", "[", "cr_", "]"}], "=", "ds"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dtw1", "[", "cr_", "]"}], "=", "dtw"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tws", "[", "cr_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cr", ",", 
      SubscriptBox["t", "w"], ",", "S"}], "}"}], "/.", "\[VeryThinSpace]", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ds1", "[", "cr", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"dtw1", "[", "cr", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"S", ",", "0.2`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["t", "w"], ",", "40"}], "}"}], ",", 
      RowBox[{"MaxIterations", "\[Rule]", "200"}], ",", 
      RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tv4", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tws", "[", "cr", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"cr", ",", 
       StyleBox["900.01",
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox[",",
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox["1800.01",
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox[",",
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox["100",
        FontColor->RGBColor[0, 0, 1]]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ftv4", "=", 
   RowBox[{"ListInterpolation", "[", 
    RowBox[{"tv4", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"800", ",", "1800"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pp4", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ftv4", "[", 
        RowBox[{"cr", ",", "3"}], "]"}], ",", 
       RowBox[{"ftv4", "[", 
        RowBox[{"cr", ",", "2"}], "]"}], ",", "cr"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"cr", ",", "800", ",", "1800"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Hue", "[", ".7", "]"}], ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<S(\!\(\*SubscriptBox[\(c\), \(r\)]\))   \>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(t\), \(w\)]\)(\!\(\*SubscriptBox[\(c\), \(r\
\)]\))\>\"", ",", "\"\<   \!\(\*SubscriptBox[\(c\), \(r\)]\)\>\""}], "}"}]}], 
     ",", 
     RowBox[{"FaceGrids", "->", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2.589", ",", 
        RowBox[{"-", "0.864"}], ",", "2.000"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{"tv4", ",", 
     RowBox[{"TableHeadings", "->", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<   \!\(\*SubscriptBox[\(c\), \(r\)]\)\>\"", ",", 
          "\"\<   \!\(\*SubscriptBox[\(t\), \
\(w\)]\)(\!\(\*SubscriptBox[\(c\), \(r\)]\))\>\"", ",", 
          "\"\<   S(\!\(\*SubscriptBox[\(c\), \(r\)]\))\>\""}], "}"}]}], 
       "}"}]}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 CellMargins->{{Inherited, 8.6875}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.533240571765395*^9, 3.5332405835520697`*^9}, 
   3.5390216354750896`*^9, 3.5390347459669666`*^9, 3.6980446881019773`*^9, {
   3.6980447416644144`*^9, 
   3.6980447858047953`*^9}},ExpressionUUID->"caa1b828-d8b7-4f55-aac3-\
ef020d8f9336"],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"   \\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\)\"\>",
        HoldForm], 
       TagBox["\<\"   \\!\\(\\*SubscriptBox[\\(t\\), \
\\(w\\)]\\)(\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\))\"\>",
        HoldForm], 
       TagBox["\<\"   S(\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\))\"\>",
        HoldForm]},
      {"900.01`", "15.420566301051611`", "0.09169517296362746`"},
      {"1000.01`", "16.084865432455462`", "0.09971655186872674`"},
      {"1100.01`", "16.674973480667703`", "0.10665495610339817`"},
      {"1200.01`", "17.204994855804955`", "0.11274346523411115`"},
      {"1300.01`", "17.685427416969993`", "0.11815004818623186`"},
      {"1400.01`", "18.1242878713341`", "0.1229992333082403`"},
      {"1500.01`", "18.527830690974202`", "0.12738557773747958`"},
      {"1600.01`", "18.90102497783659`", "0.1313823636960122`"},
      {"1700.01`", "19.247880860517114`", "0.1350473978437951`"},
      {"1800.01`", "19.57167894018956`", "0.1384269882516621`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {
      None, {"   \!\(\*SubscriptBox[\(c\), \(r\)]\)", 
        "   \!\(\*SubscriptBox[\(t\), \(w\)]\)(\!\(\*SubscriptBox[\(c\), \
\(r\)]\))", "   S(\!\(\*SubscriptBox[\(c\), \(r\)]\))"}}]]],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{
  3.410468880467375*^9, 3.410504964765625*^9, 3.5303609827185416`*^9, 
   3.5305657676065674`*^9, 3.5305723776416397`*^9, 3.531617856649954*^9, 
   3.5316194835400066`*^9, 3.531619760555851*^9, 3.5331482110238776`*^9, 
   3.533236452016759*^9, 3.5332400496925344`*^9, 3.5332405844061184`*^9, 
   3.53368363509375*^9, 3.533735319016613*^9, 3.5337562344375*^9, 
   3.5390212210393853`*^9, 3.5390216354750896`*^9, 3.539034745967967*^9, 
   3.5399887522466717`*^9, 3.5401275315504985`*^9, 3.5405612707351723`*^9, 
   3.541186543540289*^9, 3.5411879136636553`*^9, 3.541188037560742*^9, 
   3.5411910696031647`*^9, 3.541191167862785*^9, 3.541191248396391*^9, 
   3.5411913063967085`*^9, 3.5416041674618835`*^9, 3.6126969037698555`*^9, 
   3.6972339926043286`*^9, 3.6972358757688017`*^9, 3.697317855012307*^9, 
   3.6973235329364977`*^9, 3.6980443922061167`*^9, 3.6980446898115234`*^9, {
   3.6980447657544775`*^9, 3.698044786840551*^9}, 3.698044832281392*^9, 
   3.731421557012498*^9},
 TextAlignment->Center,ExpressionUUID->"e6f077cf-0894-413f-ac60-fdaf0aa3d125"]
}, Open  ]],

Cell["Table 8.8 Selected points from Figure 8.8", "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{55.33333333333333, 10.}, {1., 7.}},
 CellChangeTimes->{{3.530562220451681*^9, 3.530562222276786*^9}, {
   3.5305624955614166`*^9, 3.5305625064820414`*^9}, {3.5305643573699064`*^9, 
   3.530564360298074*^9}, {3.530564968711873*^9, 3.530564975622268*^9}, {
   3.530565790432873*^9, 3.5305657965332212`*^9}, 3.5390216354760895`*^9, 
   3.539034745967967*^9},
 TextAlignment->Center,ExpressionUUID->"2256e4e3-7e3a-4b90-a9ae-5ad0cc858e8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.5. The constant wealth model", "Section",
 CellChangeTimes->{
  3.531619818425161*^9, {3.5337357325182643`*^9, 3.5337357375425515`*^9}, 
   3.5390216354760895`*^9, 
   3.539034745967967*^9},ExpressionUUID->"3c186938-3ad7-445a-bb30-\
13268dcab52c"],

Cell["\<\
Alternatively, the agent may prefer to leave behind whatever estate he \
amasses during working years, spending only income during retirement.  This \
problem is simpler. In fact, if retirement consumption and retirement return \
are both known, it is straightforward to calculate the required wealth and \
from that determine the time necessary to spend working.\
\>", "Text",
 CellChangeTimes->{3.530565936759242*^9, 3.5390216354760895`*^9, 
  3.539034745967967*^9},ExpressionUUID->"a4ed5ad7-fa0d-4b10-9728-\
957e8846339a"],

Cell["\<\
To make the problem more interesting we assume that real estate investment \
continues into retirement.  This means that there are two ways the retiree \
may spend his post working days - leisure or working on his property. This \
model defines some new terms\
\>", "Text",
 CellChangeTimes->{{3.530565936759242*^9, 3.530565938174323*^9}, {
   3.530565973746358*^9, 3.5305659838999386`*^9}, 3.5390216354760895`*^9, 
   3.539034745967967*^9},ExpressionUUID->"31fc627c-4f34-48e2-81ed-\
3c5d809253b2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(S\), \(r\)]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(L\), \(r\)]\)\>\"", ",", "\"\<ur\>\"", 
          ",", "\"\<drs\>\"", ",", "\"\<sru\>\"", ",", "\"\<cru\>\"", ",", 
          "\"\<wwe\>\""}], "}"}], ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"\"\<=\>\"", ",", "7"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<portion of time during retirement devoted to working on real \
property investments, the time remaining after \
\!\(\*SubscriptBox[StyleBox[\"L\",FontSlant->\"Italic\"], \
StyleBox[\"r\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<leisure during retirement\>\"", ",", 
          "\"\<utility function during retirement, a function of the form \
\!\(\*StyleBox[\"u\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"(\",FontSlant->\
\"Italic\"]\)\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\",\"\
,FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"y\",FontSlant->\"Italic\"]\)\!\(\*\
StyleBox[\")\",FontSlant->\"Italic\"]\)=\!\(\*SuperscriptBox[StyleBox[\"x\",\
FontSlant->\"Italic\"], \
\"\[CurlyPhi]\"]\)\!\(\*SuperscriptBox[StyleBox[\"y\",FontSlant->\"Italic\"], \
\"\[Omega]\"]\), where \!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\) = \
\!\(\*SubscriptBox[StyleBox[\"c\",FontSlant->\"Italic\"], \
StyleBox[\"r\",FontSlant->\"Italic\"]]\) and \!\(\*StyleBox[\"y\",FontSlant->\
\"Italic\"]\) = \!\(\*SubscriptBox[StyleBox[\"L\",FontSlant->\"Italic\"], \
StyleBox[\"r\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<partial derivative of utility with respect to \
\!\(\*SubscriptBox[StyleBox[\"S\",FontSlant->\"Italic\"], \
StyleBox[\"r\",FontSlant->\"Italic\"]]\)\>\"", ",", 
          "\"\<portion of time spent working on real estate when utility is \
maximum (given certain data)\>\"", ",", 
          "\"\<retirement consumption when utility is maximum and real estate \
time is \!\(\*StyleBox[\"sru\",FontSlant->\"Italic\"]\) (given certain \
data)\>\"", ",", 
          "\"\<required wealth available at retirement given \
\!\(\*StyleBox[\"cru\",FontSlant->\"Italic\"]\), \
\!\(\*StyleBox[\"sru\",FontSlant->\"Italic\"]\) and the data\>\""}], "}"}]}], 
       "}"}], "]"}], ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.533240631867833*^9, 3.5332406784104953`*^9}, {
   3.533240708973243*^9, 3.533240825832927*^9}, {3.533240871056514*^9, 
   3.5332409459547977`*^9}, 3.5390216354760895`*^9, 3.539034745967967*^9, {
   3.541189793169157*^9, 
   3.541189867913432*^9}},ExpressionUUID->"678a20bd-eead-41ef-b5be-\
1c9e7e815850"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\\!\\(\\*SubscriptBox[\\(S\\), \\(r\\)]\\)\"\>", "\<\"=\"\>", \
"\<\"portion of time during retirement devoted to working on real property \
investments, the time remaining after \
\\!\\(\\*SubscriptBox[StyleBox[\\\"L\\\",FontSlant->\\\"Italic\\\"], \
StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>"},
     {"\<\"\\!\\(\\*SubscriptBox[\\(L\\), \\(r\\)]\\)\"\>", "\<\"=\"\>", \
"\<\"leisure during retirement\"\>"},
     {"\<\"ur\"\>", "\<\"=\"\>", "\<\"utility function during retirement, a \
function of the form \
\\!\\(\\*StyleBox[\\\"u\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\
\"(\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\",\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\\
(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\\!\\(\\*StyleBox[\\\")\\\
\",FontSlant->\\\"Italic\\\"]\\)=\\!\\(\\*SuperscriptBox[StyleBox[\\\"x\\\",\
FontSlant->\\\"Italic\\\"], \
\\\"\[CurlyPhi]\\\"]\\)\\!\\(\\*SuperscriptBox[StyleBox[\\\"y\\\",FontSlant->\
\\\"Italic\\\"], \\\"\[Omega]\\\"]\\), where \
\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\) = \
\\!\\(\\*SubscriptBox[StyleBox[\\\"c\\\",FontSlant->\\\"Italic\\\"], \
StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]]\\) and \\!\\(\\*StyleBox[\\\"y\
\\\",FontSlant->\\\"Italic\\\"]\\) = \
\\!\\(\\*SubscriptBox[StyleBox[\\\"L\\\",FontSlant->\\\"Italic\\\"], \
StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>"},
     {"\<\"drs\"\>", "\<\"=\"\>", "\<\"partial derivative of utility with \
respect to \
\\!\\(\\*SubscriptBox[StyleBox[\\\"S\\\",FontSlant->\\\"Italic\\\"], \
StyleBox[\\\"r\\\",FontSlant->\\\"Italic\\\"]]\\)\"\>"},
     {"\<\"sru\"\>", "\<\"=\"\>", "\<\"portion of time spent working on real \
estate when utility is maximum (given certain data)\"\>"},
     {"\<\"cru\"\>", "\<\"=\"\>", "\<\"retirement consumption when utility is \
maximum and real estate time is \
\\!\\(\\*StyleBox[\\\"sru\\\",FontSlant->\\\"Italic\\\"]\\) (given certain \
data)\"\>"},
     {"\<\"wwe\"\>", "\<\"=\"\>", "\<\"required wealth available at \
retirement given \\!\\(\\*StyleBox[\\\"cru\\\",FontSlant->\\\"Italic\\\"]\\), \
\\!\\(\\*StyleBox[\\\"sru\\\",FontSlant->\\\"Italic\\\"]\\) and the data\"\>"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{3.5411898696905336`*^9, 3.5411900248564086`*^9, 
  3.541191069662168*^9, 3.541191167919788*^9, 3.541191248460395*^9, 
  3.5411913064507113`*^9, 3.5416041683029313`*^9, 3.6126969043138866`*^9, 
  3.697233992616386*^9, 3.6972358757803316`*^9, 3.697317855082494*^9, 
  3.6973235329485245`*^9, 3.698044392231201*^9, 3.698044832298435*^9, 
  3.7314215570345573`*^9},ExpressionUUID->"ba2a9c5d-23a4-4b2e-ba23-\
bcd2b0c9c928"]
}, Open  ]],

Cell[TextData[{
 "One effect of this is to replace ",
 StyleBox["r",
  FontSlant->"Italic"],
 " in the no bequests model with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Rho]", " ", 
    FractionBox[
     SubscriptBox["S", "r"], 
     RowBox[{
      SubscriptBox["S", "r"], "+", "1"}]]}], TraditionalForm]],
  ExpressionUUID->"1665c386-5c9a-495a-a61f-9e64f06c0508"],
 ", the function that leaves the investor's entrepreneurial abilities a \
factor after retirement.  It is probable that as the investor ages he will \
\"slow down\" with age and become less willing or able to attend to property \
matters. At some time ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Rho]", " ", 
    FractionBox[
     SubscriptBox["S", "r"], 
     RowBox[{
      SubscriptBox["S", "r"], "+", "1"}]]}], TraditionalForm]],
  ExpressionUUID->"9d9fe622-4246-4345-9cee-488d26201c32"],
 " should drop to ",
 StyleBox["r",
  FontSlant->"Italic"],
 ", indicating that the owner's efforts are no longer adding to value in \
excess of those available from non-real estate passive investments bearing a \
predetermined return.  This would be a signal to sell property."
}], "Text",
 CellChangeTimes->{{3.530565936759242*^9, 3.530565938174323*^9}, {
   3.530565973746358*^9, 3.530566000605894*^9}, {3.530566247508016*^9, 
   3.5305662722104287`*^9}, 3.531619858521454*^9, {3.53902163547709*^9, 
   3.53902163548009*^9}, {3.5390347459689674`*^9, 3.539034745972967*^9}, {
   3.5399920285460653`*^9, 3.53999213177697*^9}, {3.5411900467016582`*^9, 
   3.541190049549821*^9}},ExpressionUUID->"6af6856d-03c6-4097-a9cc-\
9aa76fb4b044"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["S", "r"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TagBox[
   SubscriptBox["L", "r"],
   "NotationTemplateTag",
   BaseStyle->"NotationTemplateStyle"], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.53902163548009*^9, 
  3.539034745972967*^9},ExpressionUUID->"0fb15e0e-fa50-4f2b-be02-\
7ba24c1414d0"],

Cell["\<\
Equation 8.7 is the utility function that describes this investor\
\[CloseCurlyQuote]s problem\
\>", "Text",
 CellChangeTimes->{{3.530566655054326*^9, 3.530566672146304*^9}, 
   3.53902163548009*^9, 
   3.539034745972967*^9},ExpressionUUID->"8e03c15b-13e5-491f-bfcc-\
911ed220b624"],

Cell[BoxData[
 FormBox[Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0003<00@0006`000010000oooooj/4003Q0000
0000000000044`00^@<00215CDH0004003<009H0000500000000000000000000`180080H003;0000
2P4000000000000000000<0I0`0[3@@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000G00005000015CDH[8T0400`0000000007T0900`000000000940100`000000000
<4020100000400000020?b501`0<0000000000A0000<0000000001H0000<0000600000X0000@0000
ooooo`4000090000400007h4003R00009@0000`0000>00209@0000`0000>00204P0000`000010000
DP00070100010000Y?ooo`0000000000000009010000000014008T<0H@1/06T0HP1b06T000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000B;Hb0>2g<P1`Rbl2O;@b0?AO`f7P]c80
80000=Bd<P3oooooa;Lb05be<P15n/aQe;@b0>2g<P0P0000oooooo`2;@:jn/aQ0@000000001H0P00
9@0003L^T040008?1@820P@30PCo0P3Qoj`0@0T000000000W`40000000130640K01Y0680LP000000
0000000000000000000000Be<P2F@lIQ2P000?ooomm0]C804Vc4HEBe<P20/KQRK;Db0?`2;@8P0Rd2
I7H02000000U000030000040000U000030000040000U000030000040000H000030000000009D0000
E0000040003ooooo=P0006h000010000EEF7@=^fQd000000E`000040001<00001000000000000000
OP@00>40001@0000800003H0000H00003000000000960000:00001`00017A4U30P000?koool00000
O`@00>@000000000AP0003P:000/2P00ADe6:bY0000T000060000000P3l000200000P000P3l0080o
0020_b501@0<0000000000Q000FD2@00R0T0008@`=/200000P000609003GcLJJ00000000@15P0`09
0000035<000100T000>`10000P0:0@00000500000P4100001@000042oooo00D0000^0AT000050000
2`8000001@0000`2H0=04A<0000V1Pl0703ooooo001=01000030oooo[oooo`0A000?0`002`0002H6
3`0<04eQM6QDNG1U003000D000090P000085000050;D0TH070000?/2g_j30000002@0@0000400P0@
DgU]HVm/07M00000<`P:]AI3b7LO@lQg8<3:M`00<0040000;@4000T0000b2P0000010000:7T000D0
000D0]@2T`8L0000n`;NoX<00000090100000@02011CNFeRKf`0Md00002b3PXi5T?8Mam3b7LP`<Yg
000`00@0000]0@4010000?0100090000<PX000000@0002Ui0005000050;l0JP470000?/22OkS0000
002@0@0000400P0@DgU]HVm/07M00000<`P:]QI3b7LO@lQg8<3:M`00<0040000;@4000@0003`0@40
2@00038:00000040000XN@001@0001@2o05h21`0003k0PWnh`000000T0400001008045=iKF9_K01g
@0000;8>2SXF@lQg7d?8Mb30bWL00300100002d10@040000l04000T0000b2P0000010000:GT000D0
000D0_`1J`XL0000n`89o^<00000090100000@02011CNFeRKf`0Md00000c20Zg5T?8Mam3b7LP`<Yg
000`00@0000]0@0010000?010@090000<PX000000@0002Qi0005000050;l0Dl<70000?/22OkS0000
002@0@0000400P0@DgU]HVm/07M00000/Ph:>aI3b7LO@lQg8<3:M`00<0040000;@4100@0003`0@00
2@00038:00000040000YN@001@0001@2o06^3A`0003k0PWnh`000000T0400001008045=iKF9_K01g
@00003<82[PF@lQg7d?8Mb30bWL00300100002d100040000l04100T0000b2P0000010000:7T000D0
000D0_`1``lL0000n`89o^<00000090100000@02011CNFeRKf`0Md00002b3PXl5T?8Mam3b7LP`<Yg
000`00@0000]0@4010000?0100090000<PX000000@0002Ui0005000050;40XH170000?/28_l00000
002@0@0000000P0@E6U]IG<PCVEg859_KF5^01I3b7LO@lQg8<3:M`00<0040000;@4000@0003`0@40
2@00038:00000040000/NK`11@0001@2h05b1Q`0003k0X3n00000000T0400000008045AYKFEc84iU
Mb1BKfeQKP0F@lQg7d?8Mb30bWL00300100002d10@040000l04000T0000b2P0000010000;7T00`D0
000D0_h26@4L0000n`9Oo`00000009010@000002011DJFeULb1>IGLPDVm]HFh05T?8Mam3b7LP`<Yg
000`00@0000]0@0010000?010@0:0000<PX000000P00079b30520@D0000D0T<2j0DL0000n`8Ro`00
000009010@000002011DJFeULb1>IGLPDVm]HFh05T?8Mam3b7LP`<Yg000`00@0000]0@4010000?01
000=0000<PX000001000079bLW;/0ML3M0>l0@D0000D0/@2Y00L0000n`8Ro`00000009010@000002
011DJFeULb1>IGLPDVm]HFh05T?8Mam3b7LP`<Yg000`00@0000]0@0010000?010@0:0000<PX00000
0P0005=S8@6l0@D0000D0^01@00L0000n`:0oP00000009010@000002011DJFeULb1>IGLPDVm]HFh0
5T?8Mam3b7LP`<Yg000`00@0000]0@4010000?01000E0000<PX000002@0004eQN7EbHdaSC00n0L00
f03006/1c@7f0eD300<5000050;j0<H<70000?/28_l00000002@0@4000400P0@DgU]HVm/07M00000
<`P:_1I3b7LO@lQg8<3:M`00<0040000;@4000@0003`0@402P00038:00000080001ZMVT3_0450000
50;P0D/970000?/2P?h00000002@0@0000400P0@DgU]HVm/07M00000/Ph:@1I3b7LO@lQg8<3:M`00
<0040000;@4100@0003`0@002@00038:00000040000mMP032P4002H63`090TeQM6QDNG1UEEGm0@D1
00D0A5==E3D001=GJFi1K6a2HG=YHd=_I6E@HFMUL`0A1EAYKFEc84iUMb1BKfeQKP0A0e=iKF9_K00A
1D=_MG9YIG8PCVEg0144CE@PAGQdLV404P088Bm5Sd@_@E3d40m7Gd5@lQlN@E3d5@m10?A5m2GdSd9O
@@3d40m3Gd40m8m5m2YOB?B?@@3d40m0m8m1OdSd40m1:Um4GdGdGdGdGd4?30400@010P820P020041
0@03004010002P400`0G40010080Pdd00P23H@0208=h000;0@03004300400P23D`0301/000`10080
Pg80004100/2088/0080Pf<00`0K000<0@0208=b00010@002`80URP00P2F:@00004100X209P2k`80
PgD00P23LP03004300400P23H`0301/000/10080Pg80004100X2088/0080Pd`00`0K000;0@0208=b
00010@002P80URP00P2F:@000PB6?@0m0`010`010080Pf<00`0K000;0@0208=b00010@002P80URP0
0P2F:@000`0L000;0@410084Q=D3JP002P<00@<00@0208=<00<06`002`400P23LP000@4000X209HX
0080URT000<070002`410@0218CF0gH0000000/0000V1Pl0303ooooo0@000000000L0000n`8@00L0
00000;`2000000420R9CNG=dIFd000002P0Q08X100000000002liQ80:D;8M`@0000]0@0010000?01
0@0300000008@048900001P000024<3K0@0000<00000000000000000000K@000@00003@000010000
0P00000000000000002:A@00F4@300000:RZ_[nZZSnY`Xm4_jZZ?`2XZ[jY:V=38@0000P0001R0000
30000040000:000040000000000000008@0000P0001R000030000040000A0000300000P0000:0000
40000000000000002@00010000104@00H0<000`0000@00000@000000000;0000400007h4003R0000
8@0000P0000U0000300000L0080U000030000000080F000030000000000H000030000000000I0000
30000?ooo`0D0000300000d0001B0000L0400080002Toooo0000000000000000T04000000007@00R
@`1Q06`0J@1R0780J@00000000000000000000000000000000000000000000000000000000000000
00000000FGD000000000000000000000000000000000000000000?ooool000000000000000000000
000000000000000000000000000000000000000000010000ooooo`000000000000000>2@O0D0P810
YQ4Q@100T0400000000b01Q`E`<^?G=[g:4b0=`kLf/LXS801000000000000?0o0000000000000000
0000000000000?0o00000000ND0000000820@0000000000000000000001/heegP3hmN000002L0Fd0
001]081R?`VXmW@5B@0Y0<_@001TMP08000002D0000<00000P000180000<00000@0001T0000<0000
oooo01H0000<00006@0000X0000@000000000000000900004000040A001P0`00600000`000000000
6`00010000160000e0800580001`0@000`000=knoon3000000000000002@0@0000000PL2011C07T0
K@1R06l0K00000000000000000000000000000000000000000000000000000000000000000000000
000b068nFGD20000YQ4Q@1T0/06L?5Ue000C000hC`P10000f:Hb0=XaaV4:000003Q?2040002TX380
P05MM@iLF7GPFeQeY:0b06@10000000000000234>PT4000000000?DL2PM<XS80HeaHM@00002Toooo
00000000000007`500000:HA8D3e70X70P000:Coool0000000000000002@0@00000000M002930640
K01Y0680LP1Y00000000000000000000000000000000000000000000000000000000000000000000
001IM@0000000000000006Af00P000009@0000`000030000E00005@0000C0000L@0002@0003<0000
0@000>?hS3mBohdo0000000000010000C00000000000000000000?ooooooooooD00002S`00000000
6`000100002C0P00e0800580001`0@0010000=knoon3000000000000002@0@0000000PL2011C07T0
K@1R06l0K00000000000000000000000000000000000000000000000000000000000000000000000
0000000000000380HSiIM@80002V4B506@2`0I`lFGD001<003Q?2040003HYS80fS76H@X00000>4l8
000002X0002V4B50V9Ag0>80V0:HU7L0000002S`001/heegl3dmN000002D0Fd0001]04bR<P1SG5Qe
0P1^07X:0000000000000000O0D000000`0J07X:00020000Y?oook20K@0000001000090100000000
V3Qc0:1mK@2dOVd0001g0321K@000000T:0b00000034XC80cAiRMja>DPonooooK>=MMm;PGGL00000
e02H0P00000005Ue000006Af00P000009@0000`000040000:00000`000030000E00005@0002]0000
L@000;d0003<00000@000>?hS3mBohdo0000000000010000C00000000000000000000?oooooooooo
D00002W`000000006`000100002X1000o0400580001`0@000`0000WnoooS000000000000002@0@00
00000PL2011C07T0K@1R06l0K0000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000<P1R?UUe0P000:HA8D0I0;01W3aIM@004`00>4l8
0@000=RV<P3J<LIQ000002X0002V4B50V9Ag04H1V0:HU7L0000002W`M`1/heegl3dmN000002D0Fd0
001]09@1K@0006d00P1^07/:000006h0NPX00000000000000`0J07/:000301X0NPX00;20K@000000
10000:QPO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0T:0b00400034XC80cAiRMja>DPonoooo
K>=MMm;PGGL00000>06H0P00000006d0000006Af00P000009@0000`000030000:00000`000040000
E00005@0000g0@000@0005H1002Q00000@000>?hS3mBohdo0000000000010000C000000000000000
00000?ooooooooooD00002S`000000006`000100001h2000o0400580001`0@00100000WnoooS0000
00000000002@0@0000000PL2011C07T0K@1R06l0K000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000b068nFGD20000
YQ4Q@1T0/06L?5Ue000C000hC`P10000000002X0002V4B50V9Ag0:X1V0:HU7L0000002S`M`1/heeg
l3dmN000002D0Fd0001]09@1K@0006d00P1^07`:000006h0N`X00000KP1j2P000`0J07`:000301X0
N`X00;20K@000000100008QPO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0T:0b00400034XC80
cAiRMja>DPonooooK>=MMm;PGGL00000W06H0P00000006d0000006Af00P000009@0000`000040000
:00000`000030000E00005@0000f0P000@000582002Q00000@000>?hS3mBohdo0000000000010000
C00000000000000000000?ooooooooooD00002W`000000006`000100001[2P00o0400580001`0@00
0`0000WnoooS000000000000002@0@0000000PL2011C07T0K@1R06l0K00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000380HSiIM@80002V4B506@2`0I`lFGD001<0000002X0002V4B50V9Ag00h2V0:HU7L0
000002W`M`1/heegl3dmN000002D0Fd0001]09@1K@0006d00P1^07d:000006h0O0X00000KP1k2P00
0`0J07d:000301X0O0X00;20K@00000010000:QPO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0
T:0b00400034XC80cAiRMja>DPonooooK>=MMm;PGGL0000000:H0P00000006d0000006Af00P00000
9@0000`000030000:00000`000040000E00005@0002h0P000@000=L2002Q00000@000>?hS3mBohdo
0000000000010000C00000000000000000000?ooooooooooD00002S`000000006`000100001?3000
o0400580001`0@00100000WnoooS000000000000002@0@0000000PL2011C07T0K@1R06l0K0000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000<P1R?UUe0P000:HA8D0I0;01000002X0002V4B50
V9Ag0782V0:HU7L0000002S`M`1/heegl3dmN000002D0Fd0001]09@1K@0006d00P1^07h:000006h0
O@X00000KP1l2P000`0J07h:000301X0O@X00;20K@000000100008QPO@D00000V3Qc0:1mK@2dOVd0
001g0321K@0007L0T:0b00400034XC80cAiRMja>DPonooooK>=MMm;PGGL00000I0:H0P00000006d0
000006Af00P000009@0000`000040000:00000`000030000E00005@0000f0`000@000583002Q0000
0@000>?hS3mBohdo0000000000010000C00000000000000000000?ooooooooooD00002W`00000000
6`000100002^3@00o0400580001`0@000`0000WnoooS000000000000002@0@0000000PL2011C07T0
K@1R06l0K00000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000b068nFGD20000
000002X0002V4B50V9Ag0=H2V0:HU7L0000002W`M`1/heegl3dmN000002D0Fd0001]09@1K@0006d0
0P1^07l:000006h0OPX00000KP1m2P000`0J07l:000301X0OPX00;20K@00000010000:QPO@D00000
V3Qc0:1mK@2dOVd0001g0321K@0007L0T:0b00400034XC80cAiRMja>DPonooooK>=MMm;PGGL00000
b0:H0P00000006d0000006Af00P000009@0000`000030000:00000`000040000E00005@0002A0`00
0@000;03002Q00000@000>?hS3mBohdo0000000000010000C00000000000000000000?oooooooooo
D00002S`00P000006`00010000333`00o0400580001`0@00100000WnoooS000000000000002@0@00
00000PL2011C07T0K@1R06l0K0000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000380000002X0002V4B50V9Ag03X3V0:HU7L0000002S`M`1/heegl3dmN000002D0Fd0
001]09@1K@0006d00P1^080:000006h0O`X00000KP1n2P000`0J080:000301X0O`X00;20K@000000
100008QPO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0T:0b00400034XC80cAiRMja>DPonoooo
K>=MMm;PGGL00000;0>H0P00000006d0000006Af00P000009@0000`000040000:00000`000030000
E00005@0000L10000@0003P4002Q00000@000>?hS3mBohdo0000000000010000C000000000000000
00000?ooooooooooD00002W`000000006`00010000260@00a0800580001`0@000`0002;oool00000
00000000002@0@00000000L2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000002X0002V4B50V9Ag09h3V0:HU7L0000002W`M`1/heeg
l3dmN000002D0Fd0001]09@1K@0006d00P1^084:000006h0P0X00000KP1o2P000`0J084:000301X0
P0X00;20K@00000010000:QPO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0T:0b00400034XC80
cAiRMja>DPonooooK>=MMm;PGGL00000T0>H0P00000006d0000006Af00P000009@0000`000030000
:00000`000040000E00005@0001W0000Q0000=X0003600000@000>?hS3mBohdo0000000000010000
C00000000000000000000?ooooooooooD00002`0002l0@006`000100001b1P00h0400580001`0@00
1000083nool0000000000000002@0@00000000L2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>@4002V4B50V9Ag0084V0:HU7L0
000002`0M`1/heegl3dmN000002D0Fd0001]09@1K@0006d00P1^088:000006h0P@X00000KP202P00
0`0J088:000301X0P@X00;20K@000000100008QPO@D00000V3Qc0:1mK@2dOVd0001g0321K@0007L0
T:0b00400034XC80cAiRMja>DPonooooK>=MMm;PGGL00000m0>H0P00000006d0000006Af00P00000
9@0000`000040000:00000`000030000E00005@0002_0@00900007H2002E00000@000>?hS3mBohdo
0000000000010000C00000000000000000000?ooooooooooD00002`000000`006`000100000I0@00
oP800580001`0@000`0005ooool0000000000000002@0@000@0000L2011D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>@4002V4B50
V9Ag06H4V0:HU7L0000002`0M`1/heegl3dmN000002D0Fd0001]09@1K@0006d00P1^08<:000006h0
PPX00000KP212P000`0J08<:000301X0PPX00;20K@00000010000:QPO@D00000V3Qc0:1mK@2dOVd0
001g0321K@0007L0T:0b00400034XC80cAiRMja>DPonooooK>=MMm;PGGL00000F0BH0P00000006d0
000006Af00P000009@0000`000030000:00000`000040000E00005P0001:0000XP000><0003A0000
0@000>?hS3mBohdo0000000000020000C00000000000000000000?ooooooooooD0000780LP0<0@00
@P4001/0000@0000j0D004<2001B0000L04000@0000Roooo0000000000000000T040004000070P0@
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003T1000YQ4Q@9RDM`3:19P2V9Ag0000001b0780K>=MMo0m?GP00000U05]0000K@2D0Fd0
001]0080KP242P00001^08<:000006h0PPX000<06P242P000`0J08<:002`P6d0000000P00028H7d5
000009PhL`2POFd0]7i]0000M`0`PFd0001g092P<P010000a:4b0<dNHWN/CU8?o_ooofcSGGOBh5eg
00000;`4V0800000001]0000001TMP08000002D0000<0000100002P0000<00000`0005@0001T0000
R`4006<0001T1000Y0000040003Sn8`oD_n=?`0000000000100004`00000000000000000003ooooo
oooooe@0001b0780LP1b0>`1003G0`00M0<00;`1000K000040000:@000340P00DP00070100030000
8_ooo`000000000000000901000100001`8045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000i0@00:HA8D0@HgH5<0FH0Q1SMPD00000
LP1b0780LP3`?Ceh000009`1K@0006d0U05]0000K@1803P0bm000000KP242P00001^08<:001902T0
bm0000<06P242P00/81]0000000@0000Z61m1@00002PNS`9X7e]0;QnK@0007H5V85]0000M`2@X380
0@000<BQ<P3=7V9g[4iB3okooom/heegd^1MM`00000R1IP200000000K@000000I7H02000000U0000
300000<0000X0000300000@0001D0000F00002`000250000jP000<H000010000hoR<?e;oSCl00000
00000080001<00000000000000000000oooooooooom@0000D`1S0241002l0@006`00010000100000
h0400580001`0@001000083nool0000000000000002@0@000@0000L2011D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>@4002V4B50
V9Ag09`5V0:HU7L0000005<0H`1/heegl3dmN000002D0Fd0001]09`1K@0006d00P1^08D:000003P0
bm000000KP242P000`0J08D:001902T0bm000;20K@000000200008QPO@D00000V3Qc0:1mK@2dOVd0
001g0321K@0007H5T:0b00400034XC80cAiRMja>DPonooooK>=MMm;PGGL00000SPFH0P00000006d0
000006Af00P000009@0000`000040000:00000`000030000E00008@0000A0000900008D4002E0000
0@000>?hS3mBohdo0000000000090000C00000000000000000000?ooooooooooH00004d0H@1h07D0
LP1S04`0H`1<0000?P400<00003H0000`00006/1003=0@00mP<005D300000`006`00010000363000
nP000580001`0@000`0002;oool0000000000000002@0@000@000PL2011C07T0K@1R06l0K0000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>@4002V4B50
F5if1@86V09HGWH5000004d0H@1h07D0LP1S04`0H`1<06d0001]09@1K@0006d04P260?D3000006h0
Q@X00000>03;d0004`2B0?D3000301X0Q@X00;20K@00000090000:QPO@D00000P7Xl2J1mK@34OVd0
001f1M22K@0007L0T:0b00400034XC80cAiRMja>DPonooooK>=MMm;PGGL00000m0FH0P00000006d0
000006Af00P000009@0000`000030000:00000`000040000E00005P0001E0`001`000:/4001=0000
0@000>?hS3mBohdo0000000000020000C00000000000000000000?ooooooooooD00006[`M_1Y0`00
_04001/0000@0000B`T00>01001B0000L04000@00020o_oo0000000000000000T040000000870P0@
D`1i06d0HP1_06`00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000Z0000YQ4Q@9RDM`1n1YP2V9Ag0000001Zl7K`K>=MMo0m?GP00000U05]0000K@1<06d0
001]0080KP262P0000260?D3000006h0Q@X000<06P262P004`2B0?D3002`P6d0000000P00028H7d5
000009PhL`2POFd0]7i]0000M`0`PFd0001f1I2P<P010000a:4b0<dNHWN/CU8?o_ooofcSGGOBh5eg
00000706V0800000001]0000001TMP08000002D0000<0000100002P0000<00000`0005@0001D0000
K@8001X0000d0`00T`000040003Sn8`oD_n=?`00000000000@0004`00000000000000000003ooooo
oooooe00000ml00000<00580001`0@000`0001000007000000000000002l0P00000000L20R9C07T0
L`1d06D0K@0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000002X0002V4B50V9Ag0>@6V0:HU7L0000003g`M`1/heegl3dmN000002D0Fd0001]09@1K@0006d0
0P1^08L:000006h0QPX00000QP3e0`000`0J08L:000301X0QPX00;20K@00000010000:QPO@D00000
V3Qc0:1mK@2dOVd0001g0321K@0007L0T:0b00400034XC80cAiRMja>DPonooooK>=MMm;PGGL00000
ePJH0P00000006d0000006Af00P000009@0000`000030000:00000`0000400009@0000`000070020
9@0000`000000020<00000`0000?00209@0000`000010000B`000100000000001@0002P0000<0000
0`0002D0000<00000000P2D0000<00001`00P280000<0000ooooobD0000<00003@00P2P0000<0000
0P000280000<0000ooooob80000<0000ooooodH0001`0000I00004E=AR//@000900001P0002bHHDn
0000P0000830dhDn0:RZ_[nZZSlZ@000900001P00000080o0000P0000800080o0020?`00P;lQ@0L0
300000000004@0003000000000160000500000P00017A4U30`0002D0000<00003P00P2D0000<0000
3P00P4H0000d0000:00004E=AR/Z@000900001P00000080o0000P0000800080o0020?`00P;lQ0000
20000680000<00000@0000X0000@000000000000001<0000I000004000000000OP@00>4000010000
000007h4003R0000:@2Z0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000008P0000`0003oooooAP0001`0000@0000ADe6:`90000<0000000000h0000D0000
00000100000D0000
\>"], "Graphics",
   GeneratedCell->False,
   CellAutoOverwrite->False,
   ImageSize->{136.66666666666666`, 26.739130434782624`},
   ImageMargins->{{47.33333333333333, 0.}, {0., -3.333333333333333}},
   ExpressionUUID->"0c420d46-61b5-4aa8-b97b-e6b1a75ff185"], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.5305666281637883`*^9, 3.5305666420915847`*^9}, 
   3.53902163548109*^9, 3.5390347459739676`*^9, {3.540565454765485*^9, 
   3.540565454765485*^9}},ExpressionUUID->"51de9fb5-c536-4ea0-85f8-\
345e159d5ad0"],

Cell["8.5.1. Simulation #5", "Subsection",
 CellChangeTimes->{3.531619879134633*^9, 3.53902163548109*^9, 
  3.5390347459739676`*^9},ExpressionUUID->"cf852df5-05af-4c41-ac69-\
bb949508d07a"],

Cell[CellGroupData[{

Cell[TextData[{
 "We begin with the differential equation, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["w", "2"], "[", 
    SubscriptBox["t", "r"], "]"}], TraditionalForm]],ExpressionUUID->
  "e1a3348a-fc3f-4532-a347-08c0da19c24c"],
 ", that leads to the retirement years wealth producing function, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], "'"}], "[", 
    SubscriptBox["t", "r"], "]"}], TraditionalForm]],ExpressionUUID->
  "12622ceb-552d-44be-b2fe-dc8412abce76"],
 ", again substituting ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 " for ",
 StyleBox["t",
  FontSlant->"Italic"],
 " in Equation 8.8"
}], "Text",
 CellChangeTimes->{{3.5305671036119823`*^9, 3.53056719379014*^9}, {
  3.5332413142348623`*^9, 3.533241423726125*^9}, {3.53902163548209*^9, 
  3.5390216354830904`*^9}, {3.5390347459749675`*^9, 3.5390347459759674`*^9}, {
  3.5399921697541423`*^9, 
  3.53999225083278*^9}},ExpressionUUID->"7ef80f12-47e1-47f8-bb78-\
83bf63a9d8ac"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"wr", ",", 
    SubscriptBox["c", "r"], ",", "wr1", ",", " ", "W0", ",", 
    SubscriptBox["w", "2"], ",", "t", ",", "tr1"}], "]"}], ";", 
  RowBox[{"wr1", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["w", "2"], "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["w", "2"], "[", "t", "]"}], "\[Rho]", " ", 
           RowBox[{
            SubscriptBox["S", "r"], "/", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["S", "r"], "+", "1"}], ")"}]}]}], " ", "-", 
          RowBox[{
           SubscriptBox["c", "r"], " ", "p"}]}]}], "  ", ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["w", "2"], "[", "0", "]"}], "\[Equal]", "w0"}]}], 
       "}"}], ",", 
      RowBox[{
       SubscriptBox["w", "2"], "[", "t", "]"}], ",", "t"}], "]"}], "//", 
    "Simplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["w", "2"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["w", "2"], "[", "t", "]"}], "/.", 
      RowBox[{"wr1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
     RowBox[{"t", "\[Rule]", "tr1"}]}], "//", "Simplify"}]}], ";"}]}], "Input",
 CellMargins->{{Inherited, 8.625}, {Inherited, Inherited}},
 CellOpen->False,
 CellChangeTimes->{{3.533241265048049*^9, 3.5332412781007957`*^9}, 
   3.5390216354830904`*^9, 
   3.5390347459759674`*^9},ExpressionUUID->"2fd05c1f-2726-4253-bf03-\
b7ccf076fa75"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], "(", 
     SubscriptBox["t", "r"], ")"}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SubscriptBox["S", "r"], " ", "tr1", " ", "\[Rho]"}], 
         RowBox[{"1", "+", 
          SubscriptBox["S", "r"]}]]], " ", 
       SubscriptBox["S", "r"], " ", "w0", " ", "\[Rho]"}], "-", 
      RowBox[{
       SubscriptBox["c", "r"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{
            SubscriptBox["S", "r"], " ", "tr1", " ", "\[Rho]"}], 
           RowBox[{"1", "+", 
            SubscriptBox["S", "r"]}]]], "-", "1"}], ")"}], " ", "p", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["S", "r"], "+", "1"}], ")"}]}]}], 
     RowBox[{
      SubscriptBox["S", "r"], " ", "\[Rho]"}]]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.530566800971672*^9, 3.530566852791636*^9}, {
   3.530567016958026*^9, 3.530567061597579*^9}, 3.53902163548409*^9, 
   3.5390347459759674`*^9},ExpressionUUID->"a1150500-d15f-487b-b2be-\
a31663965cb1"],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox[
    FractionBox[
     RowBox[{
      SubscriptBox["dw", "2"], "(", 
      SubscriptBox["t", "r"], ")"}], "dt"],
    FontSlant->"Italic"], 
   StyleBox["=",
    FontSlant->"Italic"], 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox[
       StyleBox["w",
        FontSlant->"Italic"], "2"], "(", 
      SubscriptBox["t", "r"], ")"}], 
     FractionBox[
      SubscriptBox["\[Rho]S", "r"], 
      RowBox[{
       SubscriptBox["S", "r"], "+", "1"}]]}], "-", 
    RowBox[{
     SubscriptBox["c", "r"], "p"}]}]}], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.539992340391902*^9, 
  3.5399924569875712`*^9}},ExpressionUUID->"3e55bf2e-b733-4e33-9e46-\
4433bebc1d75"],

Cell[TextData[{
 "The next step is a simplification of the above that retains the initial \
conditions in the rate of change of wealth. Even though the rate of change of \
wealth will be zero (the obvious case when wealth is constant) in this model, \
it is useful to define the rate of change of wealth in terms of the initial \
conditions. Taking the partial derivative of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["w", "2"], "(", 
    SubscriptBox["t", "r"], ")"}], TraditionalForm]],ExpressionUUID->
  "03c8c861-e6dd-4cbc-a79a-6719c2882ebd"],
 " with respect to ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 ",we solve for a named ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["c", "r"], "Input"], TraditionalForm]],ExpressionUUID->
  "f979113a-173b-4cd5-ae4c-7daf2d10383c"],
 ", consumption during retirement. This is done by fixing the rate of change \
of post-retirement wealth at zero. Another obvious consequence of this is \
that post-retirement consumption must equal returns from ",
 StyleBox["w0",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.5305676973909445`*^9, 3.530567747475809*^9}, {
   3.5390216354850903`*^9, 3.5390216354860907`*^9}, {3.539034745976968*^9, 
   3.5390347459789677`*^9}, 3.539094142999283*^9, {3.5399925118977118`*^9, 
   3.5399925243564243`*^9}},ExpressionUUID->"052f66d4-24c9-4321-bda5-\
0f167da4d3f0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cr1", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "tr1"], " ", 
       SubscriptBox["w", "2"]}], "\[Equal]", "0"}], ",", 
     SubscriptBox["c", "r"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["c", "r"], "=", 
  RowBox[{
   SubscriptBox["c", "r"], "/.", 
   RowBox[{"cr1", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.530567272595648*^9, 3.530567300006215*^9}, 
   3.5390216354860907`*^9, 
   3.5390347459789677`*^9},ExpressionUUID->"16df2b7a-5f48-4f40-9035-\
5910d4baddf4"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["S", "r"], " ", "w0", " ", "\[Rho]"}], 
  RowBox[{"p", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SubscriptBox["S", "r"]}], ")"}]}]]], "Output",
 CellOpen->False,
 CellChangeTimes->{3.5305673006502523`*^9, 3.5305723778356504`*^9, 
  3.5316178586070657`*^9, 3.5316194836990156`*^9, 3.5316197607208605`*^9, 
  3.533148212325952*^9, 3.5332364536108503`*^9, 3.533240049881545*^9, 
  3.533683635671875*^9, 3.5337353207317114`*^9, 3.5337562349375*^9, 
  3.5390212236095324`*^9, 3.5390216354860907`*^9, 3.5390347459789677`*^9, 
  3.539988754937826*^9, 3.5401275343396583`*^9, 3.5405612711291943`*^9, 
  3.541186546730471*^9, 3.5411879139346704`*^9, 3.5411880378197565`*^9, 
  3.541191069806176*^9, 3.5411911680627966`*^9, 3.5411912486024027`*^9, 
  3.5411913065877194`*^9, 3.541604169572004*^9, 3.6126969050499287`*^9, 
  3.697233992702625*^9, 3.6972358759392543`*^9, 3.697317855276009*^9, 
  3.697323533072829*^9, 3.6980443924497647`*^9, 3.698044832429785*^9, 
  3.731421557158887*^9},ExpressionUUID->"9325b167-3a96-4950-8d47-\
d5a6898e6b74"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
    SubscriptBox["c", "r"], "=", 
    FractionBox[
     RowBox[{
      SubscriptBox["S", "r"], " ", "w0", " ", "\[Rho]"}], 
     RowBox[{"p", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SubscriptBox["S", "r"]}], ")"}]}]]}],
   FontSlant->"Italic"], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.53056725497464*^9, 3.5305672628880925`*^9}, 
   3.5390216354860907`*^9, 
   3.5390347459789677`*^9},ExpressionUUID->"5f44e784-3fe2-4160-83a9-\
ddc39bba2953"],

Cell[CellGroupData[{

Cell[TextData[{
 "In Table 8.9 we show ",
 StyleBox["d",
  FontVariations->{"Underline"->True}],
 "ata ",
 StyleBox["v",
  FontVariations->{"Underline"->True}],
 "alues during ",
 StyleBox["r",
  FontVariations->{"Underline"->True}],
 "etirement, ",
 StyleBox["dvr", "Input"],
 ", that are assigned for simulation, definitions are provided for leisure \
during retirement, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "r"], TraditionalForm]],ExpressionUUID->
  "3150f5ac-1a5e-43cd-ad90-c5ac719d22c9"],
 ", utility during retirement, ",
 StyleBox["ur",
  FontSlant->"Italic"],
 ", and its partial derivative with respect to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "r"], TraditionalForm]],ExpressionUUID->
  "5cd6cb7f-fbf8-4163-a13e-c59daccd7eaf"],
 ", the time spent working on property during retirement."
}], "Text",
 CellChangeTimes->{{3.53056786061528*^9, 3.530567872776976*^9}, {
  3.5390216354860907`*^9, 3.5390216354880905`*^9}, {3.5390347459789677`*^9, 
  3.5390347459809675`*^9}, {3.5399925481837873`*^9, 3.5399925822487354`*^9}, {
  3.5399935570044885`*^9, 
  3.5399935570104885`*^9}},ExpressionUUID->"3866fedb-b9f5-466f-a5de-\
7afb92aa68db"],

Cell["", "Text",ExpressionUUID->"9b05a0c4-1400-4a46-b495-ab89ce17c64d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dvr1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Rho]", "\[Rule]", "1"}], ",", 
     RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", ".9"}], ",", 
     RowBox[{"p", "\[Rule]", "2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["L", "r"], "=", 
   RowBox[{"1", "-", 
    SubscriptBox["S", "r"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ur", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["c", "r"], "\[CurlyPhi]"], " ", 
     SuperscriptBox[
      SubscriptBox["L", "r"], "\[Omega]"]}], "/.", "dvr1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"drs", "=", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     SubscriptBox["S", "r"]], " ", "ur"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ur", "//", "Simplify"}], ";"}], "\n", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Rho]", ",", "\[CurlyPhi]", ",", "\[Omega]", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.1", ",", "0.9", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5332414909819717`*^9, 3.5332415325933514`*^9}, 
   3.5390216354880905`*^9, 
   3.5390347459809675`*^9},ExpressionUUID->"13ed8886-8a85-456f-9965-\
44c8e6829dd0"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\[Rho]", "\[CurlyPhi]", "\[Omega]", "p"},
     {"1", "0.1`", "0.9`", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  StripOnInput->False,
  FontFamily->"Times"]], "Output",
 CellChangeTimes->{{3.531620080294139*^9, 3.5316200881375875`*^9}, 
   3.533148213249005*^9, 3.5332364546569104`*^9, 3.5332400500075526`*^9, {
   3.5332414734569693`*^9, 3.53324152417387*^9}, 3.533683635765625*^9, 
   3.5337353213277454`*^9, 3.53375623503125*^9, 3.539021224690594*^9, 
   3.5390216354880905`*^9, 3.5390347459809675`*^9, 3.5399887556218653`*^9, 
   3.5401275349396925`*^9, 3.5405612711771975`*^9, 3.541186547790532*^9, 
   3.541187913990674*^9, 3.54118803787676*^9, 3.5411910698611794`*^9, 
   3.5411911681338005`*^9, 3.541191248657406*^9, 3.5411913066427226`*^9, 
   3.541604170193039*^9, 3.612696905437951*^9, 3.6972339927136197`*^9, 
   3.697235876002423*^9, 3.6973178553431873`*^9, 3.6973235330838847`*^9, 
   3.698044392548026*^9, 3.6980448324648776`*^9, 3.731421557189969*^9},
 TextAlignment->Center,ExpressionUUID->"c3c22c24-e1f4-46d1-bbd6-5da6803304d3"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Table 8.9 Fixed parameter values, ",
 StyleBox["dvr1",
  FontFamily->"Courier New",
  FontWeight->"Bold"],
 ", for simulation #5"
}], "TableTitle",
 PageWidth->WindowWidth,
 CellMargins->{{38, 10}, {1, 7}},
 CellChangeTimes->{{3.530561082895617*^9, 3.5305610961973777`*^9}, {
   3.5305628115044875`*^9, 3.5305628144376554`*^9}, {3.5305647582438345`*^9, 
   3.5305647612080045`*^9}, {3.5305674591043153`*^9, 3.530567477299356*^9}, 
   3.5390216354880905`*^9, 3.5390347459809675`*^9},
 TextAlignment->Center,ExpressionUUID->"3d2c9422-71de-445a-bb82-dedcf4ca5c81"],

Cell[CellGroupData[{

Cell[TextData[{
 "Prior to optimization we need to take a short detour, beneath this cell, to \
overcome a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " feature that is inconvenient for this task. When we expand ",
 StyleBox["drs", "Input"],
 " into two terms in ",
 StyleBox["drs1", "Input"],
 " we see that the two terms in ",
 StyleBox["drs1", "Input"],
 " have a common multiplier, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["w0", "0.1"], TraditionalForm]],ExpressionUUID->
  "accd75b6-78ae-4fec-a118-379eb194a623"],
 ". "
}], "Text",
 CellOpen->False,
 CellChangeTimes->{{3.5305676075448055`*^9, 3.5305676113400226`*^9}, {
  3.5390216354880905`*^9, 3.5390216354890904`*^9}, {3.5390347459809675`*^9, 
  3.539034745981968*^9}},ExpressionUUID->"4db81cc8-d286-4a3d-a987-\
c236827bf165"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"drs1", "=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"drs", "//", "Simplify"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.5390216354890904`*^9, 
  3.539034745981968*^9},ExpressionUUID->"2c7ada6a-bf2a-4fee-87aa-\
9669ecd11c03"],

Cell[BoxData[
 FractionBox[
  RowBox[{"0.09330329915368074`", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"1.`", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SubscriptBox["S", "r"]}], ")"}], "0.9`"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["S", "r"]}], ")"}], "0.9`"], " ", 
       SuperscriptBox["w0", "0.09999999999999998`"]}], 
      SubsuperscriptBox["S", "r", "0.9`"]], "-", 
     FractionBox[
      RowBox[{"9.`", " ", 
       SubsuperscriptBox["S", "r", "0.1`"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["S", "r"]}], ")"}], "1.9`"], " ", 
       SuperscriptBox["w0", "0.1`"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["S", "r"]}], ")"}], "0.09999999999999998`"]]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SubscriptBox["S", "r"]}], ")"}], "2"]]], "Output",
 CellOpen->False,
 CellChangeTimes->{3.4104688809205*^9, 3.4105049649375*^9, 
  3.53036098496367*^9, 3.5305674953853903`*^9, 3.5305723779616575`*^9, 
  3.53161786008515*^9, 3.5316194838030214`*^9, 3.531619760854868*^9, 
  3.5331482137840357`*^9, 3.5332364552869463`*^9, 3.533240050064556*^9, 
  3.533683635875*^9, 3.533735321967782*^9, 3.533756235171875*^9, 
  3.53902122531363*^9, 3.5390216354890904`*^9, 3.539034745981968*^9, 
  3.5399887562929034`*^9, 3.5401275356187315`*^9, 3.5405612712242002`*^9, 
  3.541186548611579*^9, 3.541187914047677*^9, 3.5411880379317627`*^9, 
  3.541191069917183*^9, 3.541191168217805*^9, 3.541191248712409*^9, 
  3.5411913066957254`*^9, 3.541604170817075*^9, 3.612696905864976*^9, 
  3.697233992764786*^9, 3.69723587609517*^9, 3.6973178554344344`*^9, 
  3.6973235331219597`*^9, 3.698044392701434*^9, 3.698044832503005*^9, 
  3.7314215572551427`*^9},ExpressionUUID->"b69e2cc2-f40a-485e-a4f8-\
2df83fb01d17"]
}, Open  ]],

Cell[TextData[{
 "We seek the optimum via the usual approach by setting drs1 equal to zero \
and solving. The common multipliers should cancel provided that the zero \
point of the derivative is independent of w0.  Here ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s accuracy presents a minor problem. Although the two multipliers appear \
to have the same the exponent, 0.1, the two 0.1 exponents are not ",
 StyleBox["exactly",
  FontVariations->{"Underline"->True}],
 " equal as we see below.  Thus, the multipliers do not cancel in a normal \
Solve, FindRoot or Simplify procedures.  We will engage in a slight \
subterfuge to overcome ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s penchant for accuracy but before we do that we want to be certain that \
the difference in the multipliers is too small to affect our outcome. To do \
that we isolate the separate \"0.1\" portions of drs1 and use SetAccuracy[ ] \
to see how close to .1 they each are. Fortunately they both turn out to be \
very close."
}], "Text",
 CellOpen->False,
 CellChangeTimes->{3.5390216354890904`*^9, 
  3.539034745981968*^9},ExpressionUUID->"064e3824-bc53-40a1-93f3-\
d4e4a24d6e9a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"n1", "=", 
  RowBox[{"SetAccuracy", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"drs1", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "5"}], "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", "30"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.5390216354900904`*^9, 
  3.539034745981968*^9},ExpressionUUID->"22c81dc7-b8aa-4097-bece-\
f8194443a929"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \
\\!\\(\\*RowBox[{FractionBox[RowBox[{\\\"0.09330329915368074`\\\", \\\" \\\", \
RowBox[{\\\"(\\\", RowBox[{FractionBox[RowBox[{\\\"1.`\\\", \\\" \\\", \
SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{\\\"1\\\", \\\"-\\\", RowBox[{\\\"\
\[LeftSkeleton]\\\", \\\"1\\\", \\\"\[RightSkeleton]\\\"}]}], \\\")\\\"}], \\\
\"0.9`\\\"], \\\" \\\", SuperscriptBox[RowBox[{\\\"\[LeftSkeleton]\\\", \\\"1\
\\\", \\\"\[RightSkeleton]\\\"}], RowBox[{\\\"\[LeftSkeleton]\\\", \\\"4\\\", \
\\\"\[RightSkeleton]\\\"}]], \\\" \\\", SuperscriptBox[\\\"w0\\\", \
\\\"0.09999999999999998`\\\"]}], SubsuperscriptBox[\\\"S\\\", \\\"r\\\", \
\\\"0.9`\\\"]], \\\"-\\\", FractionBox[RowBox[{\\\"9.`\\\", \\\" \\\", \
SubsuperscriptBox[\\\"S\\\", \\\"r\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \
\\\"4\\\", \\\"\[RightSkeleton]\\\"}]], \\\" \\\", \
SuperscriptBox[RowBox[{\\\"\[LeftSkeleton]\\\", \\\"1\\\", \\\"\
\[RightSkeleton]\\\"}], RowBox[{\\\"\[LeftSkeleton]\\\", \\\"4\\\", \\\"\
\[RightSkeleton]\\\"}]], \\\" \\\", SuperscriptBox[\\\"w0\\\", \
\\\"0.1`\\\"]}], SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{\\\"1\\\", \\\"-\\\
\", RowBox[{\\\"\[LeftSkeleton]\\\", \\\"1\\\", \\\"\[RightSkeleton]\\\"}]}], \
\\\")\\\"}], RowBox[{\\\"\[LeftSkeleton]\\\", \\\"20\\\", \
\\\"\[RightSkeleton]\\\"}]]]}], \\\")\\\"}]}], SuperscriptBox[RowBox[{\\\"(\\\
\", RowBox[{\\\"1\\\", \\\"+\\\", SubscriptBox[\\\"S\\\", \\\"r\\\"]}], \\\")\
\\\"}], \\\"2\\\"]], \\\"\[LeftDoubleBracket]\\\", RowBox[{\\\"1\\\", \\\",\\\
\", \\\"5\\\"}], \\\"\[RightDoubleBracket]\\\"}]\\) is longer than depth of \
object.\"",2,104,1,22143460035033458222,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.697233992776814*^9, 3.697235876163885*^9, 
  3.697317855496596*^9, 3.6973235331360245`*^9, 3.698044392854843*^9, 
  3.6980448325410814`*^9, 
  3.731421557292241*^9},ExpressionUUID->"700b2413-4d0b-40e6-8318-\
ce00aed37cd3"],

Cell[BoxData["1.`30."], "Output",
 CellOpen->False,
 CellChangeTimes->{3.410468880967375*^9, 3.41050496496875*^9, 
  3.530360985297689*^9, 3.5305675228599615`*^9, 3.5305723780106606`*^9, 
  3.531617860411169*^9, 3.531619483843024*^9, 3.5316197609128714`*^9, 
  3.5331482142410617`*^9, 3.5332364556999702`*^9, 3.533240050118559*^9, 
  3.5336836359375*^9, 3.533735322418808*^9, 3.53375623525*^9, 
  3.539021225759655*^9, 3.5390216354900904`*^9, 3.539034745981968*^9, 
  3.539988756768931*^9, 3.5401275362677684`*^9, 3.5405612712662024`*^9, 
  3.5411865491656103`*^9, 3.5411879141006804`*^9, 3.5411880379877663`*^9, 
  3.5411910699711857`*^9, 3.541191168271808*^9, 3.5411912487654123`*^9, 
  3.5411913067477283`*^9, 3.5416041715291157`*^9, 3.612696906147992*^9, 
  3.6972339927778163`*^9, 3.697235876164856*^9, 3.6973178554975986`*^9, 
  3.697323533138029*^9, 3.69804439285688*^9, 3.6980448325460944`*^9, 
  3.7314215572942467`*^9},ExpressionUUID->"fe5b39b6-748a-4ff1-bbb3-\
4d4b7d0b1e63"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"n2", "=", 
  RowBox[{"SetAccuracy", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"drs1", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "5"}], "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", "30"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.5390216354900904`*^9, 
  3.539034745981968*^9},ExpressionUUID->"b41e87e8-531f-421a-80b1-\
d73d64da499c"],

Cell[BoxData[
 TemplateBox[{
  "Part","partw",
   "\"Part \\!\\(\\*RowBox[{\\\"5\\\"}]\\) of \\!\\(\\*FractionBox[\\\"1\\\", \
SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{\\\"1\\\", \\\"+\\\", SubscriptBox[\
\\\"S\\\", \\\"r\\\"]}], \\\")\\\"}], \\\"2\\\"]]\\) does not exist.\"",2,105,
   2,22143460035033458222,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.6972339927868137`*^9, 3.697235876201953*^9, 
  3.697317855543721*^9, 3.697323533147027*^9, 3.6980443929210176`*^9, 
  3.698044832566147*^9, 
  3.73142155734438*^9},ExpressionUUID->"0f72b65e-dc84-47e2-96d0-5396b316dc80"],

Cell[BoxData["2.`30.30102999566398"], "Output",
 CellOpen->False,
 CellChangeTimes->{3.410468881061125*^9, 3.41050496496875*^9, 
  3.530360985505701*^9, 3.5305675261401496`*^9, 3.530572378060663*^9, 
  3.5316178606481824`*^9, 3.5316194838820257`*^9, 3.5316197609558735`*^9, 
  3.533148214459074*^9, 3.5332364559639854`*^9, 3.533240050168562*^9, 
  3.533683636*^9, 3.5337353227968297`*^9, 3.5337562353125*^9, 
  3.5390212262186813`*^9, 3.5390216354900904`*^9, 3.539034745981968*^9, 
  3.539988757237958*^9, 3.540127536870803*^9, 3.540561271309205*^9, 
  3.541186549614636*^9, 3.5411879141526833`*^9, 3.541188038039769*^9, 
  3.5411910700231886`*^9, 3.5411911683238115`*^9, 3.541191248818415*^9, 
  3.5411913067997313`*^9, 3.54160417196014*^9, 3.6126969063410025`*^9, 
  3.697233992787816*^9, 3.697235876203959*^9, 3.6973178555447245`*^9, 
  3.6973235331480336`*^9, 3.698044392923023*^9, 3.69804483256715*^9, 
  3.7314215573453836`*^9},ExpressionUUID->"1aede207-d4e3-426d-9090-\
543cc44e2702"]
}, Open  ]],

Cell[TextData[{
 "The difference is virtually zero.Chop[] uses a default tolerance level of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "10"}]], TraditionalForm]],ExpressionUUID->
  "bd5c798f-b67b-4650-a722-dcee3c690857"]
}], "Text",
 CellOpen->False,
 CellChangeTimes->{{3.5390216354900904`*^9, 3.5390216354900904`*^9}, {
  3.539034745981968*^9, 
  3.5390347459829683`*^9}},ExpressionUUID->"894bdd84-95de-4548-9ee9-\
458a081f964e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"n2", "-", "n1"}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.5390216354900904`*^9, 
  3.5390347459829683`*^9},ExpressionUUID->"5982b20a-cb83-4c79-9863-\
09467badca65"],

Cell[BoxData["1.`29.69897000433602"], "Output",
 CellOpen->False,
 CellChangeTimes->{3.410468881108*^9, 3.410504964984375*^9, 
  3.5303609857957177`*^9, 3.530567534940653*^9, 3.530572378109666*^9, 
  3.5316178610222034`*^9, 3.531619483921028*^9, 3.531619760997876*^9, 
  3.5331482147600913`*^9, 3.533236456468014*^9, 3.533240050218565*^9, 
  3.53368363609375*^9, 3.533735323130849*^9, 3.533756235390625*^9, 
  3.5390212268117156`*^9, 3.5390216354900904`*^9, 3.5390347459829683`*^9, 
  3.5399887579399977`*^9, 3.5401275375058393`*^9, 3.5405612713532076`*^9, 
  3.5411865503716793`*^9, 3.541187914204686*^9, 3.5411880380927725`*^9, 
  3.541191070076192*^9, 3.541191168374814*^9, 3.5411912488724184`*^9, 
  3.541191306854735*^9, 3.5416041726071777`*^9, 3.612696906621019*^9, 
  3.6972339927968407`*^9, 3.6972358762696342`*^9, 3.6973178555908465`*^9, 
  3.697323533156074*^9, 3.6980443929982233`*^9, 3.6980448326202908`*^9, 
  3.731421557363431*^9},ExpressionUUID->"9ce0965e-2170-4e70-9d81-\
d71befa21b07"]
}, Open  ]],

Cell[TextData[{
 "Finally, we force the ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["w0", "0.1"], "Input"], TraditionalForm]],ExpressionUUID->
  "aa12c7cf-b18a-46b5-bcfd-eadd3d0fa0fc"],
 "terms to cancel"
}], "Text",
 CellOpen->False,
 CellChangeTimes->{{3.5390216354900904`*^9, 3.539021635491091*^9}, {
  3.539034745983968*^9, 
  3.539034745983968*^9}},ExpressionUUID->"5e196c3d-e004-498e-b760-\
1ac8d15c0135"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"drs2", "=", 
  RowBox[{"Cancel", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"drs1", "/.", 
      RowBox[{
       SuperscriptBox["w0", "_"], "\[Rule]", "w1"}]}], ")"}], "/", "w1"}], 
   "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.539021635491091*^9, 
  3.539034745983968*^9},ExpressionUUID->"b701aa64-c246-4867-b514-\
a343328194d1"],

Cell[BoxData[
 FractionBox[
  RowBox[{"0.09330329915368074`", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"1.`", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["S", "r"]}], ")"}], "1.`"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["S", "r"]}], ")"}], "0.9`"]}], "-", 
     RowBox[{"9.`", " ", 
      SubsuperscriptBox["S", "r", "1.`"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["S", "r"]}], ")"}], "1.9`"]}]}], ")"}]}], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SubscriptBox["S", "r"]}], ")"}], "0.09999999999999998`"], " ", 
   SubsuperscriptBox["S", "r", "0.9`"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1.`", "\[VeryThinSpace]", "+", 
      SubscriptBox["S", "r"]}], ")"}], "2"]}]]], "Output",
 CellOpen->False,
 CellChangeTimes->{3.41046888113925*^9, 3.410504965*^9, 
  3.5303609860777335`*^9, 3.530567540434967*^9, 3.530572378158669*^9, 
  3.5316178613572226`*^9, 3.53161948395903*^9, 3.5316197610388784`*^9, 
  3.533148215069109*^9, 3.5332364568850374`*^9, 3.5332400502685676`*^9, 
  3.533683636171875*^9, 3.533735323446867*^9, 3.53375623546875*^9, 
  3.539021227549758*^9, 3.539021635491091*^9, 3.539034745983968*^9, 
  3.539988758703041*^9, 3.5401275380568705`*^9, 3.54056127139721*^9, 
  3.541186551287732*^9, 3.541187914258689*^9, 3.5411880381457753`*^9, 
  3.541191070128195*^9, 3.5411911684378176`*^9, 3.5411912489244213`*^9, 
  3.541191306908738*^9, 3.541604173154209*^9, 3.6126969069260364`*^9, 
  3.6972339928088713`*^9, 3.6972358763107424`*^9, 3.6973178556429853`*^9, 
  3.69732353316708*^9, 3.6980443930643997`*^9, 3.6980448326513968`*^9, 
  3.7314215573814783`*^9},ExpressionUUID->"b7d40782-9dbe-4e84-97d2-\
e6f34eecdb50"]
}, Open  ]],

Cell[TextData[{
 "With this resolved we can either use ",
 StyleBox["drs2", "Input"],
 " or, because we know that ",
 StyleBox["w0", "Input"],
 " does not matter we can use any arbitrary non-zero number for ",
 StyleBox["w0", "Input"],
 " in ",
 StyleBox["drs", "Input"],
 "."
}], "Text",
 CellOpen->False,
 CellChangeTimes->{3.539021635491091*^9, 
  3.539034745983968*^9},ExpressionUUID->"c562d311-f5f8-4111-b45d-\
21d8ddfa4711"]
}, Closed]],

Cell[TextData[{
 "Assuming that one amassed sufficient funds to retire, we ask for the \
optimal portion of time spent on real estate after retirement by setting the \
partial derivative equal to zero and solving for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "r"], TraditionalForm]],ExpressionUUID->
  "67a87317-aa7b-4dc4-9db7-fbf83bc0e41f"],
 "."
}], "Text",
 CellChangeTimes->{
  3.53324165635143*^9, {3.539021635491091*^9, 3.5390216354920907`*^9}, {
   3.539034745983968*^9, 3.539034745984968*^9}, {3.5399926047450223`*^9, 
   3.5399926188828306`*^9}},ExpressionUUID->"bee319b2-a514-4738-8685-\
8bfd28c574f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sru", "=", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"drs2", "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["S", "r"], ",", ".1"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"Cell", "[", 
    RowBox[{
     RowBox[{"TextData", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<Given the data in \>\"", ",", 
        RowBox[{"StyleBox", "[", 
         RowBox[{"\"\<dvr1\>\"", ",", "Bold"}], "]"}], ",", 
        "\"\< that produced \>\"", ",", 
        RowBox[{"StyleBox", "[", 
         RowBox[{"\"\<drs1\>\"", ",", "Italic"}], "]"}], ",", 
        RowBox[{"\"\<, our agent would spend \>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"NumberForm", "[", 
           RowBox[{
            RowBox[{"100", " ", 
             RowBox[{"sru", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "3"}], "}"}]}], "]"}], "]"}], "<>", 
         "\"\<% of his time on his real estate during retirement. The same \
result is obtained when the technique of setting \>\""}], ",", 
        RowBox[{"StyleBox", "[", 
         RowBox[{"\"\<w0\>\"", ",", "Italic"}], "]"}], ",", "\"\< in \>\"", 
        ",", 
        RowBox[{"StyleBox", "[", 
         RowBox[{"\"\<drs\>\"", ",", "Italic"}], "]"}], ",", 
        "\"\< to an arbitrary value is used.\>\""}], "}"}], "]"}], ",", 
     "\"\<Text\>\""}], "]"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.533241664093873*^9, 3.5332418118013215`*^9}, {
   3.533241865733406*^9, 3.533241887437648*^9}, {3.533241929323043*^9, 
   3.533241942288785*^9}, {3.5332420182801313`*^9, 3.533242037612237*^9}, 
   3.5390216354920907`*^9, 3.539034745984968*^9, {3.541186669584498*^9, 
   3.5411866908837166`*^9}, {3.541186739098474*^9, 3.5411868033841505`*^9}, {
   3.5411868519529285`*^9, 
   3.5411868642266307`*^9}},ExpressionUUID->"aabc05d8-8c2b-43bc-bd08-\
48460f7c5849"],

Cell[TextData[{
 "Given the data in ",
 StyleBox["dvr1",
  FontWeight->Bold],
 " that produced ",
 StyleBox["drs1",
  FontSlant->Italic],
 ", our agent would spend 9.233% of his time on his real estate during \
retirement. The same result is obtained when the technique of setting ",
 StyleBox["w0",
  FontSlant->Italic],
 " in ",
 StyleBox["drs",
  FontSlant->Italic],
 " to an arbitrary value is used."
}], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.731421557435624*^9},ExpressionUUID->"79d3cf6d-1af6-4c55-b6f2-\
0e259ac33945"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sru", "=", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"drs", "/.", 
        StyleBox[
         RowBox[{"w0", "\[Rule]", "1"}],
         FontColor->RGBColor[1, 0, 0]]}], ")"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["S", "r"], ",", ".1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sru", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2"}], "]"}], "]"}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.533242054006175*^9, 3.5390216354920907`*^9, 
  3.539034745984968*^9},ExpressionUUID->"902936b5-8758-4f52-9cda-\
e536352c6bf7"],

Cell[TextData[{
 "To determine what wealth is necessary to provide consumption during \
retirement we solve for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "r"], TraditionalForm]],ExpressionUUID->
  "7bbb81ca-ec84-4635-bc6a-54107c3e9659"],
 " in terms of wealth at retirement, ",
 StyleBox["w0",
  FontSlant->"Italic"],
 ",",
 StyleBox[" ", "Input"],
 "to obtain a function providing a constant factor which when multiplied \
times retirement wealth produces consumption income. This factor is the cash \
flow rate on accumulated wealth."
}], "Text",
 CellChangeTimes->{{3.5390216354920907`*^9, 3.5390216354930906`*^9}, {
  3.539034745985968*^9, 3.539034745985968*^9}, {3.5399926496265893`*^9, 
  3.5399926840145564`*^9}},ExpressionUUID->"3fdf65ce-1dba-4841-ab00-\
3b9217845ace"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cru", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["c", "r"], "/.", "dvr1"}], ")"}], "/.", 
   RowBox[{
    SubscriptBox["S", "r"], "\[Rule]", 
    RowBox[{"sru", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{3.5390216354930906`*^9, 
  3.539034745985968*^9},ExpressionUUID->"a78a2b86-6c2f-4e5c-99b2-\
68b25667197c"],

Cell[BoxData[
 RowBox[{"0.042262026288674884`", " ", "w0"}]], "Output",
 CellChangeTimes->{3.41046888126425*^9, 3.41050496503125*^9, 
  3.530360987284803*^9, 3.530567983658318*^9, 3.530572378302677*^9, 
  3.5316178626372957`*^9, 3.531619484093038*^9, 3.531619761160886*^9, 
  3.5331482162311754`*^9, 3.533236459616194*^9, 3.533240050470579*^9, 
  3.533242071108153*^9, 3.533683636390625*^9, 3.5337353244189224`*^9, 
  3.5337562356875*^9, 3.5390212287358255`*^9, 3.5390216354930906`*^9, 
  3.539034745986968*^9, 3.5399887599991155`*^9, 3.5401275394129486`*^9, 
  3.5405612716052217`*^9, 3.54118655300583*^9, 3.541187914465701*^9, 
  3.541188038461793*^9, 3.5411910703492074`*^9, 3.5411911686948323`*^9, 
  3.5411912501574917`*^9, 3.541191307105749*^9, 3.5416041746872964`*^9, 
  3.6126969084151216`*^9, 3.6972339928720393`*^9, 3.6972358764721727`*^9, 
  3.6973178558144417`*^9, 3.697323533206196*^9, 3.698044393269946*^9, 
  3.698044832795764*^9, 
  3.7314215574847536`*^9},ExpressionUUID->"5fbe920e-10dd-441b-84c1-\
d35a8369f597"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"wwe", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"cru", "\[Equal]", "60000"}], ",", "w0"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"TextCell", "[", 
    RowBox[{
     RowBox[{
     "\"\<We can then 'back in' to the amount of wealth required, given a \
certain level of consumption. Suppose one wishes to have an annual income of \
$60,000, then the capital needed to produce the requisite income given the \
return is: $\>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"AccountingForm", "[", 
        RowBox[{"wwe", ",", 
         RowBox[{"DigitBlock", "\[Rule]", "3"}]}], "]"}], "]"}], "<>", 
      "\"\<\>\""}], ",", "\"\<Text\>\""}], "]"}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.5332421029439735`*^9, 3.5332421798803744`*^9}, 
   3.5390216354930906`*^9, 
   3.539034745986968*^9},ExpressionUUID->"4db3cbfc-76a7-4780-9478-\
86babad7bfb6"],

Cell["\<\
We can then 'back in' to the amount of wealth required, given a certain level \
of consumption. Suppose one wishes to have an annual income of $60,000, then \
the capital needed to produce the requisite income given the return is: \
$1,419,714.\
\>", "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.7314215575048065`*^9},ExpressionUUID->"cbb38e44-09a4-4f18-ae4c-\
45426f2b2c93"]
}, Open  ]],

Cell["\<\
As expected, consumption available during retirement is a rising function of \
wealth.\
\>", "Text",
 CellChangeTimes->{{3.5332422202336826`*^9, 3.533242224106904*^9}, 
   3.5390216354930906`*^9, 
   3.539034745986968*^9},ExpressionUUID->"297c133e-77cd-449c-be22-\
67e5375e4ce0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"60000", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["c", "r"], "/.", "dvr1"}], ")"}], "/.", 
        RowBox[{
         SubscriptBox["S", "r"], "\[Rule]", 
         RowBox[{"sru", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"w0", ",", 
       RowBox[{"1.3", " ", 
        SuperscriptBox["10", "6"]}], ",", 
       RowBox[{"1.5", " ", 
        SuperscriptBox["10", "6"]}]}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*StyleBox[\"w0\",FontSlant->\"Italic\"]\)\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(c\), \(r\)]\)\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "5"}], "}"}], "]"}], ",", "Green"}], "}"}], ",",
         "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"wwe", ",", 
            RowBox[{"AccountingForm", "[", "wwe", "]"}]}], "}"}], ",", 
          "1500000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1300000", ",", "55000"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"wwe", ",", "55000"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"wwe", ",", "60000"}], "}"}]}], "}"}], "]"}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Graphics", "[", "p1", "]"}], ",", 
      RowBox[{"Graphics", "[", "p2", "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"SL5", "=", 
  RowBox[{"Legended", "[", 
   StyleBox[
    RowBox[{
     StyleBox["s1",
      CharacterEncoding -> "WindowsANSI"], 
     StyleBox[",",
      CharacterEncoding -> "WindowsANSI"], 
     RowBox[{"LineLegend", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Green", ",", 
           RowBox[{"AbsoluteDashing", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Red", ",", 
           RowBox[{
            StyleBox["AbsoluteDashing",
             CharacterEncoding -> "WindowsANSI"], 
            StyleBox["[",
             CharacterEncoding -> "WindowsANSI"], 
            RowBox[{
             StyleBox["{",
              CharacterEncoding -> "WindowsANSI"], 
             RowBox[{"1", ",", "0"}], 
             StyleBox["}",
              CharacterEncoding -> "WindowsANSI"]}], 
            StyleBox["]",
             CharacterEncoding -> "WindowsANSI"]}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Constant \!\(\*SubscriptBox[\(c\), \(r\)]\) = 60000\>\"", ",", 
         "\"\<\!\(\*SubscriptBox[\(c\), \(r\)]\) = \
\!\(\*StyleBox[\"f\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"w0\",FontSlant-\
>\"Italic\"]\))\>\""}], "}"}]}], "]"}]}],
    FormatType->StandardForm,
    FontFamily->"Courier New"], 
   StyleBox["\n",
    FormatType->StandardForm,
    FontFamily->"Courier New",
    CharacterEncoding -> "WindowsANSI"], 
   StyleBox["   ",
    FormatType->StandardForm,
    FontFamily->"Courier New",
    CharacterEncoding -> "WindowsANSI"], 
   StyleBox["]",
    FormatType->StandardForm,
    FontFamily->"Courier New",
    CharacterEncoding -> "WindowsANSI"]}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.410376562936125*^9, 3.410376581748625*^9}, {
   3.4103766195455*^9, 3.410376646779875*^9}, 3.410376762873625*^9, 
   3.410376806779875*^9, 3.410376839186125*^9, {3.41037710082675*^9, 
   3.410377110983*^9}, 3.41037722588925*^9, 3.410377476608*^9, {
   3.410377515983*^9, 3.410377533779875*^9}, {3.530568101215042*^9, 
   3.5305681203861384`*^9}, {3.5411905699875884`*^9, 3.541190585973503*^9}, {
   3.541190618307352*^9, 3.5411906378634706`*^9}, {3.6972359291328077`*^9, 
   3.697236043801064*^9}, 3.6972360922311034`*^9, {3.697236128110587*^9, 
   3.697236203726635*^9}, {3.697236365337145*^9, 
   3.697236507706897*^9}},ExpressionUUID->"f5954a4a-205c-4b22-8eb7-\
d2c7f62afd9b"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           AbsoluteDashing[{2, 5}], 
           RGBColor[0, 1, 0]], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQnV/HzahwzdiRAQR83jrInLG/d+ougn9CsmR36VME
f8rfh6tFvyH4d9sXT57NagLne8+c135ZBMHX+TxvY6gqgt/1+dOlvSYIfrSN
j1aBK4IfwHO/90oogn+46egLuVQEf4XjxsrNpQg+9/IPjHqtCP6kyZnToqYg
+D0nnidcXILgMy/ZqaS3BcF/e3yC1NUjCP6fooVyelcR/I4jrFK5TxD89rh8
729fkMybr1OSymIK539Sf39JThTBZ7N4bduliuBPf2e14LYJgj/7bb9FuSuC
LzPZ4sSPEAT/0H6pFJ0UBP+WCZPZqhIEvyDA9j9vC4JfuaX23+4pCP6y+d85
ZZYi+AGGR3mStiD4udwzXD8dQfA5evaVZlxB8I9Plts04TGC//NxswrzFwR/
xS2bvmhmMzj/lORv3X/CCH7mf56jbcoIvm5ORMZBIwQ/RXGlo5szgi9R6yu0
MQjBt1f8LpGWjOB3+dzSPluM4AfLCZpJNSP4/Ra+ZRsnI/geP++s1VuM4Ks6
LvsYuwnBL71Ykn39EILvzDH9jtklBP/VkaO5p28h+BMbv/yLf4zgAwDBwgIr

           "]]}, Annotation[#, "Charting`Private`Tag$2849#1"]& ], 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0, 0]], 
          LineBox[CompressedData["
1:eJwVx3s4lQccwHGlNgsplx63zjrJZpHMed93puT3e0Qq53E5KXddjmiOWFHz
tBihZrZyWZZK9YiJFDo71mNd5hxj3UPoOBJq2nkvLp2YMmfv/vg+3+cj3Jkc
EjfXwMBAzPf/kzOM5yzrFmGTvDigpFMLmmVvtkXzPrvuDYzw3qR8dqWMd077
VtKzSwsrjBqjrHpEGKSxETznrS4M+3VBrwhpw/Ojzt1a8KusTH7zVIQCyeUi
Za8W7O95P7vTL8K8cVXvRL8W2m1Sm9NeilDiOikNfqWFkn8Ha60mRWjSO2B2
f1YL/Ucrik/PJ1DI1gfetaBh86nyo52WBDpfLXfY7kSDy+vyhlBHAiUXLPKv
raMh//VExw2CwJ7Z5NxvJTRErg1YmeJLYHqBxELwBQ1BJgPfd4USaNomITd+
Q4Myu/WVII5AvWwNM1lCQzU2pF9LI9DMp4bcVUuD8c9jc1xzCTyUY2AZcpuG
ouI9JyNKCFTv25/X00VDQfvI9scXCdxamPSdHU2D4cXry13lBLrZBToO6Wlg
207YPlER6PSkKTh+CQMz+y4IXJ8QaL7Wy/yICwPHVPNtk14QGL6wJl6IDByN
Sd48qSPw1qLywIxtDBiec0mNm0diVkb6vWgZAxMfj3YIrEjcYa/pe5fNwHse
tFe+I4lkfGSm2ykGSjnP830EiXFLW5pG6hg4zR73OOhLotywPjtaxYB9sUf7
P1tIjAnNHQp9ykDLLVupi5TEGcnB7hcsA2piLlWTSmJT9liU+zwWUoK89KY5
JD60D/5qrg0L6fLDs80lJL4/4vFR4WoWqs5NfWBfSaJbjFeCwpeFoE9bTXbK
SVTAJ94xESwkGf/kO6EiMVxyplqVwoJRwc20hC4SIx9PVtXlstBWLGg8MUyi
eCbp81VlLEwPH1lhqCMxdpssJrGehWr12h8iDSl8sDTE2qWVhTs271bNWlAY
bnlLWtvHwh69SWueA4U+Byz86sZYWCULS/jdnUJBbk6z73wOpMJL6OdDobXq
a+UZOw6sD4vNG0IoTNkbtf2AGwfewinr3bsofOGvPL5wAwf5AWrn+/sp3PzI
T+IVzYFEsJiyPUKhmbKhlvuSg+Me4gMNxRTqXlacjDnGgf+0ps61gkL31MNL
gs9y4IhV49GNFEqv7l+pbuAg7XFqYk8LhXLb8UfCdg58jEo1VAeFO8ZDTRgN
B04Zy7IO8b68xHnQv5+DhbpLjrd5T60xUFTy7h34be/GTgoL8mpiY59xIGsa
MojqolBhp2/sGODg5G5Xx6xuCk39qsOvD3GgVbUm3VVTeKPsbVXeKw4eegaa
L+qj0Oj2w0PDvOX1vYotvINfXgyCvznIPEPr+3mPrA58O83bMnVx0ZiGQsvW
CnESzcE6h2iF1QCFiaMBOgnHgcOpvyIieCssl/9Zz9vILEVfznuO59RZ01EO
Ot9m+zs9p7A058KGNt4JHdVqz0EKW2wmyzzHORD7u2dm8jb1vptcytv9ZrOD
ineY9Px6He+ZSw9k4iEKmSubuLoJDgY/DFtcxPuzrg+VC15z8MePg790886e
1pXG875snBhhN0zhfcEdmYp3YZZuNpa3zfpzKNRx8B+HbVx3
           "]]}, Annotation[#, "Charting`Private`Tag$2849#2"]& ]}}, {}, {}}, {
      LineBox[{{1.419714227381436*^6, 55000}, {
        1.419714227381436*^6, 60000}}]}}, {
    DisplayFunction -> Identity, Ticks -> {{{1.419714227381436*^6, 
         FormBox[
          TagBox[
           InterpretationBox[
           "\"1419714.\"", 1.419714227381436*^6, AutoDelete -> True], 
           AccountingForm], TraditionalForm]}, {1500000, 
         FormBox["1500000", TraditionalForm]}}, Automatic}, 
     AxesOrigin -> {1.3*^6, 55000.}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
       "\"\\!\\(\\*StyleBox[\\\"w0\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\)\"", TraditionalForm]}, 
     AxesOrigin -> {1.3*^6, 55000.}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{1.3*^6, 1.5*^6}, {54940.63434777542, 63393.03926051426}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {{{1.419714227381436*^6, 
         FormBox[
          TagBox[
           InterpretationBox[
           "\"1419714.\"", 1.419714227381436*^6, AutoDelete -> True], 
           AccountingForm], TraditionalForm]}, {1500000, 
         FormBox["1500000", TraditionalForm]}}, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"Constant \\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\) = 60000\"", 
       "\"\\!\\(\\*SubscriptBox[\\(c\\), \\(r\\)]\\) = \
\\!\\(\\*StyleBox[\\\"f\\\",FontSlant->\\\"Italic\\\"]\\)(\\!\\(\\*StyleBox[\\\
\"w0\\\",FontSlant->\\\"Italic\\\"]\\))\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    AbsoluteDashing[{2, 2}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    AbsoluteDashing[{2, 2}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    AbsoluteDashing[{1, 0}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    AbsoluteDashing[{1, 0}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "2"}], "}"}], "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}], "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}]}], "]"}]& ), Editable -> True], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.697236388338827*^9, 3.6972364329200373`*^9, 
  3.697236484285096*^9, 3.6973178560229964`*^9, 3.6973235333224936`*^9, 
  3.698044393544677*^9, 3.698044832940172*^9, 3.7314215576752605`*^9},
 TextAlignment->Center,ExpressionUUID->"b8d344b7-2e46-433e-8ab2-a7d1ad9b0bcc"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.9.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Consumption as a function of wealth",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
   3.5305648276488047`*^9}, {3.530565115734282*^9, 3.530565120441551*^9}, {
   3.530565584010066*^9, 3.530565587296254*^9}, {3.5305663222572913`*^9, 
   3.530566342809467*^9}, {3.5305681591723566`*^9, 3.530568165991747*^9}, 
   3.5390216355000916`*^9, 3.5390347459929686`*^9},
 TextAlignment->Center,ExpressionUUID->"a1152364-5b3d-493e-af9c-92b978d54528"],

Cell[TextData[{
 "A plot of utility, in Figure 8.10, based on time spent on real estate ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "r"], TraditionalForm]],ExpressionUUID->
  "d886548f-2a91-41d0-b302-245e6face8b7"],
 ", and initial retirement day wealth, ",
 StyleBox["w0",
  FontSlant->"Italic"],
 ", shows that under the specified conditions optimum utility is primarily \
dependent on ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "r"], TraditionalForm]],ExpressionUUID->
  "d0fa4604-f949-4475-84af-c96846579719"],
 " with the optimum where we previously calculated it at just over 9%."
}], "Text",
 CellChangeTimes->{{3.5390216355000916`*^9, 3.5390216355000916`*^9}, {
  3.5390347459929686`*^9, 3.5390347459939685`*^9}, {3.539992700830518*^9, 
  3.539992733896409*^9}, {3.5411907040872583`*^9, 
  3.5411907174120207`*^9}},ExpressionUUID->"24df2852-9930-4b0a-a7b3-\
72750c874b34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"constantwealthplot", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{"ur", ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["S", "r"], ",", ".01", ",", ".25"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w0", ",", 
      RowBox[{"1.3", " ", 
       SuperscriptBox["10", "6"]}], ",", 
      RowBox[{"1.5", " ", 
       SuperscriptBox["10", "6"]}]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SubscriptBox[\(S\), \(r\)]\)    \>\"", ",", 
       "\"\<           Wealth\>\"", ",", "\"\<ur    \>\""}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1300000", ",", "\"\<1.3 Mil\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1400000", ",", "\"\<1.4 Mil\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1500000", ",", "\"\<1.5 Mil\>\""}], "}"}]}], "}"}], ",", 
       "Automatic"}], "}"}]}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.410377583873625*^9, 3.539021635501091*^9, 
  3.5390347459949684`*^9},ExpressionUUID->"b557ade6-85d0-454a-85e4-\
45eb9bb66534"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx0nXk8Vd/3/8m9IrOKyhCFkpQyNNK5iYQ0aEAqRKMoTdIkTShlSBGhUikq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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[
        TagBox[{Polygon3DBox[CompressedData["
1:eJxNnHXcVcXXxe+5d84ZRDERLEBQEAMVFRsFVETEAEQRBQEDsLDAQkUxUAEL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           "]], Polygon3DBox[CompressedData["
1:eJw1m3f8j9X7x+91zjtkK6NNWoi0NMhM2tEglREtTZWSSFGKokRpiEI7VCgp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           "]], Polygon3DBox[CompressedData["
1:eJwt13nYjlUaAPA3X+/7IdkyXc2QZcJMZWmmqVCpaFOkkBAttglF1pE9siRb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           "]]},
         Annotation[#, "Charting`Private`Tag$2924#1"]& ]],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0rkvZlEYB+Bj35dGjJ0oZUTEMMX4C6imNJ2OgkKByhbLWKMZ0aOXoZ/E
VMoZw9iJWCKRCIkEkXgOxXuf33vu951z7rm3qr37a1dCCGFOTQoxD7icsSs5
hHz2sYIjrOUsm7nIVq7wG3+ykxv8rfrlA07wkgu84wpfuM7MFL/lJmus+6T+
6scYN1aYFMKW/gP/sdZYkbwt18XNJoawgzTeG683liL/N/agb9DvysXyHku4
z1IesIyHLOcRK3jMSp7wkY3mSDXnqf673KOq7fePvoAbTOcanz3XMm/5g+cc
5x53VZ/8ix1cZRuX2MIFfuE0P3KI5Rw29w1nrJvHUTareXvKje+OOfE+sznF
rLhXZnKcGfF/TI/vkWm8jnPLqXEt813xkzV74xnKg7xgcnwu5/BZnxS/j8S3
Yw9PmqaE9+/mFRXxR7I=
       "]]}, 
     {GrayLevel[0.2], 
      Line3DBox[{1134, 1407, 1765, 1316, 1133, 1766, 1317, 1135, 1408, 1767, 
       1318, 1489, 1409, 1513, 1601, 1319, 1603, 1602, 1120, 1514, 1604, 1320,
        1607, 1605, 1947, 1606, 1515, 1321, 1490, 1751, 1768, 1322, 1136, 
       1769, 1323, 1137, 1770, 1324, 1138, 1771, 1325, 1139, 1772, 1326, 1140,
        1773, 1327, 1141, 1774, 1328, 1142, 946, 1329, 1410}], 
      Line3DBox[{1144, 1677, 1837, 1143, 1775, 1330, 1145, 1411, 1776, 1331, 
       1491, 1412, 1516, 1608, 1332, 1611, 1609, 1610, 1777, 1517, 1612, 1333,
        1615, 1613, 1948, 1614, 1518, 1334, 1492, 1931, 1413, 1335, 1146, 
       1678, 1838, 1147, 1778, 1336, 1148, 1779, 1337, 1149, 1780, 1338, 1150,
        1781, 1339, 1151, 1782, 1340, 1152, 1783, 1341, 1153}], 
      Line3DBox[{1155, 1679, 1839, 1154, 1680, 1840, 1156, 1414, 1784, 1342, 
       1493, 1415, 1519, 1616, 1655, 1617, 1494, 1618, 1752, 1785, 1520, 1619,
        1620, 1495, 1621, 1949, 1416, 1521, 1343, 1496, 1932, 1417, 1344, 
       1157, 1681, 1841, 1158, 1682, 1842, 1159, 1786, 1345, 1160, 1787, 1346,
        1161, 1788, 1347, 1162, 1789, 1348, 1163, 1790, 1349, 1164}], 
      Line3DBox[{1166, 1683, 1843, 1165, 1684, 1844, 1167, 1418, 1685, 1915, 
       1497, 1419, 1522, 1622, 1656, 1623, 1498, 1624, 1950, 1420, 1523, 1625,
        1626, 1499, 1627, 1951, 1421, 1529, 1350, 1500, 1933, 1422, 1351, 
       1168, 1686, 1845, 1169, 1687, 1846, 1170, 1688, 1847, 1171, 1791, 1352,
        1172, 1792, 1353, 1173, 1793, 1354, 1174, 1794, 1355, 1175}], 
      Line3DBox[{1177, 1689, 1848, 1176, 1690, 1849, 1178, 1423, 1424, 1934, 
       1179, 1663, 1425, 1664, 1426, 1657, 1526, 1527, 1525, 1916, 1427, 1524,
        1428, 1528, 1532, 1531, 1917, 1429, 1530, 1430, 1180, 1918, 1431, 
       1432, 1181, 1691, 1850, 1182, 1692, 1851, 1183, 1693, 1852, 1184, 1694,
        1853, 1185, 1795, 1356, 1186, 1796, 1357, 1187, 1797, 1358, 1188}], 
      Line3DBox[{1190, 1695, 1854, 1189, 1696, 1855, 1191, 1433, 1856, 1753, 
       1192, 1665, 1434, 1666, 1435, 1658, 1535, 1536, 1534, 1754, 1939, 1533,
        1436, 1537, 1540, 1539, 1919, 1437, 1538, 1438, 1193, 1920, 1439, 
       1440, 1194, 1697, 1857, 1195, 1698, 1858, 1196, 1699, 1859, 1197, 1700,
        1860, 1198, 1701, 1861, 1199, 1798, 1359, 1200, 1799, 1360, 1201}], 
      Line3DBox[{1203, 1702, 1862, 1202, 1703, 1863, 1204, 1441, 1864, 1755, 
       1205, 1667, 1668, 1541, 1546, 1545, 1206, 1543, 1544, 1940, 1542, 1548,
        1547, 1207, 1550, 1941, 1551, 1549, 1442, 1208, 1921, 1443, 1444, 
       1209, 1704, 1865, 1210, 1705, 1866, 1211, 1706, 1867, 1212, 1707, 1868,
        1213, 1708, 1869, 1214, 1709, 1870, 1215, 1800, 1361, 1216}], 
      Line3DBox[{1220, 1801, 1362, 1218, 1802, 1363, 1222, 1446, 1803, 1364, 
       1501, 1447, 1562, 1628, 1365, 1630, 1629, 1952, 1764, 1563, 1631, 1366,
        1634, 1632, 1953, 1633, 1564, 1367, 1502, 1758, 1804, 1368, 1228, 
       1805, 1369, 1230, 1806, 1370, 1232, 1807, 1371, 1234, 1808, 1372, 1236,
        1809, 1373, 1238, 1810, 1374, 1240, 1811, 1375, 1242}], 
      Line3DBox[{1241, 1881, 1718, 1239, 1880, 1717, 1237, 1879, 1716, 1235, 
       1878, 1715, 1233, 1877, 1714, 1231, 1876, 1713, 1229, 1875, 1712, 1227,
        1449, 1874, 1757, 1226, 1448, 1559, 1561, 1943, 1560, 1225, 1557, 
       1558, 1553, 1763, 1942, 1554, 1224, 1555, 1556, 1552, 1670, 1669, 1223,
        1756, 1873, 1445, 1221, 1872, 1711, 1217, 1871, 1710, 1219}], 
      Line3DBox[{1244, 1719, 1882, 1243, 1812, 1376, 1245, 1450, 1813, 1377, 
       1503, 1451, 1565, 1635, 1378, 1638, 1636, 1637, 1814, 1566, 1639, 1379,
        1642, 1640, 1954, 1641, 1567, 1380, 1504, 1935, 1452, 1381, 1246, 
       1720, 1883, 1247, 1815, 1382, 1248, 1816, 1383, 1249, 1817, 1384, 1250,
        1818, 1385, 1251, 1819, 1386, 1252, 1820, 1387, 1253}], 
      Line3DBox[{1255, 1721, 1884, 1254, 1722, 1885, 1256, 1453, 1821, 1388, 
       1505, 1454, 1568, 1643, 1659, 1644, 1506, 1645, 1759, 1822, 1569, 1646,
        1647, 1507, 1648, 1955, 1455, 1570, 1389, 1508, 1936, 1456, 1390, 
       1257, 1723, 1886, 1258, 1724, 1887, 1259, 1823, 1391, 1260, 1824, 1392,
        1261, 1825, 1393, 1262, 1826, 1394, 1263, 1827, 1395, 1264}], 
      Line3DBox[{1266, 1725, 1888, 1265, 1726, 1889, 1267, 1457, 1727, 1922, 
       1509, 1458, 1571, 1649, 1660, 1650, 1510, 1651, 1956, 1459, 1572, 1652,
        1653, 1511, 1654, 1957, 1460, 1578, 1396, 1512, 1937, 1461, 1397, 
       1268, 1728, 1890, 1269, 1729, 1891, 1270, 1730, 1892, 1271, 1828, 1398,
        1272, 1829, 1399, 1273, 1830, 1400, 1274, 1831, 1401, 1275}], 
      Line3DBox[{1277, 1731, 1893, 1276, 1732, 1894, 1278, 1462, 1463, 1938, 
       1279, 1671, 1464, 1672, 1465, 1661, 1575, 1576, 1574, 1923, 1466, 1573,
        1467, 1577, 1581, 1580, 1924, 1468, 1579, 1469, 1280, 1925, 1470, 
       1471, 1281, 1733, 1895, 1282, 1734, 1896, 1283, 1735, 1897, 1284, 1736,
        1898, 1285, 1832, 1402, 1286, 1833, 1403, 1287, 1834, 1404, 1288}], 
      Line3DBox[{1290, 1737, 1899, 1289, 1738, 1900, 1291, 1472, 1901, 1760, 
       1292, 1673, 1473, 1674, 1474, 1662, 1584, 1585, 1583, 1761, 1944, 1582,
        1475, 1586, 1589, 1588, 1926, 1476, 1587, 1477, 1293, 1927, 1478, 
       1479, 1294, 1739, 1902, 1295, 1740, 1903, 1296, 1741, 1904, 1297, 1742,
        1905, 1298, 1743, 1906, 1299, 1835, 1405, 1300, 1836, 1406, 1301}], 
      Line3DBox[{1315, 1488, 1487, 1930, 1314, 1914, 1750, 1313, 1913, 1749, 
       1312, 1912, 1748, 1311, 1911, 1747, 1310, 1910, 1746, 1309, 1909, 1745,
        1308, 1486, 1485, 1929, 1307, 1484, 1598, 1600, 1946, 1599, 1306, 
       1596, 1597, 1591, 1945, 1593, 1592, 1305, 1594, 1595, 1590, 1676, 1675,
        1304, 1762, 1908, 1483, 1303, 1907, 1744, 1302, 1928, 1481, 1480, 
       1482}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{639, 802, 1766, 640, 811, 1775, 660, 1840, 821, 671, 1844, 
       831, 682, 1849, 841, 693, 1855, 851, 704, 1863, 861, 715, 1872, 871, 
       1802, 726, 881, 1812, 737, 1885, 891, 748, 1889, 901, 759, 1894, 911, 
       770, 1900, 921, 781, 1907, 931, 792}], 
      Line3DBox[{230, 229, 1513, 398, 613, 239, 1516, 407, 615, 244, 1519, 
       416, 617, 249, 1522, 425, 619, 1664, 254, 434, 621, 1666, 259, 443, 
       1541, 623, 264, 452, 1552, 625, 269, 1562, 461, 627, 274, 1565, 470, 
       629, 279, 1568, 479, 631, 284, 1571, 488, 633, 1672, 289, 497, 635, 
       1674, 294, 507, 1590, 637, 301, 304}], 
      Line3DBox[{642, 377, 1022, 524, 1947, 1083, 405, 1026, 530, 1948, 1086, 
       414, 1030, 1949, 536, 1089, 423, 1034, 1951, 542, 1092, 432, 1917, 
       1038, 548, 1095, 441, 1919, 1042, 554, 1098, 1941, 450, 1046, 560, 
       1101, 1943, 459, 1050, 566, 1953, 1104, 468, 1054, 572, 1954, 1107, 
       477, 1058, 1955, 578, 1110, 486, 1062, 1957, 584, 1113, 495, 1924, 
       1066, 590, 1116, 504, 1926, 1070, 596, 1119, 1946, 515, 1074, 392, 
       1014}], Line3DBox[{643, 943, 1023, 944, 1768, 644, 950, 1027, 1931, 
       951, 662, 955, 1031, 1932, 956, 673, 960, 1035, 1933, 961, 684, 965, 
       1918, 1039, 966, 695, 970, 1920, 1043, 971, 706, 975, 1921, 1047, 976, 
       717, 1874, 980, 1051, 981, 1804, 728, 985, 1055, 1935, 986, 739, 990, 
       1059, 1936, 991, 750, 995, 1063, 1937, 996, 761, 1000, 1925, 1067, 
       1001, 772, 1005, 1927, 1071, 1006, 783, 1012, 1929, 1075, 1013, 794}], 
      Line3DBox[{8, 1136, 23, 1146, 38, 1157, 53, 1168, 68, 1181, 83, 1194, 
       98, 1209, 113, 1227, 1228, 128, 1246, 143, 1257, 158, 1268, 173, 1281, 
       188, 1294, 203, 1308, 218}], 
      Line3DBox[{645, 804, 1769, 646, 1838, 813, 663, 1841, 823, 674, 1845, 
       833, 685, 1850, 843, 696, 1857, 853, 707, 1865, 863, 718, 1875, 873, 
       1805, 729, 1883, 883, 740, 1886, 893, 751, 1890, 903, 762, 1895, 913, 
       773, 1902, 923, 784, 1909, 933, 795}], 
      Line3DBox[{647, 805, 1770, 648, 814, 1778, 664, 1842, 824, 675, 1846, 
       834, 686, 1851, 844, 697, 1858, 854, 708, 1866, 864, 719, 1876, 874, 
       1806, 730, 884, 1815, 741, 1887, 894, 752, 1891, 904, 763, 1896, 914, 
       774, 1903, 924, 785, 1910, 934, 796}], 
      Line3DBox[{649, 806, 1771, 650, 815, 1779, 665, 825, 1786, 676, 1847, 
       835, 687, 1852, 845, 698, 1859, 855, 709, 1867, 865, 720, 1877, 875, 
       1807, 731, 885, 1816, 742, 895, 1823, 753, 1892, 905, 764, 1897, 915, 
       775, 1904, 925, 786, 1911, 935, 797}], 
      Line3DBox[{651, 807, 1772, 652, 816, 1780, 666, 826, 1787, 677, 836, 
       1791, 688, 1853, 846, 699, 1860, 856, 710, 1868, 866, 721, 1878, 876, 
       1808, 732, 886, 1817, 743, 896, 1824, 754, 906, 1828, 765, 1898, 916, 
       776, 1905, 926, 787, 1912, 936, 798}], 
      Line3DBox[{653, 808, 1773, 654, 817, 1781, 667, 827, 1788, 678, 837, 
       1792, 689, 847, 1795, 700, 1861, 857, 711, 1869, 867, 722, 1879, 877, 
       1809, 733, 887, 1818, 744, 897, 1825, 755, 907, 1829, 766, 917, 1832, 
       777, 1906, 927, 788, 1913, 937, 799}], 
      Line3DBox[{655, 809, 1774, 656, 818, 1782, 668, 828, 1789, 679, 838, 
       1793, 690, 848, 1796, 701, 858, 1798, 712, 1870, 868, 723, 1880, 878, 
       1810, 734, 888, 1819, 745, 898, 1826, 756, 908, 1830, 767, 918, 1833, 
       778, 928, 1835, 789, 1914, 938, 800}], 
      Line3DBox[{657, 945, 946, 658, 819, 1783, 669, 829, 1790, 680, 839, 
       1794, 691, 849, 1797, 702, 859, 1799, 713, 869, 1800, 724, 1881, 879, 
       1811, 735, 889, 1820, 746, 899, 1827, 757, 909, 1831, 768, 919, 1834, 
       779, 929, 1836, 790, 1015, 1930, 1016, 1017}], 
      Line3DBox[{791, 930, 1928, 1007, 780, 920, 1899, 769, 910, 1893, 758, 
       900, 1888, 747, 890, 1884, 736, 880, 1882, 725, 1801, 870, 1871, 714, 
       860, 1862, 703, 850, 1854, 692, 840, 1848, 681, 830, 1843, 670, 820, 
       1839, 659, 810, 1837, 638, 1765, 801, 939, 1018}], 
      Line3DBox[{793, 932, 1072, 1008, 1908, 782, 922, 1068, 1002, 1901, 771, 
       912, 1064, 1938, 997, 760, 902, 1922, 1060, 992, 749, 1821, 892, 1056, 
       987, 738, 1813, 882, 1052, 982, 727, 1803, 872, 1048, 977, 1873, 716, 
       862, 1044, 972, 1864, 705, 852, 1040, 967, 1856, 694, 842, 1036, 1934, 
       962, 683, 832, 1915, 1032, 957, 672, 1784, 822, 1028, 952, 661, 1776, 
       812, 1024, 947, 641, 1767, 803, 1020, 940, 1019}], 
      Line3DBox[CompressedData["
1:eJwV0CsvBmAYh/H7ndMEQWAT2N4gCILNeYwxxhjzjjHGnF7n8QU0H4EZxQSV
RCAQCAQCgUAgEChIgs1PuHb97+tpT3JyJbWciIg0vjMiajIjavFlV/Anb+dE
jNmjWMKHVs7vvOVtxB7GIt60Ml7TX+0hexALeHHv6aX2sz3A/ZhHif6kJe1H
TnEf5lDo7UErtu+5l3uwq8/ynVbEt9zNm3oXz+BGK+Br3tA77Q6kcaXl8yWv
e2u32zCNCy2PV/Vzu9VuwRTO3Dt6rn1qN3MTJvGTHXGiZdnH3MgNmPj/S29H
WsI+5HquwzgO3L/YR7W7ElX4Aw5TM34=
       "]]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJwUWHc41e8bTlahQkvIKIrM7FCPjBKyImWvimRk7z2OUUoLWX0lCi1k5Lwf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    "]],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(S\\), \\(r\\)]\\)    \"", TraditionalForm], 
    FormBox["\"           Wealth\"", TraditionalForm], 
    FormBox["\"ur    \"", TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0.01, 0.25}, {1.3*^6, 1.5*^6}, {2.381940675950641, 
   2.7690956383707244`}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{1300000, 
      FormBox["\"1.3 Mil\"", TraditionalForm]}, {1400000, 
      FormBox["\"1.4 Mil\"", TraditionalForm]}, {1500000, 
      FormBox["\"1.5 Mil\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.41046888220175*^9, 3.410504965421875*^9, 
  3.5303609889248962`*^9, 3.530568245634302*^9, 3.530572379066721*^9, 
  3.531617864612409*^9, 3.5316194847320747`*^9, 3.5316197617699203`*^9, 
  3.533148218115283*^9, 3.5332364616713114`*^9, 3.5332400511446176`*^9, 
  3.533683637515625*^9, 3.5337353264630394`*^9, 3.533756236828125*^9, 
  3.539021230984954*^9, 3.539021635503091*^9, 3.5390347459969687`*^9, 
  3.5399887624452553`*^9, 3.5401275417580824`*^9, 3.5405612722832603`*^9, 
  3.541186555787989*^9, 3.541187915236745*^9, 3.541188039235838*^9, 
  3.5411910712552595`*^9, 3.541191169491878*^9, 3.541191251404563*^9, 
  3.541191307893794*^9, 3.5416041770184298`*^9, 3.612696909918207*^9, 
  3.6972339930595393`*^9, 3.6972358768140826`*^9, 3.697317856194481*^9, 
  3.6973235334307814`*^9, 3.6980443937742867`*^9, 3.6980448330594683`*^9, 
  3.731421557846716*^9},
 TextAlignment->Center,ExpressionUUID->"918c7642-b8fc-492d-8b86-42a8ffc4ccf8"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.10.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Utility during retirement as a function of ",
  FontFamily->"Times New Roman",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "r"], TraditionalForm]],
  FontFamily->"Times New Roman",
  FontSize->12,ExpressionUUID->"20e63591-2ca7-4ea9-8449-afa7c1e67d33"],
 StyleBox[" and w0",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
  3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
  3.5305648276488047`*^9}, {3.530565115734282*^9, 3.530565120441551*^9}, {
  3.530565584010066*^9, 3.530565587296254*^9}, {3.5305663222572913`*^9, 
  3.530566342809467*^9}, {3.5305681591723566`*^9, 3.530568165991747*^9}, {
  3.530568269005639*^9, 3.5305682875136976`*^9}, {3.539021635503091*^9, 
  3.5390216355050917`*^9}, {3.5390347459969687`*^9, 3.5390347459969687`*^9}},
 TextAlignment->Center,ExpressionUUID->"57533565-e436-4cfe-9e67-08fd8ffaa532"],

Cell[TextData[{
 "Returning to the idea mentioned at the beginning of this section, as one \
grows older during retirement, the March of Time erodes one's efficiency \
and/or patience with the ownership of property. The result is that the output \
of the return function that influences utility in retirement, something we \
might now call effective return, ",
 StyleBox["er = ",
  FontSlant->"Italic"],
 "\[Rho] ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SubscriptBox["S", "r"], 
    RowBox[{
     SubscriptBox["S", "r"], "+", "1"}]], TraditionalForm]],ExpressionUUID->
  "d2eedf6c-6665-4586-b620-01f68444d7a7"],
 ", drops in value as less time or skill is devoted to real estate. The \
natural conclusion of this is that at some time the attraction of passive \
investments begins to compete favorably with real estate. "
}], "Text",
 CellChangeTimes->{
  3.531620253686056*^9, {3.5390216355060916`*^9, 3.5390216355170918`*^9}, {
   3.5390347459979687`*^9, 3.539034745998969*^9}, 3.5390945993043823`*^9, {
   3.539992743765974*^9, 
   3.53999282097639*^9}},ExpressionUUID->"c02e4066-6fb3-42ad-a4a6-\
f96d0ead8561"],

Cell[TextData[{
 "In Figure 8.11 effective return is declining with various combinations of \
lower \[Rho] and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "r"], TraditionalForm]],ExpressionUUID->
  "c89b8857-fc7a-40db-a1fe-7bd6d66ca0be"],
 " to a point that it drops below the cash flow rate provided by ",
 StyleBox["cru",
  FontSlant->"Italic"],
 " above (the flat plane in Exhibit 8.11). One considers selling if competing \
returns on the reinvested after tax sale proceeds are at or above the real \
estate cash flow in ",
 StyleBox["cru",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.530568721301509*^9, 3.5305687695392675`*^9}, {
  3.5316202820896807`*^9, 3.5316202999287014`*^9}, {3.5390216355170918`*^9, 
  3.539021635518092*^9}, {3.539034745998969*^9, 3.5390347459999685`*^9}, {
  3.5399928336631155`*^9, 
  3.5399928806428027`*^9}},ExpressionUUID->"cfcbfaf5-f06b-49a5-9161-\
79dc454a8115"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1s", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"\[Rho]", " ", 
      FractionBox[
       SubscriptBox["S", "r"], 
       RowBox[{
        SubscriptBox["S", "r"], "+", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["S", "r"], ",", ".05", ",", ".25"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\[Rho]\>\"", ",", 
        "\"\<      \!\(\*SubscriptBox[\(S\), \(\(r\)\(\\\ \)\)]\)\>\"", ",", 
        "\"\<er      \>\""}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2s", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"cru", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["S", "r"], ",", ".05", ",", ".25"}], "}"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"GrayLevel", "[", ".7", "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"shtwo", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p1s", ",", "p2s"}], "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.410377669342375*^9, 3.4103776999205*^9}, 
   3.41037777120175*^9, 3.539021635519092*^9, 
   3.5390347459999685`*^9},ExpressionUUID->"4a04c331-3e9c-4aed-813e-\
1a199987c60e"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxdnHlUTe8X/yuphEiZIlNFKkKI0KOkCSkic0QhUoZSVGhCSaNmzfM8z93m
USrKVGgSmhWRin4+v9/Z+/mtr3+s9Vpnnbvvq3v3Oed9n/0s1zM+oM/Bxsb2
gZONbcq//x9YpSf4+eaQZ7Kagn6+MWTnzB75rfeuE7Xx472a3OXIU2767/aY
epfUZX2406TwHHnx1+Leh+oORCJXmleK9RJ549GvbnddHpHLPiZNRi2vkV/V
5w7YZuhGEs1SApNGm5H/fio0mPnIk3zTHr4wNLcV+b3XaxQ3JHkT3//7rx35
tFkKTxJe+JFcnlxruehO5G4q2l/FfzwlLTebz7ZkdiGfUZQmfMApmEx8HlO1
LP+CXPPEjkqXxaFE+PCitcJN3cg9RytMnieEEfnybQKsjl7kbz01haaTCKK7
8cToqaF+5IvXN5eqNkQSmzDLD5OTg8j1np81cjgTTcBzkvEMe27TZHLwzrNH
SQXm6Bl4g/PDLXEH7NAz8J/HE2KtlR+hZ+CznlzgWy3sjp6BL7e8VTlnvhd6
Br7x7KO7E7P90DNwFfXArZ95A9Ez8IQFR36f5whBz8A3z2h/dWIyFD0DL5y8
mKo1EY6egat9H36s/DsSPQN/+fn2pW0/o9Ez8OPNnKrrvseiZ+Bdz51Fxb7F
o2fgJsXz2IX6E9Gzeem3SQXhdMI+UeIW9toKPQOPK+dc5WPzAD0Dj+XyVByc
4Yaegd+Njbjq/vYJegZ+SCMreFO4H3oGvnq4qv6tcRB6Bj6pbjRZIByKnoF3
L/7p5WIbjp6BNw5Yrz3THYmegRcUcVds2B+DnoFHu7ue5MyIQ8/A3c8tHHkl
lIiegcsv0qo4uDMZPQOXsZvrvv16CnoGLtH/7qRYZCp6Vpj/6pZleRYRy3f9
lG9wDz0D78me9sna6xF6Bv7mWPHVZZ0e6Bm43Durq+y3fdEzcH8duasdc4LQ
M/C/hrezzxwKRc/ApWOPbjmwPAI9Az/dLZut2B+FnoG7ic/bIpMTi56BF5//
kSVin4CegVsc7F7kKJ6MnoHPuf72uM3jFPQMPNa90v/Wj1T0DFwxNbPl2rF0
9Az8/YuIRZeKMtAz76WckUyjPJJWzS1a8sIWPQPftK3UPVfFFT0Dd3WzEfCM
9ELPwPu+KHgaTX2KnoGLBN11FEkNQc/AtdTb1F3bw9EzcOsRMv3P7Gj0DDwu
OOjZxZ1x6Bn42z2TTq+NE9EzcNvb0pEh9cnoGfhCLV2uI+dT0TPw5JUuBnyT
aegZuMoEq6LMKwM9A//wYmDl7bVZ6Bm4WdSS++srstFzI+upydDcQtIwp+oH
+xoH9AycZ5X+DgVZd/QMPErJ4C77EV/0DFw0Ja399PZg9Az8O9k4pbg2DD0D
L61LF11+Mgo9A3c/uUn5Xn8segau15dxvt0qET0D99nhX7aMOwU9A2ezP/5K
sz4VPQO/ULvo813vdPSMHgTe/0zWzUTPwGWPB3C3r8pGz8CDQk8s4P+Wg57R
W8/i1QrZeehZY1rxyFzdYvJr/WCKoMUD9Az80oq1PppCnugZeHPcuTfzRv3R
M/AIv31OAz0h6Bn4idavsS/eRaBn4AKidjXpVTHoGXjNhaU93lkJ6Bl40eEP
djsak9Ez8MW/YwWTalLRM3Bzf/PwZSXp6Bl44w7lje45megZuHSbQNmUlGz0
DNzRpv2gaXQuegb+WTSp83NQPnoGvqvS8voRbxZ6lvm//0rJlwYXUadMR/QM
3GLxJTfdoSfoGbi15mNXi/uB6Bm4YsnbyurHYegZuNIJw8rX76LQM3Dln+MV
naLx6Bm4aJXy2VHZZPQMXOzJrE7rk6noGfhKvbd6U23T0TPwVdIhHU7RmegZ
uPjERb05ddnoGfjq6g0dPt9z0TNwCa/xM0sXFqBn4JJny9oj5AvRM/D5PhXr
5qUWoecFJyNM/vOqFOw9NtD1CD0Dj5ghrNCa742egXuK3rQ5axuMnoG/KdE9
pyMegZ6BLzijqrzneQx6Bn50cp04uZaInoE/r5th7+uUgp6BDwizmwl8TEPP
wPmMRgyc12WiZ+DS+d063LbZ6Bn4/ukfVe+9ykXPwE2Ovdw6vqoAPQN3i6mQ
ML1ViJ6xfssPzjc/F6Fn4D1hOg7ps0rQ8x+H+YlGLRWkImzWplJuF/QM3Fr6
4a5tVr7oGfgj5d1m6nkh6Bn4sZFy9V9ZkegZ+Kpw5aXh6XHoGfitmE6L6CPJ
6Bl4G5vop7+vU9EzcOUj5zQOHcpAz8ATksKz4xqz0DNwAe6uFRwHctEzcItT
Ys5HGvLRM75uhv6vRI1C9Aw8jKsx2eafT/AM/PCG710JYiXoGfj0UwKL3p0r
Rc8dyQ97HZOqyB6ZLSqKj13RM3AnbZWZzRv80TPwLrm47uzeUPQM3OFZai2n
fDR6Bi52IjdJ0zUBPQPX+3laTeNqCnoGnsL6JHdDKB09A2e/f0HKrzQTPQPX
2t8nXHQ5Bz0DD55vMuvz3Hz0DPxb63e2GYUs9Ax8WdO23wvSi9AzcJXsP0Nx
PCXoGbhxQGGP/MlS9Azc5+69zhcpZei5snlcPNq2hnTNeNen7e6GnoEPyB/Z
KvwxAD0Dt8zuLRkWDEfPwO9pSXa/zo1Bz8Dtewxn5Z1OQs/AyxVe+e23TUXP
wFX4RhIUDmegZ+DVzYLFMquz0TPwPVEbm8QmctEz8OfXtb/Mry9Az8DFl8n9
4dQqQs/AL3LVcFnnFqNn4LF9R2f/EilFz8B7X3YvNHEuQ8/A1+RYiHT/LEfP
8ZxXDMp1aonu9SNrDri6o2fgueuKX5y5E4iegU//JZi3RTYCPQPPOaTmXLQ2
Dj0Dl2lmSYt6JKNn4A+nvVvw9XEaegbetuU7e7xjJnoGvvnCzF5jhxz0DNzZ
e1WTjE0+egbeWaFQ8MuqED0DFx5f0/hhezF6Bl41J6+yMLcEPQO/LqGaH7Kl
DD0DX6L4Ktk2sxw9A392VC9Cf2MlenZb2xbWIVlHYppkZ5g88EDPwB8JuKjd
nR6MnoGXbedwrjoQiZ6BT+ibNsz2i0fPwP1UfjyMN0lBz8A3vU+I0/RMR8/A
X5icf/4jKws9A788dfmgT0suegbO49c8e8dkAXoGfmC+uq+JWxF6Bh7UvjJW
UaQEPQPvj5uSJ5hRip6BbzNre/ZZuRw9A3+4s+B99tsK9Az8La9fv6NhFXq+
ceRA++RkPXHWahHsuOWJnoEv/1k1N+ol9Qz89i7R5R/OR6Fn4K9d70gJ/ElA
z8AXGPf7i6qlomfgZXP9Qwo9MtAz8Kv5qlHHPmajZ+BLzv6MHxHPR8/Aa6aF
p7peL0TPwLe9FX//3/0seAbuHjd56ixnKXoG/tX6dXtyTBl6Bk4OJJz7q1GB
noE/EbP7sudHJXoG3j96zNDXt5pwCS9aPquniHg6bXRpUkgg+w2qDF4pWKF/
4HevnMoaFzEj3y71GSaNDiBfc21opXx1LJ4fuHjKxxO/4+Pw/Da7fBWH5tYT
ufrzXY0mfnh+4EKR+wyPc3ji+YG7TxbPWLGpCjnUv9NlMHq4ogrPjzmn9ewu
6QoLPB44mQz0+eIThcfDeb4Ebl62YLY/1g+vm6UktniIo5rUHB+5+T6zgCSf
KdHKMoojd+uX6odKmZOc+xvDdSwHkRd8O2jh9jQGjx9/PuI26vjPP9/m5II7
3ng88JB5i9ac+kw/53Ce1VtnKRY23sDj8X0ZsE+R/ROF54f65UYfCFmVe2P9
cH6V4XA7Sw1aP5ynavcft/QwMzweXvfhlMwPCTyxWA+cx2j9l+818p5YD7zu
fKWIacrrqkl26TNzNrYyzCenC+6uWadtS+JVC/xkZJ7h61ru3aK4N8cOORx/
+YJo3UM1R9JgoHNKRuYFHn9p0FcgfBPlcPz5j+wXrwa5EvXVmoO1tU14/FH3
8U/jKS7I4XjvB0M9wv+er8t6Ve8aGLzF48P81ras9nZHDsdXbmi/XOPpTeQT
FfjZ2N7j8Ysut5YeOvQEORw/+r5hwGyWP8k2kQv19aV5vvsO1/h7Aj7I4fjV
94tMRBwDyeuxuXoGBjTPv9s2ZPXO5SlyOL68f78cqzCUCJxwl5CRoTn/+BGt
NI5Vwcjh+A8lKrcFrcKJZgHf98nJz3h8VnFM1AKHEOSYt3uTfEO5SOK8xCmv
tvYrHn9NgiNgbVcocjiez0j2T9Gvf5/DO9x2vr49ePxaj2OuSkrhyOH4lYrS
8vMzYgh3u+1eA4M+PL5nPNXuWFgEcjhefv6qO0bX4oiSIttcGRn6/Y04N93C
hCMKORyv07ekqFQ6AT+HkN9mnth5PGn/ffy8Ab+4Lah/RroLfq6Az5o5STbN
8MTPDx5vuXbaOXkf/JwAL+s9+dLdJAA/D8BdEiqen9YKxr878O36pzaYG4bi
3xe4V5PzeGRAJP4dge96JHaalRGNfy/g33YVlL2qi8W/C/DAce3V/V/i0T9w
9bQ+Z072JPQM3HKT4u+ZzsnoE/gB/sdxvr4p6BNyWi1foXCHdU7oE7j8tpfr
xa3c0SfwptXe/DP1vNEn8IsLTgwNKQegT+B3bF0v9D4JRp/Aa8auvT3JE4Y+
gc+9dki14VYE+gQed1pIPEM3Fn0CH3kz4b3qZTz6BL5zfyu3n1IS+gSu3Nm2
zaElGX0C713y8nqhYCr6BO56rDRudF8a+gS+2Su9c/39dPQJeezL4MPlrF+P
0Sfw33kH0j7wPUGfwB+sGpvyPsQPfQJ/VK0pYSQUjD6Ba98JP9DXGYo+gS/e
NHrrUkIE+gTe2bMnrMcsGn0Cv374+/ev0xLRJ3BhBxG+9IvJ6BM4+5l9odfr
UtAn8K5tNzfLyKShT+DV80Jqhr3T0SfwhKGaU6kTGegTuFvtj+GrZ7LQJ+Su
2lOmblp90A19Apf/E2H8wsUbfQKX+KUca1H7FH0Cdxq9PuzKGYo+gd81LZvV
tSICfQI3GxZcs1UhGn0Cv2ysr+6sG4c+gcdttC0RqktGn8BXXpd8oXQyFX0C
D0lpbL3Sl4Y+gS/+dnvA53YG+gTuvVb0TwlvFvoEPseodnq/bzb6BO4cd0No
/upc9An56g4tlQbvJR7oE7j1NG+VCDY/9Am89fR13aNXg9EncLYdixad7ghD
n8CXLSx9bXAwCn0C3zli6G5UFos+gZ9+MUfjxqZE9An8hVJKR5FTKvoE3r7B
fqeSUjr6BD607Ghg5b/PFfgEzjFrzYR6Rhb6BD7nD9uxOqMc9Al8RW9TltbK
PPQJfMO76LmvPuajT8hRRzMctAI+eqJP4Ja25bO/nwlAn8DvinN8DR8OQZ+Y
S7uEqGimR6BP4Jw/d0aNm8agT+AVJ9q4omQT0CfwsnYiE2OZjD6BO6i2umvL
p6NPzNXHExUllmaiT+CqSdbDk5NZ6BN4jJ5G6Ku2HPQJnHfekgNxxXnoE/il
6n72e6EF6BN4rWVBymHbQvQJealgV6hqqIcX+gTONfZbYF96IPoEbnU/evC2
YRj6BP6TX/vQi1tR6BNz3YDJ3JVOcegTePfKuGWW/knoE3jKEcnSr69S0Cdw
ic7X4vKfM9An8PPR8S0XBrLQJ/AwI5vHHj9z0Cfwtg1HFFh/89AncOHRNT++
crHQJ/CEj/caH3IXoU/ge4r7pIKmF6NPyEVrplzkm/3vPgd8An8rJKaw1DIY
fQKvTZt7e/O7cPQJvHAvV8a+zTHoE3ha18+Bcx4J6BP4wcLrgvKjyegT+PPp
l1OqV6ahT+BF4Sd622yz0CdwuSHtB5dTc9Anvu6OfWKjbXnoE/gax90ltrNY
6BO4dm9gEvfSIvQJ3JV/kfW+zcXoE+uU9d7rsa8EfWKua2IvqPLRF30CLzjc
/U3MOwR9AlcdcdERJ5HoE3iTx2aWxJdY9An89IYPomtcktAncNOvxeXei1LR
J/A82bm/fYzT0Sfmuq/zdP3n56BP4M5iszwCLuWhT+Avb+hVPC0sQJ/AZ3Q0
W9ZPK0KfwJMe2s1rkClGn5hXr1+b3HCyBH0CH3n7Ru3F/VL0CTln/JEq6fAb
/ugTuNzL4zkWcaHoE/gS88ZjIQFR6BM4x5I9E1XO8egT+Pcz7RrmhcnoE/Pq
jU+XztiShj6Bv+E++i0oOQN9As9LaHCrDMlFn8AT7j7SOy5UgD6BBx1UlRl0
L0SfwNUEOGyKpxajT+AlE7qG0xVL0CfwbZ8LDhyyLkWfwNPrF20Lyi1Dn5Bn
8i3c+OEO+1P0iblx6/2Kwzlh6BNz2lTTwP6haPSJ57E/a2YnkYg+gX+PE49y
TklBn8BPPVkq8G5fOvrEfNV63h3Rnkz0CTxUi1Mnb0U++sTX3TZewlXIQp/A
d8yxmB+TUIQ+sR6HG8/rxqlP4DHjxrY/1ErRJ9ZpcmmrkE8Z+gQu2GUwSD6X
o0/ILWtOKNistQ9En8DNrolZ/iwKR5/AHTZLZB0isegTuNfY2uH0giT0CVy7
1Xceb2Aq+gR+QmFx+taTGegT+LmwQK2Li7PRJ3DT82GPqvwK0Cfwwk9z5k5I
FaFP4CVzmzo9HhWjT+AVyk9SJftK0CfwZzcP3yvdU4Y+gddHz9c8HleOPoE3
vnu75DtvJfqEfMn00UltNrZg9Alc1GRfoEtJBPoE/vLgjq9L7OPQJ/Bi/3kL
34Qlo0/gPs58rCX2aegTuPEdrrMGBpnoE7jy1b/ciSo56BP4iPaA1g7eQvQJ
3EDk+u2SEeoT+IHFg/sMDErQJ/Adcy8t431Tij6Br+b7MpygUo4+gc/lPluu
lV2B3jZ3JW1iY0smK2V3zt/22YbmHhmRtUNzk8injgsvdm1+iN7sg/vXdEom
Ep+rl3jPs9HczIPJb221ZR9clKb5WIjZ7W/lOvHERylnqDTak+ZgTH44/WFe
sWKfF3or2DstLdo2lrxfLj/a9dsHvUGdwePmgo/20lzrFlNnCU+zXsntMPT2
gKlTYOftT7yu4ejNi6nTI+SEr/7DCPQWztSpsMb63svzkegtlalzSWdrgJZk
FHqb3OKZLBedRno+fRNa9tcBvdknyp7573n1mhFbKn/0Y/Q2Q7SFX4qVSmqn
86h4/HCn3nytS/77/SB5yEUn6bQXehOateK6cFMK0fvqzXvSxxe9hdiVi8zT
TSFdg0tPB/gHoDfxsQtNfD3JZAuP+BEjwyD0BnXyCTZz20jRvMiBqTNA4K/a
jrwo9DaTqdN9kd7JYukY9ObJ1DkoyaXI5xiL3hYxdaYr9fwSqYlDb2FMne36
fHc4vsXj93c1U6epy7U3MeM0f6t6ZC5pqplFHqWE71zY7kifHzkWvzdq+dff
A9YfixtzQ5+vbhY++u/7pijxOShXywt9nujX26E7lEGms5tczTX1Q5+delwD
OpYZZMPy+rpYg0D0afg2JlCTO4McK2d/v3tOCPoc2rdvv5p7OnkW6OCV+Ibm
b1Dn4lXDpdbDMehzP1OnwzTvuTIf49Dna6bOYNeVCbrJCejzJFPnhfxgR86L
SejzE1OncQXHm9l2yejzMlMn271YpxblFPQ5zNTZ7axytmOC5m9ubScik0Zz
yfLC88KnYmleNP8wm060bS5RFRXpZbl4os/AZ2HcIXy5hCNNK8r13+cNfIop
qGT7+uYQlhPZFW4cSK/XmT0X3EVziLyOWaulYwh9fpR6vNApKZs8dZZyVi2j
+VtuyPoaW7ls8vdCicSmLpq/QZ2Oug78dkEJ9HmHqdOwdK9KYVcS+gxi6hQ1
sMh0nkbzopVMnXN3bFeoFUhFnwlMnfc/D+zy509Dn5uYOs313FhjHOnoM4+p
sydZJKXnC83fjm1UWN4TzCIlf0dlTdfQvKgt5tOLDkkWUbf5UzYoQPOi80sf
2LRkFhB2z6sh36oD0OeAp6RMk0IB+e4b+zlvVQj6NOWt76ytzSd/12mHK74M
Q58Td655luvkk2UuGQ8fnYtEn7Yjc3ezOvLIsfQ6L9+PNH+DOr/VF6vu8qN5
UTtT53Znu6s3u1PQ5wWmToG1ImudpWheNMjUaZb61NrubDr6NGPqPCf0Q+/k
4wz0+Zeps1V/Zcv8hEz0acfU+clz45e0Qpq/8ZfN0XAXLSbqrTfCX/92R5+v
rM9F8vUUkfCaTybt933Rp8/WzL+OSUWE97gKK/ZzEPo8/oNbh9u0iBBVDeWF
02letDTpaJKtXBGx3jRstH16JH3euRjHzcb27/nWdNZr1neav+1VGyscdSwk
LtyR1sFlNH+bw9RZOOqqKnuU5kVQJ5vSvfjTjWno05ep035LYnKOAs2LTjB1
7n09/5BieCb6XMbUqSPM8h0bo/lbJ1Nn+MwQ647dOehzH1PnpqiiKWN2NH/7
2W/nlDRaQqbFn+gpy6V5UW70605JVgkZVTI7IN3njz6tzopvj7YtISFH1fVL
btK8aOeSW56iaiXk+vjxGL2OcPTJ+e5ZXzBfCfnObWI6uimaPu94CO8Wbiom
S+84VNtei0OfThrGT319i8nY6aAITh+av0GduWwLz8+YSfMiqDMiRCRJMCUD
fUKdX25K53mr0bxIganzju12pyevs9En1HmlTH0p35Fc9FnF1Jkud+wmex3N
36BOzc+GHsZbCtBny/xfVbW1ZWTJBcXp8SY0Lwp6qbpczb2MjFvNFDdSoHmR
nrOfRblOGfnw4PXFp8OhtH+q9r1QEP73/OQ2+z5vYiT67OaQl2B1lJJL79J7
/xyIpc87BS42ctGlROh0qffNdpq/mZi3N2calZIPcwLL8+Jp/vaeqZM/1dxL
MpPmRVBngn5EM5ctzYugzuIt9xUjlGhetJKpc5/kkjqu8Vz0CXVq7TC0kozM
R58JTJ11Vy5pCiiz0CfUWVK4XIXVTPO3IoWLXD3BFcTdtrhmeBHNi+wmck8Z
GFQQK683RQJKNC9SyZqR1SFZQfjOR7eSczQv4r12apbuUDmxkmkstroSjT7r
pJLPt2SWk+pxnfPP9eLp884X9iIdy3LyW3fRBe9lNC86FHpwQZNCOZkolP3b
wJmKPqFO0x2ayaPaNC+COt2XdX8PV6N5EdQZyC698JgMzYumM3X6ti1ftmBO
AfqEOm0Kinlau2j+5s7UuWbv/Ys6OjR/gzpdt9gV7tpM87eISy27uE2ryOZz
g3/H8mledHHlmgBbuSqyyD1l/rXTNC+Sarf+MTlZSaJy1Pr+1kagz0H/hr2W
5ZWEJb7zj4gozYvSDq+IGHWsJKdbPdXb9RPRpxn/jT83NCtJ5YCI4SK1FPQp
V1t+aGhuJQl3k9rnrk3zt0imThPN8dKX3dnoE+oM31FgoTOV5kVQZ6BG4j7x
eTQv+sbUecq2juxeXIg+oc6hfj7xN040f7vJ1DlfSqNwvR3N36DOpRPh+htu
0vzN8cm+e6JqNcRih2DLcm2aF2loBr0L5qshA+nvDvKb0byIf/rQeuGmajJV
7XiM5BqaFzWVKzr+tz6Gs4VvQLc+Dn363PXsmKtbTUw3jc3WWUvzouPbPsu5
i1aT4xP2K5wMaf629KesB19PFdlYEiu5N4Dmb1Cnosg2XUFTmhdBnYmGYz/u
ZeajT6hzVsoBG8t+Fvp8xdS5fjxkCoczzd+gTm3hLwozAmn+doKpc4g1Ov4+
huZvUCdP2+v1N5Jp/mZcWMhSEK4lREp0U1F7AP394hb/fFbHMyJWfEtmrT3N
i35uPGssF/2MFMkZnBGwp3lRzmB6ZabRMzJsox3uYpKAPq1iuZb9d773tSus
X4jQvGin/hHzpNEa4lQYkL7SnuZvnMtiGyRZNcR+oY+pynuav5kwdY6Q8hcC
v/Lo7xdMnX+t/yranqR5EdQZ435iaesJmhflMnVa+N7S67CneRHUOXDwneGz
GJq/KTB18pSYb/Grovkb1FnVeeSZRgfN37S710+cGnpOgk30KyQMaF60INxW
uyXzOYlt/B3G8ZjmRS2nXsXrWD4np7dfrZpsikGfgQtXTf1vvZvpsE/DDB6a
F+k1mZ/U5H5Ovt/a8tFTgOZFYi41GbW1teRY2MRuSV+av3WrLeZTc68lV4d9
gqoFs9An1Fn3fdllEROaF0GdrTy/mzPGCtEn1KkR2iQcvYPmRUFMnQ6NC1R+
m9O8COoUXKB2USOJ5m8rmTp/G+vbRbXR/A3q3Nxi5MM5k+YesgLhWy3L6wmb
Pref9Nsg9Anrl6x/yfeWu9K8iPVApeeGZj3RcEteJytM8yJY98XLL2gzbw/N
i5T/9vgZtdSR7qaXqY1/qE/enO3fu4PryC5PT4nGSJq/Pb/+eI+BQR0R2n+0
W1CZ5m9bmDrlY2Ry3dpY6HOCqfPKyFbuLZU0Lypk6hzzaNFWXUjzIlumTqXk
v+UWBjQvUmHq3Kcedqw2keZvUOccveo5O4dpbsli8hnhfYsUXx65g56LGH6W
PXixQx1db7ORyW1GMlfqXzKIx/PA+13mlnzeNCEQj69j+F4TlnijdCVy+HsJ
BjSa3OOsQg65Fhtbq/eIeBWeH9b/CB9MaP9qYY3rPyFHmvFMUo6n2hbXrQFf
us3EW3G+Oa4LBe7aXz+H7b4TrgsFzsuTO3I71A3XhQLfs3BGx817T3BdKHBn
iVN110/74rpQ4PXbknONyVNcFwr8wcp7jZtcgnFdKPDV0rHVadZ0vhh4tWxj
4fordL4YuOHOiYykk3S+GOtXE4tfs4/OFwOP09IIjdtO54uB7z1202e1VDz6
hBwp/Zd+b4DZffQJ/PVie1cDV0v0Cdw6WUnF9oAr+gQuqv96QXa3J/oEXrXw
Qk/fXV/0Cfxy3e+85QsC0SfwB8XlynE6IegTeLP/46TdYWHoE7iUmc6CtoEI
9Il1ai67d0suGn0Cb5Do7hZ0iEWfwFdMTT2Q9CIefQK/0XorT004CX0C73y/
fM619GRcVwmcT91BmTSnoGfIkdI+rDrJM8sJPQN/yymde8Oc7j8AXPn4bLa6
l+7oGXhG5aMX85f4oGfgyzdOCztz8Sl6Bq7SoJh76FgIegZuxcUeNjYZhp6B
p28vdAqKiETPwHuuWd1Q2hODnoEvi9l2svtbHHoGrtP6e/djr0T0DLyS94T3
wsBk9Ay8Qyxvet+3FPQM/M9OobusXWnoGbjQCYsfrl7p6BlypNj5VZxj7o/R
M/A+xb12JMAGPQPf+DNEsVnpCXoG7tHWaiO70x89Azfvenym5mkwegYe3ZzA
buEfhp6Bv6mvDVnlG4megXOV9yq89opBz8A35fJ22HnGo2fg55JW28i4J6Fn
4GoHRPmHVFLQM/D2WpkzVRWp6Bm4hcqulKDd6egZ+OySA+w3yzLQM/CY7Xpa
Gruy0DPkSOHfC+c4s7uhZ+BLuvbPGUuj+zwAz/mhs1g4xhs9A68fGRRL0AxE
z8Cvjpd6L7EMRc/AJ8ZdAj7XR6Bn4A4Tx0MSRWLQM/DZf1ZFmt2MR8/A/f58
j5V/loSegc+ZbNWxdUlBz8B1JncfO781DT0DD5iMO7GnMx09A2+f5NeVds5E
z8BXspmfEZDNRs/Ajdg+nv3VloOeIUdq158vODXZHT0D92vmD+cqckDPwG98
FHvNxeaHnoHbSwrt5Yym89rA684vXzNVMxw9A18QLs7HNUrntYGfaZMe5AqO
Q8/AYxfLNnCrJqFn4BZSQUc4zem8NvDAmhXVnHvT0DPw0guRW6cuy0DPwL9y
ScRO/UHntYHPiEgQ4qqi89rA1+9a78QVkIuegeu0p49zmeSjZ8iREooP3dxw
yBM9A3+1e9fd0iK6nwZw47aHa6eoB6Bn4L6TH4cvLg1Fz8B/81lovFwYiZ6B
H1siECsnGIuegeeuSZgaxpeInoE7B4Yl23OmoGfg8pEmH3PY09Az8IGEHTMG
/tJ5beCBGbxyKybovDbw/QVvzh/+Tee1gf8tC3/i+JPOawNPqr1ayvpO57WB
n2mSHxr+xkLPkMsF1a3cY2zrjZ6BH4l8fYcjmO6nAXya2Pq4K8fpHDHwso66
ZLGRcPQM3Cr4cub7x3SOGPjmU7z5HuJ0jhj46Mym02Jn6Bwx8Fd9oZ1siXSO
GHjKs6sG78cy0DPwx7E7u7NU6BwxcMOHsy57eNI5YuAqFz4OXGnPR8/ARVUS
rqqvpXPEwNkE5MfcC+gcMXBjm4g8tk/F6NmWybsqVw4ois70Rc/Au0KvrtS4
8xg9A+djaeVoGtE5YuA5F6S0ZmnTOWLgegLc3c/l6BwxcK5Wk50Vs+kcMfDj
G089ErOjc8TAkx7ueWv3Kx09A5/aukX0kyGdIwZ+dONKk10fc9Az8MSHAvmh
WnSOGPiUVjYejnIWegYuJfQrZl0AnSMG/rqsf3/bq2L0DNzG+NOIy6xS9CzJ
5F0RXMH3WI/pfBPwUj4zrlMSdN8S4Lsmz1m7WNA5YuCbxn/nFcZFoWfgYr8e
/x78EI+egTv+dls0m4fOEQO3uXlCTjwkDT0DvzWy8uhOOTpHDPza9aGbRxqz
0TNww6E8L5PLeegZuJ6xQ8aDqXSOGHiCmbih5n46Rww8JsPZ4r1/MXpGbz+G
H1z4Sue1gYfKHPH5sbGM7k/C5F151fvDbvME0P1MGD4/mMdvz2w3um8Jw5Mt
9rw+dDeM7lvCcBu+wWajCTqvDVw7zL3V3jyR7lvCcIHFi4Y1xqhn4Lc/X/5x
LJvOawP/lMz6aWCWRfctYfi+27N/X9tI54iBZ+zWG7cepvPawJfMTv/jmFxI
9y1huFI/x909snSOGLj5S8l7Wl50Xht4fJa2jc4IndcG3h5gZXtSuxw932by
Ll/fO8Net56iZ+AHGnm6PIaoZ+DfpMcna+/ReW3ggh6ZDhrKsegZ+OLxbK4L
U+kcMfCE+Hk10V/ovDZwcuqGc3c1ndcG3jDrpaZEPJ3XBq5XLC146XEeegb+
45rzmzgTFnoGvsvddJ9ZDJ3XBj7jkmiSlxCdIwbetKtxdpYTndcG/nSxzbU3
E3ReG/j5kXVNv4wq0LMIk3dpXllgo9YViJ6BJ++ZHXG0ju7DA9xc1TVpsTWd
1wZedVQw0PMhndcG/mjTXmWHGuoZuIz84x2KDXReG3iLcsPGv6/ovDZwm/1z
pHJb6Lw2cIkj2iJm7XReG/iL015CG77QeW3g+Rv7eG6a0Xlt4LO3OnMe+k09
Az+3Yy2bjCWd1waepVA/PnuSzmsDn6ls8mvgXiXd34/Joz7unyeiL0rnhYH7
WjksvWRK57KBH4r7uehqBZ3LBv7wssyjPCc6lw3cwPaSo3w6ncsGruQX9qD4
PZ3LBr48pcVBaWoe3d+P4X8rBewr17Do/n4MvzIYoSAWR+eygb8fKy4yIHQu
G/gero8kupHOZQPP5R9jdZ+nc9nAVwvPk5ecoHPZwDXebbcId60i8nf3zbST
q8UcyXjpdPkzLEeiF/ilwVaO5mljwTpOUvJuJNxS3L9ch+ZpcqkxN8WFn5DP
xy7qc5vSPM2ydPys6IQPEd8aK63m/hE5q2mf5rKWAJLhNGJZrkPzNLbv+5fw
nQwmvy5uVuE2pbnZTs5QXt7t4WTBu8NS0bY0N+uY8YztgWQk2ap6k1/NneZm
NnN//Jy6KJocy/L+2R1MczORJcL9tryx5PbK7BbHJJqbla1U7mQfiyOBT94W
SbIG6Xo2I2dekU8JJJHJnyH/MWPWj/naBHm3ZL5ArtvrFruj14O8P912Rrjp
FXLOYBHLazY+ZAlZLqU79A55lHbGvqiFT8lpYb2fwXwfkUfahc268jaYvLDS
Oj00l+Zjo6cum/OIhpGNz1JnNSnQvGuwvyL1DVcsOSTX+OOGJs27dla5LLp2
IJ6YxXx/N1eX5l3uoUfsZgQmEu8FgoWZRjTvusZyNWu8kYxzwbgOTXIkNtgv
hbxg8nbIZ5SY9V0Cu33ETTVfIU/x0rvK+dSfHBJ5N5xp9A65yz3j5atuBBMf
dqGCUccPyMuz1vDWLgwj/cYJu4Sb2pBP9PcOmxRGkKtS0m+D+Wi+dPnssDqH
ZDJx999foCBM86X71lqFTVYpJI3XJLRDkuZLwb7JMlENqeSVhet9WzmaLxWk
z4q2EEkne5jfCyAPKWbWUzlzu+Xw9byl+Ukeq/juplBS3/XCVpP7A3L55A9n
pGUiyDS9aavU3NuQX4mYYP+4LpokOscFG7X0IE/I2uMW5p5G6iee2fP19CFX
2nC8/RZ/Bhli5tyBf4g3XH/A9Z8n5vcLyBPY1v+/9UjcNQ/Vo23fI3dcvyyG
d2UUEdPW5zXVbEMuuKEv4aVFLOkdWHVRLroPeYzQMX2FLVlk5ilVjZbMAeQD
QkXnxTqyyU7m9xF4vlZh1ucoKBf3B/O1IX+cMi+r0D+eiGuGr+c2HUBeHSc6
2LEwj2xj+gw+T3VazRMKDyJnmD4D3Dbp/eyyS+EkjOkzwLcb3Zp3e2oM6WL6
DPARiQWLNwQlkFVMnwGu86PZ9cbiFJLO9BngGxtjBDQvppGfTJ8B3u+qspB7
Sjb2GeA1xvMCOvbnki1MnwEeqdG1hBWQj30G61+THuLbzSK3mD4DfJ2Dgruc
fxF5yvQZfF4eiT4YXVxMvJl+As8jYgqpR15KRJBmpp8Ab+h99M2VP5YsYvoJ
cAuv8w/2jyaSU0w/scV1Ectn3x9MIQ1MPwH+2ZTvxGe9dCLD9BN8fjR9TTgL
8og200+Ayz0rdTq7jkVMmX4CXNX17aV2rSLixfQT4MNy9fxuTsUkm+knwAO7
yrN2lpcQfqZvwHPBk4yPq6UnY8kBpm8AL3mbk5a0IJk8YfoG8NzDdi8rU1JJ
L9M3gKc2aQy1qmcQY6ZvAPeoNb+8M6mQuDF9A/juiJDdUqLFJIXpG8AVPnEd
yjYpIU1M3wAuL3L5nFJBKXnI9Ae43/4qe/R3XkQyqWX6A/ADHHHjlWfTCBfT
H4Dn1E78aVyeSeKZ/gD8bFsNJ09fMXnO9Afg3uXfp/LtKSWDTH8AXhu7mFsw
toxMYfoA3Jdesr6rMIcrnaxg+gDwCemPnAe/ZpKvTB8Anib1oLZXqIzwMn0A
uNVU2bUzHpWTHcz3He7HJuLkd3wJzCJizPcduNoNrrv2ZytIdF+T+7boPLye
8ueoT8n5aIH3IcBPFfC85RdOJE+Y4+H+ZHujLcdDxSd4/wycU62gsyfSgwQz
3yPg3DznMtadrCLij7ZxJY+W4PVLgvMDX7SFPRnuu7rbXZT+rqS+dVN7qHEE
8dGO89AdKsbrQmNo8+99ZvfJEv414p2SNfR3nIKLdSZcboSv9bk4q6MD+QbR
2Ja5+tFEWmNgpu7QJ+QXjl0oy+WNI9zM/iSY5/tOn7pw/AFxfheQ8d+6DeCc
WaUl3ebuZNqeWWJOSQ3I9ULYp6jc8CESL1bP6AnuQP7Ub1Hoo7VxZM9O9SHH
pE/In7vIKW6TSiSXkwxfS7I+I7cqkRr64ZlMBmrmnrQqL8Q+fyTPVclxhiP5
EzJjl6JwFfKSU22SrxI8iIJ0ZW+HZAPy17rmm/QP+RHbmTyZompNyE3XPQi6
ZR1MlEvtB+fqdiAP3JCd6vc8gZzfENmUafQJuefCkuMprsnkQUhFjo7lZ+TN
C8VPPZFLJTGzvwSOOn5FvlTo8WmLT/+um8z+J3B9Obw0obQ70ZFcNrRs+G/9
EHB5nq4wsyhPMrTy7zlTzXrkL+9+1zf/5U/yhwotLcsbkadPsAkWhIWQP/Vs
KqyON8gntvCMFOyJIHoZ7S8VhDuQ9/3k29u2PJnYinJkd0h+Qs7/xD2/bSSF
hHuseGor9xn5Jpl5a9qr00g5xy4bUbWvyI+/8H3a/jSDfL569ny5Tg/yO8bC
fB1Xs0gC872A3LVlzgw29c+OpGVD38kQvgrk0uJyWSPnn5DTg0bDomp1yIeU
r1ypOPGUfH91c1eTQiPy5g0v3J9Fh5JN6dkz5+m+QS6neGlAJiyS3HT//UbH
sgW5v9ZU9YCnscQ6akemUQvNq9dmB9zdrJZCguad8ufroXn1x8KLiYbKaaTI
3vpu0ijNq10qN78P3JVB2n8E6mtyf0VO6qfwNu7MIhznCtWH5vYgH3zdIMst
n0NWNLZKu4v2IQ/6+FR/27Y88opZjwHX01nMesuVTB+A6074m99asbleJJq5
nwd+i1nfOMT0B+Dbn41H7X6dSeYw6zqAuzLrDD2YvgHXBQdb0rH9hReZx/QN
vB4VpCfW+f17PmXun4GHM+v9ZjD9BHjsgYWzRzuzyBqmn2Bu1tC5drZVLtnP
rCcBHsCsx2Nj+gxcFwS3qhZJZ3oRO6bPAD+WUvlJ+k0wmcr0GeBSype6VQ5G
ElXYP4HhbMx6OXGm/wAX8dZga2vNJmpM/wHudCaYo+9pHjFk+g/wEclhztHj
LOIE+x4wfC2zzu0905fguqMqlFyy9ZIXGWb6EnAVE4ELS8aCyXamL+H1rrFu
IIgVSe4wfQm462ZH0+W28aSIuX8G/pZZn7aL6VfAH7dvq/KoySHnmH4FfJmH
r1NTfD5xYPoV8FSlXxpzXQpJJNOvgK+4LTEtbksxqWLW8wDvZdabZTF9DK6b
O9qqK/4M/fv+Mn0M+BX27hdmnCGki+ljwFlzjIoGZkWRTKaPAZ8lOpRosCiB
/GL6GPBEv1wNY48UIsfczwM/xKwf02X6G/CI9Lsbw8JzyV2mvwHfV1AiqRtb
QEKY/gZ8TM/GbeaRIlLC9DfgGudFnHubi0kn09+Ah14qe1B9spRwMuuagI8w
68Tqmf4G1/e7Ofc+Tf8VTLSZ/gZ8x5ehNn7VKNLP9Dfgo4J6H+b7JhBppr8B
P7a8u4/vX382Yfob8M1blve6CWeQdNj3ieFzmXVft5i+B3xY3+2L95U84s/0
PeANltVdQt4sks/0PeBvqtmG61qLyAem7wHf/Wrx1dk3Ssjfs/+v7wFPb9vy
TYunjCxj+h5wkT5tY4+AcrKLWWcF91G/mHVcxbDOijleilnHpQD7LzFclVnH
Bevr4DwxERX1nwvpXCHwjasEhFMJ3acLuPu44kuTIA9cXwd8qP7afelJL1xf
B1wrPHT7wCk/XF8HPMX85VA86ymuowPe0DXb+NIEnR/EvKghulo9PgLX0QGX
zt0pKnGC7mcFXDf8rfW0GXTfKuCPH5u8+5oXi+vWgI8yPuP/J/+5/j/zg7he
KDNJqVrLA/0Anymrm/xwvzf6AS6bxbdYfZ8/+gF+RpZ1n3dPEPoBXt6SaaEf
Tvf7Ap7S+OqOcC6dBwRe4ZGQ8Sc7Dj0Abzlo3/shKwE9AP8mcHI5KzMJPQDn
MPSTrG9OxvcL97e7/me+D3gn1yUtnh463wfcrnOQ47BNEL5f4HNOyzVrzQzF
9wv8bN1EqvlROh8KfOjvV3uHCTqXBzwk81DSYdEUfF/Aq/ozFxmqp+L7Av5N
dMEDK5M0rB/ukwv/Z54O18mUp672qKfzdMCvlZev1z4fjvUD317+duvcyUis
E/h4/u7yeF067wa8dft+Nec4Ou8GvCz/yHOjXxlYD9wPT/7PPBrwpKXfwv+m
0Xk04Kf5HkXkPqGff+D5/Ipnt03SuTDMi6a5nl1oko3nh/vS3f8znwX8l6rI
wU5hOk8K3PqXRMGP5lz8HuHv3flTlny4Red0gA/f11twX5Hu6wK8c31pSJAK
3dcFf8dvEZHM3kv3dQFeYW+X3qBF93UB/t57OPBGXAr2GeC83KtbsrLpPA5w
jhPvlirl0Xkc4OPJD881FND9W4D/mCoXc6KoAD1jvnSsp/9rSSH6wfers883
t6MIPcB95j7JFaztTnS+BviSost5+i/pfA3wAe2s7McL6X4swFt/sLUcT6bz
NZjbkMij3xrp/lTAxwwfX9tqROdlcD1AhszQc1c6LwP82eRbY730Qny/wBeK
kZvjvXReBt9XjVtm+Z9ifF9wH2tbapXQpU3nXIDrPk+5UvuezrkAf9o77H00
lc65AH/07dHo3p90XhK400HVxEXH6HwK8O1SV+9z19P5FOBpa1my7EN0PgW4
5PrpX8fmlNL9xOC+Wn4k8+QeOj8CXGZWp9n0JDo/Anx6W8PmnDn/335fDA/o
9Ol8y6LzHcB5al1Kk77R+Q7gpukOYQ4ryvB14T7TdsvJMt9IOmcBXCLcm1dv
dSaeH3jRw5/O0r103gG4R6FAiodUOZ4H7tOMLLhzrsll4fHAOVp6duxZT9fz
4+8UVsutVpg74Pp54Hk6FZYKSRF4PObzN866LX3/EPsGcK3hPRu7gtzwPMAT
jjxScPwbjd9r4JE3jv66oROH54e+Omf0bRn7Gmc8P3D/16kcHR898PsIfM36
3yt2rfLF1wWuOcz3kmtbPL4ucN+lG/RkWxPx+wXcJFLid1pxMtYD/fYdT3RH
yiZXrAf4iqXi+Qb8XlgP8Eubop8s6vfH7xHmJ2Keshc+BWOdwDfxfJ2jpZ+E
dQJPmNZU+GQ1nTsGTmZt/GkTnIrfI+AvBT2lTObT+Wvo82sUs6b3P6Pz18Cn
e+uXv5b1wfqB9/YK3CkKC8T6gRssO7P41X26Xx/wV+pbflcX0Pl04I9E7h/+
K0/7OfCy7OGy0Xe0v2Ges++UzPcb6fi+gG/srA7pn0Xnf4FfNt80+2ssnY+G
/OHOtytJFkfpfnrABeTzA90O0P30gDeWc1Y2RdD99IA/vRzHOr2CzvMCPy9w
ILMvkO6nB3xd7miC+SI6Bw38+5BZ/LMSOgcNXGe3ejT/PbpvHvB8H+FwHZKJ
HoCv6PsW9PQP3TcPuAMp8+/Mo/vmAe919/ZefSsP64Hr2mwmhwFv0P83T15X
/9Lpjd6AWzI5DJwH+PJDQp89l9F5T+BuTA4D54f+PNx8Z6/Hfjp3CdylUUnt
nByduwQeyeQw8LrA7S/ExDrb0rlI4G4tkhPNtbnoE69HTA6D+1gy/dmjyzn2
a5of3ceS4fefPPxQIknnFnH9z5Zafbc/dN8w4FOYHAb3n2T4Lo42OY1Wut8X
8JCD7Hc2qdJ5Q+DsEStKF6fQeUPg65gcBuqH/q+TNvhVmJ/OCQJPVLv08+AC
OicIPCXn1OgCcTonCDxj9YGxD7J0ThB4C5PDwPsC/rLy2YsZG+ncH67PuVN+
YDCP7ruFuYp/a/fX5XTuD3jfzRMSzfp07g94P5PDwPuF61f4YSfn8+fpPlrA
a9dNyZNjo3N8wHdn7kwq3kvn+IAXbbMOU/Wl+2gBD2j78OzLMJ2LBH6UyWHA
A3AyZ33kn3t0vyz8/aVp/zIFcTqvB/z9Htl9il+oB+DbEpR5z8nReT3gfnyH
K+2d6bwe8F9MDpP9P3nCUiZPwP3AYV1KWgyfbyf1A7ztdhxH5iW6Lxbw60oJ
P19+p3OOwO0cdEZ+FdC5POB1hkeMuWzoXB7whf8zlwf80pP3bAer6Zwj8Jb8
KwXJynQuD/jkWuOxrGg65whcNMRYtpCXzuUBVxcwuVFxmc7lATe2N0l5Xkf3
xcLjmbzl/wByO7He
    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[
         TagBox[{Polygon3DBox[CompressedData["
1:eJwtmXfgVuMbxt9znhsNkr1L+GUlI5QiZKUilWgvoozKqEg7oSISaaoUSVkZ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            "]], Polygon3DBox[CompressedData["
1:eJwtmgn8VsMexs/MHGUXadUeWSttJFlaCEUrIi6yFdpL0r6qaEVRSqFEtpRd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            "]], Polygon3DBox[CompressedData["
1:eJwt1ne8j2UfB/BzHHuPbJlZDUJmmWWV7JUZGT12ViqhrAqlRwplZZeEEC0q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            "]]},
          Annotation[#, "Charting`Private`Tag$2968#1"]& ]],
        Lighting->"Neutral"]}, {}, {}, {}, {}}, {
      {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0bsrR2EcwOHjfr9lkiKbFKsUqxSTsrAxMbAympgJf4CYJUbXn+siud8v
SXId3CXxvGX4nOfUe87b9+0tae1q7IyLoqhX7wrvz7rSUHwU5XKUxZxkBRdY
w0028JwtfGIHf9jDzIQo6mchR1jGcVZxmnVc4jxv+KltvepBM4bZ4Sx3Oce9
8D33wxw84CIPGeMRl3jMZZ5whadc5RnXeM51XnDAvLf80qXe9Kg2c22xiTHW
coqVHGMph1nAPqazm9/2aw9nYDNPWc8NVodzsJwTLArn8981P5SjF90r33zZ
zGNWWGMms5jBDKYzjWlMYSqTmMIEJoc7ZRJ/lRjuJ6yFOWWEaNDj7v/+/wCI
PEiz
        "],
        VertexColors->None]}, 
      {GrayLevel[0.2], 
       Line3DBox[{661, 957, 458, 660, 1060, 868, 662, 1061, 869, 663, 1062, 
        870, 664, 1063, 871, 665, 1064, 872, 666, 1065, 873, 667, 465, 668, 
        1066, 874, 669, 1067, 875, 670, 1068, 876, 671, 1069, 877, 672, 1070, 
        878, 673, 1057, 1071, 879, 958},
        VertexColors->None], 
       Line3DBox[{675, 962, 1149, 674, 1072, 880, 676, 1073, 881, 677, 1074, 
        882, 678, 1075, 883, 679, 1076, 884, 680, 1077, 885, 681, 963, 1150, 
        682, 479, 683, 1078, 886, 684, 1079, 887, 685, 1080, 888, 686, 1081, 
        889, 687, 1082, 890, 688},
        VertexColors->None], 
       Line3DBox[{690, 964, 1151, 689, 965, 1152, 691, 1083, 891, 692, 1084, 
        892, 693, 1085, 893, 694, 1086, 894, 695, 1087, 895, 696, 966, 1153, 
        697, 967, 1154, 698, 494, 699, 1088, 896, 700, 1089, 897, 701, 1090, 
        898, 702, 1091, 899, 703},
        VertexColors->None], 
       Line3DBox[{705, 968, 1155, 704, 969, 1156, 706, 970, 1157, 707, 1092, 
        900, 708, 1093, 901, 709, 1094, 902, 710, 1095, 903, 711, 971, 1158, 
        712, 972, 1159, 713, 973, 1160, 714, 509, 715, 1096, 904, 716, 1097, 
        905, 717, 1098, 906, 718},
        VertexColors->None], 
       Line3DBox[{720, 974, 1161, 719, 975, 1162, 721, 976, 1163, 722, 977, 
        1164, 723, 1099, 907, 724, 1100, 908, 725, 1101, 909, 726, 978, 1165, 
        727, 979, 1166, 728, 980, 1167, 729, 981, 1168, 730, 524, 731, 1102, 
        910, 732, 1103, 911, 733},
        VertexColors->None], 
       Line3DBox[{735, 982, 1169, 734, 983, 1170, 736, 984, 1171, 737, 985, 
        1172, 738, 986, 1173, 739, 1104, 912, 740, 1105, 913, 741, 987, 1174, 
        742, 988, 1175, 743, 989, 1176, 744, 990, 1177, 745, 991, 1178, 746, 
        539, 747, 1106, 914, 748},
        VertexColors->None], 
       Line3DBox[{106, 347, 107, 348, 108, 349, 109, 350, 110, 351, 111, 352, 
        112, 353, 113, 354, 114, 355, 115, 356, 116, 357, 117, 358, 118, 359, 
        119, 360, 120},
        VertexColors->None], 
       Line3DBox[{750, 992, 1179, 749, 993, 1180, 751, 994, 1181, 752, 995, 
        1182, 753, 996, 1183, 754, 997, 1184, 755, 547, 756, 998, 1185, 757, 
        999, 1186, 758, 1000, 1187, 759, 1001, 1188, 760, 1002, 1189, 761, 
        1003, 1190, 762, 554, 763},
        VertexColors->None], 
       Line3DBox[{765, 555, 764, 1107, 915, 766, 1108, 916, 767, 1109, 917, 
        768, 1110, 918, 769, 1111, 919, 770, 1112, 920, 771, 1004, 1191, 772, 
        1113, 921, 773, 1114, 922, 774, 1115, 923, 775, 1116, 924, 776, 1117, 
        925, 777, 1118, 926, 778},
        VertexColors->None], 
       Line3DBox[{780, 1005, 1192, 779, 1006, 1193, 781, 1119, 927, 782, 1120,
         928, 783, 1121, 929, 784, 1122, 930, 785, 1123, 931, 786, 1007, 1194,
         787, 1008, 1195, 788, 1124, 932, 789, 1125, 933, 790, 1126, 934, 791,
         1127, 935, 792, 1128, 936, 793},
        VertexColors->None], 
       Line3DBox[{795, 1009, 1196, 794, 1010, 1197, 796, 1011, 1198, 797, 
        1129, 937, 798, 1130, 938, 799, 1131, 939, 800, 1132, 940, 801, 1012, 
        1199, 802, 1013, 1200, 803, 1014, 1201, 804, 1133, 941, 805, 1134, 
        942, 806, 1135, 943, 807, 1136, 944, 808},
        VertexColors->None], 
       Line3DBox[{810, 1015, 1202, 809, 1016, 1203, 811, 1017, 1204, 812, 
        1018, 1205, 813, 1137, 945, 814, 1138, 946, 815, 1139, 947, 816, 1019,
         1206, 817, 1020, 1207, 818, 1021, 1208, 819, 1022, 1209, 820, 1140, 
        948, 821, 1141, 949, 822, 1142, 950, 823},
        VertexColors->None], 
       Line3DBox[{825, 1023, 1210, 824, 1024, 1211, 826, 1025, 1212, 827, 
        1026, 1213, 828, 1027, 1214, 829, 1143, 951, 830, 1144, 952, 831, 
        1028, 1215, 832, 1029, 1216, 833, 1030, 1217, 834, 1031, 1218, 835, 
        1032, 1219, 836, 1145, 953, 837, 1146, 954, 838},
        VertexColors->None], 
       Line3DBox[{840, 1033, 1220, 839, 1034, 1221, 841, 1035, 1222, 842, 
        1036, 1223, 843, 1037, 1224, 844, 1038, 1225, 845, 1147, 955, 846, 
        1039, 1226, 847, 1040, 1227, 848, 1041, 1228, 849, 1042, 1229, 850, 
        1043, 1230, 851, 1044, 1231, 852, 1148, 956, 853},
        VertexColors->None], 
       Line3DBox[{867, 961, 1245, 1059, 866, 1244, 1056, 865, 1243, 1055, 864,
         1242, 1054, 863, 1241, 1053, 862, 1240, 1052, 861, 1239, 1051, 860, 
        1238, 1050, 859, 1237, 1049, 858, 1236, 1048, 857, 1235, 1047, 856, 
        1234, 1046, 855, 1233, 1045, 854, 1058, 1232, 959, 960},
        VertexColors->None]}, 
      {GrayLevel[0.2], 
       Line3DBox[{251, 459, 1060, 252, 472, 1072, 278, 1152, 486, 292, 1156, 
        500, 306, 1162, 514, 320, 1170, 528, 334, 1180, 542, 348, 556, 1107, 
        362, 1193, 570, 376, 1197, 584, 390, 1203, 598, 404, 1211, 612, 418, 
        1221, 626, 432, 1233, 640, 446},
        VertexColors->None], 
       Line3DBox[{253, 460, 1061, 254, 473, 1073, 279, 487, 1083, 293, 1157, 
        501, 307, 1163, 515, 321, 1171, 529, 335, 1181, 543, 349, 557, 1108, 
        363, 571, 1119, 377, 1198, 585, 391, 1204, 599, 405, 1212, 613, 419, 
        1222, 627, 433, 1234, 641, 447},
        VertexColors->None], 
       Line3DBox[{255, 461, 1062, 256, 474, 1074, 280, 488, 1084, 294, 502, 
        1092, 308, 1164, 516, 322, 1172, 530, 336, 1182, 544, 350, 558, 1109, 
        364, 572, 1120, 378, 586, 1129, 392, 1205, 600, 406, 1213, 614, 420, 
        1223, 628, 434, 1235, 642, 448},
        VertexColors->None], 
       Line3DBox[{257, 462, 1063, 258, 475, 1075, 281, 489, 1085, 295, 503, 
        1093, 309, 517, 1099, 323, 1173, 531, 337, 1183, 545, 351, 559, 1110, 
        365, 573, 1121, 379, 587, 1130, 393, 601, 1137, 407, 1214, 615, 421, 
        1224, 629, 435, 1236, 643, 449},
        VertexColors->None], 
       Line3DBox[{259, 463, 1064, 260, 476, 1076, 282, 490, 1086, 296, 504, 
        1094, 310, 518, 1100, 324, 532, 1104, 338, 1184, 546, 352, 560, 1111, 
        366, 574, 1122, 380, 588, 1131, 394, 602, 1138, 408, 616, 1143, 422, 
        1225, 630, 436, 1237, 644, 450},
        VertexColors->None], 
       Line3DBox[{261, 464, 1065, 262, 477, 1077, 283, 491, 1087, 297, 505, 
        1095, 311, 519, 1101, 325, 533, 1105, 339, 547, 353, 561, 1112, 367, 
        575, 1123, 381, 589, 1132, 395, 603, 1139, 409, 617, 1144, 423, 631, 
        1147, 437, 1238, 645, 451},
        VertexColors->None], 
       Line3DBox[{8, 667, 23, 681, 38, 696, 53, 711, 68, 726, 83, 741, 98, 
        756, 113, 771, 128, 786, 143, 801, 158, 816, 173, 831, 188, 846, 203, 
        860, 218},
        VertexColors->None], 
       Line3DBox[{263, 465, 264, 1150, 478, 284, 1153, 492, 298, 1158, 506, 
        312, 1165, 520, 326, 1174, 534, 340, 1185, 548, 354, 1191, 562, 368, 
        1194, 576, 382, 1199, 590, 396, 1206, 604, 410, 1215, 618, 424, 1226, 
        632, 438, 1239, 646, 452},
        VertexColors->None], 
       Line3DBox[{265, 466, 1066, 266, 479, 285, 1154, 493, 299, 1159, 507, 
        313, 1166, 521, 327, 1175, 535, 341, 1186, 549, 355, 563, 1113, 369, 
        1195, 577, 383, 1200, 591, 397, 1207, 605, 411, 1216, 619, 425, 1227, 
        633, 439, 1240, 647, 453},
        VertexColors->None], 
       Line3DBox[{267, 467, 1067, 268, 480, 1078, 286, 494, 300, 1160, 508, 
        314, 1167, 522, 328, 1176, 536, 342, 1187, 550, 356, 564, 1114, 370, 
        578, 1124, 384, 1201, 592, 398, 1208, 606, 412, 1217, 620, 426, 1228, 
        634, 440, 1241, 648, 454},
        VertexColors->None], 
       Line3DBox[{269, 468, 1068, 270, 481, 1079, 287, 495, 1088, 301, 509, 
        315, 1168, 523, 329, 1177, 537, 343, 1188, 551, 357, 565, 1115, 371, 
        579, 1125, 385, 593, 1133, 399, 1209, 607, 413, 1218, 621, 427, 1229, 
        635, 441, 1242, 649, 455},
        VertexColors->None], 
       Line3DBox[{271, 469, 1069, 272, 482, 1080, 288, 496, 1089, 302, 510, 
        1096, 316, 524, 330, 1178, 538, 344, 1189, 552, 358, 566, 1116, 372, 
        580, 1126, 386, 594, 1134, 400, 608, 1140, 414, 1219, 622, 428, 1230, 
        636, 442, 1243, 650, 456},
        VertexColors->None], 
       Line3DBox[{273, 470, 1070, 274, 483, 1081, 289, 497, 1090, 303, 511, 
        1097, 317, 525, 1102, 331, 539, 345, 1190, 553, 359, 567, 1117, 373, 
        581, 1127, 387, 595, 1135, 401, 609, 1141, 415, 623, 1145, 429, 1231, 
        637, 443, 1244, 651, 457},
        VertexColors->None], 
       Line3DBox[{275, 653, 654, 1071, 276, 484, 1082, 290, 498, 1091, 304, 
        512, 1098, 318, 526, 1103, 332, 540, 1106, 346, 554, 360, 568, 1118, 
        374, 582, 1128, 388, 596, 1136, 402, 610, 1142, 416, 624, 1146, 430, 
        638, 1148, 444, 1245, 656, 657, 658},
        VertexColors->None], 
       Line3DBox[{445, 639, 655, 1232, 431, 625, 1220, 417, 611, 1210, 403, 
        597, 1202, 389, 583, 1196, 375, 569, 1192, 361, 555, 347, 541, 1179, 
        333, 527, 1169, 319, 513, 1161, 305, 499, 1155, 291, 485, 1151, 277, 
        471, 1149, 250, 458, 652, 659},
        VertexColors->None]}, {}, {}}},
    VertexColors->{
      Hue[0.], 
      Hue[0.01567944665201706], 
      Hue[0.031358893304034116`], 
      Hue[0.04703833995605118], 
      Hue[0.06271778660806823], 
      Hue[0.07839723326008528], 
      Hue[0.09407667991210233], 
      Hue[0.10975612656411939`], 
      Hue[0.12543557321613646`], 
      Hue[0.1411150198681535], 
      Hue[0.15679446652017057`], 
      Hue[0.1724739131721876], 
      Hue[0.18815335982420467`], 
      Hue[0.20383280647622173`], 
      Hue[0.21951225312823885`], 
      Hue[0.006547720477252807], 
      Hue[0.026436412700238967`], 
      Hue[0.04632510492322511], 
      Hue[0.06621379714621128], 
      Hue[0.08610248936919743], 
      Hue[0.10599118159218358`], 
      Hue[0.12587987381516974`], 
      Hue[0.1457685660381559], 
      Hue[0.16565725826114205`], 
      Hue[0.18554595048412817`], 
      Hue[0.20543464270711434`], 
      Hue[0.22532333493010048`], 
      Hue[0.24521202715308663`], 
      Hue[0.26510071937607277`], 
      Hue[0.284989411599059], 
      Hue[0.012921991431858775`], 
      Hue[0.036908426048865], 
      Hue[0.060894860665871214`], 
      Hue[0.08488129528287745], 
      Hue[0.10886772989988368`], 
      Hue[0.13285416451688992`], 
      Hue[0.15684059913389614`], 
      Hue[0.18082703375090234`], 
      Hue[0.20481346836790854`], 
      Hue[0.22879990298491473`], 
      Hue[0.252786337601921], 
      Hue[0.27677277221892715`], 
      Hue[0.3007592068359334], 
      Hue[0.3247456414529396], 
      Hue[0.34873207606994594`], 
      Hue[0.019129614804859984`], 
      Hue[0.047106661311885775`], 
      Hue[0.07508370781891156], 
      Hue[0.10306075432593735`], 
      Hue[0.13103780083296315`], 
      Hue[0.1590148473399889], 
      Hue[0.1869918938470147], 
      Hue[0.2149689403540405], 
      Hue[0.24294598686106625`], 
      Hue[0.270923033368092], 
      Hue[0.2989000798751178], 
      Hue[0.3268771263821436], 
      Hue[0.3548541728891693], 
      Hue[0.3828312193961951], 
      Hue[0.410808265903221], 
      Hue[0.02517704146942584], 
      Hue[0.057041716349106944`], 
      Hue[0.08890639122878805], 
      Hue[0.12077106610846917`], 
      Hue[0.15263574098815025`], 
      Hue[0.18450041586783136`], 
      Hue[0.21636509074751245`], 
      Hue[0.24822976562719354`], 
      Hue[0.2800944405068746], 
      Hue[0.3119591153865557], 
      Hue[0.3438237902662368], 
      Hue[0.37568846514591786`], 
      Hue[0.407553140025599], 
      Hue[0.43941781490528004`], 
      Hue[0.4712824897849613], 
      Hue[0.031070393591860822`], 
      Hue[0.06672364900207929], 
      Hue[0.10237690441229776`], 
      Hue[0.13803015982251624`], 
      Hue[0.17368341523273467`], 
      Hue[0.20933667064295317`], 
      Hue[0.24498992605317158`], 
      Hue[0.28064318146339], 
      Hue[0.3162964368736084], 
      Hue[0.3519496922838269], 
      Hue[0.38760294769404535`], 
      Hue[0.4232562031042639], 
      Hue[0.4589094585144822], 
      Hue[0.4945627139247007], 
      Hue[0.5302159693349193], 
      Hue[0.03681548530498918], 
      Hue[0.07616201105750592], 
      Hue[0.11550853681002264`], 
      Hue[0.1548550625625394], 
      Hue[0.1942015883150561], 
      Hue[0.23354811406757284`], 
      Hue[0.2728946398200895], 
      Hue[0.31224116557260617`], 
      Hue[0.3515876913251229], 
      Hue[0.39093421707763965`], 
      Hue[0.4302807428301563], 
      Hue[0.46962726858267306`], 
      Hue[0.5089737943351899], 
      Hue[0.5483203200877066], 
      Hue[0.5876668458402233], 
      Hue[0.042417841840666604`], 
      Hue[0.08536587967921606], 
      Hue[0.12831391751776552`], 
      Hue[0.171261955356315], 
      Hue[0.21420999319486445`], 
      Hue[0.25715803103341384`], 
      Hue[0.3001060688719633], 
      Hue[0.34305410671051273`], 
      Hue[0.3860021445490621], 
      Hue[0.42895018238761157`], 
      Hue[0.471898220226161], 
      Hue[0.5148462580647105], 
      Hue[0.5577942959032599], 
      Hue[0.6007423337418094], 
      Hue[0.6436903715803589], 
      Hue[0.04788271725376338], 
      Hue[0.09434388652612853], 
      Hue[0.14080505579849367`], 
      Hue[0.18726622507085888`], 
      Hue[0.233727394343224], 
      Hue[0.2801885636155891], 
      Hue[0.32664973288795424`], 
      Hue[0.3731109021603194], 
      Hue[0.4195720714326845], 
      Hue[0.46603324070504965`], 
      Hue[0.5124944099774148], 
      Hue[0.55895557924978], 
      Hue[0.6054167485221451], 
      Hue[0.6518779177945103], 
      Hue[0.6983390870668755], 
      Hue[0.05321511085713103], 
      Hue[0.10310424475254566`], 
      Hue[0.1529933786479603], 
      Hue[0.20288251254337494`], 
      Hue[0.2527716464387895], 
      Hue[0.3026607803342042], 
      Hue[0.35254991422961873`], 
      Hue[0.40243904812503334`], 
      Hue[0.45232818202044794`], 
      Hue[0.5022173159158626], 
      Hue[0.5521064498112772], 
      Hue[0.6019955837066918], 
      Hue[0.6518847176021064], 
      Hue[0.701773851497521], 
      Hue[0.7516629853929359], 
      Hue[0.05841978247561329], 
      Hue[0.11165477406830653`], 
      Hue[0.16488976566099975`], 
      Hue[0.218124757253693], 
      Hue[0.2713597488463862], 
      Hue[0.3245947404390794], 
      Hue[0.37782973203177256`], 
      Hue[0.4310647236244658], 
      Hue[0.48429971521715903`], 
      Hue[0.5375347068098523], 
      Hue[0.5907696984025455], 
      Hue[0.6440046899952387], 
      Hue[0.6972396815879318], 
      Hue[0.750474673180625], 
      Hue[0.8037096647733184], 
      Hue[0.06350126661693213], 
      Hue[0.1200029240195211], 
      Hue[0.1765045814221101], 
      Hue[0.23300623882469904`], 
      Hue[0.28950789622728795`], 
      Hue[0.34600955362987695`], 
      Hue[0.4025112110324659], 
      Hue[0.45901286843505484`], 
      Hue[0.5155145258376438], 
      Hue[0.5720161832402327], 
      Hue[0.6285178406428218], 
      Hue[0.6850194980454107], 
      Hue[0.7415211554479997], 
      Hue[0.7980228128505886], 
      Hue[0.8545244702531777], 
      Hue[0.06846388564812592], 
      Hue[0.12815579563556925`], 
      Hue[0.18784770562301256`], 
      Hue[0.24753961561045593`], 
      Hue[0.3072315255978992], 
      Hue[0.3669234355853424], 
      Hue[0.42661534557278574`], 
      Hue[0.48630725556022897`], 
      Hue[0.5459991655476724], 
      Hue[0.6056910755351156], 
      Hue[0.6653829855225589], 
      Hue[0.7250748955100023], 
      Hue[0.7847668054974455], 
      Hue[0.8444587154848887], 
      Hue[0.9041506254723323], 
      Hue[0.07331176205801516], 
      Hue[0.13612016157457374`], 
      Hue[0.1989285610911323], 
      Hue[0.2617369606076908], 
      Hue[0.3245453601242494], 
      Hue[0.38735375964080787`], 
      Hue[0.45016215915736646`], 
      Hue[0.512970558673925], 
      Hue[0.5757789581904835], 
      Hue[0.6385873577070421], 
      Hue[0.7013957572236006], 
      Hue[0.7642041567401591], 
      Hue[0.8270125562567177], 
      Hue[0.8898209557732762], 
      Hue[0.952629355289835], 
      Hue[0.07804882987881318], 
      Hue[0.1439024848874694], 
      Hue[0.2097561398961256], 
      Hue[0.27560979490478177`], 
      Hue[0.34146344991343797`], 
      Hue[0.4073171049220941], 
      Hue[0.4731707599307503], 
      Hue[0.5390244149394066], 
      Hue[0.6048780699480627], 
      Hue[0.6707317249567187], 
      Hue[0.7365853799653751], 
      Hue[0.8024390349740311], 
      Hue[0.8682926899826874], 
      Hue[0.9341463449913435], 
      Hue[1.], 
      Hue[0.012195125842235695`], 
      Hue[0.0032959809124767404`], 
      Hue[0.24357289401596868`], 
      Hue[0.2524720389457276], 
      Hue[0.10786379722827939`], 
      Hue[0.07569390823046772], 
      Hue[0.944280911171383], 
      Hue[0.9670731724956716], 
      Hue[0.007839723326008522], 
      Hue[0.21167252980223028`], 
      Hue[0.11097565738314126`], 
      Hue[0.9764508001691947], 
      Hue[0.0058391917424138046`], 
      Hue[0.23186239519331034`], 
      Hue[0.09314946421246954], 
      Hue[0.9719844168437665], 
      Hue[0.001653576863693499], 
      Hue[0.21559239146523454`], 
      Hue[0.09451224363097722], 
      Hue[0.9882591381887906], 
      Hue[0.003919861663004259], 
      Hue[0.23604801007203066`], 
      Hue[0.07687474286744553], 
      Hue[0.9835365862478358], 
      Hue[0.023950326172365696`], 
      Hue[0.02743903164102984], 
      Hue[0.04135293186747857], 
      Hue[0.041158547461544764`], 
      Hue[0.05875553756259147], 
      Hue[0.0548780632820597], 
      Hue[0.07615814325770434], 
      Hue[0.06859757910257461], 
      Hue[0.09356074895281721], 
      Hue[0.08231709492308954], 
      Hue[0.1109633546479301], 
      Hue[0.09603661074360448], 
      Hue[0.128365960343043], 
      Hue[0.12347564238463431`], 
      Hue[0.16317117173326878`], 
      Hue[0.13719515820514924`], 
      Hue[0.18057377742838165`], 
      Hue[0.1509146740256642], 
      Hue[0.19797638312349455`], 
      Hue[0.16463418984617909`], 
      Hue[0.21537898881860743`], 
      Hue[0.17835370566669403`], 
      Hue[0.2327815945137203], 
      Hue[0.19207322148720896`], 
      Hue[0.25018420020883314`], 
      Hue[0.20579273730772388`], 
      Hue[0.26758680590394607`], 
      Hue[0.033910121721739225`], 
      Hue[0.05489825201161966], 
      Hue[0.0758863823015001], 
      Hue[0.09687451259138054], 
      Hue[0.11786264288126101`], 
      Hue[0.13885077317114145`], 
      Hue[0.1598389034610219], 
      Hue[0.20181516404078279`], 
      Hue[0.2228032943306632], 
      Hue[0.24379142462054368`], 
      Hue[0.2647795549104241], 
      Hue[0.2857676852003045], 
      Hue[0.306755815490185], 
      Hue[0.3277439457800654], 
      Hue[0.04360953049850755], 
      Hue[0.06808944619215511], 
      Hue[0.09256936188580267], 
      Hue[0.11704927757945023`], 
      Hue[0.1415291932730978], 
      Hue[0.16600910896674534`], 
      Hue[0.1904890246603929], 
      Hue[0.23944885604768804`], 
      Hue[0.26392877174133555`], 
      Hue[0.2884086874349831], 
      Hue[0.3128886031286307], 
      Hue[0.33736851882227825`], 
      Hue[0.3618484345159258], 
      Hue[0.3863283502095734], 
      Hue[0.0530586319891468], 
      Hue[0.08094022250886776], 
      Hue[0.10882181302858872`], 
      Hue[0.1367034035483097], 
      Hue[0.16458499406803068`], 
      Hue[0.19246658458775165`], 
      Hue[0.22034817510747257`], 
      Hue[0.27611135614691446`], 
      Hue[0.3039929466666354], 
      Hue[0.3318745371863564], 
      Hue[0.35975612770607734`], 
      Hue[0.38763771822579834`], 
      Hue[0.4155193087455193], 
      Hue[0.44340089926524023`], 
      Hue[0.06226699207580198], 
      Hue[0.09346359055974311], 
      Hue[0.12466018904368427`], 
      Hue[0.15585678752762544`], 
      Hue[0.18705338601156657`], 
      Hue[0.21824998449550773`], 
      Hue[0.2494465829794489], 
      Hue[0.31183977994733114`], 
      Hue[0.34303637843127227`], 
      Hue[0.37423297691521346`], 
      Hue[0.40542957539915464`], 
      Hue[0.43662617388309577`], 
      Hue[0.46782277236703695`], 
      Hue[0.4990193708509781], 
      Hue[0.07124369533844133], 
      Hue[0.10567190537189346`], 
      Hue[0.1401001154053456], 
      Hue[0.17452832543879773`], 
      Hue[0.20895653547224985`], 
      Hue[0.24338474550570197`], 
      Hue[0.2778129555391541], 
      Hue[0.34666937560605837`], 
      Hue[0.38109758563951046`], 
      Hue[0.4155257956729626], 
      Hue[0.4499540057064148], 
      Hue[0.4843822157398669], 
      Hue[0.518810425773319], 
      Hue[0.5532386358067712], 
      Hue[0.07999737494939738], 
      Hue[0.11757690805812814`], 
      Hue[0.15515644116685892`], 
      Hue[0.19273597427558967`], 
      Hue[0.23031550738432047`], 
      Hue[0.2678950404930512], 
      Hue[0.30547457360178193`], 
      Hue[0.3806336398192435], 
      Hue[0.4182131729279742], 
      Hue[0.455792706036705], 
      Hue[0.49337223914543576`], 
      Hue[0.5309517722541666], 
      Hue[0.5685313053628973], 
      Hue[0.6061108384716282], 
      Hue[0.08853624036708287], 
      Hue[0.12918976348040237`], 
      Hue[0.16984328659372191`], 
      Hue[0.2104968097070414], 
      Hue[0.25115033282036087`], 
      Hue[0.29180385593368036`], 
      Hue[0.33245737904699985`], 
      Hue[0.4137644252736388], 
      Hue[0.45441794838695837`], 
      Hue[0.4950714715002778], 
      Hue[0.5357249946135975], 
      Hue[0.576378517726917], 
      Hue[0.6170320408402364], 
      Hue[0.6576855639535559], 
      Hue[0.09686810301561882], 
      Hue[0.1405210951741066], 
      Hue[0.18417408733259444`], 
      Hue[0.2278270794910822], 
      Hue[0.27148007164957], 
      Hue[0.3151330638080578], 
      Hue[0.35878605596654556`], 
      Hue[0.4460920402835211], 
      Hue[0.4897450324420089], 
      Hue[0.5333980246004968], 
      Hue[0.5770510167589845], 
      Hue[0.6207040089174725], 
      Hue[0.6643570010759601], 
      Hue[0.7080099932344479], 
      Hue[0.10500040011921984`], 
      Hue[0.15158101776282645`], 
      Hue[0.198161635406433], 
      Hue[0.24474225305003958`], 
      Hue[0.2913228706936461], 
      Hue[0.33790348833725264`], 
      Hue[0.3844841059808592], 
      Hue[0.4776453412680724], 
      Hue[0.524225958911679], 
      Hue[0.5708065765552855], 
      Hue[0.6173871941988921], 
      Hue[0.6639678118424986], 
      Hue[0.7105484294861051], 
      Hue[0.7571290471297119], 
      Hue[0.11294021684419746`], 
      Hue[0.1623791670714628], 
      Hue[0.21181811729872815`], 
      Hue[0.2612570675259935], 
      Hue[0.31069601775325884`], 
      Hue[0.36013496798052413`], 
      Hue[0.4095739182077895], 
      Hue[0.5084518186623203], 
      Hue[0.5578907688895856], 
      Hue[0.607329719116851], 
      Hue[0.6567686693441164], 
      Hue[0.7062076195713817], 
      Hue[0.7556465697986471], 
      Hue[0.8050855200259124], 
      Hue[0.1206943068871388], 
      Hue[0.17292472812615173`], 
      Hue[0.2251551493651646], 
      Hue[0.27738557060417746`], 
      Hue[0.32961599184319035`], 
      Hue[0.3818464130822032], 
      Hue[0.4340768343212162], 
      Hue[0.5385376767992419], 
      Hue[0.5907680980382549], 
      Hue[0.6429985192772678], 
      Hue[0.6952289405162807], 
      Hue[0.7474593617552936], 
      Hue[0.7996897829943064], 
      Hue[0.8519202042333193], 
      Hue[0.1282691116350039], 
      Hue[0.18322646121199265`], 
      Hue[0.23818381078898135`], 
      Hue[0.29314116036597004`], 
      Hue[0.3480985099429588], 
      Hue[0.40305585951994755`], 
      Hue[0.4580132090969362], 
      Hue[0.5679279082509138], 
      Hue[0.6228852578279026], 
      Hue[0.6778426074048911], 
      Hue[0.7327999569818798], 
      Hue[0.7877573065588687], 
      Hue[0.8427146561358574], 
      Hue[0.8976720057128461], 
      Hue[0.13567077801138736`], 
      Hue[0.19329272614396154`], 
      Hue[0.25091467427653563`], 
      Hue[0.30853662240910984`], 
      Hue[0.366158570541684], 
      Hue[0.42378051867425814`], 
      Hue[0.48140246680683224`], 
      Hue[0.5966463630719807], 
      Hue[0.6542683112045549], 
      Hue[0.711890259337129], 
      Hue[0.7695122074697031], 
      Hue[0.8271341556022773], 
      Hue[0.8847561037348516], 
      Hue[0.02287609098573815], 
      Hue[0.038663690355423094`], 
      Hue[0.053143208205394823`], 
      Hue[0.06657041466262427], 
      Hue[0.07894530972711145], 
      Hue[0.09026789339885637], 
      Hue[0.10053816567785903`], 
      Hue[0.15866961679901423`], 
      Hue[0.17051835616713026`], 
      Hue[0.18131478414250407`], 
      Hue[0.1910589007251356], 
      Hue[0.19975070591502483`], 
      Hue[0.2073901997121718], 
      Hue[0.033113337852413466`], 
      Hue[0.05228024867446314], 
      Hue[0.07042272389800779], 
      Hue[0.08754076352304745], 
      Hue[0.10363436754958207`], 
      Hue[0.1187035359776117], 
      Hue[0.1327482688071363], 
      Hue[0.19743285557668946`], 
      Hue[0.2130142418039716], 
      Hue[0.22757119243274873`], 
      Hue[0.24110370746302082`], 
      Hue[0.25361178689478786`], 
      Hue[0.26509543072805], 
      Hue[0.275554638962807], 
      Hue[0.04283357757688239], 
      Hue[0.06553988737639992], 
      Hue[0.08724854420341252], 
      Hue[0.10795954805792025`], 
      Hue[0.12767289893992312`], 
      Hue[0.14638859684942107`], 
      Hue[0.16410664178641418`], 
      Hue[0.2351811177222958], 
      Hue[0.25439564211804616`], 
      Hue[0.2726125135412917], 
      Hue[0.2898317319920323], 
      Hue[0.3060532974702681], 
      Hue[0.3212772099759989], 
      Hue[0.3355034695092248], 
      Hue[0.052302703656076074`], 
      Hue[0.07845645874956246], 
      Hue[0.10363830674988501`], 
      Hue[0.12784824765704378`], 
      Hue[0.1510862814710387], 
      Hue[0.17335240819186976`], 
      Hue[0.19464662781953704`], 
      Hue[0.27195375298777036`], 
      Hue[0.2947058332551834], 
      Hue[0.3164860064294325], 
      Hue[0.33729427251051786`], 
      Hue[0.35713063149843943`], 
      Hue[0.3759950833931971], 
      Hue[0.39388762819479095`], 
      Hue[0.061530323060497605`], 
      Hue[0.09104310739650004], 
      Hue[0.11960874659986813`], 
      Hue[0.1472272406706019], 
      Hue[0.1738985896087013], 
      Hue[0.1996227934141664], 
      Hue[0.22439985208699714`], 
      Hue[0.30778810296780656`], 
      Hue[0.3339858793395889], 
      Hue[0.3592365105787368], 
      Hue[0.3835399966852504], 
      Hue[0.40689633765912964`], 
      Hue[0.4293055335003746], 
      Hue[0.45076758420898505`], 
      Hue[0.07052555887430026], 
      Hue[0.10331231485803678`], 
      Hue[0.13517575325619874`], 
      Hue[0.16611587406878614`], 
      Hue[0.19613267729579895`], 
      Hue[0.2252261629372372], 
      Hue[0.2533963309931009], 
      Hue[0.3427196275924063], 
      Hue[0.37227477202663184`], 
      Hue[0.4009065988752829], 
      Hue[0.4286151081383593], 
      Hue[0.45540029981586116`], 
      Hue[0.4812621739077884], 
      Hue[0.5062007304141412], 
      Hue[0.0792970803824377], 
      Hue[0.11527594090270059`], 
      Hue[0.15035442340145533`], 
      Hue[0.18453252787870186`], 
      Hue[0.21781025433444023`], 
      Hue[0.25018760276867036`], 
      Hue[0.2816645731813924], 
      Hue[0.3767820221770052], 
      Hue[0.40960955962198947`], 
      Hue[0.4415367190454656], 
      Hue[0.47256350044743345`], 
      Hue[0.5026899038278932], 
      Hue[0.5319159291868448], 
      Hue[0.5602415765242882], 
      Hue[0.08785313094044576], 
      Hue[0.12694526176867427`], 
      Hue[0.16515910973844883`], 
      Hue[0.20249467484976946`], 
      Hue[0.23895195710263614`], 
      Hue[0.2745309564970489], 
      Hue[0.30923167303300775`], 
      Hue[0.410007325842413], 
      Hue[0.4460254666660528], 
      Hue[0.4811653246312387], 
      Hue[0.5154268997379706], 
      Hue[0.5488101919862486], 
      Hue[0.5813152013760726], 
      Hue[0.6129419279074427], 
      Hue[0.09620155381519788], 
      Hue[0.13833100561750233`], 
      Hue[0.17960346626404441`], 
      Hue[0.22001893575482415`], 
      Hue[0.2595774140898415], 
      Hue[0.2982789012690965], 
      Hue[0.3361233972925891], 
      Hue[0.4424260220379319], 
      Hue[0.48155600479506805`], 
      Hue[0.519828996396442], 
      Hue[0.5572449968420534], 
      Hue[0.5938040061319025], 
      Hue[0.6295060242659892], 
      Hue[0.6643510512443136], 
      Hue[0.1043498161669096], 
      Hue[0.14944338543388622`], 
      Hue[0.1937004902765432], 
      Hue[0.23712113069488053`], 
      Hue[0.27970530668889815`], 
      Hue[0.3214530182585962], 
      Hue[0.3623642654039746], 
      Hue[0.47406713183064336`], 
      Hue[0.5162330756125012], 
      Hue[0.5575625549700395], 
      Hue[0.598055569903258], 
      Hue[0.6377121204121569], 
      Hue[0.6765322064967362], 
      Hue[0.7145158281569958], 
      Hue[0.11230503132653259`], 
      Hue[0.16029212958365918`], 
      Hue[0.20746256138831176`], 
      Hue[0.2538163267404904], 
      Hue[0.2993534256401952], 
      Hue[0.344073858087426], 
      Hue[0.38797762408218284`], 
      Hue[0.5049583005609967], 
      Hue[0.5500870662344644], 
      Hue[0.5943991654554583], 
      Hue[0.6378945982239782], 
      Hue[0.6805733645400242], 
      Hue[0.7224354644035962], 
      Hue[0.7634808978146943], 
      Hue[0.1200739795082396], 
      Hue[0.17088651022213966`], 
      Hue[0.22090147778982613`], 
      Hue[0.27011888221129904`], 
      Hue[0.3185387234865583], 
      Hue[0.3661610016156041], 
      Hue[0.4129857165984363], 
      Hue[0.5351258784085953], 
      Hue[0.5831469381107478], 
      Hue[0.6303704346666867], 
      Hue[0.6767963680764122], 
      Hue[0.7224247383399239], 
      Hue[0.7672555454572221], 
      Hue[0.8112887894283067], 
      Hue[0.12766312708376773`], 
      Hue[0.18123536972724152`], 
      Hue[0.23402848998843642`], 
      Hue[0.2860424878673526], 
      Hue[0.3372773633639899], 
      Hue[0.38773311647834835`], 
      Hue[0.43740974721042813`], 
      Hue[0.5645949953617018], 
      Hue[0.6154403096671998], 
      Hue[0.6655065015904187], 
      Hue[0.7147935711313592], 
      Hue[0.7633015182900207], 
      Hue[0.8110303430664032], 
      Hue[0.8579800454605071], 
      Hue[0.1348928129726719], 
      Hue[0.19134714531573757`], 
      Hue[0.24685433222466321`], 
      Hue[0.30160020526056436`], 
      Hue[0.3555847644234411], 
      Hue[0.4088080097132934], 
      Hue[0.46126994113012143`], 
      Hue[0.5933896310387954], 
      Hue[0.6469935332651601], 
      Hue[0.6998361216185002], 
      Hue[0.7519173960988159], 
      Hue[0.8032373567061074], 
      Hue[0.8537960034403742], 
      Hue[0.01480836644957172], 
      Hue[0.21376782836115857`], 
      Hue[0.2597187630360467], 
      Hue[0.12905607048800014`], 
      Hue[0.9034359446228031], 
      Hue[0.9366799865363534], 
      Hue[0.9423780518674256], 
      Hue[0.013719515820514925`], 
      Hue[0.02509179194421123], 
      Hue[0.005734785586058794], 
      Hue[0.04445432847082624], 
      Hue[0.06381686499744127], 
      Hue[0.08317940152405627], 
      Hue[0.10254193805067131`], 
      Hue[0.12190447457728633`], 
      Hue[0.14126701110390136`], 
      Hue[0.16062954763051637`], 
      Hue[0.17999208415713136`], 
      Hue[0.19935462068374638`], 
      Hue[0.21871715721036136`], 
      Hue[0.23807969373697638`], 
      Hue[0.25744223026359137`], 
      Hue[0.034290422711708485`], 
      Hue[0.011328423693207284`], 
      Hue[0.05725242173020968], 
      Hue[0.08021442074871092], 
      Hue[0.1031764197672121], 
      Hue[0.12613841878571333`], 
      Hue[0.14910041780421454`], 
      Hue[0.17206241682271572`], 
      Hue[0.19502441584121694`], 
      Hue[0.21798641485971812`], 
      Hue[0.24094841387821933`], 
      Hue[0.2639104128967205], 
      Hue[0.28687241191522167`], 
      Hue[0.3098344109337229], 
      Hue[0.3327964099522242], 
      Hue[0.043282323088252986`], 
      Hue[0.016801756039984534`], 
      Hue[0.06976289013652143], 
      Hue[0.09624345718478991], 
      Hue[0.12272402423305835`], 
      Hue[0.1492045912813268], 
      Hue[0.17568515832959522`], 
      Hue[0.2021657253778637], 
      Hue[0.22864629242613213`], 
      Hue[0.25512685947440056`], 
      Hue[0.281607426522669], 
      Hue[0.30808799357093747`], 
      Hue[0.33456856061920587`], 
      Hue[0.3610491276674743], 
      Hue[0.3875296947157429], 
      Hue[0.05207418883049636], 
      Hue[0.02215332813714291], 
      Hue[0.08199504952384981], 
      Hue[0.11191591021720328`], 
      Hue[0.1418367709105567], 
      Hue[0.17175763160391017`], 
      Hue[0.2016784922972636], 
      Hue[0.23159935299061704`], 
      Hue[0.26152021368397044`], 
      Hue[0.29144107437732386`], 
      Hue[0.3213619350706773], 
      Hue[0.3512827957640307], 
      Hue[0.3812036564573842], 
      Hue[0.4111245171507376], 
      Hue[0.44104537784409115`], 
      Hue[0.060672441093971574`], 
      Hue[0.02738704851533896], 
      Hue[0.09395783367260419], 
      Hue[0.12724322625123682`], 
      Hue[0.1605286188298694], 
      Hue[0.19381401140850205`], 
      Hue[0.22709940398713466`], 
      Hue[0.26038479656576724`], 
      Hue[0.2936701891443998], 
      Hue[0.3269555817230324], 
      Hue[0.360240974301665], 
      Hue[0.39352636688029763`], 
      Hue[0.42681175945893024`], 
      Hue[0.4600971520375628], 
      Hue[0.4933825446161955], 
      Hue[0.06908323951593595], 
      Hue[0.03250666652014292], 
      Hue[0.10565981251172897`], 
      Hue[0.14223638550752207`], 
      Hue[0.17881295850331508`], 
      Hue[0.2153895314991081], 
      Hue[0.2519661044949011], 
      Hue[0.28854267749069407`], 
      Hue[0.32511925048648704`], 
      Hue[0.3616958234822801], 
      Hue[0.3982723964780731], 
      Hue[0.4348489694738662], 
      Hue[0.4714255424696591], 
      Hue[0.5080021154654523], 
      Hue[0.5445786884612454], 
      Hue[0.07731249463521969], 
      Hue[0.03751577987194886], 
      Hue[0.1171092093984905], 
      Hue[0.15690592416176136`], 
      Hue[0.19670263892503215`], 
      Hue[0.23649935368830297`], 
      Hue[0.27629606845157373`], 
      Hue[0.3160927832148445], 
      Hue[0.35588949797811537`], 
      Hue[0.39568621274138616`], 
      Hue[0.43548292750465695`], 
      Hue[0.4752796422679278], 
      Hue[0.5150763570311986], 
      Hue[0.5548730717944694], 
      Hue[0.5946697865577404], 
      Hue[0.09322163567026447], 
      Hue[0.047199607827126275`], 
      Hue[0.13924366351340264`], 
      Hue[0.1852656913565409], 
      Hue[0.23128771919967903`], 
      Hue[0.2773097470428172], 
      Hue[0.3233317748859554], 
      Hue[0.36935380272909357`], 
      Hue[0.4153758305722317], 
      Hue[0.4613978584153699], 
      Hue[0.5074198862585081], 
      Hue[0.5534419141016462], 
      Hue[0.5994639419447845], 
      Hue[0.6454859697879226], 
      Hue[0.6915079976310609], 
      Hue[0.10091415519594137`], 
      Hue[0.05188201245628911], 
      Hue[0.14994629793559364`], 
      Hue[0.19897844067524592`], 
      Hue[0.24801058341489815`], 
      Hue[0.29704272615455035`], 
      Hue[0.3460748688942026], 
      Hue[0.39510701163385475`], 
      Hue[0.4441391543735071], 
      Hue[0.49317129711315927`], 
      Hue[0.5422034398528116], 
      Hue[0.5912355825924638], 
      Hue[0.6402677253321161], 
      Hue[0.6892998680717682], 
      Hue[0.7383320108114206], 
      Hue[0.10844832557489618`], 
      Hue[0.05646803061868243], 
      Hue[0.16042862053110993`], 
      Hue[0.21240891548732374`], 
      Hue[0.2643892104435374], 
      Hue[0.3163695053997511], 
      Hue[0.3683498003559648], 
      Hue[0.4203300953121786], 
      Hue[0.4723103902683923], 
      Hue[0.5242906852246061], 
      Hue[0.5762709801808198], 
      Hue[0.6282512751370335], 
      Hue[0.6802315700932472], 
      Hue[0.7322118650494609], 
      Hue[0.7841921600056748], 
      Hue[0.11582884904391379`], 
      Hue[0.060960524546272696`], 
      Hue[0.1706971735415549], 
      Hue[0.22556549803919598`], 
      Hue[0.2804338225368371], 
      Hue[0.33530214703447814`], 
      Hue[0.39017047153211915`], 
      Hue[0.44503879602976026`], 
      Hue[0.4999071205274013], 
      Hue[0.5547754450250424], 
      Hue[0.6096437695226835], 
      Hue[0.6645120940203246], 
      Hue[0.7193804185179656], 
      Hue[0.7742487430156066], 
      Hue[0.8291170675132479], 
      Hue[0.12306025087553911`], 
      Hue[0.06536224875362978], 
      Hue[0.18075825299744847`], 
      Hue[0.23845625511935778`], 
      Hue[0.29615425724126715`], 
      Hue[0.3538522593631764], 
      Hue[0.4115502614850857], 
      Hue[0.469248263606995], 
      Hue[0.5269462657289045], 
      Hue[0.5846442678508138], 
      Hue[0.6423422699727231], 
      Hue[0.7000402720946325], 
      Hue[0.7577382742165417], 
      Hue[0.8154362763384511], 
      Hue[0.8731342784603605], 
      Hue[0.13014688712032033`], 
      Hue[0.0696758547505982], 
      Hue[0.19061791949004245`], 
      Hue[0.25108895185976454`], 
      Hue[0.31155998422948666`], 
      Hue[0.37203101659920873`], 
      Hue[0.43250204896893085`], 
      Hue[0.49297308133865286`], 
      Hue[0.5534441137083751], 
      Hue[0.613915146078097], 
      Hue[0.6743861784478191], 
      Hue[0.7348572108175413], 
      Hue[0.7953282431872634], 
      Hue[0.8557992755569853], 
      Hue[0.9162703079267077], 
      Hue[0.13709295198868565`], 
      Hue[0.2002820084417564], 
      Hue[0.26347106489482713`], 
      Hue[0.3266601213478979], 
      Hue[0.3898491778009686], 
      Hue[0.4530382342540394], 
      Hue[0.5162272907071102], 
      Hue[0.5794163471601808], 
      Hue[0.6426054036132516], 
      Hue[0.7057944600663222], 
      Hue[0.7689835165193929], 
      Hue[0.8321725729724637], 
      Hue[0.8953616294255344], 
      Hue[0.9585847165096747], 
      Hue[0.042494397639324125`], 
      Hue[0.061856934165939154`], 
      Hue[0.08121947069255414], 
      Hue[0.10058200721916917`], 
      Hue[0.11994454374578419`], 
      Hue[0.13930708027239924`], 
      Hue[0.17803215332562922`], 
      Hue[0.19739468985224426`], 
      Hue[0.21675722637885925`], 
      Hue[0.2361197629054743], 
      Hue[0.2554822994320893], 
      Hue[0.2746352822032864], 
      Hue[0.05228024867446318], 
      Hue[0.07524224769296438], 
      Hue[0.09820424671146559], 
      Hue[0.12116624572996677`], 
      Hue[0.144128244748468], 
      Hue[0.1670902437669692], 
      Hue[0.23597624082247284`], 
      Hue[0.25893823984097397`], 
      Hue[0.2819002388594752], 
      Hue[0.30486223787797634`], 
      Hue[0.32782423689647766`], 
      Hue[0.08724854420341256], 
      Hue[0.11372911125168102`], 
      Hue[0.14020967829994946`], 
      Hue[0.16669024534821789`], 
      Hue[0.19317081239648637`], 
      Hue[0.2990930805895602], 
      Hue[0.32557364763782864`], 
      Hue[0.35205421468609693`], 
      Hue[0.3785347817343655], 
      Hue[0.12784824765704383`], 
      Hue[0.15776910835039729`], 
      Hue[0.18768996904375068`], 
      Hue[0.21761082973710416`], 
      Hue[0.36721513320387134`], 
      Hue[0.3971359938972247], 
      Hue[0.4270568545905783], 
      Hue[0.1738985896087014], 
      Hue[0.20718398218733397`], 
      Hue[0.24046937476596655`], 
      Hue[0.4401817302377622], 
      Hue[0.4734671228163948], 
      Hue[0.22522616293723732`], 
      Hue[0.2618027359330302], 
      Hue[0.5178387469035814], 
      Hue[0.13387515878358391`], 
      Hue[0.1798971866267222], 
      Hue[0.22591921446986032`], 
      Hue[0.2719412423129985], 
      Hue[0.3179632701561366], 
      Hue[0.3639852979992748], 
      Hue[0.45602935368555114`], 
      Hue[0.5020513815286894], 
      Hue[0.5480734093718276], 
      Hue[0.5940954372149657], 
      Hue[0.640117465058104], 
      Hue[0.6861394929012422], 
      Hue[0.1873631483571545], 
      Hue[0.23639529109680676`], 
      Hue[0.28542743383645897`], 
      Hue[0.33445957657611125`], 
      Hue[0.3834917193157634], 
      Hue[0.5305881475347202], 
      Hue[0.5796202902743725], 
      Hue[0.6286524330140247], 
      Hue[0.6776845757536769], 
      Hue[0.7267167184933294], 
      Hue[0.24568078523275685`], 
      Hue[0.29766108018897053`], 
      Hue[0.34964137514518423`], 
      Hue[0.401621670101398], 
      Hue[0.609542849926253], 
      Hue[0.6615231448824667], 
      Hue[0.7135034398386804], 
      Hue[0.7654837347948942], 
      Hue[0.3086846512381313], 
      Hue[0.36355297573577244`], 
      Hue[0.4184213002334134], 
      Hue[0.6927629227216189], 
      Hue[0.7476312472192599], 
      Hue[0.8024995717169011], 
      Hue[0.37623672560846744`], 
      Hue[0.4339347277303767], 
      Hue[0.7801227404618327], 
      Hue[0.8378207425837422], 
      Hue[0.44820414884807], 
      Hue[0.8715013754361248], 
      Hue[0.007959571818498528], 
      Hue[0.27686006843572614`], 
      Hue[0.08194977085058092], 
      Hue[0.07390729860112828], 
      Hue[0.950542244260222], 
      Hue[0.029318249655961946`], 
      Hue[0.1900522427854704], 
      Hue[0.03428741010687565], 
      Hue[0.060767977155144134`], 
      Hue[0.2196513794447548], 
      Hue[0.2461319464930232], 
      Hue[0.03808566557698348], 
      Hue[0.06800652627033693], 
      Hue[0.09792738696369037], 
      Hue[0.2475316904304576], 
      Hue[0.277452551123811], 
      Hue[0.3073734118171644], 
      Hue[0.0407570192941709], 
      Hue[0.07404241187280354], 
      Hue[0.10732780445143612`], 
      Hue[0.14061319703006875`], 
      Hue[0.27375476734459914`], 
      Hue[0.30704015992323175`], 
      Hue[0.3403255525018644], 
      Hue[0.373610945080497], 
      Hue[0.04234329795827213], 
      Hue[0.07891987095406515], 
      Hue[0.11549644394985818`], 
      Hue[0.15207301694565128`], 
      Hue[0.18864958994144426`], 
      Hue[0.29837930892882325`], 
      Hue[0.33495588192461634`], 
      Hue[0.37153245492040926`], 
      Hue[0.4081090279162024], 
      Hue[0.4446856009119954], 
      Hue[0.042884284601767575`], 
      Hue[0.0826809993650384], 
      Hue[0.12247771412830923`], 
      Hue[0.16227442889158006`], 
      Hue[0.20207114365485085`], 
      Hue[0.24186785841812167`], 
      Hue[0.3214612879446633], 
      Hue[0.36125800270793407`], 
      Hue[0.4010547174712049], 
      Hue[0.4408514322344757], 
      Hue[0.48064814699774644`], 
      Hue[0.5204448617610173], 
      Hue[0.4100073258424129], 
      Hue[0.08929886287785004], 
      Hue[0.13833100561750222`], 
      Hue[0.43252386205541576`], 
      Hue[0.48155600479506794`], 
      Hue[0.08973990036411561], 
      Hue[0.1417201953203293], 
      Hue[0.1937004902765431], 
      Hue[0.4536019650576117], 
      Hue[0.5055822600138254], 
      Hue[0.5575625549700394], 
      Hue[0.08921135324756704], 
      Hue[0.14407967774520808`], 
      Hue[0.19894800224284917`], 
      Hue[0.2538163267404903], 
      Hue[0.47328962473105457`], 
      Hue[0.5281579492286956], 
      Hue[0.5830262737263369], 
      Hue[0.6378945982239778], 
      Hue[0.08774671499892081], 
      Hue[0.14544471712083012`], 
      Hue[0.2031427192427395], 
      Hue[0.26084072136464886`], 
      Hue[0.31853872348655804`], 
      Hue[0.49163272985228607`], 
      Hue[0.5493307319741955], 
      Hue[0.6070287340961048], 
      Hue[0.6647267362180141], 
      Hue[0.7224247383399235], 
      Hue[0.08537795462973759], 
      Hue[0.1458489869994597], 
      Hue[0.20632001936918182`], 
      Hue[0.26679105173890394`], 
      Hue[0.32726208410862595`], 
      Hue[0.387733116478348], 
      Hue[0.5086751812177923], 
      Hue[0.5691462135875144], 
      Hue[0.6296172459572364], 
      Hue[0.6900882783269586], 
      Hue[0.7505593106966807], 
      Hue[0.8110303430664026], 
      Hue[0.14532465886476736`], 
      Hue[0.20851371531783816`], 
      Hue[0.27170277177090885`], 
      Hue[0.3348918282239796], 
      Hue[0.3980808846770502], 
      Hue[0.46126994113012104`], 
      Hue[0.5244589975831918], 
      Hue[0.5876480540362625], 
      Hue[0.6508371104893333], 
      Hue[0.714026166942404], 
      Hue[0.7772152233954747], 
      Hue[0.8404042798485455], 
      Hue[0.25971876303604674`], 
      Hue[0.12905607048800036`], 
      Hue[0.9034359446228025], 
      Hue[0.04000831111145084], 
      Hue[0.0568847611101926], 
      Hue[0.07376121110893433], 
      Hue[0.09063766110767607], 
      Hue[0.10751411110641783`], 
      Hue[0.1243905611051596], 
      Hue[0.17554606679775597`], 
      Hue[0.19242251679649774`], 
      Hue[0.20929896679523946`], 
      Hue[0.2261754167939812], 
      Hue[0.24305186679272298`], 
      Hue[0.2597187630360468], 
      Hue[0.05228024867446315], 
      Hue[0.07224394336583857], 
      Hue[0.092207638057214], 
      Hue[0.11217133274858944`], 
      Hue[0.13213502743996489`], 
      Hue[0.1520987221313403], 
      Hue[0.232977936495347], 
      Hue[0.2529416311867224], 
      Hue[0.27290532587809785`], 
      Hue[0.2928690205694733], 
      Hue[0.3128327152608487], 
      Hue[0.08724854420341253], 
      Hue[0.11023198043830275`], 
      Hue[0.133215416673193], 
      Hue[0.15619885290808322`], 
      Hue[0.17918228914297346`], 
      Hue[0.2955959497761819], 
      Hue[0.31857938601107216`], 
      Hue[0.34156282224596235`], 
      Hue[0.36454625848085254`], 
      Hue[0.1278482476570438], 
      Hue[0.15378602399043712`], 
      Hue[0.1797238003238304], 
      Hue[0.2056615766572237], 
      Hue[0.36323204884391125`], 
      Hue[0.38916982517730453`], 
      Hue[0.4151076015106978], 
      Hue[0.17389858960870133`], 
      Hue[0.20272732526105663`], 
      Hue[0.23155606091341194`], 
      Hue[0.4357250733114849], 
      Hue[0.4645538089638402], 
      Hue[0.22522616293723727`], 
      Hue[0.2568844202139656], 
      Hue[0.5129204311845169], 
      Hue[0.1280675126245383], 
      Hue[0.16828189430863086`], 
      Hue[0.20849627599272338`], 
      Hue[0.24871065767681597`], 
      Hue[0.28892503936090846`], 
      Hue[0.329139421045001], 
      Hue[0.4502217075265056], 
      Hue[0.49043608921059806`], 
      Hue[0.5306504708946906], 
      Hue[0.5708648525787833], 
      Hue[0.6110792342628758], 
      Hue[0.6512936159469682], 
      Hue[0.18112700662022774`], 
      Hue[0.22392300762295317`], 
      Hue[0.26671900862567854`], 
      Hue[0.30951500962840395`], 
      Hue[0.3523110106311294], 
      Hue[0.5243520057977935], 
      Hue[0.5671480068005189], 
      Hue[0.6099440078032444], 
      Hue[0.6527400088059697], 
      Hue[0.6955360098086951], 
      Hue[0.23902641128367028`], 
      Hue[0.2843523322907973], 
      Hue[0.32967825329792433`], 
      Hue[0.3750041743050515], 
      Hue[0.6028884759771664], 
      Hue[0.6482143969842935], 
      Hue[0.6935403179914206], 
      Hue[0.7388662389985478], 
      Hue[0.30162194406280785`], 
      Hue[0.3494275613851253], 
      Hue[0.39723317870744274`], 
      Hue[0.6857002155462955], 
      Hue[0.7335058328686129], 
      Hue[0.7813114501909304], 
      Hue[0.36877523686003727`], 
      Hue[0.41901175023351617`], 
      Hue[0.7726612517134026], 
      Hue[0.8228977650868815], 
      Hue[0.44035309890850055`], 
      Hue[0.8636503254965554], 
      Hue[0.03180433618383521], 
      Hue[0.19253832931334366`], 
      Hue[0.04028401876112721], 
      Hue[0.06376628148226987], 
      Hue[0.22564798809900635`], 
      Hue[0.24913025082014903`], 
      Hue[0.048577058017118147`], 
      Hue[0.07500078789709336], 
      Hue[0.10142451777706858`], 
      Hue[0.2580230828705922], 
      Hue[0.2844468127505675], 
      Hue[0.3108705426305426], 
      Hue[0.056689356734011445`], 
      Hue[0.08599166495268391], 
      Hue[0.11529397317135638`], 
      Hue[0.14459628139002886`], 
      Hue[0.2896871047844397], 
      Hue[0.3189894130031122], 
      Hue[0.34829172122178464`], 
      Hue[0.37759402944045717`], 
      Hue[0.06462658258965864], 
      Hue[0.09674649865917434], 
      Hue[0.1288664147286901], 
      Hue[0.16098633079820582`], 
      Hue[0.19310624686772151`], 
      Hue[0.32066259356020976`], 
      Hue[0.35278250962972546`], 
      Hue[0.3849024256992412], 
      Hue[0.41702234176875697`], 
      Hue[0.44914225783827266`], 
      Hue[0.07239417891615509], 
      Hue[0.10727257796036131`], 
      Hue[0.14215097700456755`], 
      Hue[0.17702937604877378`], 
      Hue[0.21190777509298], 
      Hue[0.2467861741371862], 
      Hue[0.35097118225905083`], 
      Hue[0.38584958130325697`], 
      Hue[0.4207279803474632], 
      Hue[0.4556063793916695], 
      Hue[0.4904847784358756], 
      Hue[0.525363177480082], 
      Hue[0.41000732584241295`], 
      Hue[0.09510650903689571], 
      Hue[0.1383310056175023], 
      Hue[0.43833150821446143`], 
      Hue[0.48155600479506794`], 
      Hue[0.10221218383796936`], 
      Hue[0.14795633705725625`], 
      Hue[0.19370049027654318`], 
      Hue[0.46607424853146545`], 
      Hue[0.5118184017507524], 
      Hue[0.5575625549700394], 
      Hue[0.10917447509482713`], 
      Hue[0.15738842564338157`], 
      Hue[0.20560237619193594`], 
      Hue[0.25381632674049037`], 
      Hue[0.4932527465783147], 
      Hue[0.5414666971268691], 
      Hue[0.5896806476754236], 
      Hue[0.6378945982239781], 
      Hue[0.11599754370021549`], 
      Hue[0.1666328386468012], 
      Hue[0.2172681335933869], 
      Hue[0.2679034285399726], 
      Hue[0.31853872348655826`], 
      Hue[0.5198835585535808], 
      Hue[0.5705188535001666], 
      Hue[0.6211541484467523], 
      Hue[0.671789443393338], 
      Hue[0.7224247383399238], 
      Hue[0.1226853983718899], 
      Hue[0.1756949419931816], 
      Hue[0.2287044856144733], 
      Hue[0.281714029235765], 
      Hue[0.3347235728570566], 
      Hue[0.3877331164783483], 
      Hue[0.5459826249599447], 
      Hue[0.5989921685812363], 
      Hue[0.6520017122025279], 
      Hue[0.7050112558238197], 
      Hue[0.7580207994451115], 
      Hue[0.811030343066403], 
      Hue[0.1290560704880001], 
      Hue[0.18457990856261675`], 
      Hue[0.23991791507611768`], 
      Hue[0.2952559215896185], 
      Hue[0.35059392810311946`], 
      Hue[0.40593193461662036`], 
      Hue[0.4612699411301213], 
      Hue[0.571565297220611], 
      Hue[0.626903303734112], 
      Hue[0.6822413102476127], 
      Hue[0.7375793167611137], 
      Hue[0.7929173232746147], 
      Hue[0.8482553297881156], 
      Hue[0.9034359446228027]},
    VertexNormals->CompressedData["
1:eJwUmXc81e8bxlWKlBYJZSY7I5WVnhIqpIivEUopkrKKRCVbNplJRmb23vc5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     "]], GraphicsComplex3DBox[CompressedData["
1:eJx12E1oz3EcwPGFPCzlwKK0g5vQHKwU5d+42EVIprCFSBg7YNJQ5Gk7SDnY
isso8rApbW0yD+uPxrZiHDaLTYhhm1qN0d9D3g7vT/9f/S6vPn2+397H74yN
u1ZuHpWRkfHt9z/693/iwM1rVZUNicfzl0+pqrycaKmoyC+svpjIH1nbt3xc
MnhbffehjrzW4LMa52bOaXoafMfZko7irhfBr++9cb5muDP4wKqvWwezXgWv
/Pv1BG8c33hwwaU3wbtKOzd11b0N/uPd96VlyffBs1dPz8nu+BB8UXLh5Kbe
vuBFueuGCwc/Bz9cXdadSvUHp3PNrolHx+2pDZ3tdLbT2U5nO53tdLbT2U5n
O53tdLbT2U5nO53tdLbTeV/zQCov+2bobKeznc52OtvpbKeznc52OtvpbKez
nc52OtvpbKeznc55U5/vL0vWh852OtvpbKeznc52OtvpbKeznc52OtvpbKez
nc52OtvpnLm9Yaiu+FbobKeznc52OtvpbKeznc52OtvpbKeznc52OtvpbKez
nc7Pms6VDGbdCZ3tdLbT2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbTedmE
e0NZRfdCZzud7XS209lOZzud7XS209lOZzud7XS209lOZzud7XSe9/drDp3t
dLbT2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbTedr6iyV/urqznc52Otvp
bKeznc52OtvpbKeznc52OtvpbKeznc52Ov88NvV6cdeD0NlOZzud7XS209lO
Zzud7XS209lOZzud7XS209lOZzude2tP9pXXPAqd7XS209lOZzud7XS209lO
Zzud7XS209lOZzud7XS20/lh58jMS0daQmc7ne10ttPZTmc7ne10ttPZTmc7
ne10ttPZTmc7ne10vjpm55ZkwZPQ2U5nO53tdLbT2U5nO53tdLbT2U5nO53t
dLbT2U5nO51P57yu7p3dFjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53Odjrb
6Wyn8+41K3tSqfbQ2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U5n+9js
6TMmfbybOFORe6oj71robx/Y/mlbzfCX4Oy3s//wksrFg1ntYb+d/ek83f3D
++q/eTvz6fr43Ja1Q6Uv624najfcX1FffOW/NxzPvVBQ1h+c+ZHWodPD5e1h
3k6HdPt9f/anu7/3M5/u/dbncp909/e5vwDKhUrk
    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[
         TagBox[Polygon3DBox[CompressedData["
1:eJwBCQX2+iFib1JiAgAAAKgBAAADAAAA4gIRFQUGEgIDEwMEFgYHFwcIGgoL
HAwNGAgJGQkKFAQFKhobGwsMKRkaIxMUIBARIRESJBQVJRUWKBgZ7+XkJhYX
JxcYHQ0OKxscLBwdPy8wRzc4MSEiLR0eMiIjNCQlNycoMyMkNSUmNiYnLx8g
MCAhOCgpOSkqQDAxPCwtPi4vQTEyIhITQjIzRDQ1OiorOyssQzM0RTU2gHBx
RjY3f29wTj4/Sjo7Szs8Tz9AUEBBU0NEVUVGUUFCUkJDTT0+Y1NUVERFYlJT
XExNWEhJWUlKXU1OXk5PYVFSV0dIX09QYFBRVkZHZFRVZVVWd2doSTk6aVla
ZlZXa1tcbV1ecGBhbFxdbl5fb19gZ1dYaFhZcWFicmJjeGhpdWVmdmZnempr
SDg5e2tsfW1uc2NkdGRlfGxtfm5vWkpLgXFyzb2+hnZ3g3N0hHR1nIyNh3d4
inp7i3t8jHx9jX1+hXV2iXl6jn5/kICBlYWGkoKDk4OEloaHmIiJm4uMkYGC
mYmKmoqLj3+A8PjnnY2On4+Qo5OUoJCRoZGSno6PpJSVp5eYqJiZqZmaqpqb
opKTq5ucrJydrZ2er5+gsKChsaGisqKjlISFs6OkuKiprp6ftqant6eotKSl
gnJzuamqu6uswLCxva2uvq6vwbGywrKzxra3yLi5w7O0xbW2v6+w1sbHx7e4
1cXGzr6/y7u8zLy9z7/A0MDB5sXUyrq70cHC0sLDybm618fI2MjJCBgXvKyt
3MzN2cnK3c3O38/Q4+IQ3s7P4NDR7ejS2srL28vMAhIRAxMSCRkYBhYVBxcW
ChoZuqqrCxsaDR0cBBQTBRUUDBwb5B0OECAfESEgEiIhFCQjFSUkFiYlFycm
GCgnGSkoGiopGysqHCwrHS0sHy8uIDAvITEwIjIxIzMyJDQzJTU0JjY1Jzc2
KDg3KTk4Kjo5Kzs6LDw7Lj49Lz8+M0NCMEA/MUFASVlYNERDNkZFN0dGOEhH
OUlIMkJBOkpJO0tKPU1MP09OQFBPQVFQQlJRSFhXQ1NSR1dWPk5NRVVURlZV
RFRTNUVESlpZbn59TV1cTl5dT19eUGBfUWFgUmJhU2NiVGRjVWVkVmZlV2dm
WGhnWWloW2tqXGxrXW1sXm5tX29uYHBvYXFwYnJxY3NyZHRzZXV0ZnZ1Z3d2
bHx7aHh3anp5TFxbbX18b39+cIB/cYGAcoKBa3t6c4OCdISDdYWEd4eGeYmI
eoqJe4uKgZGQfIyLgJCPdoaFfo6Nf4+OfY2MEyMigpKRhJSTiZmYhZWUhpaV
ipqZi5uajp6dkKCfjJybjZ2ciJiXnq6tj5+ena2sl6emk6OilKSjmKinmamo
nKyrkqKhmqqpm6uqkaGgn6+uoLCvssLBu8vKpLSzobGwpra1qLi3q7u6p7e2
qbm4qrq5orKxo7OyrLy7rb28s8PCsMC/scHAtcXElaWktsbFuMjHrr69r7++
t8fGucnIusrJvMzLg5OSwdHQvs7Nv8/OwtLR8Ofmx9fWydnYxdXUxtbVwNDP
yNjXytrZ6+QOzNzbzd3czt7dz9/eHeQe0ODf8u7jy9va7uriEOIR6ODRpZWW
5OUe+fHhvc3M8eno7ObU6Ong8+/r9u4B4uoC9PDs9fHt5ufE0ujR4+7i9+8P
7vIB7PDm7fHo7/MPxebE8PTT7vbq6+/k+PDT8fXh7/fl8fnpl2heKQ==
           "]],
          Annotation[#, "Charting`Private`Tag$3017#1"]& ]],
        Lighting->"Neutral"]}, {}, {}, {}, {}}, 
     {GrayLevel[0], 
      Line3DBox[{246, 1, 242, 227, 16, 31, 46, 61, 76, 91, 106, 121, 136, 151,
        166, 181, 196, 231, 248, 211, 244, 236, 212, 213, 214, 215, 216, 217, 
       218, 219, 220, 221, 222, 223, 224, 233, 249, 225, 245, 237, 210, 195, 
       180, 165, 150, 135, 120, 105, 90, 75, 60, 45, 30, 229, 247, 15, 243, 
       235, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 234, 246},
       VertexColors->None]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGD4CcRpYPDMfpQepUfpUXqUHqVH6aFHAwAuZnMS
     "],
    VertexNormals->CompressedData["
1:eJztyLEJACEURMGPVmIl9nAlCBdfC5ZsanZGgtjCLDwWprTveVNEzFWOvX7+
qJxzzjnnnHPOOeecc845v/0H/ZUifQ==
     "]]},
  Axes->True,
  AxesLabel->{
    FormBox["\"\[Rho]\"", TraditionalForm], 
    FormBox[
    "\"      \\!\\(\\*SubscriptBox[\\(S\\), \\(\\(r\\)\\(\\\\ \\)\\)]\\)\"", 
     TraditionalForm], 
    FormBox["\"er      \"", TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Lighting->"Neutral",
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{All, All, All},
  PlotRangePadding->{Automatic, Automatic, Automatic},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.410468882654875*^9, 3.410504965609375*^9, 
  3.5303609899279537`*^9, 3.5305685889059362`*^9, 3.5305723792147293`*^9, 
  3.531617865656469*^9, 3.5316194848560815`*^9, 3.5316197618719263`*^9, 
  3.5331482185533085`*^9, 3.53323646234235*^9, 3.5332400512096214`*^9, 
  3.533683637703125*^9, 3.5337353269710684`*^9, 3.53375623703125*^9, 
  3.5390212316509924`*^9, 3.5390216355220923`*^9, 3.539034746002969*^9, 
  3.539988763076291*^9, 3.5401275424511223`*^9, 3.540561272356265*^9, 
  3.541186556588035*^9, 3.541187915332751*^9, 3.5411880393908463`*^9, 
  3.541191071422269*^9, 3.541191169585883*^9, 3.5411912515295706`*^9, 
  3.5411913079877996`*^9, 3.5416041776854677`*^9, 3.6126969104282365`*^9, 
  3.6972339931738424`*^9, 3.6972358770797977`*^9, 3.6973178563759356`*^9, 
  3.697323533544083*^9, 3.698044394060047*^9, 3.6980448331617575`*^9, 
  3.731421557990097*^9},
 TextAlignment->Center,ExpressionUUID->"064dc942-d7e9-4963-8da1-ba5f670236c8"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.11.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Effective return vs. passive income instruments",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
   3.5305648276488047`*^9}, {3.530565115734282*^9, 3.530565120441551*^9}, {
   3.530565584010066*^9, 3.530565587296254*^9}, {3.5305663222572913`*^9, 
   3.530566342809467*^9}, {3.5305681591723566`*^9, 3.530568165991747*^9}, {
   3.530568269005639*^9, 3.5305682875136976`*^9}, {3.530568545559457*^9, 
   3.5305685777522984`*^9}, {3.530568686144498*^9, 3.530568694791992*^9}, 
   3.5390216355220923`*^9, 3.539034746002969*^9},
 TextAlignment->Center,ExpressionUUID->"00e2658e-abeb-4c22-b681-8fbd1a7a3241"],

Cell[TextData[{
 "Let's define an effective return function, ",
 StyleBox["er,",
  FontSlant->"Italic"],
 " dependent on \[Rho] and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "r"], TraditionalForm]],ExpressionUUID->
  "3beb23d9-a2b2-42d1-9202-8be36d86742e"],
 ", and plot various values for it in Figure 8.13. Working from right to \
left, returns decline as time shortens or ability erodes."
}], "Text",
 CellChangeTimes->{{3.5305688880870485`*^9, 3.530568940087023*^9}, {
  3.531620362344271*^9, 3.5316203707247505`*^9}, {3.5390216355220923`*^9, 
  3.5390216355240927`*^9}, {3.539034746003969*^9, 3.539034746004969*^9}, {
  3.53999312833397*^9, 3.5399931549424915`*^9}, {3.5411907899471693`*^9, 
  3.5411907903151903`*^9}},ExpressionUUID->"0bed3cb5-505c-480f-8a67-\
526e81c3fae9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"er", "[", "\[Rho]_", "]"}], "=", 
   RowBox[{"\[Rho]", " ", 
    FractionBox[
     SubscriptBox["S", "r"], 
     RowBox[{
      SubscriptBox["S", "r"], "+", "1"}]]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"er", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Rho]", ",", "0.1`", ",", "0.9`", ",", "0.3`"}], "}"}]}], 
       "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["S", "r"], ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", "0.3`", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "10"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", "0.6`", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"3", ",", "5"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", "0.9`", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], "}"}]}], 
     ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(S\), \(r\)]\)\>\"", ",", "\"\<er\>\""}], 
       "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"SL6", "=", 
  RowBox[{"Legended", "[", 
   RowBox[{"p2", ",", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", "0.9", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], "]"}]}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", "0.6", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"3", ",", "5"}], "}"}], "]"}]}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Hue", "[", "0.3", "]"}], ",", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
          RowBox[{"AbsoluteDashing", "[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "10"}], "}"}], "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\[Rho] = .9\>\"", ",", "\"\<\[Rho] = .4\>\"", ",", 
        "\"\<\[Rho] = .1\>\""}], "}"}]}], "]"}]}], "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.530568803968237*^9, {3.5305731051822524`*^9, 3.530573114111763*^9}, 
   3.5390216355240927`*^9, 3.539034746004969*^9, 3.539993172885518*^9, {
   3.6972381413231516`*^9, 
   3.6972382846891923`*^9}},ExpressionUUID->"3065c018-167e-42ad-b318-\
3e8dd4d24905"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          Hue[0.3, 1, 1], 
          AbsoluteThickness[2], 
          AbsoluteDashing[{2, 10}]], 
         LineBox[CompressedData["
1:eJwVx3840wkAx3Gki5Bc9+jHIz2r9IPUQ6tuJR/LnnsQzslJquMqUTp1G7X8
ym70g6GGYqbtq7qerR8aqmOcWjKV+RW2WPv6cSROuPzcJdf98X7ez4ty6KR/
mJGBgYHPl/7/2kfx/Xl5EtxgVHl/y2HBRSbrfnBHgoyqfdSgDBb87/ZplZUS
9L3tpZ3JZyG+0K9pvEsCI7eNouKHLDRnrC7/wV4KGm+mxXaAhcTwujRTuRQn
6uIMVf7RaF1is+ms9g6813E/Ja2KATdOHhO04j46FJvDvBWnsax0IN2FK4On
l6yihxaLT8zG6K2qEji511Qcj0jActdIhczsEUwnpz2nXZLQL2TZ6GL/QI9h
IOVvkoOd1QHzo5+UY3HwClF4KBcu524Yy7dWoivkPtbrkxH73e0wLlGFltGl
3ddTzoMySL8XPPoEF3lDWRkjF9D+qc/R216BMeXjtFrWJWiYbDbT9xk8uy82
xKpTMR515PSbE9Xg+Cam6jby8I56QZ974znObjNddrMgHbYhVz3Sn9eAo6tw
TfuQAfs9Wpv2WSVax/rtTBwuI1AVfzOc+gLd1A55ieYylHdMJ9YHvMTxE4t8
aewrsAhQqRi8V4CbRFa4ko/c0IST2UV1KDGEsU8VH1Nbj1xzGVShVKC/99vR
LJzJusW0ozQgkMMXrDXJhq30fRqF0og1cNr/RJiNyOF8QlvZCEqpyI27Iwft
Rxk2zn5NKH5udS1HlYN9FMHIbbIJJUn8svrgq1C4mZl4xTUjknSaVo9ehS+f
mXze/DVyHjsWvIq/hmqPcfdhyWvM6NHnbpULr112B9mMFnStsa4YEOfin192
d+S3tMBqXchdS7s8pHzmCQdPtaJMxSgMK87D9qfVilajNvzI2x2WQhVgtkay
q/NKG/4qHwiMLBagyEk6d7GjGmZbMouotHxw6sWO/ZVqLIqIeuDxMB+ujcW5
vcEaqMpKaLM0IZYbyyMShjRQ1u6SMUqFMI87xd+S8AZtYN4T2RegN5A+u3Rp
O1jpe80CJQXoOmLSlCttB/jmPZa216FUD/S6e3Rg5YHR4veC66hMjw2w7OnA
wETieu0iEVpjDNbFsLSwe/m0m84VQaMgXOctfAv5+CGLFL0IM3Ra+ebCt+gv
Gj22nSqGs3FiZpKTDsfdVyxgHxPD30F3e7pOh30NU7+mFIqRnUy1s/iJRM7l
vP3L1GKMubFHskNJDNW8L5ujEWPPjFxuc5jEXg+N2dAXf33a3X9DBAmX5dmp
Ve1iZIb7n9vNJLFJVPjxsE6MVK9Tby6dJ1HrMBkt7RWDs/Bu+ldFJGjOwTs2
jonRWTcclCEjsSE22NJ6XAy3S5tXW5eSsP55iXrmiz8bysvtykgEDzfSVZNi
xH988Y7xjES9m19y5L9isNve0blqEvv1oX/eMiKg4TtYmLWTmPN7UT1vDoFt
35/U8LUkJpmvmlnGBCaUE1GFXSQUPlGP6F8RYJXNFT4dJOFsHj+oNSXQHOMZ
7vmBxM5aX8Gz+QScndOdm0ZIDB+YcJGaERiRfvOic5zEvAHlwTMWBPzCg7Ij
pkiYN3zsOLiAQNEqYciInsRY2JQPw5LAgk7Snj1DovFmW4n9QgJRwlUTs7Mk
sjiZFlZWBP4DuQ5u9A==
          "]]}, Annotation[#, "Charting`Private`Tag$3056#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          Hue[0.6, 1, 1], 
          AbsoluteThickness[2], 
          AbsoluteDashing[{3, 5}]], 
         LineBox[CompressedData["
1:eJwVkns0lAkAR5GKhmTbo8eRzlR6kDo01U7Jj8zZg7BWVppq2UqUVu1ITUhZ
aSuvXUNJWnmUMxMxM6gxNN83yaiMV5iJyeexJFbYPGeTtX/cc8/9/9KPnvEO
1NPR0fGY439vKIvqv3OHj1yWzP2bGB7shcLu4kd8JMkOMvySePAu6NMoKvno
e9fLvHCXh6gcr8bxLj70HLdkiUp5aEpaV/69lQDMhJlmiwEeooNq4w2lApyu
jdRVeqeiZbn51ouaR3DfGPv5yto0xEZKw/1WP0a7fFugu/wWVpYMJNrHCuHq
JqzoYWbgM6fh3A6lGLbO1RWngu9hlUOIXEgrg+HktOu0/X30Z4aZd0Q8RY+u
L/1vKht7qnwWnSPKsYy9OisoIBf2l3P1pTsq0eX/GJu0eYj4Nj8wNluG5tEV
3X/GPQR90KmQPUrgesIQL2kkH22f+2zcreQYUzyJrwnjQ83hcjmez+Hafb0+
QiXAeOjx829PVyHGM/pmx5YCvGf8pk3PfYGLOw1X5t0rhIX/LZfEF9WI6ahw
iP/4GFb7NeZtswq0jPVbGlgXw1cZlRfEeIluRrtUrC6G4pHhxCafVzh1eqkn
kyuEsY9SyUp4DTjyhTlrREgPuHQmtagWYl3oe8hEmNpx/Lb9oBIlGdrCX0+I
cYH3gGNJr4dvTErGBoMSWAg+xNPpDVgP20NEZglChu9mayobQC/JcozdXYq2
EyxzO69GiF6Y3k5TluIgPWMkn2qE+EqKpI5dBrkjzcAtsgkhlO20arQMnimc
q9eM3iDtic2911FPUOUy7jzMf4MZLfqcTZ/Cba/lES6rGV3rzSoG7j/FPz/v
a7/b3AzTjf4FJpYSxH1JyBw82wKJkpUTKJJgF1klb9FrxQ8J+wLjGOWYrebv
7fyjFX+VD/iGiMpRZCuYv8xGBdr25CIGU4qYuvs2/ZUqLA0OLXYplcKhQZTe
y1ZDKREzZ5kVWKUvDb40pIaiZq+QVVIBo8izKdsvvUUrOIVZVpXo9XWaXbGi
DWGJB2i+/LkPjhs0pgvagBSjHhOLZ1CoBnqdXdqx5vCo6EPGM1QmRviY9LRj
YCJ6k2apDC3hOhvDwzSwfEV2O8XKoJZnOyxc8g7S8aPGcVoZZpyY5dty3qG/
aPTkLgYBO/3o5Cu2HTjlvHox9yQBb+uO/OnaDhysn/olLodA6lWGpfGPFNJ+
v3NopYrAmCN3JDWAwlD1B8k8NYH9M1Kp+TEKB1zUtKG5/uq8s/fmYAr2q1Jv
ytoIJAd5X97HobA1K+fTsQ4CN93Ovr1xjUKN9eQ5QS+BmCUFiQuKKDDt2Lu3
jBHorB32SxJS2BzBNjEbJ+B4Y9s6sxIKZj8tV83M9RddabmlhAJ7uMFJOUkg
6tPL96znFOocva6G/EuA2/reKVZF4ZA24NkDPRLqFGtjWhuFeQ+L6hLmkdj5
3Rl1iobCJOd1U5g+iQnFRGhOFwW5R2iZ0wISYZL5meQgBTujqEGNIYmmcNcg
148U9tR4ZjxfRMLOLtGucYTC8OEJewGNxIjg65ed4xQWDiiOXDAm4RXklxo8
RcGo/lP7kcUkitZm+o9oKYwFTnmwTEgs7qSsuDMUGvJaxVZLSIRmrp2YnaXA
i0k2NjUl8R+pp3iU
          "]]}, Annotation[#, "Charting`Private`Tag$3056#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          Hue[0.9, 1, 1], 
          AbsoluteThickness[2]], 
         LineBox[CompressedData["
1:eJwVi3081HcAx+WlxsRU26JOi/JKmsoxW2U+nlpC2GUly7IoSWGkbhzWS1Jx
PRyvKNfWnZbXHeVx5+G6eTrOw30LeTjnzk/lKWpMqES39sf79X69/3ibHY5k
HNHW0tLa84H/vUHEGr1xQwDDgxtcly3jwaG4+GlRvgA5qQ+t2TQeGAXDKplE
AEtzAUPXkgcW37d95okA2kx3z3lHHjour6/63kqIYmXgnPIED4mh8jQ9sRBq
htfPMU08dBnTtvyqyodL/ZTKKImP5HhxrP8X95HkwVZoj+ViVdkY2yG5GJq1
q3fmTd3FfHTbKXtSipY46yOBYgFMHcPrivVF8I6KdS47XoBRbgytP64CHsn7
tqt3FeJbqd/Hp2qq0BmxIz9guggOSbk6YnsJnmVUrBwMKEHcd3lHknnVuFHa
vXi8rBRm4873Av6twWtlZC1rqgzK+WFrL6s6zDx0ivPZKYIimsmM9q6HpiEr
No1VjpmIkNO9J6QoOre5UltQgRG71Lns3AZcMmq6PvG8EmsOXXdnNzSi0GWo
u9JIDKu9KppSI8Ppgv0u3p4PsI+w7oTaNeMSt/rC9ngJZPl6sxv9WlC5wHMP
4fwNAz9C3NJbcXLrqIj7oBrZQQmRmYVyJJiVBweH1uCNfUiWwzhB4K4d/iVv
a3Am489oC7NHsLJxyjNPrcUa4fM0M7M2OK1s9bHUq0P4RA5PJWlDjiRNsTyz
DsqjbjS6bzvm07cMPl1RjwNmNyfzqHbc2hr09NSVetQ56et6xHcgIVd/jrtC
Cm9O9LnzSx+Dr3VhI50thdR9xnVC8Bjcd2fCVn/SAA8Xi0CmWyd0DmeEkPQG
TJ307Mvp7ISh62PRSa1GpLxP545HdWGR3fxLY1YjttdK67q0u9G8il8x/bIR
mkaBy8C1bqQGG7wwPShDoY1w8UrrHoR53zIx7JDh7MPb1qOSHhjlBN38w7EJ
jm0l2UMBClxzSWBUlzTBVEd8LOGlAvciV61+YNqMpfFRnK8SeqF8XV/umdKM
oX3OGhMTJaQ5L3Zvmm7GkxDd9myhEq81wuE9AS2Q9YwNubr3gbs1g5Uua4GE
Hef3ybM+LDX2uRNk04quWC3L2BgVqKthd3s5rVDU8Rw/MlJDJ0sUbveuFQvO
26ps+Wp0vjq67eiPctB1Eq/8ZtOPt3+JjDkVcjA29ee9lfej73hMahiNIPOc
nYXBTxR0JF5rI5gE007MycwgCqa0AylL4gj2LojFtGAKWYlVnb/HEyw/7cr4
8hgFS9tk+qNEgiuhjCTPaAqc6wfHNqcQXPKI6r14nsKt9CKvsWsEZ40K2EsK
KTzrUY/45hMMyCf8LxdTkP/Qf3O4gMDpou36z8soDAuOf8O6T/B+kbjKopKC
mm9tm1dMwHrVPOJWTyH0l/QN8+UEzO4R5+QeCmtEGw34UgIFZ5OBvpJCyuHS
MPtGgq99IhUcFYUteoNFLTKCWdlsBP8JhWW6zpqpFoKYysXc2nEK+z8z4bq0
E3TE7g7d/Q+F8H497+4OAjqdTW+fpMA3LxwL6ySYFH7aPDBDIa3XdPBqD4Fv
qH/msTcU/IRjTut7CQrXcQ9Nzn34S6IvlCsJDAcoK+bCh75dXuWhIojgrpvV
aCjUmIt71GqC/wA7tnvt
          "]]}, Annotation[#, "Charting`Private`Tag$3056#3"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0.05, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(S\\), \\(r\\)]\\)\"", TraditionalForm], 
       FormBox["\"er\"", TraditionalForm]}, AxesOrigin -> {0.05, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.05, 0.5}, {0., 0.23333333047619043`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"\[Rho] = .9\"", "\"\[Rho] = .4\"", "\"\[Rho] = .1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.9, 1, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{0, 1}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.9, 1, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{0, 1}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.6, 1, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{3, 5}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.6, 1, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{3, 5}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.3, 1, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{2, 10}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Hue[0.3, 1, 1], 
                    AbsoluteThickness[2], 
                    AbsoluteDashing[{2, 10}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"]
          , LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Arial"}, 
         Background -> Automatic, StripOnInput -> False], TraditionalForm]& ),
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.9, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.9`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.9], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}], "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.6], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.6, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.6`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.6, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.6], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"3", ",", "5"}], "}"}], "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.3], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> Hue[0.3, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"Hue", "[", "0.3`", "]"}], NumberMarks -> False]],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.3, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.3], Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"AbsoluteDashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "10"}], "}"}], "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}]}], "]"}]& ), Editable -> 
      True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.410468883373625*^9, 3.41050496596875*^9, 3.5303609919070673`*^9, 
   3.53056879772488*^9, 3.530572379885768*^9, 3.530573115946868*^9, 
   3.5316178667375307`*^9, 3.5316194853591104`*^9, 3.5316197624209576`*^9, 
   3.5331482195333643`*^9, 3.5332364633074055`*^9, 3.533240051848658*^9, 
   3.533683638609375*^9, 3.5337353280141277`*^9, 3.533756237921875*^9, 
   3.539021233022071*^9, 3.539021635533093*^9, 3.5390347460129695`*^9, 
   3.53998876427636*^9, 3.539993173728566*^9, 3.5401275437531967`*^9, 
   3.540561273237315*^9, 3.54118655824613*^9, 3.541187916169799*^9, 
   3.5411880401458893`*^9, 3.541191072168311*^9, 3.541191170423931*^9, 
   3.5411912523046145`*^9, 3.5411913088048463`*^9, 3.5416041790715475`*^9, 
   3.6126969115102987`*^9, 3.697233993262079*^9, 3.6972358772121415`*^9, {
   3.697238271476454*^9, 3.697238288811932*^9}, 3.6973178565564156`*^9, 
   3.697323533678463*^9, 3.698044394239524*^9, 3.6980448332640285`*^9, 
   3.731421558101393*^9},
 TextAlignment->Center,ExpressionUUID->"a21491a1-f04d-4969-a082-06a7388a9934"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.12.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["Effective return over a range of ",
  FontFamily->"Times New Roman",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "r"], TraditionalForm]],ExpressionUUID->
  "5469bbb7-ee9c-4b98-84c0-db3f253578c7"],
 StyleBox["for various values of \[Rho]",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
  3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
  3.5305648276488047`*^9}, {3.530565115734282*^9, 3.530565120441551*^9}, {
  3.530565584010066*^9, 3.530565587296254*^9}, {3.5305663222572913`*^9, 
  3.530566342809467*^9}, {3.5305681591723566`*^9, 3.530568165991747*^9}, {
  3.530568269005639*^9, 3.5305682875136976`*^9}, {3.530568545559457*^9, 
  3.5305685777522984`*^9}, {3.530568686144498*^9, 3.530568694791992*^9}, {
  3.530568832626876*^9, 3.530568860108448*^9}, {3.539021635533093*^9, 
  3.539021635534093*^9}, {3.5390347460139694`*^9, 3.5390347460139694`*^9}},
 TextAlignment->Center,ExpressionUUID->"b2761a1f-ed25-4f77-9b75-257ffeec6fd3"],

Cell[TextData[{
 "The last two illustrations are merely mathematical/graphical expressions of \
the aging process playing itself out over an investment career. Late in life \
most Tier II investors s",
 StyleBox["uccumb to the rigors of property ownership and operation, turning \
to management-free investments for a more complete retirement. While these \
may at first thought sound like offerings of the securities market, let's \
reserve judgment for a bit.  In later chapters we will encounter familiar and \
comfortable real estate-oriented strategies that offer the investor a passive \
safe harbor in the most golden of his later years.",
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{{3.53056898427355*^9, 3.5305689900178785`*^9}, {
   3.531620393689064*^9, 3.5316204048097*^9}, 3.539021635534093*^9, 
   3.5390347460139694`*^9, 3.539094774836422*^9, {3.5405657672923603`*^9, 
   3.5405657948079343`*^9}},ExpressionUUID->"ef175ab5-83ec-41b5-98ca-\
65d849aba579"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.6. Conclusion", "Section",
 CellChangeTimes->{3.5316204214126496`*^9, 3.539021635534093*^9, 
  3.5390347460139694`*^9},ExpressionUUID->"f365bdc2-aa83-4c35-83cc-\
404818cf2c15"],

Cell[TextData[{
 StyleBox["If the investor adds efficient labor in order to accelerate \
retirement, he influences his return by making ",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["r",
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" in Equation 8.11 ",
  CharacterEncoding -> "WindowsANSI"],
 "larger."
}], "Text",
 CellChangeTimes->{{3.5305690752017508`*^9, 3.5305690864643946`*^9}, 
   3.539021635534093*^9, 
   3.5390347460139694`*^9},ExpressionUUID->"9e270397-1349-4afa-913b-\
ccda3fa465c2"],

Cell[BoxData[
 FormBox[
  RowBox[{"r", 
   StyleBox["=",
    FontSlant->"Italic"], 
   StyleBox[
    FractionBox[
     SubscriptBox["P", "t"], 
     SubscriptBox["P", 
      RowBox[{"t", "-", "1"}]]],
    FontSlant->"Italic"]}], TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5305690791969795`*^9, 3.539021635534093*^9, 
  3.5390347460139694`*^9},ExpressionUUID->"6767188b-e4bc-49e8-85cd-\
c5294be0f028"],

Cell[TextData[{
 StyleBox["Different agents exhibiting different levels of efficiency in real \
property ownership self-select into the private real estate investment \
market.  These agents experience different right tail investment return \
outcomes depending on the time they devote to their property, the real estate \
market during their tenure, their length of ownership, their operational \
efficiency, the demands of an outside employer, the length of their life and \
a host of other realistic game-of-life ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   RowBox[{"conditions", 
    SuperscriptBox[".", 
     ButtonBox["10",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote10"]]}], TraditionalForm]],ExpressionUUID->
  "692f61d1-0dfe-49c3-98d2-8c966102dcb8"],
 StyleBox[" ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["Mathematica",
  PageWidth->WindowWidth,
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" can be coaxed into creating a broad range of simulations \
illustrating these outcomes. Those shown in this chapter offer a mere \
beginning once the concept is established.",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{
  3.53056909616895*^9, {3.530569160639638*^9, 3.530569162061719*^9}, {
   3.530569381723283*^9, 3.5305693913668346`*^9}, {3.5390216355350933`*^9, 
   3.539021635536093*^9}, {3.53903474601497*^9, 
   3.5390347460159698`*^9}},ExpressionUUID->"1b1b138f-54f8-4b33-9a43-\
698abf8b7126"],

Cell[TextData[{
 StyleBox["The value of a theory is its expression, in a compact and elegant \
form, of a rule that has universal value. The most desirable form is an \
equation that (a) is true across the entire real number line (",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["-\[Infinity],\[Infinity]",
  PageWidth->WindowWidth,
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[") and is thus universal; and (b) submits to the rigorous proof and \
comparative statics possible when expressed in a closed analytical form. The \
labor exposition advanced here is sorely lacking on both points. Some would \
argue that the empirical demonstration of fat tails provided in Chapter 7 \
should follow rather than precede a chapter on theory. The order was \
deliberate. The empirics provide strong evidence for a ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["positive",
  PageWidth->WindowWidth,
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" claim of fat tails. A strong theoretical argument providing a ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["normative",
  PageWidth->WindowWidth,
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" explanation is at present dependent on demonstrative simulation \
rather than ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   RowBox[{"proof", 
    SuperscriptBox[".", 
     ButtonBox["11",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote11"]]}], TraditionalForm]],ExpressionUUID->
  "d8211666-833a-4064-b94e-e2f5a78ad298"]
}], "Text",
 CellChangeTimes->{{3.53056909616895*^9, 3.530569104673436*^9}, {
  3.530569432254173*^9, 3.5305694578096347`*^9}, {3.5305695130677953`*^9, 
  3.530569562641631*^9}, {3.5305696689957137`*^9, 3.5305696689957137`*^9}, {
  3.539021635536093*^9, 3.5390216355390935`*^9}, {3.5390347460169697`*^9, 
  3.53903474601897*^9}},ExpressionUUID->"0ad1c484-54cd-4cfe-8083-\
f548f539b163"],

Cell[TextData[{
 StyleBox["On the other hand it has been said that economics is just common \
sense expressed ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 Cell[BoxData[
  FormBox[
   RowBox[{"mathematically", 
    SuperscriptBox[
     SuperscriptBox[".", 
      ButtonBox["12",
       BaseStyle->"Hyperlink",
       ButtonData->"endnote12"]], 
     ButtonBox["",
      BaseStyle->"Hyperlink",
      ButtonData->"endnote11"]]}], TraditionalForm]],ExpressionUUID->
  "637261a6-f464-497b-8b4f-c841cab7f688"],
 StyleBox[" The idea that sweat produces equity is common sense. The idea \
that such equity shows up in real estate returns is logical. The idea that \
most people seek a comfortable and early retirement is not much in doubt.  \
The failure of the labor-added argument to rise to a formal theory may lie in \
the large number of variables required to describe this particular game of \
life. That does not make the argument less real. Further work with Lord \
Occam's razor may make the problem more mathematically tractable but the \
problem then described may be less real than what actual investors \
experience.",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{{3.53056909616895*^9, 3.530569109003684*^9}, {
  3.5305696858986807`*^9, 3.53056968745777*^9}, {3.531620461068918*^9, 
  3.531620461751957*^9}, {3.5390216355390935`*^9, 3.5390216355400934`*^9}, {
  3.53903474601897*^9, 3.53903474601997*^9}, {3.539993277931526*^9, 
  3.539993302598937*^9}, {3.5399933353658113`*^9, 
  3.5399933446973453`*^9}},ExpressionUUID->"17a316de-5f4f-4d92-aee2-\
dbba343ca2d1"],

Cell[TextData[{
 StyleBox["In 1952 when Professor Markowitz propounded Modern Portfolio \
Theory it was indeed fortunate that he tackled the mathematical explanation \
of the value of diversification. He modeled the time-worn saw: \"Don't put \
all your eggs in one basket\" with the tool of choice in 1952, a #2 lead \
pencil. In this chapter we have explored diversification's converse: \"Put \
all your eggs in one basket, ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["but watch that basket",
  PageWidth->WindowWidth,
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["!\" Doing so has required computing power not dreamed of fifty \
years ago.",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{{3.53056909616895*^9, 3.5305691136229486`*^9}, 
   3.5390216355400934`*^9, 3.53903474601997*^9, {3.54056582620373*^9, 
   3.5405658264767456`*^9}},ExpressionUUID->"8b178931-467e-40e8-9a87-\
f9e718e59ab4"],

Cell[TextData[StyleBox["The news for research in this area is mixed. Data for \
testing the hypothesis proposed herein is unavailable and likely to remain so \
until real estate investors begin punching time clocks. One can only \
speculate from anecdotal evidence that labor included in Tier II returns \
explain heavy right tails. Disappointing though this may be, with the ideas \
proposed here researchers may someday develop a suitable proxy to test and \
from which they may draw inferences.",
 PageWidth->WindowWidth,
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{{3.53056909616895*^9, 3.5305691186822376`*^9}, 
   3.5390216355400934`*^9, 
   3.53903474601997*^9},ExpressionUUID->"6fd77d3c-4ce7-4e84-b5c1-\
5accc9fd90e8"],

Cell[TextData[StyleBox["An appropriate criticism of this effort would be to \
trivialize it as merely the \"work harder\" model. One could charge that this \
story is no different than one in which an agent works two jobs, his regular \
job and a part time job. Such comments fail to grasp subtleties. Yes, one who \
has two jobs probably works harder. However, an added dimension exists when \
the second job represents an opportunity to transition out of the employed \
labor force into a form of self-employment.",
 PageWidth->WindowWidth,
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{{3.53056909616895*^9, 3.530569126449682*^9}, 
   3.5390216355400934`*^9, 
   3.5390347460209703`*^9},ExpressionUUID->"f449ca19-0c69-4c61-b80a-\
f1a0f04cdebd"],

Cell[TextData[{
 StyleBox["The second job, like many others, may initially involve menial \
tasks such as showing and leasing space, doing minor repairs, etc.  Horatio \
Alger fables of the boy who starts in the mail room and ends up running the \
company brighten corporate folklore. Fewer stories exist in which the boy ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["begins by owning the company",
  PageWidth->WindowWidth,
  FontSlant->"Italic",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox[" and yet that is exactly what happens routinely in the Tier II \
market. When researchers view the building as the firm a new perspective \
emerges. In a sense Tier II property is the \"family farm\" of an urbanized \
society where market skills are handed down from generation to generation. ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["Figure 8.13 takes ",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman",
  CharacterEncoding -> "WindowsANSI"],
 StyleBox["another look at the model we used in Chapter 3, suggesting that a \
real estate investor is the general manager, owner and operator of a small \
business. ",
  PageWidth->WindowWidth,
  CharacterEncoding -> "WindowsANSI"]
}], "Text",
 CellChangeTimes->{{3.53056909616895*^9, 3.530569127728755*^9}, {
   3.530570034367612*^9, 3.5305700401719437`*^9}, {3.5316204772168417`*^9, 
   3.531620477575862*^9}, 3.5390216355400934`*^9, 
   3.5390347460209703`*^9},ExpressionUUID->"e3509e75-f585-477d-af95-\
606c0793a7c3"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0005[P0@0006`0000f00004P0004`2002Z0000
00000000003K?000da400215CDH00040h5X000l200090000000000000000000000@00003000>0@00
b`0000000000000000000;0N103h60<0AP000?0P003T8000AdA9@`4008000`00Alb@c`00003<8000
0@090003IQ0000X05P400000100000<1200500002`8000001@0000`2708a1`D000090P0000050000
0@;oool0100000@13@0400000P4200<0000N00@0000W0Ooo0`0001h0100002L1ool300007P050000
0@;oool01@0000T2000000@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005P@N0S<7
o?olo`@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005P@N0S<7o?oloa`0003k0]Ko
00000000_08000000000845bJF5/000000000000000000000000000000000000100002d1000L0000
n`8@00L000000;`2000000420R9CNG=dIFd0000000010000m>`C0040000@<QD0000000@0000]0@40
100002L1ool300007P040000;@4000D000010_ooo`0500002@8000001`0001H4J`0_1c/010040000
104=00@000020@403000038:>P270P<00017D4T08@0L00`0:000038:>P1I0aH00017LVmcLb1@KgAU
KWAYHF`PBFiSKfeU8@0@01X05`0G00`0700J00h05`0J00h0300G00`0300<01X05`0J02D05`040000
;@4100@0000W0Ooo0`0001h0100002d1000500000@;oool01@0000T2000000L0000F11h2<`Olooco
100002d10@0400009`7oo`<0000N00@0000]0@001@000042oooo00D000090P00000700005PBR02l7
K`0400@000040@d0100000810@0?0000<PY]08L21@0002QF@D<YN@h0700M01h03P0E0000<PY]05T3
2@0002QFHF=QKV=i:FL>01`05`0G01L06P0G01L03P040000;@4100@0000W0Ooo0`0001h0100002d1
000500000@;oool01@0000T2000000L0000F11h2<`Olooco100002d10@0400009`7oo`<0000N00@0
000]0@001@000042oooo00D000090P00000700005PCF02l7YP0400@000040@d0100000810@0<0000
<PZU08L20`0004E7B@0L0240300X0000<PZU05T35P0004EhL6ESM6ET84MbKg=c8219KV=_KFDL01L0
6P0G01L03P0G01X0300Q01006P0G01L0300<00`06P0G01X09@0G00@0000]0@40100002L1ool30000
7P040000;@4000D000010_ooo`0500002@8000001`0001H47P8c1ocoo?l40000;@4100@0000W0Ooo
0`0001h0100002d1000500000@;oool01@0000T2000000L0000F10d1;`OJ00@0100000@13@040000
0P4100l0000b2]P0Q`850000:4EHD2Ui3P0L01`0700>01H0000b2]P0F@<:0000:4EhL6E^LfEc:@h0
700G01X05`0J01L05`0G00h0100002d10@0400009`7oo`<0000N00@0000]0@001@000042oooo00D0
00090P00000700005P@N0S<7o?olo`@0000]0@40100002L1ool300007P040000;@4000D000010_oo
o`0500002@8000001`0001H4@@4_1a4110040000104=00@000020@403000038:40670P<0001>CdT0
7P0Q00`09@00038:405I0a@0001>IG@PCg1ULV5dJFiW84U^Hfm]IAh05`0>00`08@0J01L0400G00h0
300J01X0300<01X05`0J02D05`040000;@4100@0000W0Ooo0`0001h0100002d1000500000@;oool0
1@0000T2000000L0000F11h2<`Olooco100002d10@0400009`7oo`<0000N00@0000]0@001@000042
oooo00D000090P00000700005PAh0Bl7A@4400@000040@d0100000810@0=0000<PY30HL2100002Q4
DbT>01h0700>01`0000b2T<1F@<>0000:4AUHW@PDfEbMVUSIBT>01h05`0J00h0300L01L0400G00`0
5`0G00h0100002d10@0400009`7oo`<0000N00@0000]0@001@000042oooo00D000090P0000070000
5P@N0S<7o?olo`@0000]0@40100002L1ool300007P040000;@4000D000010_ooo`0500002@800000
1`0001H4[04_1g`110040000104=00@000020@403@00038:N`670P@00012E4=67P0K01h06P0U0000
<PYk0ET35000049UIVmbIB1DHGPP@f5cJ216K6mg7P0G00h06P0@01L0300K01L05`0<01h05`0G01X0
300J00`06P0Q00@0000]0@40100002L1ool300007P040000;@4000D000010_ooo`0500002@800000
1`0001H47P8c1ocoo?l40000;@4100@0000W0Ooo0`0001h0100002d1000500000@;oool01@0000T2
000000L0000F1><1;`N`0@@0100000@13@0400000P4100l0000b2Zh1Q`850000:5A1F2Ui3P0K01d0
700>02/0000b2Zh1F@<H0000:4U^Hfm]IB1DHGPP@fm^LfEaMFE^HfDY3P0<01X05`0J02D05`0<01/0
5`0G00`07P0J01X05`0G01X06P0G01X05`0G00h0100002d10@0400009`7oo`<0000N00@0000]0@00
1@000042oooo00D000090P00000700005P@N0S<7o?olo`@0000]0@40100002L1ool300007P040000
;@4000D000010_ooo`0500002@8000001`0001H45`8_1nL110040000104=00@000020@403@00038:
iP670P@00011E4=67@0K01h06P0T0000<P[V0ET34`00045VM6Eb85AQN213HG=X84I/KgMU7@0>00h0
5`0@00`06`0G01L0300N01L05`0J00`06P0<01X08@040000;@4100@0000W0Ooo0`0001h0100002d1
000500000@;oool01@0000T2000000L0000F11h2<`Olooco100002d10@0400009`7oo`<0000N00@0
000]0@001@000042oooo00D000090P00000700005P@K0S07000000L0003l0P0000000000100002d1
0P040000104=00@000020@80300004098@3`0000000000P0<0>P07l2300004098@3`0000000000P0
<0<;0Gl2300004098@3`0000000000P0<0=f0Gl2300004098@3`0000000000P0<0?Q0Gl21`000?`2
0000000000040000;@4300@0003`0@80100002d10@0400009`7oo`<0000N00@0000]0@001@000042
oooo00D000090P00000700005P@N0S<7o?olo`@0000]0@40100002L1ool300007P040000;@4000D0
00010_ooo`0500002@8000001`0001H4XP_:2?3ol?l40000104=00<0000N00@0000/0@0020000?X2
00030000000000@0000]0@801`000?`20@00000000040000;@4401H1000U0hT0e`<g0<<3=`2_0cL0
V`<g08L3>01d0cP0H@<i04l3>P0m0c/0;0<l01/3?P0:0cl0nP900>X2@P3K0T@0c@960;l2B02b0TX0
YP9<09X2CP2?0U00Q@9B07/2E@1c0UL0J`9J06@2G@1M0Ul0F09R05@2I@1@0VP0CP9[04d2K01<0Vh0
C09_04`2L@1<0W80C09d04d2M@1>0WH0D09i05@2O01H0Wl0G@:206@2Q01[0XL0L`::07/2S0250Xl0
S`:A09X2T`2V0YD0/P:H0;l2VP3=0Y/0f`:M0>X2W`3j0Z402P>R01X3Y00/0jD0?@>V04l3Y`1Q0jP0
M0>Y08L3Z@2K0jX0[`>Z0<<3ZP3G0jX0j`>Z0?l3ZP0C1:X09`BY03X4Z@1=1:P0G`BW0744YP231:D0
U0BT0:@4XP2d1:40a0BO0=<4W@3Q19/0k`BJ0?`4V0081ID050FC01l5T@0Y1Hl0<`F<03`5RP131HL0
B`F40545PP1F1Gl0FPEl05h5N@1P1GH0H@Ee0685M01R1G80H`Ea0685K`1R1Fh0H@E/0605J`1N1FP0
FPEU05H5HP1A1El0B`EM04<5FP0l1EL0<`EE02T5DP0O1E0050E>00P5C03l14X0k`A80>44AP3C14@0
a0A20;@4@02T13l0U0@n0884?01a13/0G`@j04d4>@0j13P09`@h01<4=`3o0cL0j`<g0=L3=`080000
nP80000000000000100002d11@070000o0800?ooo`0000@0000]0@H010000?010P0400009`7oo`<0
000N00@0000/0@0020000?X200030000000000@0000]0@80100002d1100F0@009@>90=@3eP300mH0
[0?F09P3eP240mH0L@?F05h3e`1<0mL0>P?H02T3f00H0mT01`?J0?L2fP3W0]/0f0;L0<X2g@2l0]h0
[`;O0:<2h02G0^40S0;R0882h`1h0^D0L0;V06P2i`1Q0^T0FP;Z05D2j`1A0^d0C@;^04/2l01:0_00
B@;a04T2lP190_<0B@;c04T2m01:0_D0B`;e04d2m`1A0_P0E@;j05X2n`1Q0_d0J0;n0702o`1h0P01
PP820H`20`6G0P@1X`850Jl21P6l0PL1bP880MP22@7W0PX1m`8;0@L32`4G0``1:@<=0CX33@5<0`h1
GP<>0G433`640`l1V0<?0J`33`700`l1e0<?0NP33`7l0`l140@?0B@43`4g10l1BP@>0E`43P5^10d1
P0@=0I44306Q10/1/@@;0L442P7@10T1gP@80N`41`7i10H11@D50A45104L1@<19PD20C05004i1Ol0
@0Gn04P5o@1>1O/0D`Gj05L5n01K1OL0G@Ge05h5m@1O1O@0G`Gc0605l`1O1O80G`Ga05h5l01M1O00
F`G^05L5k@1C1N/0CPGZ04P5j@101NL0>@GV0305i@0V1N<070GR0145h@051N00n@CO0>`4gP3N1=d0
d0CL0<44f`2a1=X0X@CJ0944f@1o1=P0KPCH05`4e`1:1=L0=`CF02@4eP0@1=H0o0?F0>P3eP3D0mH0
100002d11@040000;@4600@0003`0@80100002L1ool300007P040000;04000P0003j0P000`000000
00040000;@4200@0000]0@@05P4002D3R@0513/1l@<k0Md3>`790c/1]@<k0J83>`6?0c`1O@<l0F/3
?@5J0cd1B@<n0CP3?`4X0cl160=00@T3@@7k0T81k@930N02A07D0TD1b0960Kd2A`6c0TP1Z@9:0J42
B`6I0T`1TP9>0H/2C`660U01PP9B0Gh2D`5l0UD1N`9E0GX2EP5j0UL1NP9H0GX2F05j0UT1N`9J0G`2
FP5n0U`1PP9M0HH2G`6;0V01TP9R0IT2H`6Q0V@1Z@9U0K<2I`6m0VP1b09Y0M@2JP7P0V/1k@9/0O/2
K@490fh160=_0BP3L04h0g01B0=a0EX3LP5[0g81O@=c0Hl3L`6R0g@1]@=d0LT3M07M0g@1l@=d0@D4
M04I17@1;@Ad0D44M05E17@1J0Ad0G/4L`6=17<1W`Ab0K44LP721741dPA`0N84L07b16l10@E^0@l5
K@4M1F`1:PE[0CH5JP521FT1C@EX0EL5I`5Q1FD1JPET0G45H`5i1F81O`EP0H@5G`681Ed1S0EL0Hh5
FP6?1EX1T0EI0I05F06A1EP1T0EG0I05EP6?1ED1SPEE0H`5D`681E81Q0E@0Gl5C`5i1Dh1L@E<0FX5
B`5Q1DX1E`E80Dd5A`521DH1=PE50BX5A04M1D<13`E20@45@@7b1401hP@o0M84?`7213h1/0@m0Il4
?@6=13`1N`@l0FP4>`5E13/1@@@k0Bd4>`4I13/11@@k0@@0000]0@D0100002d11P040000l04200@0
000W0Ooo0`0001h0100002`100080000nP8000<000000000100002d10P040000;@4401H1000U0hT0
3`BY0O/3Z@7W0jT1d`>Y0Kl3Z@6/0jT1V@>Z0HL3ZP5e0j/1I0>[0E<3[0520jd1<P>]0B83[P4C0jl1
1@>`0OL2/@7Z0[81gP:c0M82]0770[D1_@:f0K<2^06[0[T1X`:j0I`2_06E0[d1T0:n0H`2`0680/41
QP;30HD2``640/@1Q0;50H@2aP640/H1Q0;70HD2b0660/P1R0;:0H`2b`6@0/d1U@;>0I`2d06S0]41
Z`;B0K<2d`6m0]D1a`;F0M82e`7N0]P1jP;I0OL2fP450m/14`?L0B83g@4b0mh1@P?N0E83g`5T0n01
M@?P0HL3h@6I0n41[0?R0Kl3hP7C0n81i`?R0O/3hP4?1>818`CR0CL4hP5;1>81G`CR0G84hP651>41
U`CQ0JT4h06k1>01c0CO0M`4gP7/1=h1o0CM0@/5g04I1M/19`GJ0C@5f@501MP1C0GG0EL5eP5Q1MD1
J`GC0G@5dP5k1M41P`G@0HT5cP6>1Ld1TPG;0IH5bP6H1LP1V@G80IX5a`6J1LH1V`G60IX5a@6J1L@1
V@G30IP5``6F1L41TPG00Hh5_P691Kd1P`Fl0G/5^P5d1KT1J`Fh0F45]P5G1KD1C0Fd0D05/`4d1K81
9`Fa0AT5/04;1Jl1o0B^0N`4[@7L1:d1c0B/0KX4Z`6Y1:/1U`BZ0HD4ZP5b1:T1G`BY0D/4Z@4g1:T1
8`BY0@l4Z@440000;@4500@0000]0@H010000?010P0400009`7oo`<0000N00@0000/0@00100002d1
1P080000nP850000003oool0100002d10P0<0000@0TQ0?0000000000S@1P0D<0[P040000;@4500@0
000]0@H0100002L1ool40000;@4200@0000]0@@01@0000T2000000D000010_ooo`040000;@4300@0
000]0@001@0000T2000000D000010_ooo`040000;@4300@0000]0@001`0001H4c0030TL0^@0L0000
n`;>o`0000000;`2000000000211LVUQK0000000000000000000000000000000000000@0000]0@L0
100002d10@040000;@4700@000040@d0100000810@0E0000<PY90;T02@0004eQLV]UM6U^IgHY01`0
4`0L01`04@0>01h07`040000;@4100@0000W0Ooo0`0001h01@000042oooo00D000090P0000070000
5P@J0Rl7100400@0000]0@D0100002d11P0300007P040000;04000@0000]0@H0100002d10P0<0000
@0TQ0?0000000000S@1O0JP0Z0040000;@4500@0000]0@H0100002L1ool40000;@4200@0000]0@@0
1@0000T2000000D000010_ooo`040000;@4300@0000]0@401@0000T2000000D000010_ooo`040000
;@4300@0000]0@401`0001H4<@7l0J`0/`040000;@4700@0000]0@40100002d11`040000;@4100@0
000]0@L0100002d10@040000;@4700@000040@d0100000810@0H0000<PZ^0;<02`0004m`IG9QM6U_
KW<PHbL07`0L01<0700A00h07`0N01`03P0F0000<P[_0;<02P0004eQKV5WIFeUKW@Y01`07P0L01l0
700/01`07P0A00@0000]0@40100002L1ool300007P0500000@;oool01@0000T2000000L0000F11X2
;`L400@0100002d11@040000;@4600<0000N00@0000/0@00100002d11P040000;@4200`000102B40
l0000000001=0601C@6^00@0000]0@D0100002d11P0400009`7oo`@0000]0@80100002d110050000
2@8000001@000042oooo00@0000]0@<0100002d10@0500002@8000001@000042oooo00@0000]0@<0
100002d10@0700005PBF0@<2D@6i00@0000]0@L0100002d10@040000;@4700@000040@d010000081
0@0B0000<PYC0KT01`0004IYKV5^HfD07`0>01h0700N01`070040000;@4100@0000W0Ooo0`0001h0
1@000042oooo00D000090P00000700005P@J0Rl7100400@0000]0@D0100002d11P0300007P040000
;04000@0000]0@H0100002d10P0<0000@0TQ0?0000000000B@1O0Jl1Z`040000;@4500@0000]0@H0
100002L1ool40000;@4200@0000]0@@01@0000T2000000D000010_ooo`040000;@4300@0000]0@40
1@0000T2000000D000010_ooo`040000;@4300@0000]0@401`0001H4m07o0K<1]P040000;@4700@0
000]0@40100002d11`040000104=00@000020@405P00038:]@6f00X00011Hf=_MFidJFiW8`0L01`0
7`0N01h04@0>01h07`070000<P[f0KH0000000@0000]0@40100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F11X2;`L400@0100002d11@040000;@4600<0000N00@0000/0@00100002d1
1P040000;@4200`000102B40l0000000002=05`1N`7@1@@0000]0@D0100002d11P0400009`7oo`@0
000]0@80100002d1100500002@8000001@000042oooo00@0000]0@<0100002d10@0500002@800000
1@000042oooo00@0000]0@<0100002d10@0700005P@40R47O`7K1@@0000]0@L0100002d10@040000
;@4700@0000]0@40100002d11`040000;@4100@0000]0@L0100000@13@0400000P4101D0000b2X41
f`D90000A6UfJFAUKV@PIb@03P0K00h07`0L01h07`0>0100000b2/81f`D60000D6m/JF=i8@0O00h0
3P0L01/0100002d10@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H46P8_1`@0
10040000;@4500@0000]0@H00`0001h0100002`100080000nP80004000000000100002d120070000
o0800000000000@0000]0@T0100000H10P0b0000>0D2018010390F<08`9S02<2H`0T0V<0909U02@2
IP0S0VH08`9V0<T1IP380FH0a`5V0<L1I@370FD0a`5T0<L1H`380F<0b@5S0<T1H`0O0UP0>09U01l2
L@0O0UP0100000H10@040000;@4600@0000]0@D010000?01200400009`7oo`<0000N00@0000/0@00
20000?X200010000000000@0000]0@P0100002d12@0400001P420300000h1@804@040?d1h`0Z0^`0
:`;/02/2k@0/0^d0;0;^02/2k`0Z0^l0:P;_0?`1iP3k0ND0n`7U0?/1i03l0N<0o07S0?d1h`3m0N<0
:0;P03l2lP0T0_T0:0;P00@000060@40100002d11P040000;@4500@0003`0@P0100002L1ool30000
7P040000;04000P0003j0P000@00000000040000;@4800@0000]0@T0100000H10P0^0000>0D20100
102W0Fd1CP9M0Dh2G@5?0Ud1C`9N0Dl2G`5?0V01CP9P0JP1L06W0G01Y`5`0JH1K`6V0Fh1YP5^0JL1
K@6W0Fd1B09C0F<2G@5;0V/1B09C0@@000060@40100002d11P040000;@4500@0003`0@P0100002L1
ool300007P040000;04000P0003j0P000@00000000040000;@4800@0000]0@T0100000H10P0^0000
>0D20100103Y0L`1CP;70Dh2a`5?0/L1C`;90Dl2bP5>0/X1jP7?0NT1c`7Y0Ll1j07>0NP1cP7X0Ld1
j@7<0NT1c07Y0L`1B@:l0F<2b05:0]D1B@:l0@@000060@40100002d11P040000;@4500@0003`0@P0
100002L1ool300007P040000;04000P0003j0P000@00000000040000;@4800@0000]0@T0100000H1
0P0^0000>0D20100103G1NX1N`Gl0GX5o05i1O/1N@Gj0GX5nP5j1OT1N`Gi0MH5i`7G1NL1e`GW0MP5
j07H1NT1f0GY0ML5jP7G1NX1PPD60VL5o`5m1Nd1PPD60P@000060@40100002d11P040000;@4500@0
003`0@P0100002L1ool40000;04000L0000F1:8;bPS`oo3o1@0000T2000000D000010_ooo`040000
;@4300@0000]0@4010000?0100040000l04700@0000W0Ooo0`0001h0100002L1ool30000000A0000
300000P0000;0000400004l2002]00002@000100001?0P00[@0000X0000@00000000000000090000
40000347000L0P00600000`0000000006@0000`0003oool0500000`0000=00004P0000`000020000
8@0000P0000R000030000?oooolQ000020000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
60000?cooooloooo<`L001h2000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H0000o?oooocooolc1`007P800580001`0@000@000=Koool0000000000000002l0P00
0000000002110780J@1Q06`000000000000000000000000000000000000000000000000000000000
0000000000000000000B0<3]d01h0000000007l>O`88la80CXED0<3]d02MLe@0T3jg0:PZ0`:]R4h0
:?Jj0B3c4P101QD0mE]702Sf^P4Pla80K?<B023c4P000000EZ=>090n]`0Pla807?Jj0N4UBP0l0@00
:?Jj0BSf^P501QD0D5aI0<0000000?ool=SoooCHool00<0o00000030<d000000ZiQ>0?P2LP:Xh1d0
l09b0WP15@1h0AD03`000?ooool000000037MlC`oGl0h?eo0000000000000000000009d[agL20000
MPX4/GH:0028:/MgMPX4/GH:1;410000`?<B06Af00P000009@0000`000010000DP00070100020000
400000L00000000000000;`2000000000@828U<0N@1c07@0I@1]0000000000000000000000000000
0000000000000000000000000000000000000000000001D03`000?ooool000000037MlC`oGl0h?eo
0000000000000000000009d[agL20000MPX4/GH:0028:/MgMPX4/GH:1;410000`?<B06Af00P00000
T3jg023c4P0Lm[X1hBE:03`1000Xm[X1:?Jj0D065@1@G5T0`0000000ooo`f?oom=Soo`00`3l00000
0<0c@000002[V4h0n09b0ZSP7@3`0W82N04E07P15@0?0000ooooo`0000000<Mga?3mO`3PoGl00000
0000000000000000WB_7M`800010Z/Qg300002D0000hA1T0l?<B00002P3UZLQgI7H02000000U0000
30000080000R000030000?oooolQ0000200002D0000<00000@0001T0000<0000oooo01P0000<0000
000001h0000H0000100003/0000_1`00J`0001@0000<00003@000180000<00000@0005@0001P0000
d00001<0003W00008@0000400019KPM1Kgd7@HL2000j00000`0004`00000000000000000003ooooo
oooooe@000170500B@000240000L0000300005@0003@00004`4001<0002Y0@008@0000400019KPM1
Kgd7@ET3000j00005P0004`00000000000000000003oooooooooogP000170780K`1c07<0801@06l0
M01U06h0M01Y0640K00P04T0KP1S06l0K@1U0240000@00006P0001L0000G0000300001`0000J0000
3P0001L0000J00003P0000`0000G0000300000`0000<00006P0001L0000J00009@0001L0000U0000
30000080000R000030000?oooolQ0000200002D0000<00000@0001T0000<0000oooo01P0000<0000
000001h0000H0000o?oooocooolc1`007P8002D0000<00000P000280000<0000ooooob4000080000
9@0000`0000100006@0000`0003oool0600000`0000000007P0001P000040000K`0002l7002R0000
500000`0000=00004P0000`000010000E00006`0003@000090000?@0000b00000@0004U^1d5_O@M1
Q`8006d000050000C00000000000000000000?ooooooooooF00002P0EP1104<0:@0000h0000L0000
7@0001h0000>0000E00008@0000C0@0090000581000b00000@0004U^1d5_O@M1F@<006d000090000
C00000000000000000000?ooooooooooH00002P0EP1Q06<0H@1^06<0N@0Y00003P0001`0000G0000
5`0001L0000J00005`0001L0000>00009@0000`0000200008P0000`0003ooooo8@0000P0000U0000
30000040000I000030000?ooo`0H000030000000000N000060000?cooooloooo<`L001h2000U0000
30000080000R000030000?oooolQ0000200002D0000<00000@0001T0000<0000oooo01P0000<0000
000001h0000H000010000:H0000_1`00eP0001@0000<00003@000180000<00000@0005@0001P0000
d00003D0003W0000A00000400019KPM1Kgd7@HL2002U00000`0004`00000000000000000003ooooo
oooooe@0001504L0B@0001`0000Q0000300005@0003@00004`4003D0002`0@00A00000400019KPM1
Kgd7@ET3002U00005P0004`00000000000000000003oooooooooogP0001507P0L01U06<0M01U06@0
80170780K`1c07<0800P04T0KP1S06l0K@1U01`0000G00006P0001L0000G00003P0001L0000J0000
30000240000@00006P0001L0000G0000300000`0000<00006P0001L0000J00009@0001L0000U0000
30000080000R000030000?oooolQ0000200002D0000<00000@0001T0000<0000oooo01P0000<0000
000001h0000H0000o?oooocooolc1`007P8002D0000<00000P000280000<0000ooooob4000080000
9@0000`0000100006@0000`0003oool0600000`0000000007P0001P000040000fP0002l7000=0@00
500000`0000=00004P0000`000010000E00006`0003@0000AP000?<0001D00000@0004U^1d5_O@M1
Q`800=P000050000C00000000000000000000?ooooooooooF00002P0A@1H0500:@0000h0000L0000
700001`0000>0000E00008P0000C0@00AP0005X1001D00000@0004U^1d5_O@M1F@<00=P0000:0000
C00000000000000000000?ooooooooooH00002P0A@1h0700I@1^07<0I@1c02T03P0001`0000G0000
6P0001L0000J00005`0001L0000G00003P0002D0000<00000P000280000<0000ooooob4000080000
9@0000`0000100006@0000`0003oool0600000`0000000007P0001P0003looooo?oooc<7000N0P00
9@0000`0000200008P0000`0003ooooo8@0000P0000U000030000040000I000030000?ooo`0H0000
30000000000N0000600000@0000A0@00;`L00441000D0000300000d0000B000030000040001D0000
H0000=00001G0000j00006H000010000BFh7@Fmm1d670P00404000<0001<00000000000000000000
oooooooooomD0000CP1?04T0000N00008@0000`0001D0000a00001<1001G0000W`4006H000010000
BFh7@Fmm1d5I0`00404001@0001<00000000000000000000oooooooooomd0000CP1U07@0801?0700
I@1b0640M01Y06h0I`0P04T0KP1S06l0K@1U01h0000G00003P0000`0000Q00006P0001L0000@0000
5`0000h0000<00006P0001X0000<0000300001X0000G00006P0002D0000G00009@0000`000020000
8P0000`0003ooooo8@0000P0000U000030000040000I000030000?ooo`0H000030000000000N0000
60000?cooooloooo<`L001h2000U000030000080000R000030000?oooolQ0000200002D0000<0000
0@0001T0000<0000oooo01P0000<0000000001h0000H0000100004D1000_1`00N04001@0000<0000
3@000180000<00000@0005@0001T0000d00006P0003[0000M`0000400019KPM1Kgd7@HL200130@00
100004`00000000000000000003ooooooooooe@0000X04@0D`0Y00h0000N0000700000h0001D0000
X00001<1001X0000K@4007L000010000BFh7@Fmm1d5I0`00@`4000h0001<00000000000000000000
oooooooooomX0000:01406D0HP1d0200D`1U0780MP1Y06<0I@0Y00h0000N00005`0001X0000>0000
300001`0000G0000400001L0000<00005`0001L0000>00009@0000`0000200008P0000`0003ooooo
8@0000P0000U000030000040000I000030000?ooo`0H000030000000000N000060000?cooooloooo
<`L001h2000U000030000080000R000030000?oooolQ0000200002D0000<00000@0001T0000<0000
oooo01P0000<0000000001h0000H0000100007`1000_1`00[04001@0000<00003@000180000<0000
0@0005@0001T0000d00007X0003d0000R00000400019KPM1Kgd7@HL2001k0@00100004`000000000
00000000003ooooooooooe@0001205@0@`1601h0000K00007P0001X0001D0000a00001<1001j0000
X04008P000010000BFh7@Fmm1d5I0`00N`4001@0001<00000000000000000000oooooooooomd0000
@P1U06H0K`1b06D0801D0640N00P04<0H@1c06P0801606`0K`1g01h0000G00003P0001X0000@0000
5`0000`0000K00005`0001L0000<00007P0001L0000G00006P0000`0000J0000300001X0000Q0000
9@0000`0000200008P0000`0003ooooo8@0000P0000U000030000040000I000030000?ooo`0H0000
30000000000N000060000?cooooloooo<`L001h2000U000030000080000R000030000?oooolQ0000
200002D0000<00000@0001T0000<0000oooo01P0000<0000000001h0000H000010000;01000_1`00
h`4001@0000<00003@000180000<00000@0005@0001/0000d00008X0003c0000V@0000400019KPM1
Kgd7@HL2002^0@001@0004`00000000000000000003ooooooooooeP0000X05@0@@1H02T0000>0000
6`0001d0000L00003P0005@0003L00004`4008X000320@00V@0000400019KPM1Kgd7@ET3002^0@00
600004`00000000000000000003oooooooooog`0000X04T0KP1S06l0K@1U0200E01Q07P0801306l0
KP1c06D0L@1e06D0KP1S06D0:@0>0000300001X0000G00006P0002D0000G0000300001/0000G0000
5`0000`0000N00006P0001X0000G00005`0001X0000J00005`0001X0000G00005`0000h0000U0000
30000080000R000030000?oooolQ0000200002D0000<00000@0001T0000<0000oooo01P0000<0000
000001h0000H0000o?oooocooolc1`007P8002D0000<00000P000280000<0000ooooob4000080000
9@0000`0000100006@0000`0003oool0600000`0000000007P0001P000040000i`4002l7000G0P00
500000`0000=00004P0000`000010000E00006@0003@0000W0000?<0002Z00000@0004U^1d5_O@M1
Q`800>H100040000C00000000000000000000?ooooooooooE0000440E01304H07@0001/0000N0000
6P0005@0003000004`4009`0002E0@00ZP0000400019KPM1Kgd7@ET3003V0@004`0004`000000000
00000000003oooooooooog@0001106H0M01U0780801D0640N00P04<0H@1c06P0801606`0K`1g0000
7@0000h0000>00005`000100000<00006`0001L0000G0000300001h0000G00005`0001X0000<0000
6P0000`0000J00008@0002D0000<00000P000280000<0000ooooob40000800009@0000`000010000
6@0000`0003oool0600000`0000000007P0001P0003looooo?oooc<7000N0P009@0000`000020000
8P0000`0003ooooo8@0000P0000U000030000040000I000030000?ooo`0H000030000000000N0000
6000000000000000<0L001/2000W0000600000<00000000000000000000U0000300000<0000D0000
300000d0000B000030000080001<0000I0000<d0000c0000dP4003D0001o0P00X000030300080000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
C00006@0003=0000EP000=81001G0000O`8000/1000`0`0020000240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000004`0001T0000c@0007P0003B0@00
N@0007l2001f0@00<0<000P0000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000001<0000I0000<d0002J0000dP4009`0001o0P00h@40030300080000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9`0001P00004000000000000000000009@0000`000040000:00000`0000300009@0000`000020000
8P0000`0003ooooo8@0000P0000U000030000040000I000030000?ooo`0H000030000000000N0000
60000?cooooloooo<`L001h2000U000030000080000R000030000?oooolQ0000200002D0000<0000
0@0001T0000<0000oooo01P0000<0000000001h0000H0000l?oooo3oooo:2000XP/001@0000<0000
3@00024000080000B`000100000000001@0002H0000L00000`0000000003000000000000000U0000
300000<0000U0000300000D0081G0000@0800;d0000B0000^`4003H000290000e`<g0<<3=`2_0cL0
V`<g08L3>01d0cP0H@<i04l3>P0m0c/0;0<l01/3?P0:0cl0nP900>X2@P3K0T@0c@960;l2B02b0TX0
YP9<09X2CP2?0U00Q@9B07/2E@1c0UL0J`9J06@2G@1M0Ul0F09R05@2I@1@0VP0CP9[04d2K01<0Vh0
C09_04`2L@1<0W80C09d04d2M@1>0WH0D09i05@2O01H0Wl0G@:206@2Q01[0XL0L`::07/2S0250Xl0
S`:A09X2T`2V0YD0/P:H0;l2VP3=0Y/0f`:M0>X2W`3j0Z402P>R01X3Y00/0jD0?@>V04l3Y`1Q0jP0
M0>Y08L3Z@2K0jX0[`>Z0<<3ZP3G0jX0j`>Z0?l3ZP0C1:X09`BY03X4Z@1=1:P0G`BW0744YP231:D0
U0BT0:@4XP2d1:40a0BO0=<4W@3Q19/0k`BJ0?`4V0081ID050FC01l5T@0Y1Hl0<`F<03`5RP131HL0
B`F40545PP1F1Gl0FPEl05h5N@1P1GH0H@Ee0685M01R1G80H`Ea0685K`1R1Fh0H@E/0605J`1N1FP0
FPEU05H5HP1A1El0B`EM04<5FP0l1EL0<`EE02T5DP0O1E0050E>00P5C03l14X0k`A80>44AP3C14@0
a0A20;@4@02T13l0U0@n0884?01a13/0G`@j04d4>@0j13P09`@h01<4=`3o0cL0j`<g0=L3=`0V0000
700000D00000000000000000000000009@0000`0000500009`0001P00006000000000?ooo`000000
9@0000`000060000:00000`0000300008P0000`0003ooooo8@0000P0001;00004000000000050000
9P0001`000030000000000<000000000000002D0000<00000`0002D0000<00001@00P5L000100P00
_00004D0002j0@00E`0008T0003D0mH0`0?F0:`3eP2H0mH0Q0?F0743eP1N0mL0C0?G03X3f00Y0mP0
60?I00L3fP3g0]X0i`;K0=P2g03:0]d0_0;N0:l2g`2S0^00U`;Q08`2hP220^<0N0;U0702iP1X0^L0
H@;Y05X2jP1E0^/0D@;]04d2kP1;0_00BP;`04T2l@190_80B@;c04T2l`190_@0BP;e04/2m@1=0_L0
D@;h05D2nP1J0_/0H@;m06P2oP1`0_l0N0800H820P6<0P<1U`840J<21@6_0PH1_0870LX2207H0PT1
i`8:0OL22`470`/15`<<0BT33@4j0`d1C0<>0Eh33P5a0`l1Q0<?0IP33`6/0`l1`0<?0M@33`7X0`l1
o0<?0A043`4T10l1=`@?0DX43P5L10h1KP@=0H043@6A10`1X@@;0K442`7110X1d0@90Mh4207/10L1
n@@60@D51@4A1@@170D30BH50P4`1@01>@Go0405oP181Od0CPGk05<5nP1G1OP0F`Gg05d5m@1N1OD0
G`Gd05l5l`1P1O<0G`Gb05l5l@1N1O00G@G`05/5kP1G1Nd0D`G[04h5jP181NT0@0GW03T5iP0`1ND0
9PGS01`5hP0A1N401@GP0?T4g`3/1=h0gPCM0=04g0311=/0/@CJ0:44fP2A1=T0O`CH06h4f01L1=L0
BPCG03L4eP0T1=H040CF0?`3eP3X0mH0e0?F02D0000<00001@0002D0000<00001P0002P0000<0000
0`000280000<0000ooooob4000080000B`000100000000001@0002H0000L00000`00000000030000
00000000000U0000300000<0000U0000300000D0081G0000@0800<`0001U0000b@4007L000290000
1@@k0O43>`7M0c/1b@<k0KD3>`6R0c/1S`<l0Gd3?05[0cd1FP<m0DT3?P4h0cl1:0<o0AP3@0490d41
n`920Nd2@`7P0T@1e0950LP2AP6m0TL1/`980JT2BP6Q0T/1V@9<0I82CP6;0Tl1QP9@0H82DP5n0U<1
O09E0G/2E@5j0UH1NP9G0GX2F05j0UP1NP9I0G/2FP5l0UX1OP9L0H82G@660Ul1R`9P0I82HP6I0V<1
X@9T0JT2I@6c0VL1_@9X0LP2J@7D0VX1h09[0Nd2K07k0Vd12@=^0AP3K`4X0g01>0=`0DP3L@5J0g81
J`=b0Gd3L`6?0g<1XP=d0KD3M0790g@1g@=d0O43M04517@16@Ad0Bd4M05117@1E@Ad0FP4M05k17<1
S@Ac0Il4LP6a1781`PAa0M84L07R1701lPA_0@45KP4?1Fd17@E/0BX5J`4f1FX1@PEY0Dd5J05G1FL1
H@EU0FX5I05a1F<1N@ER0Gl5H0641El1R0EM0H`5G06>1EX1S`EJ0I05F@6@1EP1T@EH0I05E`6@1EH1
S`EE0Hh5E@6<1E<1R0EB0H@5D05o1Dl1N@E>0G45C05Z1D/1H@E:0EL5B05=1DL1@PE60CH5A@4Z1D@1
7@E30@l5@P411D41lPA00N84?`7B13l1`P@n0K04?@6O13d1S@@l0G/4?05X13/1E@@k0D44>`4]13/1
6@@k0@D4>`4U0000300000D0000U0000300000H0000X0000300000<0000R000030000?oooolQ0000
200004/0000@0000000000D0000V0000700000<0000000000`000000000000009@0000`000030000
9@0000`000050020E`000402003?0000R0000<d1002J0000R@0000l4Z@7k0jT1i`>Y0M<3Z@6o0jT1
[0>Y0IT3ZP670jX1M@>[0F@3Z`5C0j`1@P>]0C83[@4R0jh14`>_0@D3/07g0[41jP:b0Mh2/`7B0[@1
a`:e0Kd2]P6c0[P1Z`:i0J<2^P6L0[`1U@:m0I02_P6<0/01R0;10HH2``650/<1Q0;40H@2a@640/H1
Q0;60H@2a`650/P1QP;80HP2bP6<0//1T0;=0ID2cP6L0]01X`;A0J/2dP6c0]<1_@;E0LL2eP7B0]L1
gP;H0NX2f@7g0]X11@?K0A<3g04R0md1<P?N0D83gP5B0ml1I0?P0GD3h0670n41V@?Q0J`3hP6o0n81
d`?R0NL3hP7k0n813`CR0B<4hP4g1>81B`CR0El4hP5b1>81Q@CQ0IL4h@6Y1>01^`CP0L`4g`7L1=h1
k0CN0O`4g@4;1M`16@GK0BL5fP4d1MT1@0GH0D`5e`5G1MH1H@GE0F/5d`5d1M81N`GA0H<5d0691Lh1
SPG=0I85b`6F1LX1V0G80IT5b06J1LL1VPG60I/5aP6J1LD1VPG40IT5``6H1L<1UPG10I85`06>1Kh1
R@Fm0H<5_05k1KX1M0Fi0F/5^05Q1KH1E`Fe0D`5]0501K<1=0Fb0BL5/@4I1K012`F_0O`4[P7/1:d1
g0B]0L`4[06j1:/1Z@B[0IL4ZP651:X1LPBY0El4Z@5;1:T1=`BY0B<4Z@4?1:T19@0000`000050000
9@0000`000060000:00000`0000300008P0000`0003ooooo8@0000P0001;00004000000000050000
9@0000`0000600009@0000`000080020C00006@0000h00005@000:P000120000[P0004<0001P0@00
S@000240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00001@0002D0000<00001P000280000<0000ooooobD0000<00002000P2D0000<0000
1@00P1P0000<0000000001T0000<0000oooo02D0000<0000100002D0000<00000@0001P0000<0000
000001T0000<0000oooo02D0000<0000100002D0000<00000@0001h0000H0000^@0004L000030P00
c0000580001`0@000`000<koool0000000000000002l0P000000000002110780J@1Q06`000000000
0000000000000000000000000000000000000000000000000000000000000000000N0;2P7P1h0AD0
l09b0]Sb4P1D8OEg60400407LP8001D0l09b0P00002/la80_aoeMgP15@238?Eg20HE08dFmGN90000
00000?P2LP9TMP080000090n]`3h0W8210000200001P0QD0000E09Ca4P010040000E0;TOagL00<Mg
a?3mO`3PoGl000000000000000000000WB_7M`80001f30@MMP`008PZagMf30@M12HN0040003l9Ah0
0037MlC`oGl0h?eo0000000000000000000009d[agL20000MPX4eWH:0028:/MgMPX4eWH:1=H10000
`?<B06Af00P000009@0000`0000300009@0000`0000200009@0000`000030000500000`0000=0000
4P0000`000010000E00008@0000k00005`0008H0000Y00000@0004U^1d5_O@M1^@0004T000090000
C00000000000000000000?ooooooooooH00004d0H@1b06/0I@1d06T0KP1W0000:@0001`0000C0000
700001`0000A00003P0001h0000O00009@0000`0000200008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600000@000040000;`L001X2000U0000300000D0000U0000
300000H0000Q0000200004/0000@0000000000D0000U0000300000H0000U0000300000P0081<0000
I00003H0000f0000YP000680002X0000Z00005l1002=00008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000500009@0000`000060000
8P0000`0003ooooo9@0000`0000800209@0000`000050020600000`0000000006@0000`0003oool0
9@0000`0000400009@0000`000020000600000`0000000006@0000`0003oool09@0000`000040000
9@0000`0000200007P0001P0002c0000[0000?`1000a0@009@0000`0000300009@0000`000020000
9@0000`0000300009@0000`0000200009@0000`0000300009@0000`0000200009@0000`000030000
500000`0000=00004P0000`000010000E0000900000i0000>0000980001:00000@0004U^1d5_O@M1
/`000:h0000;0000C00000000000000000000?ooooooooooI00004l0L01U0780H@1d06T0K`1^07<0
800002L0000O0000700001<0000L00004@0000h0000O00007P0001`0000>0000E00008P0000i0000
C@0009X0001O00000@0004U^1d5_O@M1/`000>l0000:0000C00000000000000000000?oooooooooo
H00004d0H@1^0640I`1U06d0I@1^07@0:@0001`0000N0000700001l0000L0000;00001`0000N0000
4@0002D0000<00000P000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P000040000100002l7000J0P009@0000`0000500009@0000`0000600008@0000P0001;0000
40000000000500009@0000`0000600009@0000`000080020C00006@0000h0000J`000:P000220000
[P0004d1001P0@00C@000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00001@0002D0000<00001P000280000<0000ooooobD0000<0000
2000P2D0000<00001@00P1P0000<0000000001T0000<0000oooo02D0000<0000100002D0000<0000
0P0001P0000<0000000001T0000<0000oooo02D0000<0000100002D0000<00000P0001h0000H0000
^@00054100030P00UP4002D0000<00000`0002D0000<00000P0002D0000<00000`0001@0000<0000
3@000180000<00000@0005@0001h0000>`0006d0001g0000O`0000400019KPM1Kgd7@KT0001C0@00
1`0004`00000000000000000003ooooooooooe`0001606T0KP1Q06h0H`1U00007`0000h0000N0000
700001h0000L0000700002D0000<00000P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P000040000100002l7000J0P009@0000`0000500009@0000`000060000
8@0000P0001;000040000000000500009@0000`0000600009@0000`000080020C00006@0000g0000
RP000:L0002P0000Z`000:l1001O0@00B@000240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00001@0002D0000<00001P000280000<0000
ooooobD0000<00002000P2D0000<00001@00P1P0000<0000000001T0000<0000oooo02D0000<0000
100002D0000<00000P0001P0000<0000000001T0000<0000oooo02D0000<0000100002D0000<0000
0P0001h0000H0000]P000;<1003o0@00m04002D0000<00000`0002D0000<00000P0002D0000<0000
0`0001@0000<00003@000180000<00000@0005@000280000>P0008`0002A0000WP0000400019KPM1
Kgd7@KH0002e0@002P0004`00000000000000000003oooooooooof00001106<0H`1_07D0KP1d06T0
KP1W02<0000L0000700001l0000N00007P000140000>00007P0001l0001D0000C000000000000000
ooooooooool10000BFh7@Fmm1d6f0000mP400000001<00000000000000000000oooooooooom<0000
9@0000`0000200008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600000@000040000;`L001X2000U0000300000D0000U0000300000H0000Q0000200004/0000@0000
000000D0000U0000300000H0000U0000300000P0081<0000I0000=h1001i0000C0800:H0003@1@00
N`4005`1002=00008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000500009@0000`0000600008P0000`0003ooooo9@0000`000080020
9@0000`000050020600000`0000000006@0000`0003oool09@0000`0000400009@0000`000020000
600000`0000000006@0000`0003oool09@0000`0000400009@0000`0000200007P0001P0003K1@00
O`40024700040P009@0000`0000300009@0000`0000200009@0000`0000300009@0000`000020000
9@0000`0000300009@0000`0000200009@0000`000030000500000`0000=00004P0000`000010000
E00008@0003Q0@00N`0002T2002=00000@0004U^1d5_O@M1f`D0084100090000C000000000000000
00000?ooooooooooH00004@0J@1f06T0I01U06h0I00P0000900000h0000K00003P0001l0000L0000
7P0001l0000>0000E0000700003Q0@00T0000102002R00000@0004U^1d5_O@M1f`D00<8100060000
C00000000000000000000?ooooooooooF0000500K`1/06T0H`1i0240000O00003P0000h0000L0000
6`0002D0000<00000P000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P000040000100002l7000J0P009@0000`0000500009@0000`0000600008@0000P0001;0000
40000000000500009P0001`0000700000000004000000000000002D0000<00001`0002L0000H0000
2000000000000000000002D0000<0000200001<0000<00000P0005/000200000TP0001`0002f0000
90000080000F00004P0000@000390F<08`9S02<2H`0T0V<0909U02@2IP0S0VH08`9V0<T1IP380FH0
a`5V0<L1I@370FD0a`5T0<L1H`380F<0b@5S0<T1H`0O0UP0>09U01l2L@0O0UP04`0000`000010000
9@0000`0000600009@0000`000050000:00000`0000700008P0000`0003ooooo8@0000P0001;0000
40000000000500009P0001`0000700000000004000000000000002D0000<00001`0002D0000<0000
200001<0000<00000P0005/0001l0000X`0004P0002i0000D0000080000E00004@0000@0003m0N<0
:P;/02/2k00[0^d0;0;]02`2kP0[0^l0:P;_02X2k`3l0NH0n`7U0?/1i@3k0N@0o07S0?`1h`3m0N<0
o@7S02P2h00o0_8090;i02P2h00C000030000040000U0000300000H0000U0000300000D0000X0000
300000L0000R000030000?oooolQ0000200004/0000@0000000000D0000V0000700000L000000000
0@000000000000009@0000`0000700009@0000`0000800004`0000`000020000F`0007P000280000
K@000<@0001f00000P0001@0000@000010000:L1K@5>0Ud1CP9M0Dl2G@5?0Uh1C`9O0Dl2H05>0V01
Z05`0JL1L06W0G01YP5_0JH1KP6V0Fh1Y`5]0JL1K@580U<1H`9M0D/2J`580U<14`0000`000010000
9@0000`0000600009@0000`000050000:00000`0000700008P0000`0003ooooo8@0000P0001;0000
40000000000500009P0001`0000700000000004000000000000002D0000<00001`0002D0000<0000
200001<0000<00000P0005/0001h0000W@0008h000340000UP000080000D0000400000@0003Y0L`1
CP;70Dh2a`5?0/L1C`;90Dl2bP5>0/X1jP7?0NT1c`7Y0Ll1j07>0NP1cP7X0Ld1j@7<0NT1c07Y0L`1
B@:l0F<2b05:0]D1B@:l0A<0000<00000@0002D0000<00001P0002D0000<00001@0002P0000<0000
1`000280000<0000ooooob4000080000B`000100000000001@0002H0000L00001`00000000010000
00000000000U0000300000L0000U0000300000P0000C000030000080001K0000N0000;`1002L0000
h0400:H0000200005000010000040000e`GZ0G/5o05j1O`1N@Gk0GT5nP5j1OX1NPGi0G/5n@7F1NL1
e`GW0ML5i`7H1NP1f0GY0MP5j@7G1NX1e`GZ0H851P9W1Ol1O@G]0H851P8C000030000040000U0000
300000H0000U0000300000D0000X0000300000L0000R000030000?oooom;00004000000000050000
7P0001P0003`ooool?ooolX8002R2`00600000`0000000006@0000`0003oool09@0000`000040000
9@0000`000020000:00000`000010000:00000`0000300008P0000`0003ooooo8@0000P0000R0000
30000?oooolU0000300000L0080U000030000000080`0000300000l0081;00004000000000050000
:00000`000020000:00000`000040000:00000`000050000:00000`000060000:00000`000080000
3P0001@000000000400001@0
\>"], "Text",
 TextAlignment->Center,
 TextJustification->0.,
 ImageSize->{498.66666666666663`, 141.94257178526837`},
 ImageMargins->{{56.666666666666664`, 0.}, {0., 
  0.}},ExpressionUUID->"0c178e9c-5ba4-4c1c-bc4e-ad44a81f1150"],

Cell[TextData[{
 StyleBox["Figure 8.13.\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
  "FigureCaptionLabel"],
 StyleBox["The building as the firm",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "FigureCaption",
 CellChangeTimes->{{3.5305630766026506`*^9, 3.5305630891353674`*^9}, {
   3.5305644553435097`*^9, 3.530564458907714*^9}, {3.5305648218574734`*^9, 
   3.5305648276488047`*^9}, {3.530565115734282*^9, 3.530565120441551*^9}, {
   3.530565584010066*^9, 3.530565587296254*^9}, {3.5305663222572913`*^9, 
   3.530566342809467*^9}, {3.5305681591723566`*^9, 3.530568165991747*^9}, {
   3.530568269005639*^9, 3.5305682875136976`*^9}, {3.530568545559457*^9, 
   3.5305685777522984`*^9}, {3.530568686144498*^9, 3.530568694791992*^9}, {
   3.530568832626876*^9, 3.530568860108448*^9}, {3.530569888534271*^9, 
   3.530569893855575*^9}, 3.5390216355400934`*^9, 3.5390347460209703`*^9},
 TextAlignment->Center,ExpressionUUID->"304ac100-663f-4c08-a952-bed1cd557a45"],

Cell[TextData[StyleBox["Tier II activities hold lessons that extend beyond \
the study of real estate:",
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{3.5390216355400934`*^9, 
  3.5390347460209703`*^9},ExpressionUUID->"ec351d34-4da9-493c-8748-\
b66ff6820bf4"],

Cell[TextData[StyleBox["The field of finance may wish to re-think the \
transition from uncertainty to risk. In corporate settings venture \
capitalists undertake a form of uncertainty prior to the firm offering shares \
to the public and becoming subject to \[OpenCurlyDoubleQuote]normal\
\[CloseCurlyDoubleQuote] risk analysis. Other than the plottage gained by \
assembling adjoining property, there appears little chance for our Tier II \
investor to \[OpenCurlyDoubleQuote]grow\[CloseCurlyDoubleQuote] into a \
larger, more sophisticated investor the way industrial giants appear to grow. \
Later chapters may suggest otherwise. It may be that Tier II is a sort of \
training ground in uncertainty and studying that market provides valuable \
insight into a previously shadowy area.",
 CharacterEncoding -> "WindowsANSI"]], "Item1",
 CellChangeTimes->{
  3.5305700793031816`*^9, {3.5305701122730675`*^9, 3.5305701158172703`*^9}, 
   3.5390216355400934`*^9, 
   3.5390347460209703`*^9},ExpressionUUID->"7674ff4b-d318-4df1-b18d-\
711a672d486a"],

Cell[TextData[StyleBox["There is an approach to this problem using option \
theory. Dixit and Pindyke (1994) offer a method using the Bellman equation to \
solve a dynamic optimization problem under uncertainty. That methodology \
would focus on the option to retire as its central theme. This may represent \
a useful simplification without loss of considerable reality.",
 CharacterEncoding -> "WindowsANSI"]], "Item1",
 CellChangeTimes->{3.5305700762290063`*^9, 3.5390216355400934`*^9, 
  3.5390347460209703`*^9},ExpressionUUID->"dcc29e75-9bfe-46c9-b700-\
00f78557a2fb"],

Cell[TextData[StyleBox["Management academics complain of the ill-formed \
definition of entrepreneurship. It may be that research built on surveys of \
entrepreneurs could be enhanced by studying the entrepreneurship required of \
Tier II investors. Such a study would go beyond surveys. Tier II properties \
should be viewed as \[OpenCurlyDoubleQuote]entrepreneurial objects\
\[CloseCurlyDoubleQuote] traded by a certain investor type. Observing what \
people do usually offers more powerful explanations than recording what they \
say.",
 CharacterEncoding -> "WindowsANSI"]], "Item1",
 CellChangeTimes->{
  3.5305700737238626`*^9, {3.530570180704982*^9, 3.5305701827961016`*^9}, 
   3.5390216355400934`*^9, 
   3.5390347460209703`*^9},ExpressionUUID->"0a74c8cf-5f64-4979-9714-\
fe0776378136"],

Cell[TextData[StyleBox["International policy academics studying emerging \
capitalist societies may want to consider the importance of wide dispersion \
of land ownership in the form of small parcels in the hands of many citizens \
as a means to \[OpenCurlyDoubleQuote]train\[CloseCurlyDoubleQuote] a society \
in the ways of capitalistic behavior.",
 CharacterEncoding -> "WindowsANSI"]], "Item1",
 CellChangeTimes->{
  3.530570071910759*^9, {3.530570194988799*^9, 3.530570195308817*^9}, 
   3.5390216355400934`*^9, 
   3.5390347460209703`*^9},ExpressionUUID->"c2900aac-878b-4d5f-95d3-\
1fcbc3ded202"],

Cell[TextData[StyleBox["At the end of Chapter 1 we suggested how nascent \
international real estate data providers might organize their efforts to \
anticipate demand.  It may be that international educational institutions \
could better place real estate in their curriculum before it ossifies among \
the politics and budgets of academic finance. It is not clear that real \
estate is a subset of finance. There may be a cross-disciplinary role for \
real estate, especially Tier II real estate, to play. There may be lessons \
for economics, management and finance in Tier II activities.",
 CharacterEncoding -> "WindowsANSI"]], "Item1",
 CellChangeTimes->{3.53057006930561*^9, 3.5390216355400934`*^9, 
  3.5390347460209703`*^9},ExpressionUUID->"67b757a6-c612-4a40-961d-\
466a23935b37"],

Cell[TextData[StyleBox["One final illustration emphasizes the point. In \
numerous observations of repeat sales of Tier II real estate it appears that \
the number of units in the building in the second sale often differs from the \
number of units in the first sale. If the number of units increase in a \
statistically meaningfully way more often than they decrease, several \
questions arise. Is the increase due to owners recognizing that income can be \
increased by converting a larger unit to two smaller units? Is this \
income-increasing activity a finance issue? Is it entrepreneurship, therefore \
a management issue?  It is a response to housing shortage, therefore a \
housing economics issue?",
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{3.5305702325869493`*^9, 3.5390216355400934`*^9, 
  3.5390347460209703`*^9},ExpressionUUID->"88e345a9-180b-401b-9640-\
1396fe42a2e6"],

Cell[TextData[StyleBox["Perhaps it is some of all three.\n",
 CharacterEncoding -> "WindowsANSI"]], "Text",
 CellChangeTimes->{{3.5305702325869493`*^9, 3.5305702340030303`*^9}, 
   3.5390216355400934`*^9, 
   3.5390347460209703`*^9},ExpressionUUID->"3606a54c-d45b-4700-ba97-\
2799ee749cce"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Endnotes", "EndnoteSection",
 CellChangeTimes->{{3.530541702588127*^9, 3.5305417051812754`*^9}, 
   3.5390216355400934`*^9, 
   3.5390347460209703`*^9},ExpressionUUID->"0444de5b-404a-40ff-a5c0-\
6f19ec98c55f"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "1"], TraditionalForm]],ExpressionUUID->
  "a25a592b-4a41-458a-80fc-c7f1d5fa0f62"],
 "It is interesting to note that the misuse of this idea played a significant \
role in two major financial crises, one in 1998 when Long Term Capital \
Management collapsed, the other in 2007-? involving the subprime mortgage \
lending mess. Many have written about this with strong criticism of relying \
on models which assume life is distributed normally. The author first wrote \
about this in 1999. "
}], "Endnote",
 CellChangeTimes->{{3.5305417156138716`*^9, 3.5305417531400185`*^9}, {
  3.53054186785958*^9, 3.5305420284977674`*^9}, {3.5390216355400934`*^9, 
  3.5390216355400934`*^9}, {3.5390347460209703`*^9, 3.53903474602197*^9}, {
  3.54119082912141*^9, 3.541190835257761*^9}},
 CellTags->"endnote1",ExpressionUUID->"f68bc0f7-1a04-440c-90bf-6a24dba46404"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]],ExpressionUUID->
  "da5c4541-f026-4c78-a35a-8608ca64b383"],
 "The simplest example is purchasing a small apartment building, making \
improvements that increase income and therefore increase value."
}], "Endnote",
 CellChangeTimes->{{3.530542704833452*^9, 3.5305427544952927`*^9}, {
  3.5390216355400934`*^9, 3.539021635541094*^9}, {3.53903474602197*^9, 
  3.53903474602297*^9}},
 CellTags->"endnote2",ExpressionUUID->"2b968c7e-9faf-45dd-8828-ea8812bf2642"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "3"], TraditionalForm]],ExpressionUUID->
  "306b403e-281c-47d1-9272-8bf77d54f1f0"],
 "This list could be applied to one\[CloseCurlyQuote]s home, a real estate \
parcel in the Tier I market, but often the motivation is less economic and \
more oriented to personal matters."
}], "Endnote",
 CellChangeTimes->{{3.530542758402516*^9, 3.5305427647738805`*^9}, {
   3.5305529768079753`*^9, 3.5305530575695944`*^9}, 3.531617015965869*^9, {
   3.539021635541094*^9, 3.5390216355420933`*^9}, {3.53903474602297*^9, 
   3.53903474602397*^9}},
 CellTags->"endnote3",ExpressionUUID->"75ace251-579c-4f7f-bc0a-0ef1ce878983"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "4"], TraditionalForm]],ExpressionUUID->
  "8a4986a9-4ce4-4014-bf9b-4da0826747e5"],
 "A large literature holds that property rights gravitate to the highest \
bidder, presumably the one who can make the most efficient use of them."
}], "Endnote",
 CellChangeTimes->{{3.5305530602227464`*^9, 3.5305530659750752`*^9}, {
  3.5305531481287746`*^9, 3.530553188028056*^9}, {3.5390216355420933`*^9, 
  3.5390216355420933`*^9}, {3.53903474602397*^9, 3.53903474602497*^9}},
 CellTags->"endnote4",ExpressionUUID->"2875e4c7-ac06-4cb5-a7c6-04418a12af74"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "5"], TraditionalForm]],ExpressionUUID->
  "badddc99-8d35-4cff-9960-9506e42b50b4"],
 "There are, of course, factors out of the investor\[CloseCurlyQuote]s \
control such as general inflation, interest rates and global economic \
changes. These are out of the control of one who invests in financial assets \
as well. The point is that ",
 StyleBox["some",
  FontSlant->"Italic"],
 " of the site specific factors relating to real estate are controllable \
where none are in the case of financial assets."
}], "Endnote",
 CellChangeTimes->{{3.5305531901161757`*^9, 3.5305531956004896`*^9}, {
  3.5305533539005437`*^9, 3.5305534603566327`*^9}, {3.5390216355420933`*^9, 
  3.5390216355430937`*^9}, {3.53903474602497*^9, 3.5390347460259705`*^9}},
 CellTags->"endnote5",ExpressionUUID->"f54e6254-70b6-4079-805f-71fd84d09c38"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "6"], TraditionalForm]],ExpressionUUID->
  "6ebd5e8f-c0e1-4bd4-8ce6-aa8c92814490"],
 "This can be a very short time if one is to believe the \
\[OpenCurlyDoubleQuote]nothing down\[CloseCurlyDoubleQuote] infomercials that \
appear on late night television."
}], "Endnote",
 CellChangeTimes->{{3.530553462544758*^9, 3.5305534672610273`*^9}, {
   3.5305535460345335`*^9, 3.5305535748381805`*^9}, {3.5390216355430937`*^9, 
   3.5390216355440936`*^9}, {3.5390347460259705`*^9, 3.5390347460269704`*^9}, 
   3.5411908427871914`*^9},
 CellTags->"endnote6",ExpressionUUID->"d382f0e2-8758-4ab9-b9e1-979e1eef6693"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "7"], TraditionalForm]],ExpressionUUID->
  "8542b584-3c72-4b7a-816b-e449c4f60dc3"],
 "Equation 8.3 makes a crucial substitution of ",
 StyleBox["tr1",
  FontSlant->"Italic"],
 " for ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", the reason for which will become clear shortly."
}], "Endnote",
 CellChangeTimes->{{3.5305535771253114`*^9, 3.530553588742976*^9}, {
  3.5305591063215637`*^9, 3.5305591476179256`*^9}, {3.5390216355450935`*^9, 
  3.5390216355450935`*^9}, {3.5390347460269704`*^9, 3.5390347460279703`*^9}},
 CellTags->"endnote7",ExpressionUUID->"e04a9228-ea28-42f4-a553-c23aac899ef5"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "8"], TraditionalForm]],ExpressionUUID->
  "439ad019-deab-49bb-b8bb-b344302244d3"],
 "Macabre as it may seem, in this model it also fixes the date of death."
}], "Endnote",
 CellChangeTimes->{{3.5305591539022846`*^9, 3.5305591654999485`*^9}, {
  3.530560104694667*^9, 3.530560122940711*^9}, {3.5390216355450935`*^9, 
  3.5390216355450935`*^9}, {3.5390347460279703`*^9, 3.5390347460279703`*^9}, {
  3.5405659451765347`*^9, 3.5405659460445843`*^9}},
 CellTags->"endnote8",ExpressionUUID->"2346c6e1-bae6-4916-a123-97534217f02a"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "9"], TraditionalForm]],ExpressionUUID->
  "60fad391-f2f1-4b9b-928d-5e74fcef60fe"],
 "This functional form is chosen in part for convenience.  The simpler, \
general, two period model, ",
 StyleBox["U(C, L)",
  FontSlant->"Italic"],
 " = ",
 StyleBox["U(C",
  FontSlant->"Italic"],
 StyleBox["1",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox[",L",
  FontSlant->"Italic"],
 StyleBox["1",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox[")",
  FontSlant->"Italic"],
 " + ",
 StyleBox["U(C",
  FontSlant->"Italic"],
 StyleBox["2",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox[", L",
  FontSlant->"Italic"],
 StyleBox["2",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->Subscript}],
 StyleBox[")",
  FontSlant->"Italic"],
 ", was attempted.   However, given the constraints, the second order \
condition for this model contains variables that must have known values to \
confirm that the Hessian matrix of the function is negative definite. Our \
problem suffers similarly and we overcome it by specifying these values in \
advance and then conducting simulations."
}], "Endnote",
 CellChangeTimes->{{3.530560124641808*^9, 3.5305601296370935`*^9}, {
  3.530560410921182*^9, 3.5305604362766323`*^9}, {3.539021635546094*^9, 
  3.539021635546094*^9}, {3.5390347460279703`*^9, 3.5390347460289707`*^9}},
 CellTags->"endnote9",ExpressionUUID->"5cc4ad3d-c1f4-48a8-802d-1648e6ac9ab0"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "10"], TraditionalForm]],ExpressionUUID->
  "be4cf41a-c2c7-4491-9592-ed645d1f77c4"],
 "This is consistent with Markowitz\[CloseCurlyQuote] (1991:b.5) advice \
regarding modeling the individual investor: \[OpenCurlyDoubleQuote]In sum, I \
encourage readers with requisite skills to try building and using realistic \
game-of-life simulators; and editors to look kindly on the publication of \
their results.\[CloseCurlyDoubleQuote]"
}], "Endnote",
 CellChangeTimes->{{3.530560438447757*^9, 3.530560443118024*^9}, {
  3.530561882223336*^9, 3.530561882223336*^9}, {3.5305619164312925`*^9, 
  3.530561931578159*^9}, {3.5305692434733753`*^9, 3.5305693569438653`*^9}, {
  3.5305695709921083`*^9, 3.5305695709971085`*^9}, {3.539021635546094*^9, 
  3.539021635547094*^9}, {3.5390347460289707`*^9, 3.5390347460299706`*^9}},
 CellTags->"endnote10",ExpressionUUID->"978581f7-805d-4dc1-9cb6-484851a488c6"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "11"], TraditionalForm]],ExpressionUUID->
  "0c91fe65-b699-492c-a6e7-95f522c689d2"],
 "I leave it to purists to provide a bright line distinction between \
simulations that demonstrate a concept under bounded conditions and theories \
blessed with formal proof."
}], "Endnote",
 CellChangeTimes->{{3.5305695727982116`*^9, 3.5305696329966545`*^9}, {
  3.539021635547094*^9, 3.539021635547094*^9}, {3.5390347460299706`*^9, 
  3.5390347460309706`*^9}},
 CellTags->"endnote11",ExpressionUUID->"12aacaa6-8484-44fc-aed0-81a61e319f5d"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "12"], TraditionalForm]],ExpressionUUID->
  "df623e0b-e955-4ab4-abd8-da31c430f758"],
 "The author first heard this from N. Edward Coulson. Similar observations \
have no doubt been made by other scholars."
}], "Endnote",
 CellChangeTimes->{{3.530569635605804*^9, 3.5305696386229763`*^9}, {
  3.5305696941341515`*^9, 3.530569726429999*^9}, {3.530569837487351*^9, 
  3.5305698471469035`*^9}, {3.539021635548094*^9, 3.539021635548094*^9}, {
  3.5390347460309706`*^9, 3.539034746031971*^9}},
 CellTags->"endnote12",ExpressionUUID->"c7c77fc5-9975-4245-84b4-207ccd2638a2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "ReferenceSection",
 CellChangeTimes->{{3.5305420393133864`*^9, 3.530542040917478*^9}, 
   3.539021635548094*^9, 
   3.539034746031971*^9},ExpressionUUID->"3f567f4d-adc2-4e00-9f54-\
b5c2ab2ed943"],

Cell[TextData[{
 "Bellman, R., & Cooke, K. L. (1968). ",
 StyleBox["Modern Elementary Differential Equations",
  FontVariations->{"Underline"->True}],
 ". New York, NY: Dover Publications, Inc."
}], "Reference",
 CellChangeTimes->{{3.5305422882506247`*^9, 3.5305422900477276`*^9}, 
   3.5305423305220423`*^9, {3.530570290210245*^9, 3.5305702919253435`*^9}, 
   3.539021635548094*^9, 3.539034746031971*^9, 
   3.5399933985884275`*^9},ExpressionUUID->"11ce2adf-1d23-4782-aee4-\
931932dd83ab"],

Cell["\<\
Black, Fischer; Myron Scholes (1973). \[OpenCurlyDoubleQuote]The Pricing of \
Options and Corporate Liabilities\[CloseCurlyDoubleQuote]. Journal of \
Political Economy 81 (3): 637\[Dash]654.\
\>", "Reference",
 CellChangeTimes->{{3.530542292291856*^9, 3.5305423264298086`*^9}, {
   3.530570140511683*^9, 3.5305701405146832`*^9}, {3.5305703715278964`*^9, 
   3.530570381485466*^9}, 3.539021635548094*^9, 3.539034746031971*^9, 
   3.5399934005475397`*^9, 
   3.541190858731104*^9},ExpressionUUID->"d38b2e9d-820e-421e-916a-\
b075a7395ab0"],

Cell[TextData[{
 "Dixit, A. K. and Pindyke, R.S. (1994). ",
 StyleBox["Investment under Uncertainty",
  FontVariations->{"Underline"->True}],
 ". Princeton, NJ: Princeton University Press."
}], "Reference",
 CellChangeTimes->{{3.5305701429378214`*^9, 3.5305701496832075`*^9}, {
   3.5305704784590125`*^9, 3.530570478461013*^9}, {3.5305705127839756`*^9, 
   3.530570537004361*^9}, 3.539021635548094*^9, 3.539034746031971*^9, 
   3.539993402077627*^9},ExpressionUUID->"cd64df15-55eb-48fc-9c32-\
8f7d5d637018"],

Cell[TextData[{
 "Farlow, S. J.  (1982). ",
 StyleBox["Partial Differential Equations for Scientists and Engineers",
  FontVariations->{"Underline"->True}],
 ". New York, NY: Dover Publications, Inc."
}], "Reference",
 CellChangeTimes->{{3.5305704799670987`*^9, 3.5305704825532465`*^9}, 
   3.539021635548094*^9, 3.539034746031971*^9, 
   3.5399934037337217`*^9},ExpressionUUID->"7d766eb3-9951-463f-92fa-\
630efd6119af"],

Cell[TextData[{
 "Killingsworth, M. R. (1983). ",
 StyleBox["Labor Supply",
  FontVariations->{"Underline"->True}],
 ". Cambridge, UK: Cambridge University Press."
}], "Reference",
 CellChangeTimes->{{3.5305421863717976`*^9, 3.5305421864898043`*^9}, {
   3.5305422763079414`*^9, 3.5305422803201714`*^9}, {3.530569255633071*^9, 
   3.5305692556370707`*^9}, 3.530570396162305*^9, 3.530570493244858*^9, 
   3.539021635548094*^9, 3.539034746031971*^9, 
   3.539993405240808*^9},ExpressionUUID->"a4402b76-f197-4cae-8f7c-\
8ccb02a2f892"],

Cell["\<\
Markowitz, H. M., (1991). \[OpenCurlyDoubleQuote]Foundations of Portfolio \
Theory\[CloseCurlyDoubleQuote], Journal of Finance, 2, p. 469-77.\
\>", "Reference",
 CellChangeTimes->{{3.530569263978548*^9, 3.530569268224791*^9}, {
   3.5305703860147247`*^9, 3.5305704041577625`*^9}, {3.5305707768450794`*^9, 
   3.5305707776101227`*^9}, 3.539021635548094*^9, 3.539034746031971*^9, 
   3.5399934066938915`*^9},ExpressionUUID->"4a5386c1-1506-4e64-9260-\
600afc50ce7b"],

Cell["\<\
Merton, Robert C. (1973). \[OpenCurlyDoubleQuote]Theory of Rational Option \
Pricing\[CloseCurlyDoubleQuote]. Bell Journal of Economics and Management \
Science (The RAND Corporation) 4 (1): 141\[Dash]183.\
\>", "Reference",
 CellChangeTimes->{{3.530570405051814*^9, 3.530570424111904*^9}, {
   3.530570558193573*^9, 3.530570558198573*^9}, 3.530570781497345*^9, 
   3.539021635548094*^9, 3.539034746031971*^9, 
   3.5399934091320305`*^9},ExpressionUUID->"f71a822d-3980-49ce-8715-\
4527d335bb4a"],

Cell[TextData[{
 "\tRoy, A. D. (1951). Some Thoughts on the Distribution of Earnings. ",
 StyleBox["Oxford Economic Papers, 3(2), 135-146",
  FontVariations->{"Underline"->True}],
 "."
}], "Reference",
 CellChangeTimes->{{3.5305705600036764`*^9, 3.5305705717463484`*^9}, 
   3.530570783866481*^9, 3.539021635548094*^9, 3.539034746031971*^9, 
   3.5399934108401284`*^9},ExpressionUUID->"8a052cf5-1830-43ed-b53d-\
dab192cf6929"],

Cell[TextData[{
 "Utz, W. R. (1967). ",
 StyleBox["A Short Course in Differential Equations",
  FontVariations->{"Underline"->True}],
 ". New York, NY: McGraw-Hill, Inc."
}], "Reference",
 CellChangeTimes->{{3.530570592305524*^9, 3.5305706154768496`*^9}, 
   3.5305707870086603`*^9, 3.539021635548094*^9, 3.539034746031971*^9, 
   3.5399934129232473`*^9},ExpressionUUID->"b2069c4f-dac5-468b-a177-\
3d1a0aa9a4e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "ExerciseSection",
 CellChangeTimes->{{3.5305422260820684`*^9, 3.530542227620157*^9}, 
   3.539021635548094*^9, 
   3.539034746031971*^9},ExpressionUUID->"4b147275-007f-4ecc-8ea7-\
67c68dbd1c44"],

Cell[TextData[{
 "An investor buys a duplex with a one bedroom, one bath unit and a three \
bedroom, 2 bath unit that has a combined monthly rent of ",
 StyleBox["x",
  FontSlant->"Italic"],
 ". After work and on week-ends he converts the larger unit into two units, \
one a two bedroom, one bath unit and the other a two bedroom, one bath unit. \
After the conversion the combined income of all three units is 1.5",
 StyleBox["x",
  FontSlant->"Italic"],
 ". Find the variable among the list in the Notation Guide that represents \
his time spent on the conversion project."
}], "Item1Exercise",
 CellChangeTimes->{{3.53054223239643*^9, 3.5305422362306495`*^9}, {
   3.5305726217636023`*^9, 3.5305728126845226`*^9}, 3.539021635548094*^9, 
   3.539034746031971*^9, {3.5405660547778034`*^9, 
   3.5405660782541466`*^9}},ExpressionUUID->"3df55ff1-22ad-4189-a0be-\
92f647829212"],

Cell[TextData[{
 "Two investors each buy a duplex and convert them as described above. One \
investor spends ",
 StyleBox["y",
  FontSlant->"Italic"],
 " time on the project and improves the income from x to 1.5",
 StyleBox["x",
  FontSlant->"Italic"],
 ". The other investor spends .75",
 StyleBox["y",
  FontSlant->"Italic"],
 " time on his building and improves the income from ",
 StyleBox["x",
  FontSlant->"Italic"],
 " to 1.7",
 StyleBox["x",
  FontSlant->"Italic"],
 ". This is an example of a difference which is described by which variable \
in the notation guide?"
}], "Item1Exercise",
 CellChangeTimes->{{3.530572843748299*^9, 3.530572976957918*^9}, {
   3.5316205046454105`*^9, 3.531620505130438*^9}, 3.539021635548094*^9, 
   3.539034746031971*^9, {3.541190905053753*^9, 
   3.541190907571897*^9}},ExpressionUUID->"deb307a0-1640-429a-ac0c-\
4c6ddab6b395"],

Cell["\<\
An investor works days for the US Postal Service and hates his job, a \
different investor is a middle manager for a large automotive manufacturing \
firm and loves his work. They separately decide to acquire a rental property \
and apply their efforts in managing it. How will their preferences (\[Alpha], \
\[Beta], \[Gamma]) be different?\
\>", "Item1Exercise",
 CellChangeTimes->{{3.5305729990891843`*^9, 3.5305730680921307`*^9}, {
   3.530573384443225*^9, 3.5305733844482255`*^9}, {3.5316205139689436`*^9, 
   3.5316205779386024`*^9}, 3.539021635548094*^9, 3.539034746031971*^9, 
   3.540566112298094*^9},ExpressionUUID->"4f1340d6-1538-4268-89c9-\
df1bf908e6a8"],

Cell["\<\
Figure 8.11 is reproduced below. As you move the slider to the right what is \
the effect on an investor\[CloseCurlyQuote]s willingness to own and operate \
real property investments? Choosing two different combinations of time spent, \
efficiency and alternative return, for which combination is he more likely to \
sell?\
\>", "Item1Exercise",
 CellChangeTimes->{{3.53057346040657*^9, 3.530573601624647*^9}, {
   3.5316205869161158`*^9, 3.5316205879361744`*^9}, 3.533242356310466*^9, 
   3.539021635548094*^9, 
   3.539034746031971*^9},ExpressionUUID->"24515c02-0c44-424b-86b2-\
c9b23084da21"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"plot1", "=", 
     RowBox[{"Plot3D", "[", 
      RowBox[{
       RowBox[{"\[Rho]", " ", 
        FractionBox[
         SubscriptBox["S", "r"], 
         RowBox[{
          SubscriptBox["S", "r"], "+", "1"}]]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Rho]", ",", ".1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["S", "r"], ",", ".05", ",", ".25"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Rho]\>\"", ",", 
          "\"\<      \!\(\*SubscriptBox[\(S\), \(\(r\)\(\\\ \)\)]\)\>\"", 
          ",", "\"\<er      \>\""}], "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"plot2", "=", 
     RowBox[{"Plot3D", "[", 
      RowBox[{"rate", ",", 
       RowBox[{"{", 
        RowBox[{"\[Rho]", ",", ".1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["S", "r"], ",", ".05", ",", ".25"}], "}"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"GrayLevel", "[", ".7", "]"}], "&"}], ")"}]}], ",", 
       RowBox[{"Mesh", "\[Rule]", "False"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"shtwo", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"plot1", ",", "plot2"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"rate", ",", ".04", ",", "\"\<Alternate Yield\>\""}], "}"}], 
     ",", ".02", ",", ".08", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.410377669342375*^9, 3.4103776999205*^9}, 
   3.41037777120175*^9, {3.5305732193917847`*^9, 3.530573337693551*^9}, 
   3.539021635548094*^9, 3.539034746031971*^9, {3.5433440867246084`*^9, 
   3.5433441337422976`*^9}},ExpressionUUID->"b4636047-ba9f-4fec-a7d6-\
981dffd694ba"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`rate$$ = 0.04, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`rate$$], 0.04, "Alternate Yield"}, 0.02, 0.08}}, 
    Typeset`size$$ = {540., {194., 201.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`rate$3112$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`rate$$ = 0.04}, 
      "ControllerVariables" :> {
        Hold[$CellContext`rate$$, $CellContext`rate$3112$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`plot1 = 
        Plot3D[$CellContext`\[Rho] ($CellContext`S\[UnderBracket]Subscript\
\[UnderBracket]r/($CellContext`S\[UnderBracket]Subscript\[UnderBracket]r + 
           1)), {$CellContext`\[Rho], 0.1, 
           1}, {$CellContext`S\[UnderBracket]Subscript\[UnderBracket]r, 0.05, 
           0.25}, PlotRange -> All, ColorFunction -> Hue, 
          AxesLabel -> {
           "\[Rho]", "      \!\(\*SubscriptBox[\(S\), \(\(r\)\(\\ \)\)]\)", 
            "er      "}]; $CellContext`plot2 = 
        Plot3D[$CellContext`rate$$, {$CellContext`\[Rho], 0.1, 
           1}, {$CellContext`S\[UnderBracket]Subscript\[UnderBracket]r, 0.05, 
           0.25}, ColorFunction -> (GrayLevel[0.7]& ), Mesh -> 
          False]; $CellContext`shtwo = 
        Show[$CellContext`plot1, $CellContext`plot2]), 
      "Specifications" :> {{{$CellContext`rate$$, 0.04, "Alternate Yield"}, 
         0.02, 0.08, Appearance -> "Labeled"}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{610., {257., 265.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`shtwo = Graphics3D[{
          GraphicsComplex[CompressedData["
1:eJxdnHlUTe8X/yuphEiZIlNFKkKI0KOkCSkic0QhUoZSVGhCSaNmzfM8z93m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           "], {{{
              EdgeForm[], 
              Directive[
               Specularity[
                GrayLevel[1], 3], 
               RGBColor[0.880722, 0.611041, 0.142051], Lighting -> "Neutral"], 
              GraphicsGroup[
               Annotation[{
                 Polygon[CompressedData["
1:eJwtmXfgVuMbxt9znhsNkr1L+GUlI5QiZKUilWgvoozKqEg7oSISaaoUSVkZ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                  "]], 
                 Polygon[CompressedData["
1:eJwtmgn8VsMexs/MHGUXadUeWSttJFlaCEUrIi6yFdpL0r6qaEVRSqFEtpRd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                  "]], 
                 Polygon[CompressedData["
1:eJwt1ne8j2UfB/BzHHuPbJlZDUJmmWWV7JUZGT12ViqhrAqlRwplZZeEEC0q
So+ZzLLLaIh6Ci16f1/n98fn9b0+73M7r5/73Pd1/Ur0HNx6UJqkpKT3JJ38
mpKU1ARMSk5KmqUX0n+WWmwUe5Zl0X+T5mwqm8dK6N9JCdadDWK/WA9g+/Vs
kpXNZ/3ZV3qWCJvH+rF9eibJzOayk+xGszPrx362vsLamTPYUnaz/os0ZhPZ
K6yw/od0YDPZcnaLflqKsa5sALtofYoVNbuw/uyC9Z+so/kyW8Fu1c9JafYQ
G8p+tz7OCpodWG923vorlslszNqyQ9YHWBazKWvPjljvYxnNRqwNO2j9Dctn
tmU92Rnrq6y9+RJbxsrrx6QAa896sXPWX7K0ZgPWgu2z3s8ym01YO3bY+iDL
Yd7POrMT1ntZilmfNWdfWh9huc2WrBs7Zf0Tq2wOYeNYiv615GGtWHd22nog
O6DniL87W8AusnrmGPYCy62flZtYT/YI+836MmtpPs8WsFL679KCTWPzWUn9
/9KUTWazWRH9WynOurGB7JL1BVbTfJQ9w7LqZ6Qke5ANjmfe+hKrb45l01ke
/ajkZ+3YQ+ys9WGWy2zBurKT1udZGbMXG8YuW3/Pypq92XB2xfoHVs7sw0aw
q9Y/svJmXzaS/WF9ghUyO7I+7HvrQyyn2Zx1YcetF0p262lxv6REWu+d6w66
Jldy6s/imrdZG3M8m8nK6mulE3uOzWUV9bekFXuKzWCl9TfkPvYEm8aK6Svk
XvY4m8qK6u9IZzYlsR/crq+WtmwCe5mV09fIA+xZ9hqroE+V9Kwau5sdsH6B
ZTfrsPvYsfg/smxmbXYvO2r9PnvUXMY+YM31D2QMW8U+Ze30N6UZG82eZ8X1
FyUva5h4B+N9W8nuN59MPKexr22SwWw+e4c11LfHM6hXktrsYz8fxy7qxeRm
9gH7Xzy/ehWpyz5hX8T+qVeWOmwL+5xd0G+RamxT/B3YJb14OPuQPR37nV5C
bmUfsXfZw+YstpLV0d+TIWwBW8ca6RvlP2w2e4vV1dfJg2w6W8Sq6uulB3uR
LWbV9A3Sk/2XLWHV9VXSOj4Te4mV0afLDewe1pp9F+8ty2BWZ/ck9ropLJ1Z
lTVg+62XsLvNYWwCy6cvlgZsKBvP8uqvSx02iI1lufSlcg8bziay/PoyachG
sEmsgL5I6rLBiT0s9qHZUiWxt8f7m06fJZVYj8TeFHvdDLk1cVbE+XEt9mV2
W+JMiT3nepwbrGKa1HMw9pdkfaZUSOxNcTYm6a/I7Yl9aAhKoy+U2rGHsjEs
pz5f7mT92WiWXZ8jdyT2nNhf0uuvStXEnhP7SwZ9svyhl5eq7PPYB9ivekm5
jW2Od5Rd1svEc8m2sknsql5O7mCfsYnsil42nmm2LfaQlPjw/i/sLsvd1rvY
33otacS+iHeeXdcryp1sVzxPrIjZjHViP1m/xqol9snYEzPqc6V6Yp98lGXS
50kN9jAbxTLrC+QuNoA9yXLoy6URG8kms4L6M3JNrxCfke30853sL72mNGTb
2Q72p14j8ezG/fuM/RTveOKeboznLs4LPa3kY8vjuWPH9PSSn61gj7Fv9dxy
I3s7zhz2o1447n/i9w1lXyfHw+N9MpbG52cn9axSiK2MPZh9F9dIUbaajWKn
9ZxShK1iyc6G3uYi9i6r5ZoCbDz7mB1iD8S5wyayT9kR1pntkTSsHruf7Ynz
lJ2KMyY+N3srznb2Q3w2Kc3ejX2Ufa8XlJvYhtiD2Xm9gJRi6+N8YefiPsVz
ydaxG32WZ+J+s6OsWzwrbDLbxr5hXVkf2aVfT0r9Djsrnon43CxFMrA5bAg7
rP8d770sZkX9vmdj/+XHWPf4v7I+bDHbyO5kxdhzbDs7zh5kfWW3nhx/YzY7
9i72jZ5G8rJl7BF2RL8W3ytkCSvs900yt/KvWRfX9JId+l+p20PSy/EuW+xk
/+j+SdIrrLjFlDhH+AnWI/Z12aunk4zsVT9PcV3f2FfZJnZX7LmsP1vBPmT1
WFY2nK1ln7N7WQ42im1gOxLnahY2jK1hn7GmLBN7JL5jsK2sCcvMhrLVbBtr
zLKzkWwd+4I1Y9nYCPYO287ui/spyawua8b2Wn/CDsX9lGJsUTyf7Hg834l3
Jt6tbexsPGexx7A1cX/ZmXjO4l1na1l7tt96bHzPkJI+R055LM5S1+30sxau
yRjfp+I7AdvC7mb52FNsMzvAOrD87Gm2hR1kHWPvk67sVbaKVYq9RbqwOYnz
N74jXZeH2EK2ntXU0/t9A9gb7CNWn6Vl/djy5NTvOXF2/yPdYr9kb7PKKakP
SS/2Otug1oh9TrqzuWw1qxLnsesGsjfZZtaA5WKPs41sF2vJ8rJx7KPk1HsW
9+4G9iR7n+1lbVgeNpq9x/aw1iw3e4JtYrtZK1aQTYi/KTvMOrFSbHp835CT
rCf7F5sFwNY=
                  "]]}, "Charting`Private`Tag$2968#1"]]}, {}, {}, {}, {}}, {{
              GrayLevel[0], 
              Line[CompressedData["
1:eJwt0bsrR2EcwOHjfr9lkiKbFKsUqxSTsrAxMbAympgJf4CYJUbXn+siud8v
SXId3CXxvGX4nOfUe87b9+0tae1q7IyLoqhX7wrvz7rSUHwU5XKUxZxkBRdY
w0028JwtfGIHf9jDzIQo6mchR1jGcVZxmnVc4jxv+KltvepBM4bZ4Sx3Oce9
8D33wxw84CIPGeMRl3jMZZ5whadc5RnXeM51XnDAvLf80qXe9Kg2c22xiTHW
coqVHGMph1nAPqazm9/2aw9nYDNPWc8NVodzsJwTLArn8981P5SjF90r33zZ
zGNWWGMms5jBDKYzjWlMYSqTmMIEJoc7ZRJ/lRjuJ6yFOWWEaNDj7v/+/wCI
PEiz
               "], VertexColors -> None]}, {
              GrayLevel[0.2], 
              
              Line[{661, 957, 458, 660, 1060, 868, 662, 1061, 869, 663, 1062, 
               870, 664, 1063, 871, 665, 1064, 872, 666, 1065, 873, 667, 465, 
               668, 1066, 874, 669, 1067, 875, 670, 1068, 876, 671, 1069, 877,
                672, 1070, 878, 673, 1057, 1071, 879, 958}, VertexColors -> 
               None], 
              
              Line[{675, 962, 1149, 674, 1072, 880, 676, 1073, 881, 677, 1074,
                882, 678, 1075, 883, 679, 1076, 884, 680, 1077, 885, 681, 963,
                1150, 682, 479, 683, 1078, 886, 684, 1079, 887, 685, 1080, 
               888, 686, 1081, 889, 687, 1082, 890, 688}, VertexColors -> 
               None], 
              
              Line[{690, 964, 1151, 689, 965, 1152, 691, 1083, 891, 692, 1084,
                892, 693, 1085, 893, 694, 1086, 894, 695, 1087, 895, 696, 966,
                1153, 697, 967, 1154, 698, 494, 699, 1088, 896, 700, 1089, 
               897, 701, 1090, 898, 702, 1091, 899, 703}, VertexColors -> 
               None], 
              
              Line[{705, 968, 1155, 704, 969, 1156, 706, 970, 1157, 707, 1092,
                900, 708, 1093, 901, 709, 1094, 902, 710, 1095, 903, 711, 971,
                1158, 712, 972, 1159, 713, 973, 1160, 714, 509, 715, 1096, 
               904, 716, 1097, 905, 717, 1098, 906, 718}, VertexColors -> 
               None], 
              
              Line[{720, 974, 1161, 719, 975, 1162, 721, 976, 1163, 722, 977, 
               1164, 723, 1099, 907, 724, 1100, 908, 725, 1101, 909, 726, 978,
                1165, 727, 979, 1166, 728, 980, 1167, 729, 981, 1168, 730, 
               524, 731, 1102, 910, 732, 1103, 911, 733}, VertexColors -> 
               None], 
              
              Line[{735, 982, 1169, 734, 983, 1170, 736, 984, 1171, 737, 985, 
               1172, 738, 986, 1173, 739, 1104, 912, 740, 1105, 913, 741, 987,
                1174, 742, 988, 1175, 743, 989, 1176, 744, 990, 1177, 745, 
               991, 1178, 746, 539, 747, 1106, 914, 748}, VertexColors -> 
               None], 
              
              Line[{106, 347, 107, 348, 108, 349, 109, 350, 110, 351, 111, 
               352, 112, 353, 113, 354, 114, 355, 115, 356, 116, 357, 117, 
               358, 118, 359, 119, 360, 120}, VertexColors -> None], 
              Line[{750, 992, 1179, 749, 993, 1180, 751, 994, 1181, 752, 995, 
               1182, 753, 996, 1183, 754, 997, 1184, 755, 547, 756, 998, 1185,
                757, 999, 1186, 758, 1000, 1187, 759, 1001, 1188, 760, 1002, 
               1189, 761, 1003, 1190, 762, 554, 763}, VertexColors -> None], 
              
              Line[{765, 555, 764, 1107, 915, 766, 1108, 916, 767, 1109, 917, 
               768, 1110, 918, 769, 1111, 919, 770, 1112, 920, 771, 1004, 
               1191, 772, 1113, 921, 773, 1114, 922, 774, 1115, 923, 775, 
               1116, 924, 776, 1117, 925, 777, 1118, 926, 778}, VertexColors -> 
               None], 
              
              Line[{780, 1005, 1192, 779, 1006, 1193, 781, 1119, 927, 782, 
               1120, 928, 783, 1121, 929, 784, 1122, 930, 785, 1123, 931, 786,
                1007, 1194, 787, 1008, 1195, 788, 1124, 932, 789, 1125, 933, 
               790, 1126, 934, 791, 1127, 935, 792, 1128, 936, 793}, 
               VertexColors -> None], 
              
              Line[{795, 1009, 1196, 794, 1010, 1197, 796, 1011, 1198, 797, 
               1129, 937, 798, 1130, 938, 799, 1131, 939, 800, 1132, 940, 801,
                1012, 1199, 802, 1013, 1200, 803, 1014, 1201, 804, 1133, 941, 
               805, 1134, 942, 806, 1135, 943, 807, 1136, 944, 808}, 
               VertexColors -> None], 
              
              Line[{810, 1015, 1202, 809, 1016, 1203, 811, 1017, 1204, 812, 
               1018, 1205, 813, 1137, 945, 814, 1138, 946, 815, 1139, 947, 
               816, 1019, 1206, 817, 1020, 1207, 818, 1021, 1208, 819, 1022, 
               1209, 820, 1140, 948, 821, 1141, 949, 822, 1142, 950, 823}, 
               VertexColors -> None], 
              
              Line[{825, 1023, 1210, 824, 1024, 1211, 826, 1025, 1212, 827, 
               1026, 1213, 828, 1027, 1214, 829, 1143, 951, 830, 1144, 952, 
               831, 1028, 1215, 832, 1029, 1216, 833, 1030, 1217, 834, 1031, 
               1218, 835, 1032, 1219, 836, 1145, 953, 837, 1146, 954, 838}, 
               VertexColors -> None], 
              
              Line[{840, 1033, 1220, 839, 1034, 1221, 841, 1035, 1222, 842, 
               1036, 1223, 843, 1037, 1224, 844, 1038, 1225, 845, 1147, 955, 
               846, 1039, 1226, 847, 1040, 1227, 848, 1041, 1228, 849, 1042, 
               1229, 850, 1043, 1230, 851, 1044, 1231, 852, 1148, 956, 853}, 
               VertexColors -> None], 
              
              Line[{867, 961, 1245, 1059, 866, 1244, 1056, 865, 1243, 1055, 
               864, 1242, 1054, 863, 1241, 1053, 862, 1240, 1052, 861, 1239, 
               1051, 860, 1238, 1050, 859, 1237, 1049, 858, 1236, 1048, 857, 
               1235, 1047, 856, 1234, 1046, 855, 1233, 1045, 854, 1058, 1232, 
               959, 960}, VertexColors -> None]}, {
              GrayLevel[0.2], 
              
              Line[{251, 459, 1060, 252, 472, 1072, 278, 1152, 486, 292, 1156,
                500, 306, 1162, 514, 320, 1170, 528, 334, 1180, 542, 348, 556,
                1107, 362, 1193, 570, 376, 1197, 584, 390, 1203, 598, 404, 
               1211, 612, 418, 1221, 626, 432, 1233, 640, 446}, VertexColors -> 
               None], 
              
              Line[{253, 460, 1061, 254, 473, 1073, 279, 487, 1083, 293, 1157,
                501, 307, 1163, 515, 321, 1171, 529, 335, 1181, 543, 349, 557,
                1108, 363, 571, 1119, 377, 1198, 585, 391, 1204, 599, 405, 
               1212, 613, 419, 1222, 627, 433, 1234, 641, 447}, VertexColors -> 
               None], 
              
              Line[{255, 461, 1062, 256, 474, 1074, 280, 488, 1084, 294, 502, 
               1092, 308, 1164, 516, 322, 1172, 530, 336, 1182, 544, 350, 558,
                1109, 364, 572, 1120, 378, 586, 1129, 392, 1205, 600, 406, 
               1213, 614, 420, 1223, 628, 434, 1235, 642, 448}, VertexColors -> 
               None], 
              
              Line[{257, 462, 1063, 258, 475, 1075, 281, 489, 1085, 295, 503, 
               1093, 309, 517, 1099, 323, 1173, 531, 337, 1183, 545, 351, 559,
                1110, 365, 573, 1121, 379, 587, 1130, 393, 601, 1137, 407, 
               1214, 615, 421, 1224, 629, 435, 1236, 643, 449}, VertexColors -> 
               None], 
              
              Line[{259, 463, 1064, 260, 476, 1076, 282, 490, 1086, 296, 504, 
               1094, 310, 518, 1100, 324, 532, 1104, 338, 1184, 546, 352, 560,
                1111, 366, 574, 1122, 380, 588, 1131, 394, 602, 1138, 408, 
               616, 1143, 422, 1225, 630, 436, 1237, 644, 450}, VertexColors -> 
               None], 
              
              Line[{261, 464, 1065, 262, 477, 1077, 283, 491, 1087, 297, 505, 
               1095, 311, 519, 1101, 325, 533, 1105, 339, 547, 353, 561, 1112,
                367, 575, 1123, 381, 589, 1132, 395, 603, 1139, 409, 617, 
               1144, 423, 631, 1147, 437, 1238, 645, 451}, VertexColors -> 
               None], 
              
              Line[{8, 667, 23, 681, 38, 696, 53, 711, 68, 726, 83, 741, 98, 
               756, 113, 771, 128, 786, 143, 801, 158, 816, 173, 831, 188, 
               846, 203, 860, 218}, VertexColors -> None], 
              
              Line[{263, 465, 264, 1150, 478, 284, 1153, 492, 298, 1158, 506, 
               312, 1165, 520, 326, 1174, 534, 340, 1185, 548, 354, 1191, 562,
                368, 1194, 576, 382, 1199, 590, 396, 1206, 604, 410, 1215, 
               618, 424, 1226, 632, 438, 1239, 646, 452}, VertexColors -> 
               None], 
              
              Line[{265, 466, 1066, 266, 479, 285, 1154, 493, 299, 1159, 507, 
               313, 1166, 521, 327, 1175, 535, 341, 1186, 549, 355, 563, 1113,
                369, 1195, 577, 383, 1200, 591, 397, 1207, 605, 411, 1216, 
               619, 425, 1227, 633, 439, 1240, 647, 453}, VertexColors -> 
               None], 
              
              Line[{267, 467, 1067, 268, 480, 1078, 286, 494, 300, 1160, 508, 
               314, 1167, 522, 328, 1176, 536, 342, 1187, 550, 356, 564, 1114,
                370, 578, 1124, 384, 1201, 592, 398, 1208, 606, 412, 1217, 
               620, 426, 1228, 634, 440, 1241, 648, 454}, VertexColors -> 
               None], 
              
              Line[{269, 468, 1068, 270, 481, 1079, 287, 495, 1088, 301, 509, 
               315, 1168, 523, 329, 1177, 537, 343, 1188, 551, 357, 565, 1115,
                371, 579, 1125, 385, 593, 1133, 399, 1209, 607, 413, 1218, 
               621, 427, 1229, 635, 441, 1242, 649, 455}, VertexColors -> 
               None], 
              
              Line[{271, 469, 1069, 272, 482, 1080, 288, 496, 1089, 302, 510, 
               1096, 316, 524, 330, 1178, 538, 344, 1189, 552, 358, 566, 1116,
                372, 580, 1126, 386, 594, 1134, 400, 608, 1140, 414, 1219, 
               622, 428, 1230, 636, 442, 1243, 650, 456}, VertexColors -> 
               None], 
              
              Line[{273, 470, 1070, 274, 483, 1081, 289, 497, 1090, 303, 511, 
               1097, 317, 525, 1102, 331, 539, 345, 1190, 553, 359, 567, 1117,
                373, 581, 1127, 387, 595, 1135, 401, 609, 1141, 415, 623, 
               1145, 429, 1231, 637, 443, 1244, 651, 457}, VertexColors -> 
               None], 
              
              Line[{275, 653, 654, 1071, 276, 484, 1082, 290, 498, 1091, 304, 
               512, 1098, 318, 526, 1103, 332, 540, 1106, 346, 554, 360, 568, 
               1118, 374, 582, 1128, 388, 596, 1136, 402, 610, 1142, 416, 624,
                1146, 430, 638, 1148, 444, 1245, 656, 657, 658}, VertexColors -> 
               None], 
              
              Line[{445, 639, 655, 1232, 431, 625, 1220, 417, 611, 1210, 403, 
               597, 1202, 389, 583, 1196, 375, 569, 1192, 361, 555, 347, 541, 
               1179, 333, 527, 1169, 319, 513, 1161, 305, 499, 1155, 291, 485,
                1151, 277, 471, 1149, 250, 458, 652, 659}, VertexColors -> 
               None]}, {}, {}}}, VertexColors -> {
             Hue[0.], 
             Hue[0.01567944665201706], 
             Hue[0.031358893304034116`], 
             Hue[0.04703833995605118], 
             Hue[0.06271778660806823], 
             Hue[0.07839723326008528], 
             Hue[0.09407667991210233], 
             Hue[0.10975612656411939`], 
             Hue[0.12543557321613646`], 
             Hue[0.1411150198681535], 
             Hue[0.15679446652017057`], 
             Hue[0.1724739131721876], 
             Hue[0.18815335982420467`], 
             Hue[0.20383280647622173`], 
             Hue[0.21951225312823885`], 
             Hue[0.006547720477252807], 
             Hue[0.026436412700238967`], 
             Hue[0.04632510492322511], 
             Hue[0.06621379714621128], 
             Hue[0.08610248936919743], 
             Hue[0.10599118159218358`], 
             Hue[0.12587987381516974`], 
             Hue[0.1457685660381559], 
             Hue[0.16565725826114205`], 
             Hue[0.18554595048412817`], 
             Hue[0.20543464270711434`], 
             Hue[0.22532333493010048`], 
             Hue[0.24521202715308663`], 
             Hue[0.26510071937607277`], 
             Hue[0.284989411599059], 
             Hue[0.012921991431858775`], 
             Hue[0.036908426048865], 
             Hue[0.060894860665871214`], 
             Hue[0.08488129528287745], 
             Hue[0.10886772989988368`], 
             Hue[0.13285416451688992`], 
             Hue[0.15684059913389614`], 
             Hue[0.18082703375090234`], 
             Hue[0.20481346836790854`], 
             Hue[0.22879990298491473`], 
             Hue[0.252786337601921], 
             Hue[0.27677277221892715`], 
             Hue[0.3007592068359334], 
             Hue[0.3247456414529396], 
             Hue[0.34873207606994594`], 
             Hue[0.019129614804859984`], 
             Hue[0.047106661311885775`], 
             Hue[0.07508370781891156], 
             Hue[0.10306075432593735`], 
             Hue[0.13103780083296315`], 
             Hue[0.1590148473399889], 
             Hue[0.1869918938470147], 
             Hue[0.2149689403540405], 
             Hue[0.24294598686106625`], 
             Hue[0.270923033368092], 
             Hue[0.2989000798751178], 
             Hue[0.3268771263821436], 
             Hue[0.3548541728891693], 
             Hue[0.3828312193961951], 
             Hue[0.410808265903221], 
             Hue[0.02517704146942584], 
             Hue[0.057041716349106944`], 
             Hue[0.08890639122878805], 
             Hue[0.12077106610846917`], 
             Hue[0.15263574098815025`], 
             Hue[0.18450041586783136`], 
             Hue[0.21636509074751245`], 
             Hue[0.24822976562719354`], 
             Hue[0.2800944405068746], 
             Hue[0.3119591153865557], 
             Hue[0.3438237902662368], 
             Hue[0.37568846514591786`], 
             Hue[0.407553140025599], 
             Hue[0.43941781490528004`], 
             Hue[0.4712824897849613], 
             Hue[0.031070393591860822`], 
             Hue[0.06672364900207929], 
             Hue[0.10237690441229776`], 
             Hue[0.13803015982251624`], 
             Hue[0.17368341523273467`], 
             Hue[0.20933667064295317`], 
             Hue[0.24498992605317158`], 
             Hue[0.28064318146339], 
             Hue[0.3162964368736084], 
             Hue[0.3519496922838269], 
             Hue[0.38760294769404535`], 
             Hue[0.4232562031042639], 
             Hue[0.4589094585144822], 
             Hue[0.4945627139247007], 
             Hue[0.5302159693349193], 
             Hue[0.03681548530498918], 
             Hue[0.07616201105750592], 
             Hue[0.11550853681002264`], 
             Hue[0.1548550625625394], 
             Hue[0.1942015883150561], 
             Hue[0.23354811406757284`], 
             Hue[0.2728946398200895], 
             Hue[0.31224116557260617`], 
             Hue[0.3515876913251229], 
             Hue[0.39093421707763965`], 
             Hue[0.4302807428301563], 
             Hue[0.46962726858267306`], 
             Hue[0.5089737943351899], 
             Hue[0.5483203200877066], 
             Hue[0.5876668458402233], 
             Hue[0.042417841840666604`], 
             Hue[0.08536587967921606], 
             Hue[0.12831391751776552`], 
             Hue[0.171261955356315], 
             Hue[0.21420999319486445`], 
             Hue[0.25715803103341384`], 
             Hue[0.3001060688719633], 
             Hue[0.34305410671051273`], 
             Hue[0.3860021445490621], 
             Hue[0.42895018238761157`], 
             Hue[0.471898220226161], 
             Hue[0.5148462580647105], 
             Hue[0.5577942959032599], 
             Hue[0.6007423337418094], 
             Hue[0.6436903715803589], 
             Hue[0.04788271725376338], 
             Hue[0.09434388652612853], 
             Hue[0.14080505579849367`], 
             Hue[0.18726622507085888`], 
             Hue[0.233727394343224], 
             Hue[0.2801885636155891], 
             Hue[0.32664973288795424`], 
             Hue[0.3731109021603194], 
             Hue[0.4195720714326845], 
             Hue[0.46603324070504965`], 
             Hue[0.5124944099774148], 
             Hue[0.55895557924978], 
             Hue[0.6054167485221451], 
             Hue[0.6518779177945103], 
             Hue[0.6983390870668755], 
             Hue[0.05321511085713103], 
             Hue[0.10310424475254566`], 
             Hue[0.1529933786479603], 
             Hue[0.20288251254337494`], 
             Hue[0.2527716464387895], 
             Hue[0.3026607803342042], 
             Hue[0.35254991422961873`], 
             Hue[0.40243904812503334`], 
             Hue[0.45232818202044794`], 
             Hue[0.5022173159158626], 
             Hue[0.5521064498112772], 
             Hue[0.6019955837066918], 
             Hue[0.6518847176021064], 
             Hue[0.701773851497521], 
             Hue[0.7516629853929359], 
             Hue[0.05841978247561329], 
             Hue[0.11165477406830653`], 
             Hue[0.16488976566099975`], 
             Hue[0.218124757253693], 
             Hue[0.2713597488463862], 
             Hue[0.3245947404390794], 
             Hue[0.37782973203177256`], 
             Hue[0.4310647236244658], 
             Hue[0.48429971521715903`], 
             Hue[0.5375347068098523], 
             Hue[0.5907696984025455], 
             Hue[0.6440046899952387], 
             Hue[0.6972396815879318], 
             Hue[0.750474673180625], 
             Hue[0.8037096647733184], 
             Hue[0.06350126661693213], 
             Hue[0.1200029240195211], 
             Hue[0.1765045814221101], 
             Hue[0.23300623882469904`], 
             Hue[0.28950789622728795`], 
             Hue[0.34600955362987695`], 
             Hue[0.4025112110324659], 
             Hue[0.45901286843505484`], 
             Hue[0.5155145258376438], 
             Hue[0.5720161832402327], 
             Hue[0.6285178406428218], 
             Hue[0.6850194980454107], 
             Hue[0.7415211554479997], 
             Hue[0.7980228128505886], 
             Hue[0.8545244702531777], 
             Hue[0.06846388564812592], 
             Hue[0.12815579563556925`], 
             Hue[0.18784770562301256`], 
             Hue[0.24753961561045593`], 
             Hue[0.3072315255978992], 
             Hue[0.3669234355853424], 
             Hue[0.42661534557278574`], 
             Hue[0.48630725556022897`], 
             Hue[0.5459991655476724], 
             Hue[0.6056910755351156], 
             Hue[0.6653829855225589], 
             Hue[0.7250748955100023], 
             Hue[0.7847668054974455], 
             Hue[0.8444587154848887], 
             Hue[0.9041506254723323], 
             Hue[0.07331176205801516], 
             Hue[0.13612016157457374`], 
             Hue[0.1989285610911323], 
             Hue[0.2617369606076908], 
             Hue[0.3245453601242494], 
             Hue[0.38735375964080787`], 
             Hue[0.45016215915736646`], 
             Hue[0.512970558673925], 
             Hue[0.5757789581904835], 
             Hue[0.6385873577070421], 
             Hue[0.7013957572236006], 
             Hue[0.7642041567401591], 
             Hue[0.8270125562567177], 
             Hue[0.8898209557732762], 
             Hue[0.952629355289835], 
             Hue[0.07804882987881318], 
             Hue[0.1439024848874694], 
             Hue[0.2097561398961256], 
             Hue[0.27560979490478177`], 
             Hue[0.34146344991343797`], 
             Hue[0.4073171049220941], 
             Hue[0.4731707599307503], 
             Hue[0.5390244149394066], 
             Hue[0.6048780699480627], 
             Hue[0.6707317249567187], 
             Hue[0.7365853799653751], 
             Hue[0.8024390349740311], 
             Hue[0.8682926899826874], 
             Hue[0.9341463449913435], 
             Hue[1.], 
             Hue[0.012195125842235695`], 
             Hue[0.0032959809124767404`], 
             Hue[0.24357289401596868`], 
             Hue[0.2524720389457276], 
             Hue[0.10786379722827939`], 
             Hue[0.07569390823046772], 
             Hue[0.944280911171383], 
             Hue[0.9670731724956716], 
             Hue[0.007839723326008522], 
             Hue[0.21167252980223028`], 
             Hue[0.11097565738314126`], 
             Hue[0.9764508001691947], 
             Hue[0.0058391917424138046`], 
             Hue[0.23186239519331034`], 
             Hue[0.09314946421246954], 
             Hue[0.9719844168437665], 
             Hue[0.001653576863693499], 
             Hue[0.21559239146523454`], 
             Hue[0.09451224363097722], 
             Hue[0.9882591381887906], 
             Hue[0.003919861663004259], 
             Hue[0.23604801007203066`], 
             Hue[0.07687474286744553], 
             Hue[0.9835365862478358], 
             Hue[0.023950326172365696`], 
             Hue[0.02743903164102984], 
             Hue[0.04135293186747857], 
             Hue[0.041158547461544764`], 
             Hue[0.05875553756259147], 
             Hue[0.0548780632820597], 
             Hue[0.07615814325770434], 
             Hue[0.06859757910257461], 
             Hue[0.09356074895281721], 
             Hue[0.08231709492308954], 
             Hue[0.1109633546479301], 
             Hue[0.09603661074360448], 
             Hue[0.128365960343043], 
             Hue[0.12347564238463431`], 
             Hue[0.16317117173326878`], 
             Hue[0.13719515820514924`], 
             Hue[0.18057377742838165`], 
             Hue[0.1509146740256642], 
             Hue[0.19797638312349455`], 
             Hue[0.16463418984617909`], 
             Hue[0.21537898881860743`], 
             Hue[0.17835370566669403`], 
             Hue[0.2327815945137203], 
             Hue[0.19207322148720896`], 
             Hue[0.25018420020883314`], 
             Hue[0.20579273730772388`], 
             Hue[0.26758680590394607`], 
             Hue[0.033910121721739225`], 
             Hue[0.05489825201161966], 
             Hue[0.0758863823015001], 
             Hue[0.09687451259138054], 
             Hue[0.11786264288126101`], 
             Hue[0.13885077317114145`], 
             Hue[0.1598389034610219], 
             Hue[0.20181516404078279`], 
             Hue[0.2228032943306632], 
             Hue[0.24379142462054368`], 
             Hue[0.2647795549104241], 
             Hue[0.2857676852003045], 
             Hue[0.306755815490185], 
             Hue[0.3277439457800654], 
             Hue[0.04360953049850755], 
             Hue[0.06808944619215511], 
             Hue[0.09256936188580267], 
             Hue[0.11704927757945023`], 
             Hue[0.1415291932730978], 
             Hue[0.16600910896674534`], 
             Hue[0.1904890246603929], 
             Hue[0.23944885604768804`], 
             Hue[0.26392877174133555`], 
             Hue[0.2884086874349831], 
             Hue[0.3128886031286307], 
             Hue[0.33736851882227825`], 
             Hue[0.3618484345159258], 
             Hue[0.3863283502095734], 
             Hue[0.0530586319891468], 
             Hue[0.08094022250886776], 
             Hue[0.10882181302858872`], 
             Hue[0.1367034035483097], 
             Hue[0.16458499406803068`], 
             Hue[0.19246658458775165`], 
             Hue[0.22034817510747257`], 
             Hue[0.27611135614691446`], 
             Hue[0.3039929466666354], 
             Hue[0.3318745371863564], 
             Hue[0.35975612770607734`], 
             Hue[0.38763771822579834`], 
             Hue[0.4155193087455193], 
             Hue[0.44340089926524023`], 
             Hue[0.06226699207580198], 
             Hue[0.09346359055974311], 
             Hue[0.12466018904368427`], 
             Hue[0.15585678752762544`], 
             Hue[0.18705338601156657`], 
             Hue[0.21824998449550773`], 
             Hue[0.2494465829794489], 
             Hue[0.31183977994733114`], 
             Hue[0.34303637843127227`], 
             Hue[0.37423297691521346`], 
             Hue[0.40542957539915464`], 
             Hue[0.43662617388309577`], 
             Hue[0.46782277236703695`], 
             Hue[0.4990193708509781], 
             Hue[0.07124369533844133], 
             Hue[0.10567190537189346`], 
             Hue[0.1401001154053456], 
             Hue[0.17452832543879773`], 
             Hue[0.20895653547224985`], 
             Hue[0.24338474550570197`], 
             Hue[0.2778129555391541], 
             Hue[0.34666937560605837`], 
             Hue[0.38109758563951046`], 
             Hue[0.4155257956729626], 
             Hue[0.4499540057064148], 
             Hue[0.4843822157398669], 
             Hue[0.518810425773319], 
             Hue[0.5532386358067712], 
             Hue[0.07999737494939738], 
             Hue[0.11757690805812814`], 
             Hue[0.15515644116685892`], 
             Hue[0.19273597427558967`], 
             Hue[0.23031550738432047`], 
             Hue[0.2678950404930512], 
             Hue[0.30547457360178193`], 
             Hue[0.3806336398192435], 
             Hue[0.4182131729279742], 
             Hue[0.455792706036705], 
             Hue[0.49337223914543576`], 
             Hue[0.5309517722541666], 
             Hue[0.5685313053628973], 
             Hue[0.6061108384716282], 
             Hue[0.08853624036708287], 
             Hue[0.12918976348040237`], 
             Hue[0.16984328659372191`], 
             Hue[0.2104968097070414], 
             Hue[0.25115033282036087`], 
             Hue[0.29180385593368036`], 
             Hue[0.33245737904699985`], 
             Hue[0.4137644252736388], 
             Hue[0.45441794838695837`], 
             Hue[0.4950714715002778], 
             Hue[0.5357249946135975], 
             Hue[0.576378517726917], 
             Hue[0.6170320408402364], 
             Hue[0.6576855639535559], 
             Hue[0.09686810301561882], 
             Hue[0.1405210951741066], 
             Hue[0.18417408733259444`], 
             Hue[0.2278270794910822], 
             Hue[0.27148007164957], 
             Hue[0.3151330638080578], 
             Hue[0.35878605596654556`], 
             Hue[0.4460920402835211], 
             Hue[0.4897450324420089], 
             Hue[0.5333980246004968], 
             Hue[0.5770510167589845], 
             Hue[0.6207040089174725], 
             Hue[0.6643570010759601], 
             Hue[0.7080099932344479], 
             Hue[0.10500040011921984`], 
             Hue[0.15158101776282645`], 
             Hue[0.198161635406433], 
             Hue[0.24474225305003958`], 
             Hue[0.2913228706936461], 
             Hue[0.33790348833725264`], 
             Hue[0.3844841059808592], 
             Hue[0.4776453412680724], 
             Hue[0.524225958911679], 
             Hue[0.5708065765552855], 
             Hue[0.6173871941988921], 
             Hue[0.6639678118424986], 
             Hue[0.7105484294861051], 
             Hue[0.7571290471297119], 
             Hue[0.11294021684419746`], 
             Hue[0.1623791670714628], 
             Hue[0.21181811729872815`], 
             Hue[0.2612570675259935], 
             Hue[0.31069601775325884`], 
             Hue[0.36013496798052413`], 
             Hue[0.4095739182077895], 
             Hue[0.5084518186623203], 
             Hue[0.5578907688895856], 
             Hue[0.607329719116851], 
             Hue[0.6567686693441164], 
             Hue[0.7062076195713817], 
             Hue[0.7556465697986471], 
             Hue[0.8050855200259124], 
             Hue[0.1206943068871388], 
             Hue[0.17292472812615173`], 
             Hue[0.2251551493651646], 
             Hue[0.27738557060417746`], 
             Hue[0.32961599184319035`], 
             Hue[0.3818464130822032], 
             Hue[0.4340768343212162], 
             Hue[0.5385376767992419], 
             Hue[0.5907680980382549], 
             Hue[0.6429985192772678], 
             Hue[0.6952289405162807], 
             Hue[0.7474593617552936], 
             Hue[0.7996897829943064], 
             Hue[0.8519202042333193], 
             Hue[0.1282691116350039], 
             Hue[0.18322646121199265`], 
             Hue[0.23818381078898135`], 
             Hue[0.29314116036597004`], 
             Hue[0.3480985099429588], 
             Hue[0.40305585951994755`], 
             Hue[0.4580132090969362], 
             Hue[0.5679279082509138], 
             Hue[0.6228852578279026], 
             Hue[0.6778426074048911], 
             Hue[0.7327999569818798], 
             Hue[0.7877573065588687], 
             Hue[0.8427146561358574], 
             Hue[0.8976720057128461], 
             Hue[0.13567077801138736`], 
             Hue[0.19329272614396154`], 
             Hue[0.25091467427653563`], 
             Hue[0.30853662240910984`], 
             Hue[0.366158570541684], 
             Hue[0.42378051867425814`], 
             Hue[0.48140246680683224`], 
             Hue[0.5966463630719807], 
             Hue[0.6542683112045549], 
             Hue[0.711890259337129], 
             Hue[0.7695122074697031], 
             Hue[0.8271341556022773], 
             Hue[0.8847561037348516], 
             Hue[0.02287609098573815], 
             Hue[0.038663690355423094`], 
             Hue[0.053143208205394823`], 
             Hue[0.06657041466262427], 
             Hue[0.07894530972711145], 
             Hue[0.09026789339885637], 
             Hue[0.10053816567785903`], 
             Hue[0.15866961679901423`], 
             Hue[0.17051835616713026`], 
             Hue[0.18131478414250407`], 
             Hue[0.1910589007251356], 
             Hue[0.19975070591502483`], 
             Hue[0.2073901997121718], 
             Hue[0.033113337852413466`], 
             Hue[0.05228024867446314], 
             Hue[0.07042272389800779], 
             Hue[0.08754076352304745], 
             Hue[0.10363436754958207`], 
             Hue[0.1187035359776117], 
             Hue[0.1327482688071363], 
             Hue[0.19743285557668946`], 
             Hue[0.2130142418039716], 
             Hue[0.22757119243274873`], 
             Hue[0.24110370746302082`], 
             Hue[0.25361178689478786`], 
             Hue[0.26509543072805], 
             Hue[0.275554638962807], 
             Hue[0.04283357757688239], 
             Hue[0.06553988737639992], 
             Hue[0.08724854420341252], 
             Hue[0.10795954805792025`], 
             Hue[0.12767289893992312`], 
             Hue[0.14638859684942107`], 
             Hue[0.16410664178641418`], 
             Hue[0.2351811177222958], 
             Hue[0.25439564211804616`], 
             Hue[0.2726125135412917], 
             Hue[0.2898317319920323], 
             Hue[0.3060532974702681], 
             Hue[0.3212772099759989], 
             Hue[0.3355034695092248], 
             Hue[0.052302703656076074`], 
             Hue[0.07845645874956246], 
             Hue[0.10363830674988501`], 
             Hue[0.12784824765704378`], 
             Hue[0.1510862814710387], 
             Hue[0.17335240819186976`], 
             Hue[0.19464662781953704`], 
             Hue[0.27195375298777036`], 
             Hue[0.2947058332551834], 
             Hue[0.3164860064294325], 
             Hue[0.33729427251051786`], 
             Hue[0.35713063149843943`], 
             Hue[0.3759950833931971], 
             Hue[0.39388762819479095`], 
             Hue[0.061530323060497605`], 
             Hue[0.09104310739650004], 
             Hue[0.11960874659986813`], 
             Hue[0.1472272406706019], 
             Hue[0.1738985896087013], 
             Hue[0.1996227934141664], 
             Hue[0.22439985208699714`], 
             Hue[0.30778810296780656`], 
             Hue[0.3339858793395889], 
             Hue[0.3592365105787368], 
             Hue[0.3835399966852504], 
             Hue[0.40689633765912964`], 
             Hue[0.4293055335003746], 
             Hue[0.45076758420898505`], 
             Hue[0.07052555887430026], 
             Hue[0.10331231485803678`], 
             Hue[0.13517575325619874`], 
             Hue[0.16611587406878614`], 
             Hue[0.19613267729579895`], 
             Hue[0.2252261629372372], 
             Hue[0.2533963309931009], 
             Hue[0.3427196275924063], 
             Hue[0.37227477202663184`], 
             Hue[0.4009065988752829], 
             Hue[0.4286151081383593], 
             Hue[0.45540029981586116`], 
             Hue[0.4812621739077884], 
             Hue[0.5062007304141412], 
             Hue[0.0792970803824377], 
             Hue[0.11527594090270059`], 
             Hue[0.15035442340145533`], 
             Hue[0.18453252787870186`], 
             Hue[0.21781025433444023`], 
             Hue[0.25018760276867036`], 
             Hue[0.2816645731813924], 
             Hue[0.3767820221770052], 
             Hue[0.40960955962198947`], 
             Hue[0.4415367190454656], 
             Hue[0.47256350044743345`], 
             Hue[0.5026899038278932], 
             Hue[0.5319159291868448], 
             Hue[0.5602415765242882], 
             Hue[0.08785313094044576], 
             Hue[0.12694526176867427`], 
             Hue[0.16515910973844883`], 
             Hue[0.20249467484976946`], 
             Hue[0.23895195710263614`], 
             Hue[0.2745309564970489], 
             Hue[0.30923167303300775`], 
             Hue[0.410007325842413], 
             Hue[0.4460254666660528], 
             Hue[0.4811653246312387], 
             Hue[0.5154268997379706], 
             Hue[0.5488101919862486], 
             Hue[0.5813152013760726], 
             Hue[0.6129419279074427], 
             Hue[0.09620155381519788], 
             Hue[0.13833100561750233`], 
             Hue[0.17960346626404441`], 
             Hue[0.22001893575482415`], 
             Hue[0.2595774140898415], 
             Hue[0.2982789012690965], 
             Hue[0.3361233972925891], 
             Hue[0.4424260220379319], 
             Hue[0.48155600479506805`], 
             Hue[0.519828996396442], 
             Hue[0.5572449968420534], 
             Hue[0.5938040061319025], 
             Hue[0.6295060242659892], 
             Hue[0.6643510512443136], 
             Hue[0.1043498161669096], 
             Hue[0.14944338543388622`], 
             Hue[0.1937004902765432], 
             Hue[0.23712113069488053`], 
             Hue[0.27970530668889815`], 
             Hue[0.3214530182585962], 
             Hue[0.3623642654039746], 
             Hue[0.47406713183064336`], 
             Hue[0.5162330756125012], 
             Hue[0.5575625549700395], 
             Hue[0.598055569903258], 
             Hue[0.6377121204121569], 
             Hue[0.6765322064967362], 
             Hue[0.7145158281569958], 
             Hue[0.11230503132653259`], 
             Hue[0.16029212958365918`], 
             Hue[0.20746256138831176`], 
             Hue[0.2538163267404904], 
             Hue[0.2993534256401952], 
             Hue[0.344073858087426], 
             Hue[0.38797762408218284`], 
             Hue[0.5049583005609967], 
             Hue[0.5500870662344644], 
             Hue[0.5943991654554583], 
             Hue[0.6378945982239782], 
             Hue[0.6805733645400242], 
             Hue[0.7224354644035962], 
             Hue[0.7634808978146943], 
             Hue[0.1200739795082396], 
             Hue[0.17088651022213966`], 
             Hue[0.22090147778982613`], 
             Hue[0.27011888221129904`], 
             Hue[0.3185387234865583], 
             Hue[0.3661610016156041], 
             Hue[0.4129857165984363], 
             Hue[0.5351258784085953], 
             Hue[0.5831469381107478], 
             Hue[0.6303704346666867], 
             Hue[0.6767963680764122], 
             Hue[0.7224247383399239], 
             Hue[0.7672555454572221], 
             Hue[0.8112887894283067], 
             Hue[0.12766312708376773`], 
             Hue[0.18123536972724152`], 
             Hue[0.23402848998843642`], 
             Hue[0.2860424878673526], 
             Hue[0.3372773633639899], 
             Hue[0.38773311647834835`], 
             Hue[0.43740974721042813`], 
             Hue[0.5645949953617018], 
             Hue[0.6154403096671998], 
             Hue[0.6655065015904187], 
             Hue[0.7147935711313592], 
             Hue[0.7633015182900207], 
             Hue[0.8110303430664032], 
             Hue[0.8579800454605071], 
             Hue[0.1348928129726719], 
             Hue[0.19134714531573757`], 
             Hue[0.24685433222466321`], 
             Hue[0.30160020526056436`], 
             Hue[0.3555847644234411], 
             Hue[0.4088080097132934], 
             Hue[0.46126994113012143`], 
             Hue[0.5933896310387954], 
             Hue[0.6469935332651601], 
             Hue[0.6998361216185002], 
             Hue[0.7519173960988159], 
             Hue[0.8032373567061074], 
             Hue[0.8537960034403742], 
             Hue[0.01480836644957172], 
             Hue[0.21376782836115857`], 
             Hue[0.2597187630360467], 
             Hue[0.12905607048800014`], 
             Hue[0.9034359446228031], 
             Hue[0.9366799865363534], 
             Hue[0.9423780518674256], 
             Hue[0.013719515820514925`], 
             Hue[0.02509179194421123], 
             Hue[0.005734785586058794], 
             Hue[0.04445432847082624], 
             Hue[0.06381686499744127], 
             Hue[0.08317940152405627], 
             Hue[0.10254193805067131`], 
             Hue[0.12190447457728633`], 
             Hue[0.14126701110390136`], 
             Hue[0.16062954763051637`], 
             Hue[0.17999208415713136`], 
             Hue[0.19935462068374638`], 
             Hue[0.21871715721036136`], 
             Hue[0.23807969373697638`], 
             Hue[0.25744223026359137`], 
             Hue[0.034290422711708485`], 
             Hue[0.011328423693207284`], 
             Hue[0.05725242173020968], 
             Hue[0.08021442074871092], 
             Hue[0.1031764197672121], 
             Hue[0.12613841878571333`], 
             Hue[0.14910041780421454`], 
             Hue[0.17206241682271572`], 
             Hue[0.19502441584121694`], 
             Hue[0.21798641485971812`], 
             Hue[0.24094841387821933`], 
             Hue[0.2639104128967205], 
             Hue[0.28687241191522167`], 
             Hue[0.3098344109337229], 
             Hue[0.3327964099522242], 
             Hue[0.043282323088252986`], 
             Hue[0.016801756039984534`], 
             Hue[0.06976289013652143], 
             Hue[0.09624345718478991], 
             Hue[0.12272402423305835`], 
             Hue[0.1492045912813268], 
             Hue[0.17568515832959522`], 
             Hue[0.2021657253778637], 
             Hue[0.22864629242613213`], 
             Hue[0.25512685947440056`], 
             Hue[0.281607426522669], 
             Hue[0.30808799357093747`], 
             Hue[0.33456856061920587`], 
             Hue[0.3610491276674743], 
             Hue[0.3875296947157429], 
             Hue[0.05207418883049636], 
             Hue[0.02215332813714291], 
             Hue[0.08199504952384981], 
             Hue[0.11191591021720328`], 
             Hue[0.1418367709105567], 
             Hue[0.17175763160391017`], 
             Hue[0.2016784922972636], 
             Hue[0.23159935299061704`], 
             Hue[0.26152021368397044`], 
             Hue[0.29144107437732386`], 
             Hue[0.3213619350706773], 
             Hue[0.3512827957640307], 
             Hue[0.3812036564573842], 
             Hue[0.4111245171507376], 
             Hue[0.44104537784409115`], 
             Hue[0.060672441093971574`], 
             Hue[0.02738704851533896], 
             Hue[0.09395783367260419], 
             Hue[0.12724322625123682`], 
             Hue[0.1605286188298694], 
             Hue[0.19381401140850205`], 
             Hue[0.22709940398713466`], 
             Hue[0.26038479656576724`], 
             Hue[0.2936701891443998], 
             Hue[0.3269555817230324], 
             Hue[0.360240974301665], 
             Hue[0.39352636688029763`], 
             Hue[0.42681175945893024`], 
             Hue[0.4600971520375628], 
             Hue[0.4933825446161955], 
             Hue[0.06908323951593595], 
             Hue[0.03250666652014292], 
             Hue[0.10565981251172897`], 
             Hue[0.14223638550752207`], 
             Hue[0.17881295850331508`], 
             Hue[0.2153895314991081], 
             Hue[0.2519661044949011], 
             Hue[0.28854267749069407`], 
             Hue[0.32511925048648704`], 
             Hue[0.3616958234822801], 
             Hue[0.3982723964780731], 
             Hue[0.4348489694738662], 
             Hue[0.4714255424696591], 
             Hue[0.5080021154654523], 
             Hue[0.5445786884612454], 
             Hue[0.07731249463521969], 
             Hue[0.03751577987194886], 
             Hue[0.1171092093984905], 
             Hue[0.15690592416176136`], 
             Hue[0.19670263892503215`], 
             Hue[0.23649935368830297`], 
             Hue[0.27629606845157373`], 
             Hue[0.3160927832148445], 
             Hue[0.35588949797811537`], 
             Hue[0.39568621274138616`], 
             Hue[0.43548292750465695`], 
             Hue[0.4752796422679278], 
             Hue[0.5150763570311986], 
             Hue[0.5548730717944694], 
             Hue[0.5946697865577404], 
             Hue[0.09322163567026447], 
             Hue[0.047199607827126275`], 
             Hue[0.13924366351340264`], 
             Hue[0.1852656913565409], 
             Hue[0.23128771919967903`], 
             Hue[0.2773097470428172], 
             Hue[0.3233317748859554], 
             Hue[0.36935380272909357`], 
             Hue[0.4153758305722317], 
             Hue[0.4613978584153699], 
             Hue[0.5074198862585081], 
             Hue[0.5534419141016462], 
             Hue[0.5994639419447845], 
             Hue[0.6454859697879226], 
             Hue[0.6915079976310609], 
             Hue[0.10091415519594137`], 
             Hue[0.05188201245628911], 
             Hue[0.14994629793559364`], 
             Hue[0.19897844067524592`], 
             Hue[0.24801058341489815`], 
             Hue[0.29704272615455035`], 
             Hue[0.3460748688942026], 
             Hue[0.39510701163385475`], 
             Hue[0.4441391543735071], 
             Hue[0.49317129711315927`], 
             Hue[0.5422034398528116], 
             Hue[0.5912355825924638], 
             Hue[0.6402677253321161], 
             Hue[0.6892998680717682], 
             Hue[0.7383320108114206], 
             Hue[0.10844832557489618`], 
             Hue[0.05646803061868243], 
             Hue[0.16042862053110993`], 
             Hue[0.21240891548732374`], 
             Hue[0.2643892104435374], 
             Hue[0.3163695053997511], 
             Hue[0.3683498003559648], 
             Hue[0.4203300953121786], 
             Hue[0.4723103902683923], 
             Hue[0.5242906852246061], 
             Hue[0.5762709801808198], 
             Hue[0.6282512751370335], 
             Hue[0.6802315700932472], 
             Hue[0.7322118650494609], 
             Hue[0.7841921600056748], 
             Hue[0.11582884904391379`], 
             Hue[0.060960524546272696`], 
             Hue[0.1706971735415549], 
             Hue[0.22556549803919598`], 
             Hue[0.2804338225368371], 
             Hue[0.33530214703447814`], 
             Hue[0.39017047153211915`], 
             Hue[0.44503879602976026`], 
             Hue[0.4999071205274013], 
             Hue[0.5547754450250424], 
             Hue[0.6096437695226835], 
             Hue[0.6645120940203246], 
             Hue[0.7193804185179656], 
             Hue[0.7742487430156066], 
             Hue[0.8291170675132479], 
             Hue[0.12306025087553911`], 
             Hue[0.06536224875362978], 
             Hue[0.18075825299744847`], 
             Hue[0.23845625511935778`], 
             Hue[0.29615425724126715`], 
             Hue[0.3538522593631764], 
             Hue[0.4115502614850857], 
             Hue[0.469248263606995], 
             Hue[0.5269462657289045], 
             Hue[0.5846442678508138], 
             Hue[0.6423422699727231], 
             Hue[0.7000402720946325], 
             Hue[0.7577382742165417], 
             Hue[0.8154362763384511], 
             Hue[0.8731342784603605], 
             Hue[0.13014688712032033`], 
             Hue[0.0696758547505982], 
             Hue[0.19061791949004245`], 
             Hue[0.25108895185976454`], 
             Hue[0.31155998422948666`], 
             Hue[0.37203101659920873`], 
             Hue[0.43250204896893085`], 
             Hue[0.49297308133865286`], 
             Hue[0.5534441137083751], 
             Hue[0.613915146078097], 
             Hue[0.6743861784478191], 
             Hue[0.7348572108175413], 
             Hue[0.7953282431872634], 
             Hue[0.8557992755569853], 
             Hue[0.9162703079267077], 
             Hue[0.13709295198868565`], 
             Hue[0.2002820084417564], 
             Hue[0.26347106489482713`], 
             Hue[0.3266601213478979], 
             Hue[0.3898491778009686], 
             Hue[0.4530382342540394], 
             Hue[0.5162272907071102], 
             Hue[0.5794163471601808], 
             Hue[0.6426054036132516], 
             Hue[0.7057944600663222], 
             Hue[0.7689835165193929], 
             Hue[0.8321725729724637], 
             Hue[0.8953616294255344], 
             Hue[0.9585847165096747], 
             Hue[0.042494397639324125`], 
             Hue[0.061856934165939154`], 
             Hue[0.08121947069255414], 
             Hue[0.10058200721916917`], 
             Hue[0.11994454374578419`], 
             Hue[0.13930708027239924`], 
             Hue[0.17803215332562922`], 
             Hue[0.19739468985224426`], 
             Hue[0.21675722637885925`], 
             Hue[0.2361197629054743], 
             Hue[0.2554822994320893], 
             Hue[0.2746352822032864], 
             Hue[0.05228024867446318], 
             Hue[0.07524224769296438], 
             Hue[0.09820424671146559], 
             Hue[0.12116624572996677`], 
             Hue[0.144128244748468], 
             Hue[0.1670902437669692], 
             Hue[0.23597624082247284`], 
             Hue[0.25893823984097397`], 
             Hue[0.2819002388594752], 
             Hue[0.30486223787797634`], 
             Hue[0.32782423689647766`], 
             Hue[0.08724854420341256], 
             Hue[0.11372911125168102`], 
             Hue[0.14020967829994946`], 
             Hue[0.16669024534821789`], 
             Hue[0.19317081239648637`], 
             Hue[0.2990930805895602], 
             Hue[0.32557364763782864`], 
             Hue[0.35205421468609693`], 
             Hue[0.3785347817343655], 
             Hue[0.12784824765704383`], 
             Hue[0.15776910835039729`], 
             Hue[0.18768996904375068`], 
             Hue[0.21761082973710416`], 
             Hue[0.36721513320387134`], 
             Hue[0.3971359938972247], 
             Hue[0.4270568545905783], 
             Hue[0.1738985896087014], 
             Hue[0.20718398218733397`], 
             Hue[0.24046937476596655`], 
             Hue[0.4401817302377622], 
             Hue[0.4734671228163948], 
             Hue[0.22522616293723732`], 
             Hue[0.2618027359330302], 
             Hue[0.5178387469035814], 
             Hue[0.13387515878358391`], 
             Hue[0.1798971866267222], 
             Hue[0.22591921446986032`], 
             Hue[0.2719412423129985], 
             Hue[0.3179632701561366], 
             Hue[0.3639852979992748], 
             Hue[0.45602935368555114`], 
             Hue[0.5020513815286894], 
             Hue[0.5480734093718276], 
             Hue[0.5940954372149657], 
             Hue[0.640117465058104], 
             Hue[0.6861394929012422], 
             Hue[0.1873631483571545], 
             Hue[0.23639529109680676`], 
             Hue[0.28542743383645897`], 
             Hue[0.33445957657611125`], 
             Hue[0.3834917193157634], 
             Hue[0.5305881475347202], 
             Hue[0.5796202902743725], 
             Hue[0.6286524330140247], 
             Hue[0.6776845757536769], 
             Hue[0.7267167184933294], 
             Hue[0.24568078523275685`], 
             Hue[0.29766108018897053`], 
             Hue[0.34964137514518423`], 
             Hue[0.401621670101398], 
             Hue[0.609542849926253], 
             Hue[0.6615231448824667], 
             Hue[0.7135034398386804], 
             Hue[0.7654837347948942], 
             Hue[0.3086846512381313], 
             Hue[0.36355297573577244`], 
             Hue[0.4184213002334134], 
             Hue[0.6927629227216189], 
             Hue[0.7476312472192599], 
             Hue[0.8024995717169011], 
             Hue[0.37623672560846744`], 
             Hue[0.4339347277303767], 
             Hue[0.7801227404618327], 
             Hue[0.8378207425837422], 
             Hue[0.44820414884807], 
             Hue[0.8715013754361248], 
             Hue[0.007959571818498528], 
             Hue[0.27686006843572614`], 
             Hue[0.08194977085058092], 
             Hue[0.07390729860112828], 
             Hue[0.950542244260222], 
             Hue[0.029318249655961946`], 
             Hue[0.1900522427854704], 
             Hue[0.03428741010687565], 
             Hue[0.060767977155144134`], 
             Hue[0.2196513794447548], 
             Hue[0.2461319464930232], 
             Hue[0.03808566557698348], 
             Hue[0.06800652627033693], 
             Hue[0.09792738696369037], 
             Hue[0.2475316904304576], 
             Hue[0.277452551123811], 
             Hue[0.3073734118171644], 
             Hue[0.0407570192941709], 
             Hue[0.07404241187280354], 
             Hue[0.10732780445143612`], 
             Hue[0.14061319703006875`], 
             Hue[0.27375476734459914`], 
             Hue[0.30704015992323175`], 
             Hue[0.3403255525018644], 
             Hue[0.373610945080497], 
             Hue[0.04234329795827213], 
             Hue[0.07891987095406515], 
             Hue[0.11549644394985818`], 
             Hue[0.15207301694565128`], 
             Hue[0.18864958994144426`], 
             Hue[0.29837930892882325`], 
             Hue[0.33495588192461634`], 
             Hue[0.37153245492040926`], 
             Hue[0.4081090279162024], 
             Hue[0.4446856009119954], 
             Hue[0.042884284601767575`], 
             Hue[0.0826809993650384], 
             Hue[0.12247771412830923`], 
             Hue[0.16227442889158006`], 
             Hue[0.20207114365485085`], 
             Hue[0.24186785841812167`], 
             Hue[0.3214612879446633], 
             Hue[0.36125800270793407`], 
             Hue[0.4010547174712049], 
             Hue[0.4408514322344757], 
             Hue[0.48064814699774644`], 
             Hue[0.5204448617610173], 
             Hue[0.4100073258424129], 
             Hue[0.08929886287785004], 
             Hue[0.13833100561750222`], 
             Hue[0.43252386205541576`], 
             Hue[0.48155600479506794`], 
             Hue[0.08973990036411561], 
             Hue[0.1417201953203293], 
             Hue[0.1937004902765431], 
             Hue[0.4536019650576117], 
             Hue[0.5055822600138254], 
             Hue[0.5575625549700394], 
             Hue[0.08921135324756704], 
             Hue[0.14407967774520808`], 
             Hue[0.19894800224284917`], 
             Hue[0.2538163267404903], 
             Hue[0.47328962473105457`], 
             Hue[0.5281579492286956], 
             Hue[0.5830262737263369], 
             Hue[0.6378945982239778], 
             Hue[0.08774671499892081], 
             Hue[0.14544471712083012`], 
             Hue[0.2031427192427395], 
             Hue[0.26084072136464886`], 
             Hue[0.31853872348655804`], 
             Hue[0.49163272985228607`], 
             Hue[0.5493307319741955], 
             Hue[0.6070287340961048], 
             Hue[0.6647267362180141], 
             Hue[0.7224247383399235], 
             Hue[0.08537795462973759], 
             Hue[0.1458489869994597], 
             Hue[0.20632001936918182`], 
             Hue[0.26679105173890394`], 
             Hue[0.32726208410862595`], 
             Hue[0.387733116478348], 
             Hue[0.5086751812177923], 
             Hue[0.5691462135875144], 
             Hue[0.6296172459572364], 
             Hue[0.6900882783269586], 
             Hue[0.7505593106966807], 
             Hue[0.8110303430664026], 
             Hue[0.14532465886476736`], 
             Hue[0.20851371531783816`], 
             Hue[0.27170277177090885`], 
             Hue[0.3348918282239796], 
             Hue[0.3980808846770502], 
             Hue[0.46126994113012104`], 
             Hue[0.5244589975831918], 
             Hue[0.5876480540362625], 
             Hue[0.6508371104893333], 
             Hue[0.714026166942404], 
             Hue[0.7772152233954747], 
             Hue[0.8404042798485455], 
             Hue[0.25971876303604674`], 
             Hue[0.12905607048800036`], 
             Hue[0.9034359446228025], 
             Hue[0.04000831111145084], 
             Hue[0.0568847611101926], 
             Hue[0.07376121110893433], 
             Hue[0.09063766110767607], 
             Hue[0.10751411110641783`], 
             Hue[0.1243905611051596], 
             Hue[0.17554606679775597`], 
             Hue[0.19242251679649774`], 
             Hue[0.20929896679523946`], 
             Hue[0.2261754167939812], 
             Hue[0.24305186679272298`], 
             Hue[0.2597187630360468], 
             Hue[0.05228024867446315], 
             Hue[0.07224394336583857], 
             Hue[0.092207638057214], 
             Hue[0.11217133274858944`], 
             Hue[0.13213502743996489`], 
             Hue[0.1520987221313403], 
             Hue[0.232977936495347], 
             Hue[0.2529416311867224], 
             Hue[0.27290532587809785`], 
             Hue[0.2928690205694733], 
             Hue[0.3128327152608487], 
             Hue[0.08724854420341253], 
             Hue[0.11023198043830275`], 
             Hue[0.133215416673193], 
             Hue[0.15619885290808322`], 
             Hue[0.17918228914297346`], 
             Hue[0.2955959497761819], 
             Hue[0.31857938601107216`], 
             Hue[0.34156282224596235`], 
             Hue[0.36454625848085254`], 
             Hue[0.1278482476570438], 
             Hue[0.15378602399043712`], 
             Hue[0.1797238003238304], 
             Hue[0.2056615766572237], 
             Hue[0.36323204884391125`], 
             Hue[0.38916982517730453`], 
             Hue[0.4151076015106978], 
             Hue[0.17389858960870133`], 
             Hue[0.20272732526105663`], 
             Hue[0.23155606091341194`], 
             Hue[0.4357250733114849], 
             Hue[0.4645538089638402], 
             Hue[0.22522616293723727`], 
             Hue[0.2568844202139656], 
             Hue[0.5129204311845169], 
             Hue[0.1280675126245383], 
             Hue[0.16828189430863086`], 
             Hue[0.20849627599272338`], 
             Hue[0.24871065767681597`], 
             Hue[0.28892503936090846`], 
             Hue[0.329139421045001], 
             Hue[0.4502217075265056], 
             Hue[0.49043608921059806`], 
             Hue[0.5306504708946906], 
             Hue[0.5708648525787833], 
             Hue[0.6110792342628758], 
             Hue[0.6512936159469682], 
             Hue[0.18112700662022774`], 
             Hue[0.22392300762295317`], 
             Hue[0.26671900862567854`], 
             Hue[0.30951500962840395`], 
             Hue[0.3523110106311294], 
             Hue[0.5243520057977935], 
             Hue[0.5671480068005189], 
             Hue[0.6099440078032444], 
             Hue[0.6527400088059697], 
             Hue[0.6955360098086951], 
             Hue[0.23902641128367028`], 
             Hue[0.2843523322907973], 
             Hue[0.32967825329792433`], 
             Hue[0.3750041743050515], 
             Hue[0.6028884759771664], 
             Hue[0.6482143969842935], 
             Hue[0.6935403179914206], 
             Hue[0.7388662389985478], 
             Hue[0.30162194406280785`], 
             Hue[0.3494275613851253], 
             Hue[0.39723317870744274`], 
             Hue[0.6857002155462955], 
             Hue[0.7335058328686129], 
             Hue[0.7813114501909304], 
             Hue[0.36877523686003727`], 
             Hue[0.41901175023351617`], 
             Hue[0.7726612517134026], 
             Hue[0.8228977650868815], 
             Hue[0.44035309890850055`], 
             Hue[0.8636503254965554], 
             Hue[0.03180433618383521], 
             Hue[0.19253832931334366`], 
             Hue[0.04028401876112721], 
             Hue[0.06376628148226987], 
             Hue[0.22564798809900635`], 
             Hue[0.24913025082014903`], 
             Hue[0.048577058017118147`], 
             Hue[0.07500078789709336], 
             Hue[0.10142451777706858`], 
             Hue[0.2580230828705922], 
             Hue[0.2844468127505675], 
             Hue[0.3108705426305426], 
             Hue[0.056689356734011445`], 
             Hue[0.08599166495268391], 
             Hue[0.11529397317135638`], 
             Hue[0.14459628139002886`], 
             Hue[0.2896871047844397], 
             Hue[0.3189894130031122], 
             Hue[0.34829172122178464`], 
             Hue[0.37759402944045717`], 
             Hue[0.06462658258965864], 
             Hue[0.09674649865917434], 
             Hue[0.1288664147286901], 
             Hue[0.16098633079820582`], 
             Hue[0.19310624686772151`], 
             Hue[0.32066259356020976`], 
             Hue[0.35278250962972546`], 
             Hue[0.3849024256992412], 
             Hue[0.41702234176875697`], 
             Hue[0.44914225783827266`], 
             Hue[0.07239417891615509], 
             Hue[0.10727257796036131`], 
             Hue[0.14215097700456755`], 
             Hue[0.17702937604877378`], 
             Hue[0.21190777509298], 
             Hue[0.2467861741371862], 
             Hue[0.35097118225905083`], 
             Hue[0.38584958130325697`], 
             Hue[0.4207279803474632], 
             Hue[0.4556063793916695], 
             Hue[0.4904847784358756], 
             Hue[0.525363177480082], 
             Hue[0.41000732584241295`], 
             Hue[0.09510650903689571], 
             Hue[0.1383310056175023], 
             Hue[0.43833150821446143`], 
             Hue[0.48155600479506794`], 
             Hue[0.10221218383796936`], 
             Hue[0.14795633705725625`], 
             Hue[0.19370049027654318`], 
             Hue[0.46607424853146545`], 
             Hue[0.5118184017507524], 
             Hue[0.5575625549700394], 
             Hue[0.10917447509482713`], 
             Hue[0.15738842564338157`], 
             Hue[0.20560237619193594`], 
             Hue[0.25381632674049037`], 
             Hue[0.4932527465783147], 
             Hue[0.5414666971268691], 
             Hue[0.5896806476754236], 
             Hue[0.6378945982239781], 
             Hue[0.11599754370021549`], 
             Hue[0.1666328386468012], 
             Hue[0.2172681335933869], 
             Hue[0.2679034285399726], 
             Hue[0.31853872348655826`], 
             Hue[0.5198835585535808], 
             Hue[0.5705188535001666], 
             Hue[0.6211541484467523], 
             Hue[0.671789443393338], 
             Hue[0.7224247383399238], 
             Hue[0.1226853983718899], 
             Hue[0.1756949419931816], 
             Hue[0.2287044856144733], 
             Hue[0.281714029235765], 
             Hue[0.3347235728570566], 
             Hue[0.3877331164783483], 
             Hue[0.5459826249599447], 
             Hue[0.5989921685812363], 
             Hue[0.6520017122025279], 
             Hue[0.7050112558238197], 
             Hue[0.7580207994451115], 
             Hue[0.811030343066403], 
             Hue[0.1290560704880001], 
             Hue[0.18457990856261675`], 
             Hue[0.23991791507611768`], 
             Hue[0.2952559215896185], 
             Hue[0.35059392810311946`], 
             Hue[0.40593193461662036`], 
             Hue[0.4612699411301213], 
             Hue[0.571565297220611], 
             Hue[0.626903303734112], 
             Hue[0.6822413102476127], 
             Hue[0.7375793167611137], 
             Hue[0.7929173232746147], 
             Hue[0.8482553297881156], 
             Hue[0.9034359446228027]}, VertexNormals -> CompressedData["
1:eJwUmXc81e8bxlWKlBYJZSY7I5WVnhIqpIivEUopkrKKRCVbNplJRmb23vc5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            "]], 
          GraphicsComplex[CompressedData["
1:eJx12E1oz3EcwPGFPCzlwKK0g5vQHKwU5d+42EVIprCFSBg7YNJQ5Gk7SDnY
isso8rApbW0yD+uPxrZiHDaLTYhhm1qN0d9D3g7vT/9f/S6vPn2+397H74yN
u1ZuHpWRkfHt9z/693/iwM1rVZUNicfzl0+pqrycaKmoyC+svpjIH1nbt3xc
MnhbffehjrzW4LMa52bOaXoafMfZko7irhfBr++9cb5muDP4wKqvWwezXgWv
/Pv1BG8c33hwwaU3wbtKOzd11b0N/uPd96VlyffBs1dPz8nu+BB8UXLh5Kbe
vuBFueuGCwc/Bz9cXdadSvUHp3PNrolHx+2pDZ3tdLbT2U5nO53tdLbT2U5n
O53tdLbT2U5nO53tdLbTeV/zQCov+2bobKeznc52OtvpbKeznc52OtvpbKez
nc52OtvpbKeznc55U5/vL0vWh852OtvpbKeznc52OtvpbKeznc52OtvpbKez
nc52OtvpnLm9Yaiu+FbobKeznc52OtvpbKeznc52OtvpbKeznc52OtvpbKez
nc7Pms6VDGbdCZ3tdLbT2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbTedmE
e0NZRfdCZzud7XS209lOZzud7XS209lOZzud7XS209lOZzud7XSe9/drDp3t
dLbT2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbTedr6iyV/urqznc52Otvp
bKeznc52OtvpbKeznc52OtvpbKeznc52Ov88NvV6cdeD0NlOZzud7XS209lO
Zzud7XS209lOZzud7XS209lOZzude2tP9pXXPAqd7XS209lOZzud7XS209lO
Zzud7XS209lOZzud7XS20/lh58jMS0daQmc7ne10ttPZTmc7ne10ttPZTmc7
ne10ttPZTmc7ne10vjpm55ZkwZPQ2U5nO53tdLbT2U5nO53tdLbT2U5nO53t
dLbT2U5nO51P57yu7p3dFjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53Odjrb
6Wyn8+41K3tSqfbQ2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U5n+9js
6TMmfbybOFORe6oj71robx/Y/mlbzfCX4Oy3s//wksrFg1ntYb+d/ek83f3D
++q/eTvz6fr43Ja1Q6Uv624najfcX1FffOW/NxzPvVBQ1h+c+ZHWodPD5e1h
3k6HdPt9f/anu7/3M5/u/dbncp909/e5vwDKhUrk
           "], {{{
              EdgeForm[], 
              Directive[
               Specularity[
                GrayLevel[1], 3], 
               RGBColor[0.880722, 0.611041, 0.142051], Lighting -> "Neutral"], 
              GraphicsGroup[
               Annotation[{
                 Polygon[CompressedData["
1:eJwBCQX2+iFib1JiAgAAAKgBAAADAAAA4gIRFQUGEgIDEwMEFgYHFwcIGgoL
HAwNGAgJGQkKFAQFKhobGwsMKRkaIxMUIBARIRESJBQVJRUWKBgZ7+XkJhYX
JxcYHQ0OKxscLBwdPy8wRzc4MSEiLR0eMiIjNCQlNycoMyMkNSUmNiYnLx8g
MCAhOCgpOSkqQDAxPCwtPi4vQTEyIhITQjIzRDQ1OiorOyssQzM0RTU2gHBx
RjY3f29wTj4/Sjo7Szs8Tz9AUEBBU0NEVUVGUUFCUkJDTT0+Y1NUVERFYlJT
XExNWEhJWUlKXU1OXk5PYVFSV0dIX09QYFBRVkZHZFRVZVVWd2doSTk6aVla
ZlZXa1tcbV1ecGBhbFxdbl5fb19gZ1dYaFhZcWFicmJjeGhpdWVmdmZnempr
SDg5e2tsfW1uc2NkdGRlfGxtfm5vWkpLgXFyzb2+hnZ3g3N0hHR1nIyNh3d4
inp7i3t8jHx9jX1+hXV2iXl6jn5/kICBlYWGkoKDk4OEloaHmIiJm4uMkYGC
mYmKmoqLj3+A8PjnnY2On4+Qo5OUoJCRoZGSno6PpJSVp5eYqJiZqZmaqpqb
opKTq5ucrJydrZ2er5+gsKChsaGisqKjlISFs6OkuKiprp6ftqant6eotKSl
gnJzuamqu6uswLCxva2uvq6vwbGywrKzxra3yLi5w7O0xbW2v6+w1sbHx7e4
1cXGzr6/y7u8zLy9z7/A0MDB5sXUyrq70cHC0sLDybm618fI2MjJCBgXvKyt
3MzN2cnK3c3O38/Q4+IQ3s7P4NDR7ejS2srL28vMAhIRAxMSCRkYBhYVBxcW
ChoZuqqrCxsaDR0cBBQTBRUUDBwb5B0OECAfESEgEiIhFCQjFSUkFiYlFycm
GCgnGSkoGiopGysqHCwrHS0sHy8uIDAvITEwIjIxIzMyJDQzJTU0JjY1Jzc2
KDg3KTk4Kjo5Kzs6LDw7Lj49Lz8+M0NCMEA/MUFASVlYNERDNkZFN0dGOEhH
OUlIMkJBOkpJO0tKPU1MP09OQFBPQVFQQlJRSFhXQ1NSR1dWPk5NRVVURlZV
RFRTNUVESlpZbn59TV1cTl5dT19eUGBfUWFgUmJhU2NiVGRjVWVkVmZlV2dm
WGhnWWloW2tqXGxrXW1sXm5tX29uYHBvYXFwYnJxY3NyZHRzZXV0ZnZ1Z3d2
bHx7aHh3anp5TFxbbX18b39+cIB/cYGAcoKBa3t6c4OCdISDdYWEd4eGeYmI
eoqJe4uKgZGQfIyLgJCPdoaFfo6Nf4+OfY2MEyMigpKRhJSTiZmYhZWUhpaV
ipqZi5uajp6dkKCfjJybjZ2ciJiXnq6tj5+ena2sl6emk6OilKSjmKinmamo
nKyrkqKhmqqpm6uqkaGgn6+uoLCvssLBu8vKpLSzobGwpra1qLi3q7u6p7e2
qbm4qrq5orKxo7OyrLy7rb28s8PCsMC/scHAtcXElaWktsbFuMjHrr69r7++
t8fGucnIusrJvMzLg5OSwdHQvs7Nv8/OwtLR8Ofmx9fWydnYxdXUxtbVwNDP
yNjXytrZ6+QOzNzbzd3czt7dz9/eHeQe0ODf8u7jy9va7uriEOIR6ODRpZWW
5OUe+fHhvc3M8eno7ObU6Ong8+/r9u4B4uoC9PDs9fHt5ufE0ujR4+7i9+8P
7vIB7PDm7fHo7/MPxebE8PTT7vbq6+/k+PDT8fXh7/fl8fnpl2heKQ==
                  "]]}, "Charting`Private`Tag$3017#1"]]}, {}, {}, {}, {}}, {{
              GrayLevel[0], 
              
              Line[{246, 1, 242, 227, 16, 31, 46, 61, 76, 91, 106, 121, 136, 
               151, 166, 181, 196, 231, 248, 211, 244, 236, 212, 213, 214, 
               215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 233, 249, 
               225, 245, 237, 210, 195, 180, 165, 150, 135, 120, 105, 90, 75, 
               60, 45, 30, 229, 247, 15, 243, 235, 14, 13, 12, 11, 10, 9, 8, 
               7, 6, 5, 4, 3, 2, 234, 246}, VertexColors -> None]}}}, 
           VertexColors -> CompressedData["
1:eJxTTMoPSmVkYGD4CcRpYPDMfpQepUfpUXqUHqVH6aFHAwAuZnMS
            "], VertexNormals -> CompressedData["
1:eJztyLENABAUQMEfJjGJHYwgUVtdq6MXG9xLXnOlzzZSROx7jl+rcs4555xz
zjnnnHPOOef89QMOQClu
            "]]}, {
         DisplayFunction -> Identity, 
          Ticks -> {Automatic, Automatic, Automatic}, FaceGrids -> None, 
          DisplayFunction -> Identity, Axes -> True, 
          AxesLabel -> {
           "\[Rho]", "      \!\(\*SubscriptBox[\(S\), \(\(r\)\(\\ \)\)]\)", 
            "er      "}, AxesOrigin -> {Automatic, Automatic, Automatic}, 
          BoxRatios -> {1, 1, 0.4}, DisplayFunction :> Identity, 
          FaceGridsStyle -> Automatic, Lighting -> "Neutral", 
          Method -> {"DefaultBoundaryStyle" -> Directive[
              GrayLevel[0.3]], "RotationControl" -> "Globe"}, 
          PlotRange -> {All, All, All}, 
          PlotRangePadding -> {Automatic, Automatic, Automatic}, 
          Ticks -> {Automatic, Automatic, Automatic}}]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.530573299436363*^9, 3.5305733393396454`*^9}, 
   3.531617867272561*^9, 3.5316194854131136`*^9, 3.5316197624749603`*^9, 
   3.533148219653371*^9, 3.533236463710428*^9, 3.5332400519696646`*^9, 
   3.53368363875*^9, 3.533735328413151*^9, 3.533756238109375*^9, 
   3.539021233582103*^9, 3.5390216356510997`*^9, 3.539034746050972*^9, 
   3.539988765039404*^9, 3.5401275444762383`*^9, 3.540561273360322*^9, 
   3.5411865590241747`*^9, 3.541187916290806*^9, 3.5411880402638965`*^9, 
   3.5411910722923183`*^9, 3.5411911705459385`*^9, 3.541191252417621*^9, 
   3.541191308926853*^9, 3.5416041797675867`*^9, {3.5433440948090706`*^9, 
   3.54334413587642*^9}, 3.612696912027328*^9, 3.697233993397448*^9, 
   3.6972358774161835`*^9, 3.697317856759986*^9, 3.6973235338168077`*^9, 
   3.698044394492196*^9, 3.698044833400366*^9, 3.731421558712016*^9},
 TextAlignment->Center,ExpressionUUID->"808c4cc9-3060-48b5-b768-b29ee3bd2fad"]
}, Open  ]]
}, Open  ]],

Cell["\<\
Appendix - Understanding the Private Real Estate Investor Life Cycle \
3D-Graphic\
\>", "AppendixSection",
 CellChangeTimes->{{3.697320758910746*^9, 3.6973207748110533`*^9}, {
  3.6973208727927256`*^9, 
  3.6973208843163843`*^9}},ExpressionUUID->"1874f153-3406-4957-a754-\
22a9f8b5751e"],

Cell["Introduction", "Section",
 CellChangeTimes->{{3.697320904535174*^9, 
  3.697320906541527*^9}},ExpressionUUID->"73ed7b6b-e378-4c91-8dc3-\
b47ebb88a846"],

Cell["\<\
While visualization with Mathematica can produce very useful models, it is \
often a challenge to understand just what information a three dimensional \
graphic conveys. This appendix is intended to supplement the text, \
specifically the information conveyed by Figure 8.11 which we refer to below \
as the Real Estate Investor Life Cycle Plot.\
\>", "Text",
 CellChangeTimes->{{3.697320957377762*^9, 3.697321063822955*^9}, {
  3.697321285511759*^9, 
  3.6973213531647415`*^9}},ExpressionUUID->"c320412d-3980-4502-9cf8-\
6b2c5fe9d875"],

Cell[TextData[{
 "We imagine that the private real estate investor improves his yield by \
adding his entrepreneurial labor to the process, composed of a combination of \
time and talent. Further, we assume that there are alternative investments \
which do not allow such additions and, as a result, have a lower return. We \
also assume that the investor\[CloseCurlyQuote]s additions diminish over time \
as he ages. Finally, we assume that there is some range of (a) time spent and \
(b) efficiency or ability each investor may contribute. In the plot below the \
\[OpenCurlyDoubleQuote]effective return\[CloseCurlyDoubleQuote] is the \
vertical axis, the two horizontal axes (the \[OpenCurlyDoubleQuote]floor\
\[CloseCurlyDoubleQuote] of the graphic) are inputs of time and ability. The \
curved plot shows all the yields which are all the possible contributions of \
time and talent, much of which are above the gray plane. The gray plane is \
called the \[OpenCurlyDoubleQuote]Effective Return Plateau\
\[CloseCurlyDoubleQuote], essentially those returns available from passive \
investments, and acts as a \[OpenCurlyDoubleQuote]floor\
\[CloseCurlyDoubleQuote] for real estate returns. For illustration only we \
make this plateau equal to 4% per ",
 StyleBox["annum",
  IgnoreSpellCheck->True],
 ". Naturally, the man who actively works his real estate investments and has \
a talent for doing so will exceed this return most of the time. This accounts \
for why most of the yellow curved plot is above the gray plane. People who \
lack the time and talent to operate real estate achieve lower returns and are \
\[OpenCurlyDoubleQuote]below the water line\[CloseCurlyDoubleQuote] in our \
graphic. We call these people stock market investors."
}], "Text",
 CellChangeTimes->{{3.697320957377762*^9, 3.6973210627521296`*^9}, 
   3.6973211039446983`*^9},ExpressionUUID->"f1b5ceb4-1f34-4887-87b1-\
23543ae733f9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1s", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"\[Rho]", " ", 
      FractionBox["s", 
       RowBox[{"s", "+", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", ".05", ",", ".25"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Yellow"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<efficiency\>\"", ",", "\"\<      time\\n      spent\>\"", ",", 
        "\"\<effective\\nreturn      \>\""}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2s", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{".04", ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", ".05", ",", ".25"}], "}"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"GrayLevel", "[", ".7", "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"showtwo", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p1s", ",", "p2s", ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"StringJoin", "[", 
      RowBox[{"\"\<Effective Return Plateau = \>\"", ",", 
       RowBox[{"ToString", "[", "4.00", "]"}], ",", "\"\<%\>\""}], "]"}]}], 
    ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "Automatic", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{".04", ",", "\"\<4%\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{".1", ",", "\"\<10%\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{".15", ",", "\"\<15%\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{".20", ",", "\"\<20%\>\""}], "}"}]}], "}"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.6973211773971167`*^9},ExpressionUUID->"ca72d1d2-5ec7-42bf-b3ab-\
e33f183ccbb4"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxdnHlUTe8X/yuphEiZIlNFKkKI0KOkCSkic0QhUoZSVGhCSaNmzfM8z93m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    "], {{
      {RGBColor[1, 1, 0], EdgeForm[None], 
       StyleBox[GraphicsGroup3DBox[
         TagBox[{Polygon3DBox[CompressedData["
1:eJwtmXfgVuMbxt9znhsNkr1L+GUlI5QiZKUilWgvoozKqEg7oSISaaoUSVkZ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            "]], Polygon3DBox[CompressedData["
1:eJwtmgn8VsMexs/MHGUXadUeWSttJFlaCEUrIi6yFdpL0r6qaEVRSqFEtpRd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            "]], Polygon3DBox[CompressedData["
1:eJwt1ne8j2UfB/BzHHuPbJlZDUJmmWWV7JUZGT12ViqhrAqlRwplZZeEEC0q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            "]]},
          Annotation[#, "Charting`Private`Tag$3249#1"]& ]],
        Lighting->Automatic]}, {}, {}, {}, {}}, {
      {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0bsrR2EcwOHjfr9lkiKbFKsUqxSTsrAxMbAympgJf4CYJUbXn+siud8v
SXId3CXxvGX4nOfUe87b9+0tae1q7IyLoqhX7wrvz7rSUHwU5XKUxZxkBRdY
w0028JwtfGIHf9jDzIQo6mchR1jGcVZxmnVc4jxv+KltvepBM4bZ4Sx3Oce9
8D33wxw84CIPGeMRl3jMZZ5whadc5RnXeM51XnDAvLf80qXe9Kg2c22xiTHW
coqVHGMph1nAPqazm9/2aw9nYDNPWc8NVodzsJwTLArn8981P5SjF90r33zZ
zGNWWGMms5jBDKYzjWlMYSqTmMIEJoc7ZRJ/lRjuJ6yFOWWEaNDj7v/+/wCI
PEiz
        "]]}, 
      {GrayLevel[0.2], 
       Line3DBox[{661, 957, 458, 660, 1060, 868, 662, 1061, 869, 663, 1062, 
        870, 664, 1063, 871, 665, 1064, 872, 666, 1065, 873, 667, 465, 668, 
        1066, 874, 669, 1067, 875, 670, 1068, 876, 671, 1069, 877, 672, 1070, 
        878, 673, 1057, 1071, 879, 958}], 
       Line3DBox[{675, 962, 1149, 674, 1072, 880, 676, 1073, 881, 677, 1074, 
        882, 678, 1075, 883, 679, 1076, 884, 680, 1077, 885, 681, 963, 1150, 
        682, 479, 683, 1078, 886, 684, 1079, 887, 685, 1080, 888, 686, 1081, 
        889, 687, 1082, 890, 688}], 
       Line3DBox[{690, 964, 1151, 689, 965, 1152, 691, 1083, 891, 692, 1084, 
        892, 693, 1085, 893, 694, 1086, 894, 695, 1087, 895, 696, 966, 1153, 
        697, 967, 1154, 698, 494, 699, 1088, 896, 700, 1089, 897, 701, 1090, 
        898, 702, 1091, 899, 703}], 
       Line3DBox[{705, 968, 1155, 704, 969, 1156, 706, 970, 1157, 707, 1092, 
        900, 708, 1093, 901, 709, 1094, 902, 710, 1095, 903, 711, 971, 1158, 
        712, 972, 1159, 713, 973, 1160, 714, 509, 715, 1096, 904, 716, 1097, 
        905, 717, 1098, 906, 718}], 
       Line3DBox[{720, 974, 1161, 719, 975, 1162, 721, 976, 1163, 722, 977, 
        1164, 723, 1099, 907, 724, 1100, 908, 725, 1101, 909, 726, 978, 1165, 
        727, 979, 1166, 728, 980, 1167, 729, 981, 1168, 730, 524, 731, 1102, 
        910, 732, 1103, 911, 733}], 
       Line3DBox[{735, 982, 1169, 734, 983, 1170, 736, 984, 1171, 737, 985, 
        1172, 738, 986, 1173, 739, 1104, 912, 740, 1105, 913, 741, 987, 1174, 
        742, 988, 1175, 743, 989, 1176, 744, 990, 1177, 745, 991, 1178, 746, 
        539, 747, 1106, 914, 748}], 
       Line3DBox[{106, 347, 107, 348, 108, 349, 109, 350, 110, 351, 111, 352, 
        112, 353, 113, 354, 114, 355, 115, 356, 116, 357, 117, 358, 118, 359, 
        119, 360, 120}], 
       Line3DBox[{750, 992, 1179, 749, 993, 1180, 751, 994, 1181, 752, 995, 
        1182, 753, 996, 1183, 754, 997, 1184, 755, 547, 756, 998, 1185, 757, 
        999, 1186, 758, 1000, 1187, 759, 1001, 1188, 760, 1002, 1189, 761, 
        1003, 1190, 762, 554, 763}], 
       Line3DBox[{765, 555, 764, 1107, 915, 766, 1108, 916, 767, 1109, 917, 
        768, 1110, 918, 769, 1111, 919, 770, 1112, 920, 771, 1004, 1191, 772, 
        1113, 921, 773, 1114, 922, 774, 1115, 923, 775, 1116, 924, 776, 1117, 
        925, 777, 1118, 926, 778}], 
       Line3DBox[{780, 1005, 1192, 779, 1006, 1193, 781, 1119, 927, 782, 1120,
         928, 783, 1121, 929, 784, 1122, 930, 785, 1123, 931, 786, 1007, 1194,
         787, 1008, 1195, 788, 1124, 932, 789, 1125, 933, 790, 1126, 934, 791,
         1127, 935, 792, 1128, 936, 793}], 
       Line3DBox[{795, 1009, 1196, 794, 1010, 1197, 796, 1011, 1198, 797, 
        1129, 937, 798, 1130, 938, 799, 1131, 939, 800, 1132, 940, 801, 1012, 
        1199, 802, 1013, 1200, 803, 1014, 1201, 804, 1133, 941, 805, 1134, 
        942, 806, 1135, 943, 807, 1136, 944, 808}], 
       Line3DBox[{810, 1015, 1202, 809, 1016, 1203, 811, 1017, 1204, 812, 
        1018, 1205, 813, 1137, 945, 814, 1138, 946, 815, 1139, 947, 816, 1019,
         1206, 817, 1020, 1207, 818, 1021, 1208, 819, 1022, 1209, 820, 1140, 
        948, 821, 1141, 949, 822, 1142, 950, 823}], 
       Line3DBox[{825, 1023, 1210, 824, 1024, 1211, 826, 1025, 1212, 827, 
        1026, 1213, 828, 1027, 1214, 829, 1143, 951, 830, 1144, 952, 831, 
        1028, 1215, 832, 1029, 1216, 833, 1030, 1217, 834, 1031, 1218, 835, 
        1032, 1219, 836, 1145, 953, 837, 1146, 954, 838}], 
       Line3DBox[{840, 1033, 1220, 839, 1034, 1221, 841, 1035, 1222, 842, 
        1036, 1223, 843, 1037, 1224, 844, 1038, 1225, 845, 1147, 955, 846, 
        1039, 1226, 847, 1040, 1227, 848, 1041, 1228, 849, 1042, 1229, 850, 
        1043, 1230, 851, 1044, 1231, 852, 1148, 956, 853}], 
       Line3DBox[{867, 961, 1245, 1059, 866, 1244, 1056, 865, 1243, 1055, 864,
         1242, 1054, 863, 1241, 1053, 862, 1240, 1052, 861, 1239, 1051, 860, 
        1238, 1050, 859, 1237, 1049, 858, 1236, 1048, 857, 1235, 1047, 856, 
        1234, 1046, 855, 1233, 1045, 854, 1058, 1232, 959, 960}]}, 
      {GrayLevel[0.2], 
       Line3DBox[{251, 459, 1060, 252, 472, 1072, 278, 1152, 486, 292, 1156, 
        500, 306, 1162, 514, 320, 1170, 528, 334, 1180, 542, 348, 556, 1107, 
        362, 1193, 570, 376, 1197, 584, 390, 1203, 598, 404, 1211, 612, 418, 
        1221, 626, 432, 1233, 640, 446}], 
       Line3DBox[{253, 460, 1061, 254, 473, 1073, 279, 487, 1083, 293, 1157, 
        501, 307, 1163, 515, 321, 1171, 529, 335, 1181, 543, 349, 557, 1108, 
        363, 571, 1119, 377, 1198, 585, 391, 1204, 599, 405, 1212, 613, 419, 
        1222, 627, 433, 1234, 641, 447}], 
       Line3DBox[{255, 461, 1062, 256, 474, 1074, 280, 488, 1084, 294, 502, 
        1092, 308, 1164, 516, 322, 1172, 530, 336, 1182, 544, 350, 558, 1109, 
        364, 572, 1120, 378, 586, 1129, 392, 1205, 600, 406, 1213, 614, 420, 
        1223, 628, 434, 1235, 642, 448}], 
       Line3DBox[{257, 462, 1063, 258, 475, 1075, 281, 489, 1085, 295, 503, 
        1093, 309, 517, 1099, 323, 1173, 531, 337, 1183, 545, 351, 559, 1110, 
        365, 573, 1121, 379, 587, 1130, 393, 601, 1137, 407, 1214, 615, 421, 
        1224, 629, 435, 1236, 643, 449}], 
       Line3DBox[{259, 463, 1064, 260, 476, 1076, 282, 490, 1086, 296, 504, 
        1094, 310, 518, 1100, 324, 532, 1104, 338, 1184, 546, 352, 560, 1111, 
        366, 574, 1122, 380, 588, 1131, 394, 602, 1138, 408, 616, 1143, 422, 
        1225, 630, 436, 1237, 644, 450}], 
       Line3DBox[{261, 464, 1065, 262, 477, 1077, 283, 491, 1087, 297, 505, 
        1095, 311, 519, 1101, 325, 533, 1105, 339, 547, 353, 561, 1112, 367, 
        575, 1123, 381, 589, 1132, 395, 603, 1139, 409, 617, 1144, 423, 631, 
        1147, 437, 1238, 645, 451}], 
       Line3DBox[{8, 667, 23, 681, 38, 696, 53, 711, 68, 726, 83, 741, 98, 
        756, 113, 771, 128, 786, 143, 801, 158, 816, 173, 831, 188, 846, 203, 
        860, 218}], 
       Line3DBox[{263, 465, 264, 1150, 478, 284, 1153, 492, 298, 1158, 506, 
        312, 1165, 520, 326, 1174, 534, 340, 1185, 548, 354, 1191, 562, 368, 
        1194, 576, 382, 1199, 590, 396, 1206, 604, 410, 1215, 618, 424, 1226, 
        632, 438, 1239, 646, 452}], 
       Line3DBox[{265, 466, 1066, 266, 479, 285, 1154, 493, 299, 1159, 507, 
        313, 1166, 521, 327, 1175, 535, 341, 1186, 549, 355, 563, 1113, 369, 
        1195, 577, 383, 1200, 591, 397, 1207, 605, 411, 1216, 619, 425, 1227, 
        633, 439, 1240, 647, 453}], 
       Line3DBox[{267, 467, 1067, 268, 480, 1078, 286, 494, 300, 1160, 508, 
        314, 1167, 522, 328, 1176, 536, 342, 1187, 550, 356, 564, 1114, 370, 
        578, 1124, 384, 1201, 592, 398, 1208, 606, 412, 1217, 620, 426, 1228, 
        634, 440, 1241, 648, 454}], 
       Line3DBox[{269, 468, 1068, 270, 481, 1079, 287, 495, 1088, 301, 509, 
        315, 1168, 523, 329, 1177, 537, 343, 1188, 551, 357, 565, 1115, 371, 
        579, 1125, 385, 593, 1133, 399, 1209, 607, 413, 1218, 621, 427, 1229, 
        635, 441, 1242, 649, 455}], 
       Line3DBox[{271, 469, 1069, 272, 482, 1080, 288, 496, 1089, 302, 510, 
        1096, 316, 524, 330, 1178, 538, 344, 1189, 552, 358, 566, 1116, 372, 
        580, 1126, 386, 594, 1134, 400, 608, 1140, 414, 1219, 622, 428, 1230, 
        636, 442, 1243, 650, 456}], 
       Line3DBox[{273, 470, 1070, 274, 483, 1081, 289, 497, 1090, 303, 511, 
        1097, 317, 525, 1102, 331, 539, 345, 1190, 553, 359, 567, 1117, 373, 
        581, 1127, 387, 595, 1135, 401, 609, 1141, 415, 623, 1145, 429, 1231, 
        637, 443, 1244, 651, 457}], 
       Line3DBox[{275, 653, 654, 1071, 276, 484, 1082, 290, 498, 1091, 304, 
        512, 1098, 318, 526, 1103, 332, 540, 1106, 346, 554, 360, 568, 1118, 
        374, 582, 1128, 388, 596, 1136, 402, 610, 1142, 416, 624, 1146, 430, 
        638, 1148, 444, 1245, 656, 657, 658}], 
       Line3DBox[{445, 639, 655, 1232, 431, 625, 1220, 417, 611, 1210, 403, 
        597, 1202, 389, 583, 1196, 375, 569, 1192, 361, 555, 347, 541, 1179, 
        333, 527, 1169, 319, 513, 1161, 305, 499, 1155, 291, 485, 1151, 277, 
        471, 1149, 250, 458, 652, 659}]}, {}, {}}},
    VertexNormals->CompressedData["
1:eJwUmXc81e8bxlWKlBYJZSY7I5WVnhIqpIivEUopkrKKRCVbNplJRmb23vc5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     "]], GraphicsComplex3DBox[CompressedData["
1:eJx12E1oz3EcwPGFDCkHW5R22E1oDlaK8m8ccBFLqHkIkTB28BRDTZ4PWjmY
4mJqYg9KW5uM0R95WjEOm8UmxDxsajVGfyxvh/en/69+l1efPt9v7+M3d932
wg3DMjIyvv/5h//5j+2/Vn22ojHxcObirLMVlxL7smrmd+2tTCwcLOpZnJkM
/qSh82BbwePgU5qmj5nW/DT41jMlbcUdL4LX7Lp6vnagPXjv0m+b+rJfBa8Y
+rqCN41qOjCr6k3wjt3t6zvq3wb/+e7HgtLk++A5yybl5bR9CD4nOXt8c3dP
8DX5KwdW930OXnahtDOV+hqczrXbxx7O3FkXOtvpbKeznc52OtvpbKeznc52
OtvpbKeznc52OtvpbKfznju9qYKca6Gznc52OtvpbKeznc52OtvpbKeznc52
OtvpbKeznc52OhdMeL63NNkQOtvpbKeznc52OtvpbKeznc52OtvpbKeznc52
OtvpbKfzmC2N/fXF10NnO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U5nO53t
dH7WfK6kL/tm6Gyns53Odjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53Oi0a3
9GevaQmd7XS209lOZzud7XS209lOZzud7XS209lOZzud7XS203nG0HcndLbT
2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U7niasulvzt6s52OtvpbKez
nc52OtvpbKeznc52OtvpbKeznc52Otvp/OvIhJrijruhs53Odjrb6Wyns53O
djrb6Wyns53Odjrb6Wyns53Odjp31x3vOVF7P3S209lOZzud7XS209lOZzud
7XS209lOZzud7XS209lO53vtg5OrDj0Ine10ttPZTmc7ne10ttPZTmc7ne10
ttPZTmc7ne10ttP5yohtG5PLH4XOdjrb6Wyns53Odjrb6Wyns53Odjrb6Wyn
s53Odjrb6Vye9/pC99QnobOdznY62+lsp7OdznY62+lsp7OdznY62+lsp7Od
znY671hR2JVKtYbOdjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53OdjrbR+ZM
yh338Vbi9Mn8U20F1aG/vXfLp821A1+Cs9/O/rJ5FXP7slvDfjv703m6+4f3
1X/zdubT9fG5D4r6d7+sv5GoW3t7SUPx5f/eeDS/cnnp1+DMDz7uLx840Rrm
7XRIt9/3Z3+6+3s/8+neb30u90l3f5/7G/YiAPg=
    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[
         TagBox[Polygon3DBox[CompressedData["
1:eJwBCQX2+iFib1JiAgAAAKgBAAADAAAA4gIRFQUGEgIDEwMEFgYHFwcIGgoL
HAwNGAgJGQkKFAQFKhobGwsMKRkaIxMUIBARIRESJBQVJRUWKBgZ7+XkJhYX
JxcYHQ0OKxscLBwdPy8wRzc4MSEiLR0eMiIjNCQlNycoMyMkNSUmNiYnLx8g
MCAhOCgpOSkqQDAxPCwtPi4vQTEyIhITQjIzRDQ1OiorOyssQzM0RTU2gHBx
RjY3f29wTj4/Sjo7Szs8Tz9AUEBBU0NEVUVGUUFCUkJDTT0+Y1NUVERFYlJT
XExNWEhJWUlKXU1OXk5PYVFSV0dIX09QYFBRVkZHZFRVZVVWd2doSTk6aVla
ZlZXa1tcbV1ecGBhbFxdbl5fb19gZ1dYaFhZcWFicmJjeGhpdWVmdmZnempr
SDg5e2tsfW1uc2NkdGRlfGxtfm5vWkpLgXFyzb2+hnZ3g3N0hHR1nIyNh3d4
inp7i3t8jHx9jX1+hXV2iXl6jn5/kICBlYWGkoKDk4OEloaHmIiJm4uMkYGC
mYmKmoqLj3+A8PjnnY2On4+Qo5OUoJCRoZGSno6PpJSVp5eYqJiZqZmaqpqb
opKTq5ucrJydrZ2er5+gsKChsaGisqKjlISFs6OkuKiprp6ftqant6eotKSl
gnJzuamqu6uswLCxva2uvq6vwbGywrKzxra3yLi5w7O0xbW2v6+w1sbHx7e4
1cXGzr6/y7u8zLy9z7/A0MDB5sXUyrq70cHC0sLDybm618fI2MjJCBgXvKyt
3MzN2cnK3c3O38/Q4+IQ3s7P4NDR7ejS2srL28vMAhIRAxMSCRkYBhYVBxcW
ChoZuqqrCxsaDR0cBBQTBRUUDBwb5B0OECAfESEgEiIhFCQjFSUkFiYlFycm
GCgnGSkoGiopGysqHCwrHS0sHy8uIDAvITEwIjIxIzMyJDQzJTU0JjY1Jzc2
KDg3KTk4Kjo5Kzs6LDw7Lj49Lz8+M0NCMEA/MUFASVlYNERDNkZFN0dGOEhH
OUlIMkJBOkpJO0tKPU1MP09OQFBPQVFQQlJRSFhXQ1NSR1dWPk5NRVVURlZV
RFRTNUVESlpZbn59TV1cTl5dT19eUGBfUWFgUmJhU2NiVGRjVWVkVmZlV2dm
WGhnWWloW2tqXGxrXW1sXm5tX29uYHBvYXFwYnJxY3NyZHRzZXV0ZnZ1Z3d2
bHx7aHh3anp5TFxbbX18b39+cIB/cYGAcoKBa3t6c4OCdISDdYWEd4eGeYmI
eoqJe4uKgZGQfIyLgJCPdoaFfo6Nf4+OfY2MEyMigpKRhJSTiZmYhZWUhpaV
ipqZi5uajp6dkKCfjJybjZ2ciJiXnq6tj5+ena2sl6emk6OilKSjmKinmamo
nKyrkqKhmqqpm6uqkaGgn6+uoLCvssLBu8vKpLSzobGwpra1qLi3q7u6p7e2
qbm4qrq5orKxo7OyrLy7rb28s8PCsMC/scHAtcXElaWktsbFuMjHrr69r7++
t8fGucnIusrJvMzLg5OSwdHQvs7Nv8/OwtLR8Ofmx9fWydnYxdXUxtbVwNDP
yNjXytrZ6+QOzNzbzd3czt7dz9/eHeQe0ODf8u7jy9va7uriEOIR6ODRpZWW
5OUe+fHhvc3M8eno7ObU6Ong8+/r9u4B4uoC9PDs9fHt5ufE0ujR4+7i9+8P
7vIB7PDm7fHo7/MPxebE8PTT7vbq6+/k+PDT8fXh7/fl8fnpl2heKQ==
           "]],
          Annotation[#, "Charting`Private`Tag$3284#1"]& ]],
        Lighting->"Neutral"]}, {}, {}, {}, {}}, 
     {GrayLevel[0], 
      Line3DBox[{246, 1, 242, 227, 16, 31, 46, 61, 76, 91, 106, 121, 136, 151,
        166, 181, 196, 231, 248, 211, 244, 236, 212, 213, 214, 215, 216, 217, 
       218, 219, 220, 221, 222, 223, 224, 233, 249, 225, 245, 237, 210, 195, 
       180, 165, 150, 135, 120, 105, 90, 75, 60, 45, 30, 229, 247, 15, 243, 
       235, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 234, 246},
       VertexColors->None]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGD4CcRpYPDMfpQepUfpUXqUHqVH6aFHAwAuZnMS
     "],
    VertexNormals->CompressedData["
1:eJztyLEJACEURMGPVmIl9nAlCBdfC5ZsanZGgtjCLDwWprTveVNEzFWOvX7+
qJxzzjnnnHPOOeecc845v/0H/ZUifQ==
     "]]},
  Axes->True,
  AxesLabel->{
    FormBox["\"efficiency\"", TraditionalForm], 
    FormBox["\"      time\\n      spent\"", TraditionalForm], 
    FormBox["\"effective\\nreturn      \"", TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotLabel->FormBox["\"Effective Return Plateau = 4.%\"", TraditionalForm],
  PlotRange->{All, All, All},
  PlotRangePadding->{Automatic, Automatic, Automatic},
  Ticks->{Automatic, Automatic, {{0.04, 
      FormBox["\"4%\"", TraditionalForm]}, {0.1, 
      FormBox["\"10%\"", TraditionalForm]}, {0.15, 
      FormBox["\"15%\"", TraditionalForm]}, {0.2, 
      FormBox["\"20%\"", TraditionalForm]}}},
  ViewPoint->{1.3000000000000003`, -2.3999999999999995`, 2.},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.6973211822079153`*^9, 3.6973235340434113`*^9, 
  3.698044394891258*^9, 3.6980448336379967`*^9, 3.7314215590679626`*^9},
 TextAlignment->Center,ExpressionUUID->"c0920ad2-f9c8-45f8-8132-4769d9c3c044"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.14",
  FontWeight->"Bold"],
 ". Real Estate Investor Life Cycle Plot"
}], "FigureCaption",
 CellChangeTimes->{{3.697321230388098*^9, 3.6973212690018272`*^9}, {
  3.697321315176675*^9, 3.697321319615485*^9}},
 TextAlignment->Center,ExpressionUUID->"d89889e3-76e0-4654-942c-fac77dcd469f"],

Cell["The beginning", "Section",
 CellChangeTimes->{{3.697321954029348*^9, 
  3.697321956893964*^9}},ExpressionUUID->"9a536296-2754-423d-ae88-\
b9f1f79446bf"],

Cell["\<\
Suppose, early in his career, one has a particular combination of time and \
ability, representing a starting point for investment in real estate, shown \
as a red dot on the graphic.\
\>", "Text",
 CellChangeTimes->{{3.6240197726752343`*^9, 3.624019831118577*^9}, {
  3.624135942724781*^9, 
  3.6241359474010487`*^9}},ExpressionUUID->"fa54779c-164b-4ccd-b950-\
e34c7a34d3ff"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pt", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "Large", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{".8", ",", ".18", ",", ".15"}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"showthree", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"showtwo", ",", "pt", ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"StringJoin", "[", 
      RowBox[{"\"\<Effective Return Plateau = \>\"", ",", 
       RowBox[{"ToString", "[", "4.00", "]"}], ",", "\"\<%\>\""}], "]"}]}], 
    ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "Automatic", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{".04", ",", "\"\<4%\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{".1", ",", "\"\<10%\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{".15", ",", "\"\<15%\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{".20", ",", "\"\<20%\>\""}], "}"}]}], "}"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.697321401862299*^9},ExpressionUUID->"d2256597-0930-42d7-8194-\
0154ff8e223d"],

Cell[BoxData[
 Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJxdnHlUTe8X/yuphEiZIlNFKkKI0KOkCSkic0QhUoZSVGhCSaNmzfM8z93m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     "], {{
       {RGBColor[1, 1, 0], EdgeForm[None], 
        StyleBox[GraphicsGroup3DBox[
          TagBox[{Polygon3DBox[CompressedData["
1:eJwtmXfgVuMbxt9znhsNkr1L+GUlI5QiZKUilWgvoozKqEg7oSISaaoUSVkZ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             "]], Polygon3DBox[CompressedData["
1:eJwtmgn8VsMexs/MHGUXadUeWSttJFlaCEUrIi6yFdpL0r6qaEVRSqFEtpRd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             "]], Polygon3DBox[CompressedData["
1:eJwt1ne8j2UfB/BzHHuPbJlZDUJmmWWV7JUZGT12ViqhrAqlRwplZZeEEC0q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             "]]},
           Annotation[#, "Charting`Private`Tag$3249#1"]& ]],
         Lighting->Automatic]}, {}, {}, {}, {}}, {
       {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0bsrR2EcwOHjfr9lkiKbFKsUqxSTsrAxMbAympgJf4CYJUbXn+siud8v
SXId3CXxvGX4nOfUe87b9+0tae1q7IyLoqhX7wrvz7rSUHwU5XKUxZxkBRdY
w0028JwtfGIHf9jDzIQo6mchR1jGcVZxmnVc4jxv+KltvepBM4bZ4Sx3Oce9
8D33wxw84CIPGeMRl3jMZZ5whadc5RnXeM51XnDAvLf80qXe9Kg2c22xiTHW
coqVHGMph1nAPqazm9/2aw9nYDNPWc8NVodzsJwTLArn8981P5SjF90r33zZ
zGNWWGMms5jBDKYzjWlMYSqTmMIEJoc7ZRJ/lRjuJ6yFOWWEaNDj7v/+/wCI
PEiz
         "]]}, 
       {GrayLevel[0.2], 
        Line3DBox[{661, 957, 458, 660, 1060, 868, 662, 1061, 869, 663, 1062, 
         870, 664, 1063, 871, 665, 1064, 872, 666, 1065, 873, 667, 465, 668, 
         1066, 874, 669, 1067, 875, 670, 1068, 876, 671, 1069, 877, 672, 1070,
          878, 673, 1057, 1071, 879, 958}], 
        Line3DBox[{675, 962, 1149, 674, 1072, 880, 676, 1073, 881, 677, 1074, 
         882, 678, 1075, 883, 679, 1076, 884, 680, 1077, 885, 681, 963, 1150, 
         682, 479, 683, 1078, 886, 684, 1079, 887, 685, 1080, 888, 686, 1081, 
         889, 687, 1082, 890, 688}], 
        Line3DBox[{690, 964, 1151, 689, 965, 1152, 691, 1083, 891, 692, 1084, 
         892, 693, 1085, 893, 694, 1086, 894, 695, 1087, 895, 696, 966, 1153, 
         697, 967, 1154, 698, 494, 699, 1088, 896, 700, 1089, 897, 701, 1090, 
         898, 702, 1091, 899, 703}], 
        Line3DBox[{705, 968, 1155, 704, 969, 1156, 706, 970, 1157, 707, 1092, 
         900, 708, 1093, 901, 709, 1094, 902, 710, 1095, 903, 711, 971, 1158, 
         712, 972, 1159, 713, 973, 1160, 714, 509, 715, 1096, 904, 716, 1097, 
         905, 717, 1098, 906, 718}], 
        Line3DBox[{720, 974, 1161, 719, 975, 1162, 721, 976, 1163, 722, 977, 
         1164, 723, 1099, 907, 724, 1100, 908, 725, 1101, 909, 726, 978, 1165,
          727, 979, 1166, 728, 980, 1167, 729, 981, 1168, 730, 524, 731, 1102,
          910, 732, 1103, 911, 733}], 
        Line3DBox[{735, 982, 1169, 734, 983, 1170, 736, 984, 1171, 737, 985, 
         1172, 738, 986, 1173, 739, 1104, 912, 740, 1105, 913, 741, 987, 1174,
          742, 988, 1175, 743, 989, 1176, 744, 990, 1177, 745, 991, 1178, 746,
          539, 747, 1106, 914, 748}], 
        Line3DBox[{106, 347, 107, 348, 108, 349, 109, 350, 110, 351, 111, 352,
          112, 353, 113, 354, 114, 355, 115, 356, 116, 357, 117, 358, 118, 
         359, 119, 360, 120}], 
        Line3DBox[{750, 992, 1179, 749, 993, 1180, 751, 994, 1181, 752, 995, 
         1182, 753, 996, 1183, 754, 997, 1184, 755, 547, 756, 998, 1185, 757, 
         999, 1186, 758, 1000, 1187, 759, 1001, 1188, 760, 1002, 1189, 761, 
         1003, 1190, 762, 554, 763}], 
        Line3DBox[{765, 555, 764, 1107, 915, 766, 1108, 916, 767, 1109, 917, 
         768, 1110, 918, 769, 1111, 919, 770, 1112, 920, 771, 1004, 1191, 772,
          1113, 921, 773, 1114, 922, 774, 1115, 923, 775, 1116, 924, 776, 
         1117, 925, 777, 1118, 926, 778}], 
        Line3DBox[{780, 1005, 1192, 779, 1006, 1193, 781, 1119, 927, 782, 
         1120, 928, 783, 1121, 929, 784, 1122, 930, 785, 1123, 931, 786, 1007,
          1194, 787, 1008, 1195, 788, 1124, 932, 789, 1125, 933, 790, 1126, 
         934, 791, 1127, 935, 792, 1128, 936, 793}], 
        Line3DBox[{795, 1009, 1196, 794, 1010, 1197, 796, 1011, 1198, 797, 
         1129, 937, 798, 1130, 938, 799, 1131, 939, 800, 1132, 940, 801, 1012,
          1199, 802, 1013, 1200, 803, 1014, 1201, 804, 1133, 941, 805, 1134, 
         942, 806, 1135, 943, 807, 1136, 944, 808}], 
        Line3DBox[{810, 1015, 1202, 809, 1016, 1203, 811, 1017, 1204, 812, 
         1018, 1205, 813, 1137, 945, 814, 1138, 946, 815, 1139, 947, 816, 
         1019, 1206, 817, 1020, 1207, 818, 1021, 1208, 819, 1022, 1209, 820, 
         1140, 948, 821, 1141, 949, 822, 1142, 950, 823}], 
        Line3DBox[{825, 1023, 1210, 824, 1024, 1211, 826, 1025, 1212, 827, 
         1026, 1213, 828, 1027, 1214, 829, 1143, 951, 830, 1144, 952, 831, 
         1028, 1215, 832, 1029, 1216, 833, 1030, 1217, 834, 1031, 1218, 835, 
         1032, 1219, 836, 1145, 953, 837, 1146, 954, 838}], 
        Line3DBox[{840, 1033, 1220, 839, 1034, 1221, 841, 1035, 1222, 842, 
         1036, 1223, 843, 1037, 1224, 844, 1038, 1225, 845, 1147, 955, 846, 
         1039, 1226, 847, 1040, 1227, 848, 1041, 1228, 849, 1042, 1229, 850, 
         1043, 1230, 851, 1044, 1231, 852, 1148, 956, 853}], 
        Line3DBox[{867, 961, 1245, 1059, 866, 1244, 1056, 865, 1243, 1055, 
         864, 1242, 1054, 863, 1241, 1053, 862, 1240, 1052, 861, 1239, 1051, 
         860, 1238, 1050, 859, 1237, 1049, 858, 1236, 1048, 857, 1235, 1047, 
         856, 1234, 1046, 855, 1233, 1045, 854, 1058, 1232, 959, 960}]}, 
       {GrayLevel[0.2], 
        Line3DBox[{251, 459, 1060, 252, 472, 1072, 278, 1152, 486, 292, 1156, 
         500, 306, 1162, 514, 320, 1170, 528, 334, 1180, 542, 348, 556, 1107, 
         362, 1193, 570, 376, 1197, 584, 390, 1203, 598, 404, 1211, 612, 418, 
         1221, 626, 432, 1233, 640, 446}], 
        Line3DBox[{253, 460, 1061, 254, 473, 1073, 279, 487, 1083, 293, 1157, 
         501, 307, 1163, 515, 321, 1171, 529, 335, 1181, 543, 349, 557, 1108, 
         363, 571, 1119, 377, 1198, 585, 391, 1204, 599, 405, 1212, 613, 419, 
         1222, 627, 433, 1234, 641, 447}], 
        Line3DBox[{255, 461, 1062, 256, 474, 1074, 280, 488, 1084, 294, 502, 
         1092, 308, 1164, 516, 322, 1172, 530, 336, 1182, 544, 350, 558, 1109,
          364, 572, 1120, 378, 586, 1129, 392, 1205, 600, 406, 1213, 614, 420,
          1223, 628, 434, 1235, 642, 448}], 
        Line3DBox[{257, 462, 1063, 258, 475, 1075, 281, 489, 1085, 295, 503, 
         1093, 309, 517, 1099, 323, 1173, 531, 337, 1183, 545, 351, 559, 1110,
          365, 573, 1121, 379, 587, 1130, 393, 601, 1137, 407, 1214, 615, 421,
          1224, 629, 435, 1236, 643, 449}], 
        Line3DBox[{259, 463, 1064, 260, 476, 1076, 282, 490, 1086, 296, 504, 
         1094, 310, 518, 1100, 324, 532, 1104, 338, 1184, 546, 352, 560, 1111,
          366, 574, 1122, 380, 588, 1131, 394, 602, 1138, 408, 616, 1143, 422,
          1225, 630, 436, 1237, 644, 450}], 
        Line3DBox[{261, 464, 1065, 262, 477, 1077, 283, 491, 1087, 297, 505, 
         1095, 311, 519, 1101, 325, 533, 1105, 339, 547, 353, 561, 1112, 367, 
         575, 1123, 381, 589, 1132, 395, 603, 1139, 409, 617, 1144, 423, 631, 
         1147, 437, 1238, 645, 451}], 
        Line3DBox[{8, 667, 23, 681, 38, 696, 53, 711, 68, 726, 83, 741, 98, 
         756, 113, 771, 128, 786, 143, 801, 158, 816, 173, 831, 188, 846, 203,
          860, 218}], 
        Line3DBox[{263, 465, 264, 1150, 478, 284, 1153, 492, 298, 1158, 506, 
         312, 1165, 520, 326, 1174, 534, 340, 1185, 548, 354, 1191, 562, 368, 
         1194, 576, 382, 1199, 590, 396, 1206, 604, 410, 1215, 618, 424, 1226,
          632, 438, 1239, 646, 452}], 
        Line3DBox[{265, 466, 1066, 266, 479, 285, 1154, 493, 299, 1159, 507, 
         313, 1166, 521, 327, 1175, 535, 341, 1186, 549, 355, 563, 1113, 369, 
         1195, 577, 383, 1200, 591, 397, 1207, 605, 411, 1216, 619, 425, 1227,
          633, 439, 1240, 647, 453}], 
        Line3DBox[{267, 467, 1067, 268, 480, 1078, 286, 494, 300, 1160, 508, 
         314, 1167, 522, 328, 1176, 536, 342, 1187, 550, 356, 564, 1114, 370, 
         578, 1124, 384, 1201, 592, 398, 1208, 606, 412, 1217, 620, 426, 1228,
          634, 440, 1241, 648, 454}], 
        Line3DBox[{269, 468, 1068, 270, 481, 1079, 287, 495, 1088, 301, 509, 
         315, 1168, 523, 329, 1177, 537, 343, 1188, 551, 357, 565, 1115, 371, 
         579, 1125, 385, 593, 1133, 399, 1209, 607, 413, 1218, 621, 427, 1229,
          635, 441, 1242, 649, 455}], 
        Line3DBox[{271, 469, 1069, 272, 482, 1080, 288, 496, 1089, 302, 510, 
         1096, 316, 524, 330, 1178, 538, 344, 1189, 552, 358, 566, 1116, 372, 
         580, 1126, 386, 594, 1134, 400, 608, 1140, 414, 1219, 622, 428, 1230,
          636, 442, 1243, 650, 456}], 
        Line3DBox[{273, 470, 1070, 274, 483, 1081, 289, 497, 1090, 303, 511, 
         1097, 317, 525, 1102, 331, 539, 345, 1190, 553, 359, 567, 1117, 373, 
         581, 1127, 387, 595, 1135, 401, 609, 1141, 415, 623, 1145, 429, 1231,
          637, 443, 1244, 651, 457}], 
        Line3DBox[{275, 653, 654, 1071, 276, 484, 1082, 290, 498, 1091, 304, 
         512, 1098, 318, 526, 1103, 332, 540, 1106, 346, 554, 360, 568, 1118, 
         374, 582, 1128, 388, 596, 1136, 402, 610, 1142, 416, 624, 1146, 430, 
         638, 1148, 444, 1245, 656, 657, 658}], 
        Line3DBox[{445, 639, 655, 1232, 431, 625, 1220, 417, 611, 1210, 403, 
         597, 1202, 389, 583, 1196, 375, 569, 1192, 361, 555, 347, 541, 1179, 
         333, 527, 1169, 319, 513, 1161, 305, 499, 1155, 291, 485, 1151, 277, 
         471, 1149, 250, 458, 652, 659}]}, {}, {}}},
     VertexNormals->CompressedData["
1:eJwUmXc81e8bxlWKlBYJZSY7I5WVnhIqpIivEUopkrKKRCVbNplJRmb23vc5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      "]], GraphicsComplex3DBox[CompressedData["
1:eJx12E1oz3EcwPGFDCkHW5R22E1oDlaK8m8ccBFLqHkIkTB28BRDTZ4PWjmY
4mJqYg9KW5uM0R95WjEOm8UmxDxsajVGfyxvh/en/69+l1efPt9v7+M3d932
wg3DMjIyvv/5h//5j+2/Vn22ojHxcObirLMVlxL7smrmd+2tTCwcLOpZnJkM
/qSh82BbwePgU5qmj5nW/DT41jMlbcUdL4LX7Lp6vnagPXjv0m+b+rJfBa8Y
+rqCN41qOjCr6k3wjt3t6zvq3wb/+e7HgtLk++A5yybl5bR9CD4nOXt8c3dP
8DX5KwdW930OXnahtDOV+hqczrXbxx7O3FkXOtvpbKeznc52OtvpbKeznc52
OtvpbKeznc52OtvpbKfznju9qYKca6Gznc52OtvpbKeznc52OtvpbKeznc52
OtvpbKeznc52OhdMeL63NNkQOtvpbKeznc52OtvpbKeznc52OtvpbKeznc52
OtvpbKfzmC2N/fXF10NnO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U5nO53t
dH7WfK6kL/tm6Gyns53Odjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53Oi0a3
9GevaQmd7XS209lOZzud7XS209lOZzud7XS209lOZzud7XS203nG0HcndLbT
2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U7niasulvzt6s52OtvpbKez
nc52OtvpbKeznc52OtvpbKeznc52Otvp/OvIhJrijruhs53Odjrb6Wyns53O
djrb6Wyns53Odjrb6Wyns53Odjp31x3vOVF7P3S209lOZzud7XS209lOZzud
7XS209lOZzud7XS209lO53vtg5OrDj0Ine10ttPZTmc7ne10ttPZTmc7ne10
ttPZTmc7ne10ttP5yohtG5PLH4XOdjrb6Wyns53Odjrb6Wyns53Odjrb6Wyn
s53Odjrb6Vye9/pC99QnobOdznY62+lsp7OdznY62+lsp7OdznY62+lsp7Od
znY671hR2JVKtYbOdjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53OdjrbR+ZM
yh338Vbi9Mn8U20F1aG/vXfLp821A1+Cs9/O/rJ5FXP7slvDfjv703m6+4f3
1X/zdubT9fG5D4r6d7+sv5GoW3t7SUPx5f/eeDS/cnnp1+DMDz7uLx840Rrm
7XRIt9/3Z3+6+3s/8+neb30u90l3f5/7G/YiAPg=
     "], {{
       {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
         GrayLevel[1], 3], 
        StyleBox[GraphicsGroup3DBox[
          TagBox[Polygon3DBox[CompressedData["
1:eJwBCQX2+iFib1JiAgAAAKgBAAADAAAA4gIRFQUGEgIDEwMEFgYHFwcIGgoL
HAwNGAgJGQkKFAQFKhobGwsMKRkaIxMUIBARIRESJBQVJRUWKBgZ7+XkJhYX
JxcYHQ0OKxscLBwdPy8wRzc4MSEiLR0eMiIjNCQlNycoMyMkNSUmNiYnLx8g
MCAhOCgpOSkqQDAxPCwtPi4vQTEyIhITQjIzRDQ1OiorOyssQzM0RTU2gHBx
RjY3f29wTj4/Sjo7Szs8Tz9AUEBBU0NEVUVGUUFCUkJDTT0+Y1NUVERFYlJT
XExNWEhJWUlKXU1OXk5PYVFSV0dIX09QYFBRVkZHZFRVZVVWd2doSTk6aVla
ZlZXa1tcbV1ecGBhbFxdbl5fb19gZ1dYaFhZcWFicmJjeGhpdWVmdmZnempr
SDg5e2tsfW1uc2NkdGRlfGxtfm5vWkpLgXFyzb2+hnZ3g3N0hHR1nIyNh3d4
inp7i3t8jHx9jX1+hXV2iXl6jn5/kICBlYWGkoKDk4OEloaHmIiJm4uMkYGC
mYmKmoqLj3+A8PjnnY2On4+Qo5OUoJCRoZGSno6PpJSVp5eYqJiZqZmaqpqb
opKTq5ucrJydrZ2er5+gsKChsaGisqKjlISFs6OkuKiprp6ftqant6eotKSl
gnJzuamqu6uswLCxva2uvq6vwbGywrKzxra3yLi5w7O0xbW2v6+w1sbHx7e4
1cXGzr6/y7u8zLy9z7/A0MDB5sXUyrq70cHC0sLDybm618fI2MjJCBgXvKyt
3MzN2cnK3c3O38/Q4+IQ3s7P4NDR7ejS2srL28vMAhIRAxMSCRkYBhYVBxcW
ChoZuqqrCxsaDR0cBBQTBRUUDBwb5B0OECAfESEgEiIhFCQjFSUkFiYlFycm
GCgnGSkoGiopGysqHCwrHS0sHy8uIDAvITEwIjIxIzMyJDQzJTU0JjY1Jzc2
KDg3KTk4Kjo5Kzs6LDw7Lj49Lz8+M0NCMEA/MUFASVlYNERDNkZFN0dGOEhH
OUlIMkJBOkpJO0tKPU1MP09OQFBPQVFQQlJRSFhXQ1NSR1dWPk5NRVVURlZV
RFRTNUVESlpZbn59TV1cTl5dT19eUGBfUWFgUmJhU2NiVGRjVWVkVmZlV2dm
WGhnWWloW2tqXGxrXW1sXm5tX29uYHBvYXFwYnJxY3NyZHRzZXV0ZnZ1Z3d2
bHx7aHh3anp5TFxbbX18b39+cIB/cYGAcoKBa3t6c4OCdISDdYWEd4eGeYmI
eoqJe4uKgZGQfIyLgJCPdoaFfo6Nf4+OfY2MEyMigpKRhJSTiZmYhZWUhpaV
ipqZi5uajp6dkKCfjJybjZ2ciJiXnq6tj5+ena2sl6emk6OilKSjmKinmamo
nKyrkqKhmqqpm6uqkaGgn6+uoLCvssLBu8vKpLSzobGwpra1qLi3q7u6p7e2
qbm4qrq5orKxo7OyrLy7rb28s8PCsMC/scHAtcXElaWktsbFuMjHrr69r7++
t8fGucnIusrJvMzLg5OSwdHQvs7Nv8/OwtLR8Ofmx9fWydnYxdXUxtbVwNDP
yNjXytrZ6+QOzNzbzd3czt7dz9/eHeQe0ODf8u7jy9va7uriEOIR6ODRpZWW
5OUe+fHhvc3M8eno7ObU6Ong8+/r9u4B4uoC9PDs9fHt5ufE0ujR4+7i9+8P
7vIB7PDm7fHo7/MPxebE8PTT7vbq6+/k+PDT8fXh7/fl8fnpl2heKQ==
            "]],
           Annotation[#, "Charting`Private`Tag$3284#1"]& ]],
         Lighting->"Neutral"]}, {}, {}, {}, {}}, 
      {GrayLevel[0], 
       Line3DBox[{246, 1, 242, 227, 16, 31, 46, 61, 76, 91, 106, 121, 136, 
        151, 166, 181, 196, 231, 248, 211, 244, 236, 212, 213, 214, 215, 216, 
        217, 218, 219, 220, 221, 222, 223, 224, 233, 249, 225, 245, 237, 210, 
        195, 180, 165, 150, 135, 120, 105, 90, 75, 60, 45, 30, 229, 247, 15, 
        243, 235, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 234, 246},
        VertexColors->None]}},
     VertexColors->CompressedData["
1:eJxTTMoPSmVkYGD4CcRpYPDMfpQepUfpUXqUHqVH6aFHAwAuZnMS
      "],
     VertexNormals->CompressedData["
1:eJztyLEJACEURMGPVmIl9nAlCBdfC5ZsanZGgtjCLDwWprTveVNEzFWOvX7+
qJxzzjnnnHPOOeecc845v/0H/ZUifQ==
      "]]}, 
   {RGBColor[1, 0, 0], PointSize[Large], Point3DBox[{0.8, 0.18, 0.15}]}},
  Axes->True,
  AxesLabel->{
    FormBox["\"efficiency\"", TraditionalForm], 
    FormBox["\"      time\\n      spent\"", TraditionalForm], 
    FormBox["\"effective\\nreturn      \"", TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotLabel->FormBox["\"Effective Return Plateau = 4.%\"", TraditionalForm],
  PlotRange->{All, All, All},
  PlotRangePadding->{Automatic, Automatic, Automatic},
  Ticks->{Automatic, Automatic, {{0.04, 
      FormBox["\"4%\"", TraditionalForm]}, {0.1, 
      FormBox["\"10%\"", TraditionalForm]}, {0.15, 
      FormBox["\"15%\"", TraditionalForm]}, {0.2, 
      FormBox["\"20%\"", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{3.6973214110898504`*^9, 3.6973235340684776`*^9, 
  3.6980443950797586`*^9, 3.6980448336821423`*^9, 3.731421559125115*^9},
 TextAlignment->Center,ExpressionUUID->"3bdba26b-6891-4cce-b007-8357e7e8d805"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.15",
  FontWeight->"Bold"],
 ". Real Estate Investor Life Cycle Plot showing a beginning point"
}], "FigureCaption",
 CellChangeTimes->{{3.697321230388098*^9, 3.6973212690018272`*^9}, {
  3.697321315176675*^9, 3.697321319615485*^9}, {3.6973214286124716`*^9, 
  3.697321448145464*^9}},
 TextAlignment->Center,ExpressionUUID->"cde5783c-2fe7-4d3f-b520-75990c8f0f22"],

Cell["The passage of time", "Section",
 CellChangeTimes->{{3.697321954029348*^9, 3.697321956893964*^9}, {
  3.697321989685192*^9, 
  3.6973219919853287`*^9}},ExpressionUUID->"67f0d9b5-91d9-47c3-8da7-\
8a4e43817cd5"],

Cell["\<\
Life is a downhill path as a practical matter. For a host of reasons, as time \
passes, the amount of time and ability devoted to operating real estate \
declines. The path varies. Some have expensive divorces and get hooked on \
drugs (the black arrow). Some enter the priesthood (the red arrow). Some go \
back to graduate school (the blue arrow). In all events, with the passage of \
time and age return declines. This observation is true of many walks of life, \
not just real estate investment.\
\>", "Text",
 CellChangeTimes->{{3.6240198423572197`*^9, 
  3.6240200289668937`*^9}},ExpressionUUID->"6d9becb2-4507-4a7a-9bf8-\
21024042f03c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pt", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "Large", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{".8", ",", ".18", ",", ".15"}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"arrows", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"{", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{".8", ",", ".18", ",", ".14"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{".4", ",", ".11", ",", ".04"}], "}"}]}], "}"}], "]"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{".8", ",", ".18", ",", ".15"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{".6", ",", ".07", ",", ".04"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{".8", ",", ".18", ",", ".15"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{".22", ",", ".23", ",", ".052"}], "}"}]}], "}"}], "]"}]}],
        "}"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"showfour", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"showthree", ",", "arrows", ",", "pt"}], "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.6973215396599092`*^9},ExpressionUUID->"92e315df-9f5d-4d61-bc48-\
0e27c10eb0c6"],

Cell[BoxData[
 Graphics3DBox[{{{GraphicsComplex3DBox[CompressedData["
1:eJxdnHlUTe8X/yuphEiZIlNFKkKI0KOkCSkic0QhUoZSVGhCSaNmzfM8z93m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      "], {{
        {RGBColor[1, 1, 0], EdgeForm[None], 
         StyleBox[GraphicsGroup3DBox[
           TagBox[{Polygon3DBox[CompressedData["
1:eJwtmXfgVuMbxt9znhsNkr1L+GUlI5QiZKUilWgvoozKqEg7oSISaaoUSVkZ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              "]], Polygon3DBox[CompressedData["
1:eJwtmgn8VsMexs/MHGUXadUeWSttJFlaCEUrIi6yFdpL0r6qaEVRSqFEtpRd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              "]], Polygon3DBox[CompressedData["
1:eJwt1ne8j2UfB/BzHHuPbJlZDUJmmWWV7JUZGT12ViqhrAqlRwplZZeEEC0q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              "]]},
            Annotation[#, "Charting`Private`Tag$3249#1"]& ]],
          Lighting->Automatic]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0bsrR2EcwOHjfr9lkiKbFKsUqxSTsrAxMbAympgJf4CYJUbXn+siud8v
SXId3CXxvGX4nOfUe87b9+0tae1q7IyLoqhX7wrvz7rSUHwU5XKUxZxkBRdY
w0028JwtfGIHf9jDzIQo6mchR1jGcVZxmnVc4jxv+KltvepBM4bZ4Sx3Oce9
8D33wxw84CIPGeMRl3jMZZ5whadc5RnXeM51XnDAvLf80qXe9Kg2c22xiTHW
coqVHGMph1nAPqazm9/2aw9nYDNPWc8NVodzsJwTLArn8981P5SjF90r33zZ
zGNWWGMms5jBDKYzjWlMYSqTmMIEJoc7ZRJ/lRjuJ6yFOWWEaNDj7v/+/wCI
PEiz
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{661, 957, 458, 660, 1060, 868, 662, 1061, 869, 663, 1062, 
          870, 664, 1063, 871, 665, 1064, 872, 666, 1065, 873, 667, 465, 668, 
          1066, 874, 669, 1067, 875, 670, 1068, 876, 671, 1069, 877, 672, 
          1070, 878, 673, 1057, 1071, 879, 958}], 
         Line3DBox[{675, 962, 1149, 674, 1072, 880, 676, 1073, 881, 677, 1074,
           882, 678, 1075, 883, 679, 1076, 884, 680, 1077, 885, 681, 963, 
          1150, 682, 479, 683, 1078, 886, 684, 1079, 887, 685, 1080, 888, 686,
           1081, 889, 687, 1082, 890, 688}], 
         Line3DBox[{690, 964, 1151, 689, 965, 1152, 691, 1083, 891, 692, 1084,
           892, 693, 1085, 893, 694, 1086, 894, 695, 1087, 895, 696, 966, 
          1153, 697, 967, 1154, 698, 494, 699, 1088, 896, 700, 1089, 897, 701,
           1090, 898, 702, 1091, 899, 703}], 
         Line3DBox[{705, 968, 1155, 704, 969, 1156, 706, 970, 1157, 707, 1092,
           900, 708, 1093, 901, 709, 1094, 902, 710, 1095, 903, 711, 971, 
          1158, 712, 972, 1159, 713, 973, 1160, 714, 509, 715, 1096, 904, 716,
           1097, 905, 717, 1098, 906, 718}], 
         Line3DBox[{720, 974, 1161, 719, 975, 1162, 721, 976, 1163, 722, 977, 
          1164, 723, 1099, 907, 724, 1100, 908, 725, 1101, 909, 726, 978, 
          1165, 727, 979, 1166, 728, 980, 1167, 729, 981, 1168, 730, 524, 731,
           1102, 910, 732, 1103, 911, 733}], 
         Line3DBox[{735, 982, 1169, 734, 983, 1170, 736, 984, 1171, 737, 985, 
          1172, 738, 986, 1173, 739, 1104, 912, 740, 1105, 913, 741, 987, 
          1174, 742, 988, 1175, 743, 989, 1176, 744, 990, 1177, 745, 991, 
          1178, 746, 539, 747, 1106, 914, 748}], 
         Line3DBox[{106, 347, 107, 348, 108, 349, 109, 350, 110, 351, 111, 
          352, 112, 353, 113, 354, 114, 355, 115, 356, 116, 357, 117, 358, 
          118, 359, 119, 360, 120}], 
         Line3DBox[{750, 992, 1179, 749, 993, 1180, 751, 994, 1181, 752, 995, 
          1182, 753, 996, 1183, 754, 997, 1184, 755, 547, 756, 998, 1185, 757,
           999, 1186, 758, 1000, 1187, 759, 1001, 1188, 760, 1002, 1189, 761, 
          1003, 1190, 762, 554, 763}], 
         Line3DBox[{765, 555, 764, 1107, 915, 766, 1108, 916, 767, 1109, 917, 
          768, 1110, 918, 769, 1111, 919, 770, 1112, 920, 771, 1004, 1191, 
          772, 1113, 921, 773, 1114, 922, 774, 1115, 923, 775, 1116, 924, 776,
           1117, 925, 777, 1118, 926, 778}], 
         Line3DBox[{780, 1005, 1192, 779, 1006, 1193, 781, 1119, 927, 782, 
          1120, 928, 783, 1121, 929, 784, 1122, 930, 785, 1123, 931, 786, 
          1007, 1194, 787, 1008, 1195, 788, 1124, 932, 789, 1125, 933, 790, 
          1126, 934, 791, 1127, 935, 792, 1128, 936, 793}], 
         Line3DBox[{795, 1009, 1196, 794, 1010, 1197, 796, 1011, 1198, 797, 
          1129, 937, 798, 1130, 938, 799, 1131, 939, 800, 1132, 940, 801, 
          1012, 1199, 802, 1013, 1200, 803, 1014, 1201, 804, 1133, 941, 805, 
          1134, 942, 806, 1135, 943, 807, 1136, 944, 808}], 
         Line3DBox[{810, 1015, 1202, 809, 1016, 1203, 811, 1017, 1204, 812, 
          1018, 1205, 813, 1137, 945, 814, 1138, 946, 815, 1139, 947, 816, 
          1019, 1206, 817, 1020, 1207, 818, 1021, 1208, 819, 1022, 1209, 820, 
          1140, 948, 821, 1141, 949, 822, 1142, 950, 823}], 
         Line3DBox[{825, 1023, 1210, 824, 1024, 1211, 826, 1025, 1212, 827, 
          1026, 1213, 828, 1027, 1214, 829, 1143, 951, 830, 1144, 952, 831, 
          1028, 1215, 832, 1029, 1216, 833, 1030, 1217, 834, 1031, 1218, 835, 
          1032, 1219, 836, 1145, 953, 837, 1146, 954, 838}], 
         Line3DBox[{840, 1033, 1220, 839, 1034, 1221, 841, 1035, 1222, 842, 
          1036, 1223, 843, 1037, 1224, 844, 1038, 1225, 845, 1147, 955, 846, 
          1039, 1226, 847, 1040, 1227, 848, 1041, 1228, 849, 1042, 1229, 850, 
          1043, 1230, 851, 1044, 1231, 852, 1148, 956, 853}], 
         Line3DBox[{867, 961, 1245, 1059, 866, 1244, 1056, 865, 1243, 1055, 
          864, 1242, 1054, 863, 1241, 1053, 862, 1240, 1052, 861, 1239, 1051, 
          860, 1238, 1050, 859, 1237, 1049, 858, 1236, 1048, 857, 1235, 1047, 
          856, 1234, 1046, 855, 1233, 1045, 854, 1058, 1232, 959, 960}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{251, 459, 1060, 252, 472, 1072, 278, 1152, 486, 292, 1156,
           500, 306, 1162, 514, 320, 1170, 528, 334, 1180, 542, 348, 556, 
          1107, 362, 1193, 570, 376, 1197, 584, 390, 1203, 598, 404, 1211, 
          612, 418, 1221, 626, 432, 1233, 640, 446}], 
         Line3DBox[{253, 460, 1061, 254, 473, 1073, 279, 487, 1083, 293, 1157,
           501, 307, 1163, 515, 321, 1171, 529, 335, 1181, 543, 349, 557, 
          1108, 363, 571, 1119, 377, 1198, 585, 391, 1204, 599, 405, 1212, 
          613, 419, 1222, 627, 433, 1234, 641, 447}], 
         Line3DBox[{255, 461, 1062, 256, 474, 1074, 280, 488, 1084, 294, 502, 
          1092, 308, 1164, 516, 322, 1172, 530, 336, 1182, 544, 350, 558, 
          1109, 364, 572, 1120, 378, 586, 1129, 392, 1205, 600, 406, 1213, 
          614, 420, 1223, 628, 434, 1235, 642, 448}], 
         Line3DBox[{257, 462, 1063, 258, 475, 1075, 281, 489, 1085, 295, 503, 
          1093, 309, 517, 1099, 323, 1173, 531, 337, 1183, 545, 351, 559, 
          1110, 365, 573, 1121, 379, 587, 1130, 393, 601, 1137, 407, 1214, 
          615, 421, 1224, 629, 435, 1236, 643, 449}], 
         Line3DBox[{259, 463, 1064, 260, 476, 1076, 282, 490, 1086, 296, 504, 
          1094, 310, 518, 1100, 324, 532, 1104, 338, 1184, 546, 352, 560, 
          1111, 366, 574, 1122, 380, 588, 1131, 394, 602, 1138, 408, 616, 
          1143, 422, 1225, 630, 436, 1237, 644, 450}], 
         Line3DBox[{261, 464, 1065, 262, 477, 1077, 283, 491, 1087, 297, 505, 
          1095, 311, 519, 1101, 325, 533, 1105, 339, 547, 353, 561, 1112, 367,
           575, 1123, 381, 589, 1132, 395, 603, 1139, 409, 617, 1144, 423, 
          631, 1147, 437, 1238, 645, 451}], 
         Line3DBox[{8, 667, 23, 681, 38, 696, 53, 711, 68, 726, 83, 741, 98, 
          756, 113, 771, 128, 786, 143, 801, 158, 816, 173, 831, 188, 846, 
          203, 860, 218}], 
         Line3DBox[{263, 465, 264, 1150, 478, 284, 1153, 492, 298, 1158, 506, 
          312, 1165, 520, 326, 1174, 534, 340, 1185, 548, 354, 1191, 562, 368,
           1194, 576, 382, 1199, 590, 396, 1206, 604, 410, 1215, 618, 424, 
          1226, 632, 438, 1239, 646, 452}], 
         Line3DBox[{265, 466, 1066, 266, 479, 285, 1154, 493, 299, 1159, 507, 
          313, 1166, 521, 327, 1175, 535, 341, 1186, 549, 355, 563, 1113, 369,
           1195, 577, 383, 1200, 591, 397, 1207, 605, 411, 1216, 619, 425, 
          1227, 633, 439, 1240, 647, 453}], 
         Line3DBox[{267, 467, 1067, 268, 480, 1078, 286, 494, 300, 1160, 508, 
          314, 1167, 522, 328, 1176, 536, 342, 1187, 550, 356, 564, 1114, 370,
           578, 1124, 384, 1201, 592, 398, 1208, 606, 412, 1217, 620, 426, 
          1228, 634, 440, 1241, 648, 454}], 
         Line3DBox[{269, 468, 1068, 270, 481, 1079, 287, 495, 1088, 301, 509, 
          315, 1168, 523, 329, 1177, 537, 343, 1188, 551, 357, 565, 1115, 371,
           579, 1125, 385, 593, 1133, 399, 1209, 607, 413, 1218, 621, 427, 
          1229, 635, 441, 1242, 649, 455}], 
         Line3DBox[{271, 469, 1069, 272, 482, 1080, 288, 496, 1089, 302, 510, 
          1096, 316, 524, 330, 1178, 538, 344, 1189, 552, 358, 566, 1116, 372,
           580, 1126, 386, 594, 1134, 400, 608, 1140, 414, 1219, 622, 428, 
          1230, 636, 442, 1243, 650, 456}], 
         Line3DBox[{273, 470, 1070, 274, 483, 1081, 289, 497, 1090, 303, 511, 
          1097, 317, 525, 1102, 331, 539, 345, 1190, 553, 359, 567, 1117, 373,
           581, 1127, 387, 595, 1135, 401, 609, 1141, 415, 623, 1145, 429, 
          1231, 637, 443, 1244, 651, 457}], 
         Line3DBox[{275, 653, 654, 1071, 276, 484, 1082, 290, 498, 1091, 304, 
          512, 1098, 318, 526, 1103, 332, 540, 1106, 346, 554, 360, 568, 1118,
           374, 582, 1128, 388, 596, 1136, 402, 610, 1142, 416, 624, 1146, 
          430, 638, 1148, 444, 1245, 656, 657, 658}], 
         Line3DBox[{445, 639, 655, 1232, 431, 625, 1220, 417, 611, 1210, 403, 
          597, 1202, 389, 583, 1196, 375, 569, 1192, 361, 555, 347, 541, 1179,
           333, 527, 1169, 319, 513, 1161, 305, 499, 1155, 291, 485, 1151, 
          277, 471, 1149, 250, 458, 652, 659}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJwUmXc81e8bxlWKlBYJZSY7I5WVnhIqpIivEUopkrKKRCVbNplJRmb23vc5
h2Nm7+3YzixZZfQ7v7/O6/W8zh+fcz33fV3X+3MEHtrpPd7NwMAwzsjAsIf+
uSi8kMZ0NROqVB7ymHGVg0va7tfG/TTUpvh6nx9HJthdm3UTGcIBo/XBrLAv
NKRzQO8mdSgDHhz8ZtWz0gLRTj9lKrRpSPvd4fiVgAx44SBhjH/aBXYHmN8d
maMiTr3vl79LZEAT/7wxrbgXvCv2yd95SkVfo9QcTDDpgA7ZRon1DcD98hUJ
5zEKYtZafHZfMx1Cti8/PN80DLs+FJQnXKUgiHDIOPQjDUJYn0nKB47BXH5b
Rc9nMjIQjL6dcD0NQvnE9WL4JsHUOyZzi0JCfGePxB2Ab1AUugc9xE3BHs1L
NXVKJHSwQrpQ6Pw3ONexXsAwQQBVPdF8O28imrI9bWKfmQq8Ks0HY2amYSlV
moGtfQk9yZpbk+dJheDVQxNafTMwziu3y5iDfh7/EOMfmQK0QVcPq8JZkLad
PphqsYjkdqEthYMpsLz+XOea+xxw45LMWQoWkP5myYwMJg/MRr4Vbr4ugxx5
xiC/bhpKuNGLEQ3OA1mc6XMmQxzsk0j4UZlAQ59W+pS5r+XBV30+H1ONFoiy
/4+B6w4NxZLN72zO5EKoYUKA6VYntOGswnMoVMR0I2FTwjEXMH1XHL5d7IWK
I/oxSy5UZNdvGnT7Zw7ENLxf231jAMhd/sMff1GQyg4JhC1yQMuh05RNehh+
Pqj0e2pGQWIe7yafN32H1i6WzrmlUQigZiGTOjKq9yp8ij3zHYSOc0O+ywSM
uJXnHTlBRucVZBYC3mWD760E0Tu2UyBaytbJYkNClZMGMrTeLPA64HB5yJcA
f924U7wqiSjzXcuuHpEs6Lc60qwYNA0ve9UDbZmIyAIvkNDqlgnb3HeLX72d
gWs9L3bbGiyhilBde4nuDEi/YyFQeG8Wfu/7ojD1bRENzq8p7hPLgEM/k0PO
iM5Bjcd+i9m1BXTa7/0xfv8iuCpMLeCfKIVfbElx7j9oqPNTsvG2TRGI6Fy4
qDCChWNnOk69i6chmxitiowrRWB0kVfH9UszZFJ3Kod1aWiX5UVmGZYiKBgr
0k2X6IT1rytJj1aoqCrKWHe6uRD0dPp0Bmp6QO70dLCBNxXdPB8YKvuuEKYi
i9ieQj/oEtrYJBmpaOvjtYhUiULw2v9v4GH8EGyU1rN5O1MQo45cfV1PAVz4
Y5pRrzUKy+ruLpvjZNR9sOfA5ssCaH/90CmuZxwytrs1TqiQUUuhhn0ZWwF8
2aive35iChKN9blloklI9CBuxORBPpjt+eOXJEMA53XD3Y9JRNQgdf0tJToP
RNYUegMvTMP+ABuNT5eJCBsps7GnnT4nOZgGVpEZ8Oob3W0cvoTKbP4UyjDm
Qplr9FPxfbNgF7L65uDcIooh58/XquQAy98ns1u9s9Ce+oWxVWkRPRz+UyQf
VwqPgp+/ib9RCkI3h5T1G2moprKkn9m1FMorbM9EW2CBalkftxlNQ28o3K7y
mqXwfbT6E8PfJlj47ql5Uo+Gjj0mRkyzlsJmbUS0qkUHNLAbvDb+Q0Ucg74L
1vgSuP7Yn8lFowceHuAVrwqhor7V6CB9xxLQq/FIMlDqB0zlP6EP7FSk8DLq
jgZHCXCpzrAI7x8CFv9bMWzBFDQut4mZLioGLV/JexMFI0AZjZcb+0tGsX9C
BXA3i4Gdeui1rcw4JEtpfZZ7QEZqhfuZLceKYG3uZ2KM3yRUK77m0AESimAN
+SpsWwRNX7CvX4xOgYhhZ68UNwmd/fEi4OrfQjjMXP0gbZIAUltqmkmORFSh
zlhc71cIZPGOTKnuafBajdiRaV1C3i9FzCOPF8Lo7e+vaAUzEFBWXisnuITy
b0bz2n8rgF3cUiLz72dh/kGFMc5tEanK6fDvRFYAczqzo0JFCUjE7xISBRry
102lqDlUwL7mYtI2GQP+M0bXdCJoyJnl24niyxVQNYlbarnXBD7zhOAtum+M
G9ba222Xg/DIDzeWL+2AbY0eyN+iItsTZlMzeeUg7ndFwaW3G1Z0msOVY6hI
RPmyQJZ+ObAy1DNiKvrgL4m9OF+QirpML8g4/iyDQadn/GZug/BUlePw5WQK
OjuS/2/Dqwy4rrROIq4RmL+v6CtwnII4juhuUo6UQQSnQs2l8DG4sng82d+D
jLxX1QeIsfR5uHOadXl6AjyyGD95z5FQSfH08ac8peAc7jWt7zcFu50+r2+p
k5Dr/rjl6q8l0JNflJfwkQAOe9f/ZaQS0QeTISdWgRLgOFWl+MttGrYaDibv
YyCiid+GJLOUYtBZ0SJym84AP+HN9CPTJbQ/LkLCR6gYtqWMd29LzEKTMkv8
QOUiqrk68feYazW8PO7F1SZZAvtxQXJHymmocn+Yqqp+NaSTL1dqu2OAQblQ
NiyIhjZ15riieauh/Pj9rhxcI/BugmW8Dg3drVCTVxiugi6M7eGBiR/gm53q
7rtDRe2SYZ4xPlVgYmOm2vioG0S7jRm3vlDRwZx2C/0zVSAv/OfbF6U++Pg4
vXRUioqapZjjJKsqIULdxHXvrwHgMsvmFy2moN0Prh9eVK+ESp2YOqr3MAjs
S4ynSVLQ94I/4jdaK6DnWs8t7tVR2K23NqeQSEbzVz14/t6ogBvTC4yMVyfg
5RFBj9/MZKRddrwnqL4cor+F+VuenwK989dJpBckVJo2w2ejXA6914L2+F4k
wL+QBkJ9NxENk0cEegvLwOrNPT9bkWngmmFipp4jouZNT8KESBkw/BqcwDPN
QHWwRUBO5BKKDPpP3i2xFOaWz47cG5qBllq9laOri+jq4tfu4zfr4MPdv/xC
6cXQ2LMQJZhHQ1uDL35GCNZB8BHyfw8OY8D10LW8YR8amvnr+vU+sRYO7tL/
5SHVCOOvXVoPa9FQtXSi37fkWkB7byS6C/8ApQumKpt0ncfrFRK7btZCj4mW
l956F0h5BE+fTKWifNdXBr6zNcCP+UJ/+l7Iwb92EFGkohWRalZ/pxrArdZu
cdkMwOEHCsyrOAqyY882T9uoBji2+Ij6ewjucZ389FSVglRvJZlkv6qGT2dz
ko6ajsK//j8Pn1SSUVt0LkGXXAUicv+NTyePw0Bnbl6VGBnpTO1eUjKvgsV9
VRZG+EkQvmkWxBlFQmLp12QJPyrhK5NKudPMFGzaYhRZt4mo6cvRiVjFSmiN
Hegr7SVAsI+/99ZDIqriw8cEpVVA/qFPXUwl0/Ch5ugAb/MSqncezq89WgFC
IwklJ31mIKrH3fjD2SXU5GBZoueJgU3tdlcO+rxv/Nc17PSNhlgceoYtX2BA
stvKVUob4IVwofbVdzRU9d4w44YuBoyu1N/g/YqH18o00isNGnrcHmoRJoGB
uef1W31ObdB6m3xYnK5zUYCEzMwmwGUzq4D9IV1wQeFFRWU6FU3TXN+9jgCQ
VssvfH+jF+QZul4XX6WihfOE9JRT9HP2YPPI+X7YnbAd2NhFQadT3n2WS6gD
FaW/FujJEJizWDoXGlBQhsyzya1jdaC5Yt8l0TgCW4uvDM/1kNFKUwpgPWth
gEX7ctLecXh2nJz95zoZya6pPpWk1MDkqOxzB6FJ+Fw6Mv21goQivbmlGu/W
wJWZCSXn8CmYYDhP/HKGhBhMB9yXy6thlTskdsqDALMRZg9uhBGRXUeYNZm7
Go5uJsatPZiG87Np8u1/6D0E43Oh8W0VrO6oiuufm4Ev1xs15B4toT+DgoHS
A1i4TYm475xeBIveF1hO0HuFRWBsaA0WCx3+BpeTPerA2aVmz9grGsqIIssO
pmIh5Wiuhhk7HgIcBdDsFbr+Y2Muh95iIdC6HFPa2ArMUd9Pn6X7cwW23Idd
BwsO2ScuD4l0AXuUkNZyJhXNhuyVLzuBhdK99aet+nrAz3IlL/EGFRlYbGj1
jGBg+TWzhfWTfhgeeLRaQ+/VyoGfy+7EYiBQzaxqcnQQOqtGjiw+oSD1o45Z
3PR7t6OxTbyQG4H8rgCJ2kUyun1UroFtHwa+S5030rQdg4efKkI7H5FR+Mcz
smL2AFKcRpfFfSdgtCP1V+IwCRnslZZu76wDLLufcMKVKbDIEFEI0yIhfmfZ
HE/JOkixnXi/I0WAy7XmmYtVRBRkYMIT4VcLMWO8NumHpsHBr/18mygRGeV0
iZ6aroH/7ImGJ6emQbfqUJR89BLKjU8+ZcdfD7mh+g+5zhYBp6l2I08oDfV7
XXaNO1APf96w7xmurgUVTRf1WlsaOuec84KHggOen0rLHCEN0G1iGm+vRENZ
VPYZHzwOaKVOHqu8rcDg8fv3KXrfuBSufd8jCgcpDOvC/wV0wkjghYypLCqi
zslc7TfD0Xv24h3/Rz3Qn7rn9j4duv5D3Fb3+XBw1ZGJM2SpD8TX7FnX5yko
RoTwc88oFjxF759p0x8Eyu2kn5L0vieolRSfHY6FYard3/HUYWDGmRgIb5PR
wdgfh+XVsLDz7+Rpcv8ofCHdnTF5S0aS51tfev3GwIT1RZso4jiUcbUFnNsg
oeDlXAXTJAzcufs9dpYwCSIcqXE7dN8OjdqSeKuFgfXjvK58E1Mgfbd8fWWa
iN5jGt7wkQBGHgW0i9USoITh8vmzBkS0P7/SSv8ygOyb/SM+IdPQUGus9rVx
Can3T82YWTRA28Veq4HyQqDQBoxivWhoD09k8zXtBpD8kOIes10D3LpjHOsP
6Xn3X9sTs7MNUOPQznDmYAOkEV9oScvREO9WyYTM3gboCjr218a9Bd44L5sd
WaWi/x4bqD/pqwfFz3jNseYOCBHwl02k67z3l+p9zOd6YA/+cLZntRt6zpBW
9+pREVbamcBuWg9htKf8G3Z98F/MLE8EjYJKtFzS1DjqQcSg+sZm1wAg1m9G
iV4UNKNfbXK+DQdjPNVY1xPDYMT5QSPoMAXdLSzianTDQfBXmZhg1VEIMzF3
q/xERoe4c8i9onTuskq4hNMdh1TMLREXdjIK0ryWLtGLhb1hRcFM6pPwO/1V
8J4wEmI9kdsX6IaFk9ccanVDpqC05K+mDzMJvYqRKE8WxMINtczMcFsCUGp1
dZnfExFv0qgecwsGVuwE8Okq03A1jPOO+8oSOrA6vK4RhwfNzS/5PhqFMPHw
eUeUCw0lz7/A7vbGQ6OqB2+Seg28e9kuHG9E52vf9dEhSzzELQhSLELq4STB
WUpOgoa+G+fIal7Cw/jln+qUiWZ409tbcuonFT2eLKvZYMGDye5dFdyHOmDv
UHKFKt03WBwuTiR1N4Cp8Nbfc4HdwLBxKa9cn4oWOTiEj4U3QMhV577YP73Q
a5a0mrVGQUcfZWyLaDbAx3cB/6zuDIDv4zdKxqEU9Cyiuh63XQ8f7LbcroQM
ATN/qOlBfgp6yjMSjM2pB4WgAJJc0QiQtmYfMWeTkbTYzcUtw3poy4WfNdVj
kLd3qNNfiowmt22+qTLUg9P1UpGS7Al4Ib7foTKPhLS0sUl66TiQmeqcSEZT
8LZWo79QgoRad9pKxjRxwOw5oU45RQC9kHcSjulE9Ncp6s17KpY+h1qZoRQC
7DZYfE/gIyJnE+sFp+ZGeHbn5hDDcAE0FyexCD2joVa2fx9PFTdC2RdHkYrI
aghXnp0pvUVD9xkY93dHNkKayPaBLPZ6OHO0tT5YkIbeClW3HnzWCFPq7L/v
ajSDTXPjoAGRimQFFtSfKTaCH6v80SWjdjj0h+Q7m0ZFjYfmFpL/4WGnROdV
7OluyL+jviX3HxUNfQ7Vda3Dgxqa9LXw7YUlxusUoy0KOkN4ntzojAcB3/Qg
pt5+ODrlfcE1joL8fHW7LMXw4HlY3EiKeQj+K3w+iJOioDIviXGpwQZwfzXf
TRAagTtFq22PasnooePP+L8eDVA1uDUfIjoG0jkza54aZHT1vFrUJ5EGyBZT
1Px7bAKkQrIslNpI6GOPMb6mrR7OpeNqLsxOwu4Olf4IbRKa+XnUVugF3W8D
Gs00O6ZgrZxa49FGRDv5bIm2h+uhL28w4k4iAVxfPlWevkFEd2gPYyRpTfBk
Vrlb0K4APq85jt02p6EBw7zdA8NNoH5UNzl9oQruOlaEG6nSkOaxFGvfqibo
91UKH0jEwZ9SvPptLjrXtLL6FIc3QSChVtSlqAnSP+zT6Jihoqzibpbl+02g
O/bfBm/WD4heE30Vm0JFo1bEvT/PNIFl33Uqra4LTIx8qeF0nZ+mhBa+mG0E
RwHvb6ocvZD/SHS5nIGKDMsZhC4lNMIKX0V7h1E/7JMzjONMoaDE+lbpszqN
kOspk67iMwhcG5e6W5UpKCmZH3tiEw+DUgczYuKHoXtSaGO+g4ymGJR+tafi
wffQt97LsaPwlU3rqYcpGRG3sylcN/Gg3sW3Mv92HBp53HmT6FyzxG6PqyI1
wEacvHWQ1iSkc/e+ufKMhO5nJe9+GNQA91x1+Eo9puAB8bqiJpWI6smsl4sk
GqDzPYFt4zYB7lk1W0XYEdFWZ+/ZctYWeLt9aLaJuQBMZ1WPntGlodshll8c
N5ph//u8F+evVkGaS6pp6EUaOkgy8lYYpp9fUU5pksTBBrN8re9hGgpr4p95
XdAMfy/L1EqfbgL58QC5mDG6P6i7emPfNcPvModrn3baIGKOedshkYqufQkZ
q1BrBq2wXidhsy4I308WXzCgIr0T+fc59zRDY0XggkRWDwT1RoVM7KGiAbOK
9HT6/Q6eEHcqJPTBCMcpqztZFJRXwFEua9sEuH6VQ1Z7B+Hdooby5esUFNH0
sjiAswn+MCRX3mUbhpHDEudzJsgoU3CJyx3TCKEYra0ullHQfPFQ4bM9GVnF
kQidlo0ws55k500ag5eCaZQ9O/R5VhoXUN3XCJu/3w8Ylk4Aw+lQbI8fCX1o
ax/0SsODasg/dQU673h2Rs3OHiKhGK0ZXoVreHi8FakVuZsAmD37VfZ9IqLd
F2NmBx2+g1s82dObsQ5anrFJJFfTUJfzKC3C9zswxM85v24uA9Kmvn1cL73v
LfPg5Ba+wa7Kxy6B1Flo/nfj3V2JRSQbcVk64PM3GE8W/CavNwdFnLXqA70L
yOmApMMR52Ywncvy3POsFJIOfr+Fo3PNjy0tA6f3zdAswHnGT7kAJqTkYxoM
aWiv7r+49cUGePHu/Ufh+inQ3tlSS8cQkbRa3EHfl3g4fAAZNCdMgVuFdEoG
ndeyJa3Mrkplgjn7B/NXL+og++SyYmkNDRV2afoG3E6B7sEtLyauOcA3KR+z
ZF5Eqcbyt4wZW8BtK973imgpRBk7V9ip05DL/nuuhyoa4IgB/ythMQKcFNeM
OeZJRF88Tp9kH8uCtT1KIRwxVUAKSwg420JD8on5qg0uqTBdLMnNenEO9mok
Dk1RFhBN7VaoM64ZFq1PlHmUFcHyT8/Fn3Re3ic+mPmAAw+sbUc3legcxOBu
m30hm4iey0qb3ZrLAsPHO9a1P8uAhaRA8uqj+8agmEjr2RSoom3ISWvNwacb
EvOcYwtIZfQjzXh/C2CrKuUvxRWBjM8jrwK6nuym0w0t2w1g+8v/b99xAiQ4
vejhCSQiNUtOR3WFTFgrVPjL0lgFxHn5TyP05/9ePK7MqZ8KW6ZDnpet5uDv
Thw7M24BbX2mHO9vbAbsnZsqBwUL4KBIiYaLPg2FkAR+LdzDg2V0BWVv1xSc
Mfi1Z7qIiMI3Li1PfsqD0y3P/V1fYkF1UzCylM5fTxg33EWJGXCLVWrHQ7oZ
PFvTPuk/oqGOXLfAbsM8mD/nXHgpqAnYlG+89H9MQxNCZIbqrAy4oD3r1qza
AXVC3TMNh+gc57acqMqSB0bysY3f37TDzK3X/DeO09DsvQjXVdMMUKSJq3kd
6YE4lq7UXdlU9Lvduz83NxesvksmrXzuBp2XXo/dS6moU7pZ7PreDDDzsjQq
pu+pmabXGPkiFV1I9PStupYLL7UWMivN+yDxrPPt0etU5Iv59+f8t3QwiD2F
uxsxCD/eszH4lFNQx8A/D4mOHKCyFN/h3DMISz3aBvIdFESelB3QVE6HX2l2
Bz/yj8BoYWBx91kK8t7S/9KhkwMPLN7BRb9hyFQS/++FJgXtmuO0azFKA41x
Z4+f7RPwlhpI8GMko74PJIVqpe907tPo7hSeAI2tll8NkmQ08J8/m8D0N7hq
6N3zxnkKNmREyK3WJFQbsvHCKysb3FkTTRb4p6B1qdTAM5qEuKWiGNWffgOt
tWRf/5cEqLlmflK8lYi4XXLGzx/PBjZK30gdDwH6K9rf/5/H/6znHb5GS4WV
/dwHCy2mYV6pPYhJnIgun1814HyfBXYTB2Mes0zDRENEepUFEXE4+GP2vUoF
rWHa2W+XZ6BQuMUqNmAJmaXGNN5ezAQlgdZVx4VpMJW90laKX0J611J2m2ym
gENwXrTowVn4IfqkcG5pEV3RK7Qf0M0EKyyPQHTpDHAKCJJ3iy8hsvfY90zP
FNh+knvGqW0W7AYMl921FtGZ3zRNz5oMID5TDAl5NQtMPK9s34cuomurghcf
2xUB2yrfc79tDLQvuz5jTaEh5xMVM++1i+Deyfa3KtRGaHO5miH5hIaIMZ63
TvEXgR71ykpJxQ/oxJ9q3MVNQ9cif20wkwqB71O5Q4N4N1z4eFaEVkfPhV6Z
kbN5hSAuTQ1Um+yFOh2bdk96/t5yb0NeNoVwwu9J+yOXAfiRptD2ZJqCVsdL
D+8XKITvlIX72r+GYPJxqaKeJQUFTc6nC38ogPH1k3FBnuPgb6Vz/48uGcWe
LEEVkgVgMtB5QihuEk6tf9vHhSWh01F/wj/m5EP5+FzudtMU6M8z3sZJklDQ
82idE9t54Ph47zliMQGodbyHlaOJSOz+mxZr7TzosTSJGQqbBpsTpvppO0uo
s9fyX/rnXNgz/En04f0ZKD+ZfeTfkyXU/22+tYuUA/Ny0Z9k+WeB2VWVKti1
iKIvSPfPvy2FYpbFh5EfMdA9k5IhlEhDOxFn7ugaloJpvx2nqUEj/JYW0bGg
76/CbwMJSeFS2LQ5cbV2qw0Cnyl6svPQUFlPiI4uqQTMUoXVpmu6IO1sW/+7
RioSI5/zKcsogd8tbCM3HvVCXHrgzP5HVLSfgQNZmpbA66mDqudo/TDtIVKs
tEJBTQSnIFuWEnh/k82p03wIiF8ev/zmRkG9HHerrA2LAZPMG6NCGAOPVii8
8ZKMbvyrqPXeKIIG14esx39PgN/cb/v8RRLyznj1ijemCBqxJCsjpymIwzdo
PDYmoYxNpcf7zxeBbPO5VwbmBPrvnX6Q3EREUvclAvZ0FULOsL0cVWka3D2S
FN3OE5ETprKj5FkhRHeVf8/YPwM7MldHl5KWULRVtHY+UyF0b+COcbXNgLZn
rnwD6xJqxYo7+ThXgL5JiLnbSQzkGVXQOOJo6Kojr9qIdgWMynwTdMDiQUaH
7K5G98nO94nvyk5UgGCu1EqCRhsYGR79ncRLQ4kp6UV/B8tBI+VEyCW9LjBg
ULTQ+UFF8zv4i2kh5aDPVPCtktgDsVieW1HPqcjT58p686VyWA+3V3pr0w9f
PXO6h+i95TV52cp7pgz28KQYYjsHITLXlfwxjILGKKz5k3xloGnj576qOgZW
JlJiA5FkJOVTcLytvBQsz43E19yeAGxTmNITVjJqGy6JKNEuhc8XBe5O8U3B
6OnkTjYvEjpG/R33YbIEuh0IP6v3EyDok+gtpjW6n0Rz7uxyKIFMqzmWtjkC
rO37feaWFREtqObw03aVwI5f4fb7kmlgDGJt7RtcQkdeqEyTIoqBcTOx+77z
DExbasXY31hCNxnTf/caV0OgxctC5QcAT9/6MO1E0BA1CQknnK0GzlvZhgbn
8JDJwKm7fJ+GasmLSGS1CsLO+aVLRLfCodaVCjxdz+knT78bFVbB536Glg/9
nSDa8wr/rouK/IYPrZ17VAXIf9vZ/1UPOKydXL7uTEXn9sYPdRyogot361kv
LfVBoLig7uOjVKT8n9wtvZxKkOn7GsavNgicKfyXxVMpaKL4UovRSAWonD4g
Up8xCvi03uCGAjIS7xuRvmpTATFiHWWy+ePwzVub0VyajP69u/coc60cbg5f
Mbj5eRJSD4jUkbJIqGL5uqGnRzlQ5wxkZcqmQPDl0D0/ARLa8OZtymUuB3Fz
URfvcAJIe639kY0hIqXixYO/Q8ugxUuybPeDaRjOmZzqOUBEPfjFxj0nyuCt
ueVxPsEZqOnXFpD3WEIl94Jcn4jWgbdBREtxWB3knq9a+BVIQ4GZGQ9O/q0F
aTnxSkJGA9Ty1jL73KOhGbPXb2h1tXAS0/PxCqkFrj8f8v9K33eH7t4dvEst
rJ2UMaw42EnvA5Uc0r1UJCjLcSHlTC30jjNEpu3pAXkdD6LqWyriVTrXkdhS
A1d1Cs5YPuuD0tK5yt08VDTMFaU0Z1kDiYeCji5VD0C+pVdGWjFdz39yqNC3
GngN1xcLD4/C+sopxottZOSY7RWSe7gavP4YePkdHYeU1I0L5Tpk9IPhR8r3
T1XAcU/I/PGfCYgj1XMe6CCh37sfVmVzVEHp67U23KMpuFf1NueSJgl1t/t+
jYquhNCzp2lnLxOggv1l4NUGIsK4pCpePV4J6JppjvrBaRB6yvFs4xIRZfx3
nPossgLIb71CX3RMgyPF9pVo6RKSezrbbO2AgWGm2Y+8zbXQPzo8wOxNQ5ze
36TsjDGgS5kqowk0wMcmCtfx/+j9M8PxAE4JA2H81O9F6i3Ativkys2TNHT5
qmt+93EMnHjK7Ld6swM4dcih7n1UtPM496nKAICb2jMxhqhuIL2e8k7zpHPK
YT3cM2eAa2hEZelnL5Q6JtC6hen77iLxx5AVQGrynQ+7/AAsPxv+y4ujILO1
cHyfUB0wcL5qa3kzAncn7i1pzZCRR1we23xGLcw6h/q1O4/BYaGM7vBnZHQ0
7unce+FaUFIVd5UwmYDxKrfZUBoJqRfz9Wcl18AB/2e2nsemgOobCar2dO67
dJvbiLuGzrerB4ZJU2B2Psr2E537Pj9QGHwaXg2MlZkrppUEWB/PxJo8IyJe
DPlCJlM1PKzu07d0m4YOYz6//xaW0LN4n/K+Biy8mv/569K+Wrj+RNrT0I2G
egR237mYg4WgYB5N46R6UJ0s1qy8TUPnDS9a5wVh4Z3DYR7jtGZwr5HeGj1B
78lcEZzfn2ChiqfO8GhwO+g9Lkz1pOvpum08mK2Ehbhdyx99xbrhaszXO8G+
VPQrmC9GYT8W2hrOpNS69sLP9+jcshQVCVhx9S30YEBxICs8vrQfmrATUWX0
HthrfZHD3AQDFsXB7YeXhiFx9mG58B8yYk7IuWXFhQGlM9uLhydHoT/AQYfV
l+4DUT8NV78DaL1rbMirHYfhuYsbMYfIaN85z1wVAQCSpviPde9JME+iXSuN
JKEyqcetKZF1ELO+KzIqfgpeB50vu8ZBQmGbKYMH6Pz23hZDMLEiwO42/PEj
dB/It+Qb1HSqhfOjbf3sYtPg+vOATR8HEV2q0kzBHKqHm/emI7o1a2BIn4Hj
lwM9j1aP/EtfxcF1Zjf2P4L1cMwkqdn3Bg3l9EZmuPbj4GednNQBlmZoZbKS
sGOjoW4F4YbUPBzMr8brz/T/gNOi2az36Pte/vNee9IHHLT7eBkLY7tgkzVc
jCOAijLXRBc3dHAAFcPWPXt74fcDN8EPF6hozqhOXOUEDtpir3A5yPcDXpLJ
LHCYgnS4b29f+IyF5UeeUr4mwyBQ9oQ0d5CCxP3E5ySMsLAg8y3XUHMUHuxJ
cr6RSEZnrgYNvjyGhZmK4/92To+D2JsLvVckyOi5zbpAXCsGIh2Eol8uTEAk
vZ3ml5DQyemaSs4PGFDJ/ezjoDkFQuvEPmtlEtIVVpCyuYiBEKHnrHc4CGB+
8p6yNJ1DVS4Jr//uB5AJ8ZyOGCTAdFA/d9k1IgqdrXzw6nYD/Pj4OjMpqhom
HbgNFqzo+RJ7b5vxYgMkyLM7ZWfhQKiY70r4FRqSOnBfxOJ4A6yW8gUnOTXB
d4HxDE4671iKKEX+otQDkSWsRVXoB5xKY53n6aaieo+U41IY+jmrZ96Pe11g
ah6gYfKRig7/Ybv6OageLJ6WpZ6I6gEln8iWeCUqejp4f7Hxbj2M3Zl7GVTT
B7xzPtVV9F562UAw4U8fDvSJuEzJziFIbm1dyeClINfN2dnLYTiQUXNYza4Y
ge5eJh2LErp/kva8Tr2BA0Yb5nLR4DG4WODmnqFORtJy08oFO1gwSby2Haw9
AbOsyrI6vSQUe2fxw3wRFl6Iu99bXqPnFyPzfR5zElrkbpqqe4wFDrzdfa3G
KZi95OzeOU9EFy59ep55Agt9QkyZNF8CpKSl3z3ygoheGEa1KvnhgXsTCdrP
V4F2T1W+phkNBfN/jo58jofF6LTwm+dxwMt6/zdRnoasIuvcU7TxUG1n9fwX
oRFYwj1ayUz/909LkzYhPMQnHvi373Ub3Bp7V0JopyLKufn5D2sNcKAW++HH
cidsHKq84UjXk5AiFa6BawCxbmqwuwi9Rym9STW+TEXeOcuXUv0b4J9wWNak
Wh+kmZikPyD+/z1PG38pUwO83bIsZrg+BAdmy4Q/SlFQ+/xseCq2Hty5oxRZ
xUdguu395stmMnJLuyfx4XU9GKe7+134Mwp7HhVZLpqR0a/ryV4DkvWQxhSY
fLdkHIaWyPe+03010cf/3plJHDwe4LN+cW8SzjQxEd+8I6EIP5rdQigOwkd5
Tpq4TEFFyaot8wESMgh9+C0Y4eDfM+tqJXkCWJbh721EEZGfXONHw7JGqMPy
FzCpVIHFXg1jcT0a8vReexyV0AgeBBu3YhwWClTlu75J0VBovg+vm1sjEFOK
kwf0GyGgLfTDDgMNVesNuVnfbQT2A82WTN2t0PHbyLu6hYr4vq42/BBqBGVv
3SMg1wl1Em1ar+j7vsl4cuj0TzxYe3DW0mq6QZBLLGvgChXJXV8V/F2Kh3Sj
wBTTrl6I0dVIivlJQdpMCfjXcni49+FazTZ2ELRvxudnXqIgi+/c7RbkBniJ
kP/7xGHQfvur/OsIGZ14OJ3JmtIA4a6WtyWtR+HGR6dbfPT+H3oM177HoAEm
d10U7eEdB6k+A4Xp/WRk9G7xC35vA3TIZz1+ipuA4A83FuITSIiSliTXXlIP
8d2ay35iU2BJf6ZfdM4ysFh5G/SwHhT/rQp4Lk5BdUT3uFc1Ed0u+/X7yHgT
MHXKYmTiKmG5ztHskwYN7bYR59eubwId61LeRn0sTCaP+nQI0VD8FQYJ0ZQm
cGF5WST2Aw9D05aP7/+hItXRhSSGN02g+ehA5UnpVnBqZtyoa6CiF1c+8V7R
agLpnaysm2864OlI6fprP7qvVo1nmHE0gWyk4OX7Bt3wiLfrvpgqFf33PWZs
eLQRrsvZGqyY90LH65r616sUhM/c/cDIqBGGQMGC58ogGLZbR/DepCANtel4
nyONMOLzrpyBYxi67irgtohkdJhdXP4Wnr5f47ctjo6MgHDFe3krfzJS8bPv
P++Ch7U4hudsQWMwS1JiZxUko5WlweYaYTq3XMwMX5aYgIjo237RFXSe2pMw
ZN7XAJ6nBbnrKifByERWIlWbhLgyVLWDPRpgakTTqIeeX6cbDRubJ4jo3e0H
OVmbzSAfGz5wfrMCui9ZSH9SoqEYNXurDUIzDDxTMX1AxMDH2FNxznROLz5e
Ij6PaQZD/fblhut4eF1+tJ3vFxUl/AqyaYtthrCxu1KnIloAZ11lukPnd87C
S5usNs3gcFRvQq2xHXpMn4aHe1ORkU3HIN+FZuj3Ha2r+NkFb8bIs1Z0Pa/G
BYW6/22CSKe+1eifPTD0+mHryT8UdJBSN2jj3AQd8cEZhtgBSNoS/LZXn4Je
0X7F8ko1wZzUw8zgsCHgds65m07P/c9/1aVuTDcCVdS+YV5nBDL33bwzEk9G
vB6sgzaRjfDAc66Cd2sUfO3sU9QVyOjcI36FvaqNEDyu+IQjdhxUlObjfXtI
qDSYTTCMiod5ocCbXYKToMBadfW8DQm57G1uGW7MhUf8/W5CnlhwvrSOdqXR
0ImB4EdjlTngZ783/EFOE1zclj8TSOf0UByL70Lyd7ArbjuMq26H7IncjVR6
ju/9a/L49/tscBPYqXLt7gb53XYBOQVUNLp/z7GF/7IgqulLcF5OH2RcNHsg
RfdDji+dF4PEMiFROW5p5NkgnGnQ8iHXUhDGy9zf7W86kD/ckDt+cATElfN/
dMpSEOtY6ElGt2zI/P1gOFtpArQDSlPFRMkoxydh2lk2C8KeDJh/vjAFfvcl
HkAgCX0NaDepJ2dA+VVV4XQVAvQoHvGsIBJRevrcwaC8dAgesLUKvzANb3pP
1EVpENEO7cQ53tdpsPmWXJzNMwOxu521Suk8nmk1ftdV8xucVakKt16bgc3x
Mb7bfxfRd5X5QGOWIviTM2gizYQFT90c89QUGvqc+/awilchbHIIqd1hbYJd
c26FgU9oSC5o/T/RlQLAB1C1qtd/gI1VvPg/Thq6sPX0v2DzAmi3dmcvNO8G
DuYGHGc1FX09HMbR4pcP0N8pcEyiD5j9oxUUdajIWkSe/6pWHuzVfC/mNT4A
OeWPuDd6KUjeNFb4OksuqGgUOEs6DcMEKio4pkNBMWcsLnCfLoAbT7Wt90WP
A6FJxaz2Fhmt2ibGty3kQd+pCyWT2ElY9GRn5iknoYQ2xxLXoFzYf0KmxWVh
Cvi8qu2/niShg89F3vJdzAHJkqTLKRMEGLOp0ihyJyJnZXDRnM8G85lfX9Ib
6ZyozdeQNrqEchJukRQTs8AlKiB29usM/LbwiMtUXELOYrcxc+aZcM0tn2fM
Zhbc733vwscsInatvwsVJ0vheLhB8HwkBm7uTj06mUhD9uJvxb5FlsB56qzN
Eye6Px2xYDhO17OcSyL6xu4SeFnqIYBT/AHoiUB7+in6XnN57z7ytBgwMjzm
iNYFxwwP5YfW0/PaS/KUY0sR7JhYmqzn9MLSpYD4A6ZUJDZ17sqiUBFoi7gX
F+kNAK7g64ePCxRUxH09fNq9ELpdRvnyxodgj5xsYLIVBb30246S2yyCtWNC
1/RXxoDoQla1sqfncmLSyrZqEZwTIazwnJwEjwtyRQ6TJEQg+hOcAgtB2jd1
0TxiClKUT81a3yQhtBxk97W/AEz97RVD/QnQcpTfPiOfiGxZG1sfChYApWbX
o2v20yCiac1kx0ZEwNMn83s2D9KfHD/feHMGVi+kycy+WkItjBWENfp9fX4p
8d3z+Cw8i2VuPDC0iMjS4j4CJypAkUkY5y6EAW3ihaDlOBqq2ymp+hpSDg7t
Vp/cJvDwpd89U92Shpwdr6aVb5YBFiexlfehDewP51+v4aWhjN+Jg033y2CX
w217Nq8uuPdnv8aFViri+k134ppSuGjzQ0nvXC+AMs6xzYqKAq4cc005Vgqn
D4d1Wbb1w1WsckXrBgW9U8zrM7csgTi7qsuJWkPgdqfpv9R3FHSDEFnlhy8F
LfHGsAyDMSj//ClLM4yM+ku+bqfsLYWwi+l+rC4T4LL48sAEIxmNneI9FaJe
AlqWR2KfX56C8MAfJ8+9JCHJPg6w8i0G/uiftOdyBAj2534VMklE6werfovS
7/1v5hOXOO5p6OfxWThzg4hoxBPRaYeKYMtYk0F0ZRryjZtOHstfQniySGWw
YSFkcynKOmBm4Od58ZY7x5fo/dlMVHi7CtrPN+KSHAAkzgq0r0fS0EjmhkvB
yyqoONZhYa2Dh6e72q4pWdDQTbbGyMmpSvhP946PcWcrCCQQNs35aGhyjd+L
8VolKI/hJE9yd0FOQrW3RCcVtdbFV/onVIDxAzvu49U9kCvNPJzgQEVS3iqs
M9RyONjNfT/iej9oDz4Wm2Ci53jC6T3ByuWgzuaM364ZhKXArmGVSArydkzs
IHyogMFst4TDVaNwNFPT6WMuGVlZHnnoW10OIctbRo394+Cs+aXZU4SMruiR
Xp1ZKYODuY+zrAYnISePc4ST3md80+XzKZJlgKrv/NKdnIIEp1K/DwdJaK/k
PgzxSSmYPkm0ATwBqExbkVOuRHRIwonAmFoCD5cCFgW/TsPE9wo1tbkl9OfT
tdhd08XAIHPnFu7ZDCR7RzxOub2EFLGryyYdtbC5bTXskVwH7vzVjEzBNCQ4
nmZuolELig2jxXvrG8Cm/b0vK723r17w/ytdVAPxnbvJsYKtwK/WbJhDn0+T
J2NpPGw18EltyczPuhOuVGe8juihosnDsXc+2FTDJ5a4WZnrPWD16teRFFcq
UsmRj2utrII1p6OnzjX1wdftaymL7FQ0fLAy2n53FT0/RvtaZQdB9iYpKCqN
gqxkygR5ZKrhQ1LNqViBUfjnPTR9g97DXWVSwm0sq6D4xVF7U/lxwApYOHhc
J6PIiAzDuehKeMy5Kf3+/CTs8l8UUcaSkGjU/Y6m5gpQ/8LUoR00BVhOybDP
F0nIZNpJR3KzHORtbWdbHAggMWprUpZJREvWz1cPSJcD+/Verg7NadhXceBg
CCcRFSt7vb38uAzW+d4cDz0xA0YvR+cO+y0htbzNa9nqGNgnGy9iPFQLRstr
uRd9aIipjKXn6G4MsO+61yt5qQHWaL7/DRnS0NlClcpT9gDJhtFn1Nxa4Gp+
8xLQ/fP0E7ZXDl11IFzksr6c0gFcDzlu+fdRkWLywg1H4ToYerWtGzXQDXcn
JkI231PRrUfDvd5OtRD3m2FJQbMPpG76aB3kp6LEI/2i3JU1sE+3e9+u7AGY
pPL5t5dSUK9qROXprlqorRx2vhk0AvyXFF0ypshoxIa3TIChFrjTrMWmPo+B
w5SH7LolGTHjAu0DztZA+aUXI4qfJsD73C6+8hkSEj5/RvyLcTV8aeYVeqE0
BSW0juV1MxI6IEe87OlTBRFfQ7PbeAnAE1RrBX1ElCR5SAUVVYLGIm7n8joB
1h2bDjDepPutgZ5w9VQFbPBeOkCrnwa+23e5squX0Elnr5S78VhoYfvoSTxe
CzXpjzM+u9PQq9XSuZuGWFA2Gw0pr6yHa812M4W6NKR9wNIuhBULWb6tgueG
m2H0TdWrYi4a4lacKCmsxUD3p/26ujPt8OPijXti/VR0xt/4nb41BmKDsPyy
T7vBXKXiXxO9T7rmV348fQgDGr2z++PpDJGdtJ3xVIyK9s/yrabdB4jWvVIW
d2YArv7Ue8XUQEHMxju2azIYkAwQ2Rb9Owy3mQY7GtfI6N+ogXZQCACH3zUH
8z1j4Hk3vXCfB72HJ0QFjZXXASkn6WjO2jjstveqyt5DRg/HLQ2FJmuBp2bU
3K93Eu7uczUp8iQhjN2/krC9tSBftpTe/2MKkp9KhLPv0H31iI/vOcka+Ov6
QyXgGwHKgvwnqp2JyPyCncT23WpYbBs+ukHPL6Uj/ae8KEso23ZW22kOB5Qf
IQbrxjXATvTSuulEQ/5jPjZcqTjo0NQ38lCmc9JPqbp8TXpOrVwd6zPGwQEn
5T1Kl5qh87cGy9fjNKRxbDjiLAsOWmxv7Hoj1g6O1BLlMPp88ojov6kpwUJg
uMO15Z0uWE5X1Rfyp6JlNV4XERMs1OmNP7pu0gu0sjfRfLL0fn4l8yzPJgb6
yq5dDfrWD8+ZAvwfdVEQzWjvSK0jFpJtvBUVnw0DTT0ouJGFgtSC/Tba6D3v
vtvD3YTno3Bre3alPZaMpmILSkfjMTDlYN00f28c/mYczJEToM9ti7xcuCQG
ku5oVRfRfeDnswW/+W8kFB+YE8PiRt+7v3O/19ymQP4cB1+nEAmZpv5R9U+o
g6fqZrV1egRI17y91JZMRJOOA86xdbUwbt5hVcc7DQWcg8J5p4hI0UT4ip5I
AzBRrxRd+1YNtVIW/rpPaajrgeTNhrl6wLyqNHmIxcHR3Kifc6o01EBVX+X9
Ug/T6TtKct+aoC3b4ETcERqyc71aTbhVD6JCx7TUXv0Aa9nQoX66fyrNnrL8
soED7Syhw40xXXA3ZKRd4iMV3WH/9vLnFxzcOqteIrvQA7fPKxhqyVORDOOM
qtdlHKjFEDU7hPvhNUe7G8MoBZW/7jxkl4uDjBoD8TeTdK7hTNfEn6Kg456p
+79exYHsiWOpL0ZHABu7eelZPhkZR2a3ve/Fggz2cPZ6/Ris8O9XsLtERnuv
j1NKHmGBn2UC7xg7AUEeYiIFDSR0XEVfZ2gZA2/OHyRfkpyCZcedBGZ6v9rN
9/bF6w8YUP/Rm03bRQCrJVYxrVYielCRb3niCAbMyfbZ+u0EaNW/pYvoPqBz
Nem9wgM8POwwMY9aqYL80Iy1BnMacuw9tjeEDw/PiNrBilo40A02Zbeic6Vi
2PVH2YMNENmRV7V6pAkWol56lbHQ0FEH02LGgAZ4xt9x16+xDfJzHT8c7aL3
z7DHAWfON8Bsue+DOLkukItNY92g6/nx2eXC1OF6oKStY2649IDxbb9PzJfo
XNnulMD/ph5auZpX7tK56cukbujmDAWlqZWXHCfUgw1T74el/4bgq9cjzylJ
OlcernyCfVkPb9kvPDqgPQJDTv+WN+vJiAHfxtu7tx5if22ZLkmNQZiIPccb
AzJaG2HoIX/CgUo0Q9rQzjh0NvzKFJ8mIYvf/0lmCuJgSjDY/kn1JGT+uV0w
QufEhFNOC5/ysZDXt+ItXjQFaf7DjLo/icjGc81V/hIWtqeD+trcCcD3o/O5
lhMRsYi/nLcNa4Q6ftHJYs0q4Gd+Qyu6S0Nvnl94W3mnEQ6cIDVMD2Fhotfk
qZosDVXjTVpK9jfCqbXs/SaejcDudh7HwkhD4VeGMO3VeDhigIy5edrgR833
HaP//1+5ZNvkbYWHD5zyPoXfOmFFd/t0Ml1PnrXROmtWPMQn0fzcWHqg+R/N
1gFRUSN3RR9bXgNUh3GzHbnQB6V6CsH2JAoS0S4Mx9K//6K7ftqzexD0Er4G
nVemIN4Id4JicgN4flQZroBhWLajfEoYICNM5PSnXtkGWN2YLqxPGAWy8Yah
vS0Z7a8ZYfr/+9WNn2o2y1bjkHz+o6DDNglxEr1LCdr1gKPs72ninwQH9gmK
+UcSwvvJOb8bwsFdo2hR90dTUD9veXqVjYR+PB3j/vgIB9s3u27KnSXAmdbY
/oV4IuLQHdo8X9EELJVNrtbplTDGXZQsdoOGsmz6S/1dm0AhTa1S2QYLbvIG
pGARem9Pu+zvJtcEnW2pDxU38JCEX13M2KLPmxx/6Mv5RhBzvTbQ97oVNPNC
0zBNVGTWHc9NjmiErR/txwkLHfDSli1FJYCKxBW0+Z8qNsLr2u6nFUndwC2x
9S7xKhUFvXl5+d0IHhwm+56sYHohhGux3fUXBa3qOHP5yjWCzrevXFduD4KN
VmrU2HUKcsRrfmRrwoP7iLqB88VhsPA4k2W9QEafNLK6vQzxcMr4xVgg6yiw
G+/We/6BjLrmmBcc5+j7xcpwva13DNhKR2QSOcjo5lKjgotDA/TlcjDl+0/A
4QttNXkZ9H3PuvyDb6se/nOwmKEdn4L9i0aqty+QUMDQjYFln3o4/0NtInZi
CoaaV66IY4jI6pjHP7ahZuA6nhI3faAShETLyEKXaCikD5t5Kb4ZZkfcj53+
h4HZrrQnejw0FDq7+VbZoBkIawn1zx3xsKhzrCFxhYraz32fldnfDAZhhNyQ
4RbY7Bl7dg9H123skW5wWRNY7Rklxcl0gM394OxpXyqKMJPo6TRrgvp3V7Qo
it3gyt6ynq5KRZ8TOq29/tHv5ZYc7tftXnDPGL0qs0ZBTNw/x131mqDXwPgu
V9cACAa3fV7WoyCVf0NSZvR7FA5vFbpaMAQLASmFb+i5b5aaXEt0bgSscn+2
2ocRwOj7BQV+IqNnxtNeVYyNgLfCVT9THQOmkvaptrNk1LjVx/4gDA8xRGdF
8d/jdF0zLszgSCi85S/BmhsP5LH/dngjJ+HKxFtOF30Sion2sqVQMsF1Xf3I
iRksWGWcNutIoyHaXrHsD6KpEDh4px8ws/CY9ldIQH8RfXuLo+1wZMCsiPvu
Ao9ZaLhywLfXdxE9Sv1DlNjVDLU+PoUt/pUwt7+McFidhurd64s+pTZAvrn6
GdPwKSB+ehS0PE1E170oenHOeNg5/XqO12gKyHvidBM2iag+SafKIg4Puwv2
2DnqTIHA2JfLVf+ISEpsVw/1VCYkp66+1PiJhS79qZkN+nN+u/lJyqouF0ik
BxsXrXBgaybmuphAz8cN/GbXr1x415cXOxVUBhEFVWzsPTQULXv97uKrXDgc
9IjnkmkLmHhKlWNv09CC0oxgJ2cuGH0SDco50AXvHvgw5pOpKHZzLcMhKwdS
ol44mGr0wlnv08Fnnanovuu+UivxHAjZ94gQZzwAGifk3zHQKChYfPnD48Tv
kNvEKXRWdRjurXlz7DehoKePWW9zM38H/rRuKbGdUfhIFZE8XUVGGouX/Y/b
ZMPp9si7LUEToNnM85b5GBldOov2FzdmQfal6v8EXabAaI9Zs7IlCTWs6Jcf
4s8CSccn3zvCCRDns+6/WUREe52DDHZcMqHY5BO7Qsw07FqdeabMQESWy5F3
jnRlgG/ToLSl/wzEj/pIpt5aQlmyAm4hYhmgbvfU2/3JLNQeeWYTnrCI1rCn
dq8mFwLfjYxr7/5gYSVAh+/sZxrdrEUeSdcVgoiUTxeZsQwIzfsuTLTT0BGb
jenfrwuBk/Kv7UdTM9z9o6URSO/PBKrfHXm1QiDbZW+v3++E1BGHt8PLVMSb
lXGRcW8hlM2YHbcY7YE2tnixBx+oCGdfexpfUwBBJkuGOYR+UMy4jr7/o6BX
qunOa7YFcKLbKKAQhqCpNy3kiT0FaTB0vmY/UQCvxt3CXzqNwp8HoZEqdD+P
rGO6wuWaDy922I+ybo0D7/5FKkaOjGrfZ/6xrM2DFmfDgxh6r9glJhKoF0hC
Go3F3fbbueCB8/+iqUHXcz3OmXOSiO7j9LkMlXPhxoWvGQZa0xC6ndy0KkNE
QunbunOvc+ABxuhP06UZKKnQfevvuYQkr9qufCn/DoIuVwi5J2dB8Z+1kET/
IoqT/S1Zu5ENW+lfOMWX6OfBXZx/xBbR3Ce0MHa3BKpzsv4shGDh2uyv546x
NPSRyefGvGMJWHHuvMJ7lAJGubCzqZmGrD9yna8WLoF9u2OzbOWbYakoOvj/
/9dUXjxbHU8uhlG9yCrd3A74VfzRJmOditDsHc7e9GJw2PMge9WxB2RG//1l
CKSipoJf0XP/FUPPc6q+uW0/KIdX8IYdoqI/Q1st1jtFsJCfcBiPhkBW/Ht1
hzcFXQy/MraaWATPoixdT5NGYHGTLVbpJxldTpgk/K+O9w7H+g3//0NFibIV
Qmmg0hAquigJJZJUIiMzu6IiI6LQshIyykr23k73srL33uTepawiv9fnOPp+
3t+j3/H91x+31+u8r+s8n8+nx0n4ZD4IuF7RuOeI+Q7GrRnlK5h+3mnbqd6e
B9mv0/1f1o6CfHiin1AuFV04rXbyi1UePNg75+n3ewxE7aO29nFQkeQqi3Xv
Ui6sTHDh19bGQX7R9JGeKQXhNVpCHEJyIX8Al/H8+wTckk7fxF9ERjJ0Eo/1
zlwIucDF5GqfhFKFZY6HnGQkWiVv8MMyB0SGnQreJUzBV7Yz1Le3Z1Eq1+SH
M/PY/ffOJd7ah4P8iH0iXyKYaK1YIbpIsARyvplWPllXBO4DodMTeCbypNk8
DiMWA95jMIYtow6Kv4gLF2LnWVpxM7UuoBj6u94X6q41Q5ZL6AG53ww0VvJo
5/mTxaBWLVjIw4Xpk6TxiX3hDNTIiDP6MFkEMrpO0xnLXcDeGDhdJ8JAWtZX
rHz9i4Ca8MDXDt8LSjIqwUZRdPT0ZKxVuEgRLCmu23TaagB4CxUfHuWgo3Wt
uz96ZxUCZ0Sbx+bxIQgq4DwY7kJDPC2Hi1tOFkLqTVWnJ8dHwTLb0Cihg4qy
DtQ9YBILQN5zSMI/bwyuOeaZXTyM6T3bfdf26hTA+u1bjc8VjcNt8wsxRiEU
tKa5q+d1Vz68HzLrKk6dANq+4ubL02Q0ectPU9w4H57zC2hmB06Cjzz7D19E
RtxShQ6JU3kQdX9LgKjhFHzvLnZcFzuL5Ljr1H0Cy2CHdoNDM74GpNdwXzTf
MNGQ9nrldZ/LQGXq1f31Twshm5yQgSqZiNNBg4WkXwbnRvddfLSrDoLfaxue
0mMil5HPJ5a3lsGJs1FPB642w/oXdZsCV7H5W3Mq7BmUwlY3M2ZGejuMJhuX
UKMZ6Fjben/O25iiw01Nvw7qgrtR9a539jFQgYfpz1MrJbCnN2xbwvle6Ku0
Pbjr0//kFbq/e1+UQKKyp2fjeD/M37RYVN6J9Wf3KN232HkoSbUQGjUcAsKZ
/msDITREurqPLBRbDCyT1rucUkcg7J5v+585KnobnqE7IlIMMscZl67bjkHi
UHXrs6tUlJv7RelcTBGcbY+xlrcfh9b9UoO7iyjIPVr6ho9QETgnt/JbGE9A
hLtI6CU+CtLSkngTGVEIZjRGVQLWT4RjHfJ0XcnoekPVig1vIYRdOCVQt2UK
HptT/ZXbZtFuM7fddPZKqAr8OL3TvAY0h+J2rgQzUaJHdID0wUrwUTg5eZiz
EOz33TehFzLRveF6q8T2CuC+tkW7KK4WFDPy0zp0mAiPHqQ6hFRAwjlj0YHc
JtjQt+14zR8GYg4HFdYoVMDxx6r25ZrtoFkpqmGRwEBbOFuMVbrLoUqVU2K9
aBeIKCgVvsJ896b+YpcPtuVw+/03b8vWHjCwExVUKaEjf9NT2cVzZeD/gfts
s1k/dIlJ67oepaPQZ3xCam5lYHVh3ud3yyAo57EV7E+hobVys9Pfv5dCVtep
2tvbR+BQDFeSNg8NSeYachn9Dxf3ka14i8QYpG3fzhL3kIqMqiK6yaMl0Csx
/KVfchykeR7YVg5R0GDZ7IOZKyWgGxS1M5p3AtyCuZuEEAVdFm2m2tcVg0fj
qctzcxMwxFZBZySSEd6mjelwqhjyXrqdTidMQvK3n5xX2LB+kmlt8/VRNTQZ
CN88zVoDx1yWS34+ZSL3X9eHIhKrgcPu6RdKZAFIMuc1f2Uy0cfpG4fuq1UD
O1+kcIJoLVjKXLUK0WailEHc+dtLVRCcOUA5vq0JJN6Ud3/D6qxkMy+2O7EK
8HHpiUcpbTAk7Hk9MYmBuu+44a6erAKxb8I2LHmdcPrggxztkwxkCd7uVfWV
wOredKwE0xtuMqk0HBE7z5R9fDI6lcAv/XSf1kQfdE182zWjTkfHOAUu2TZU
wLNGTjlbrUFwe6x8OKKShmbSbnPLowoo7Xjl4vJqGFo0u52jMN2YOdKeeTC3
HEzlK+eu5I3CumPfq+OjqWjusltsh1g5XIn2cFXrH4PH2Qpt8qxU9MikY/Zh
UBlose3Ms2sYhxdmoi8rbCkoQrZSR+dnKWwUN5MtSp+AzUI3+e60kNGfByqn
r5iWwrOAxd2dHpMgJzdZd1GejJhNDzhuROGgIka1WzymGmYOVi3PuzPRta8U
gYoMHJx8j34eKc4H4UvVDs6YDmEhb1R8+QgHUXu3TFbvIYEDe9CjZDUmEr9a
y/5VHwcXE8mvrYca4ZOrRrIn5o808d/YtkvhYLA6qy5Vvg3aHHR5Kj4xEI++
s/k3eg2wlNsX/ZzogKmFXLGO8wx0R6VB/GJeDRyPdwzxcO8Gh8yEH7qDdPSq
skub37kGsu76TZ6k90KjlTC105KOdpw2YTm6vwYsm9lk+s4NgFDi9zNr0zQU
7L5OlacCQF3HUTnIZwhoY6FTtmY0hN/84OWYOED4+vriTTEjYK70JSq8m4pu
jjpF3/athlWWtn6C9hi0FrnjZzSo6M3VeUGOkSo4lGlzXvPEOHQqJ0WmY/3E
T+ZdOz92Tja17fr2R3gCzCVkrNftpqCfnxXSPkVWgpBMR4crZQLef+LvpL4m
I+FqaQG5Mjxk9r16K06vgglWQ78dzkwk4PnnFbUZD025jR8fX8gHSRvzlm+h
THQCDdv0x+BhxlsvvCSHCO9uwqn/8VPeHsu27vfwcC1hhfOXZiMc+3Z89/Iy
Nte49pYXnsXDwGjkdfaKViAf06+rTmcg4V6hRpMteNByvljW5tMBI8478XUX
GeibTIW5TgsOjERyt/RzdAOLpL1PwBQdrVBPadkF48DlTFLYJ/deYD1APuJx
l464Ltu/iVbDgSmH0ZORun4oKxTvl12iIZzVqz7czxp4uM1xS/LvQVjjU14W
fkBD8xaNQxXJNTAQfXM5nmcE9Ke22ud8o6IPhyK1r+jXwLL70uC39WOg+Pme
+TlrKrLjFqgLWAGwTXq823FuDCbPX4vm76cgz3usb630ASB97Xli+zg80jTy
VtSmII3stljntGqI9GbRW580Aa4le36nlZOR6g/5dfxdBJCa+NrEfq4KPtd3
jpVbM5Gm8PcWPjIBPhd9sxuezIObBinDrM+ZqNgs7pZhEQF+VIxKfVcmgsSa
bRKrAhPN1vLVWrwkQG39x4/uZQ3wRSYtMW+BgRbaj2pMGhMA6VHb9/O0gn1o
fkg3Vmcg3854L0WAzr5nA5vEO+DahLdvqh4DtfCKBllP40Go+92WT3FdQG17
d92DhtWzboP67kQ89G2r9g1g7QXK+0zuUm86uiFZklR6FQ9J1A+mqhf7QVoD
P/8F0yHPXBQvbWLHQ3lhCHnh0SAMu281EntBQyEtypeZhTjQ2rYgqBwyDP5R
p8kbNtOQEHfOgqIZDro5AvGbfEch6ebZjV/8qUgrZpSYuAkHDc3B+OuZY/Ag
c549+hcFldqrvOrG7t0TnZ7kmeBx8NAOUvF1piA3oYTw/+Fj/3TyqAhjc1PB
+4HbvUkyMl+UtZKfJUKjQahawYdKyNlopjdhwkShLt5TFqtEKJ9ZTzrlkwfj
Lj21OV5MtOBUKnewgQgB5KDPBs0E0LFqvHJRjolmfnwqb0skwrPU2FeEgw3w
KvyBYQHmU0QS7VcIzkQIs9D5E22P6epTUXJbsTr38Re71SoQ4ZfEdXxkTTtE
Bf2O9LnCQNMh6iWfFwgw53JyYVS+Cx5O3O9T/UFHbyadOi7lEmC7e2xZ85se
SGm9/CIxiI6eqBJUIy0J4Pz0Geufjj5I3KU6PCdER9y26a9u8RPgz+3TLwN/
DcDgdsNNQQk09Kdkw7qnNXjguP5ci7JxGAyWjpikS9JQj6C/RacdHg7Xnb7B
tTQCJQMnhp4nUNF65iyFkwcPAgxKP5/NGNhfCo7W2EFFhVL6e4aKccB69Hbm
oPo4BLo5pM6GUVC+4Mjk2E0cbLZUvFMmgPmdtDhLo80UNOIZY1U5T4JZIbkn
q6yVQF+ZM4w1YCLRa8kH2DlrQYqx6YuPWB4IvTfhYrnHRDEHXhICe0ig6t4V
9MWMAI4fXh/g2s9EDeI3+KazSJBGbd9Vn1IPe5YMsjkZDGTlJN/i/pgE8sCI
OdOI6b3QC5keaQzUZB+QPn+GBC1FU2V2lu2gM7nZ9vZVBooOfBByiJUEaid9
Xj1s6YSNWknBlCU6ihTyufurnAjdt7beeCzZA1tuRK6cC6cjm3eOnxWdiGBQ
nXFf0LgPcP33lQr20JHgc6ligigRhB5rnDf0GoCQUNEwpzwaSvTbIOBeRwDK
PlalvKdDkC/MRsxQpCEBvw/bRZ0JkDGXZbDkOgJfNrvSX5dREa+vwWc37PuS
1nqhkbprDHiy9LYeVKKi3sbde4+VYn1PgXE0aG0MllQVmN6FFGR+rV3wpxEe
2JSfDc+1jkNkqaq6nRw2N28VR/Su1EKjQNI43rYCljx5W5mYfjg4/O7MId46
kOc3ORRWjfmh5KORazZMdDy7rjJkuBa+elOeoEU80CczruhJYH6Q9DWbWFgL
RAWtAXvJerD5s+NC3SwD+e1/LiXqXwueK08UNh9shhHj17J7UzD9JqKQek6r
FsLMHMs8NrdDn6hciLkhA12WXWKwc9TC4cmajXZ3OiEWJ3vk+SoddbVl6irU
kGDjREFiSGE3BObBUlkspp9t7x38fJcEi9bzKc++9kJR9WkecUzvOV49f1JF
ggSRMUf4bFkHQKEvh2UMR0OPXNwNiNh9vIA4NketHwLvOVXCzos0dNf9lz2n
CxEccFnfu+jD4LOxW+B7OxWtCfgpd/ARgaAsvvtQ9SjYp8/uMTagop83Fnc0
Yv0zSn56abF8DJ54rbt7uYuCGA1ZnhGGBPAbK+9owfoJT35LX6Y+BQ0YR0zn
rtbB8fvPn411lEPFM/nvs6pMVFvPZ245UgcsCtS8mDd4GOP/flpCmInULmTf
jiiqg9Dlr9ZvE+tgkmuOZ26CgaRZhiq7/OuAl9vhfF94E1j6UbaKf2Sgd2cL
vTu06qCR46Z7VX4biIvSGp5j9QwujZ3S4aiDZi4F7k8cnRBmtKNBmoWBpCjh
3Pw1tdg9Pc89r9UNp11mLbiS6KjJLpe55FoL5qFW/pfceuFg84628yp0pPpM
qLh9Zy3IG1/PqQzqhztUlglGGw15zQ5MOteRwO3Y1OPEwEEQzTVL5DOlocVQ
GZU4BxK4typOZ9gPwwSHwGLlLBUVVOJfCm8lQZM3ntqnNAoCBgHPJ52oyMQ2
4Go4Nu/Dwx5+k3swBuplb+Oc5ihIeUyQvfUSEV5YWYdoaoxD/s848on7FORc
cX8x2TsL/K26RZ48qoc3XVo3/xgxUbLfgHPE7ix4wSPX8FC5FUQ+zt1L+sVA
dwtf/ForyoQtSSWqMcMdgI8/kukXyEAjbw4uP1TKhI6Dm08ILXQD+z6r+9ew
+jijauW8rAx41laWcHGqD6of+n9Y50RHIRknpG8IZ8CPyMFIydRBeEjsP2bc
SkMuOc4N3H3pcPksvf+P3hjwGd21+ulBRdxOiDPpSDosCy9m+TmNA/v2hWm2
Rgri7g4aiQv6BJHc/aQU9wkweJvPZShEQWZ61gsR42kw6mu9x+bOJBj5Tpe/
tySjOTZx4f6TaTB2nh3RtKfg93pJMdWCWeShvzSY+C4VNqg6ajRvn4avu9+Z
bFs/i+L+8mN//vJjrH/5McUDmwvX9PLg7l6l8JWCZmgmC40KcmF+ba1YjZU/
D85MXTTn5e6AWyFyH5QTGUidansmrTkX0x+Cq3t3doNUUJjLo10MdG7iRryN
Ty60OPj+Kt/YB+Wbzojee0tHH15ZnKqRyQV3bW4WP9IAmGctu/T+oaF1BdHX
Q/Znw4j9JlcK1pf2cLmypHBSUYyyUEqhdRZERg8YHds8AemibZ+bTChItOUB
bU9yJhgQNaeT1k1C7k7/2+o5ZLRz/faNdycy4NvrTy/Q1CSk4FuvP2QhIwGl
vUZTuzIg5MCKsFTxFBTbHpaNuDqLSv/yXe7/8F0vDvEu3q4pgDDlyjNnz7VD
5zmBi+XF2Fx4OW/aca8AtHf0pBpd7IL09LhZAVVsLjyRDN29swC2NSd7vD3U
Cy2VbgrSFXSktJ0c8K0mH1Yzq0z9yP1Af2e4cFeGjvQEkuoHd+bBieXX0nbx
4zDJ4PR8moj5cZ0Nkg/ycsEtl9fqQNQElIsUr1xdIKOXbzyXDqnngnXEk+sh
XpMQOxTA1L5IRoPvXYghOTmwL1Y+O1B/CqqpuV4RSbPo01+eivUfnqqn7+Mu
xF0MW3k0fLN8O2HEInvZ0oiBuMXrV5zzi+C0EC6HcbMHFhVVLa4N0dHW/a/i
2S8VQcbVAzXqvP0g9uJglYk+HdW/ODPAwV0AZyaqJ/cfmoCnhGSRwRMUpDuQ
xmsemQ/lXqniS4KTcPddTXl5OBmx6lwruSSWD4Q9b5eAMQm8yYtgzphFX/7y
SEb/8EhW27ZPNZ4qhfDavJtNr7qhepu+6JFfdPR5RIdi114CjyGjZRL1wc1t
nKRadzrKFG+T/TZZCHTjx8WZuRMQESP7q7mXjB7eu5x6yLwQVL+vvFwInoRW
t7IzK8fJ6PRfPmfxHz7ngGrvuQjtctBVOWhx724vhAqaFA5F0VGBxC6FiI/F
wF+wM1N33yT8YlJDbDzIKPChxeIHLxzmK9oqd9oQQUPF4uQdLSZSHnALZruO
A487LbctdzXCu9JaU5WNTOTos7tqrwzmH+W6lr8WtoKw0kL3xUIGGgpaLejG
/IKq/51Xv0I6wKl+hzIrpiuschx86KU1oB7qJce1uxsM+NlkyWQ6muPQ1b/6
oAZ0d+edeRfXC7qP1L0S7tPRN5v8FNtmgPzZTQ/GFYdg3/YZnSVXGmr9lfO0
8yhA1gSe3clwBF45StqXfaUizSfXJQnh1ZBd/nTToswYtAUM+rvdoKLIC3dw
6d+rQMrA9r6ryDgIlmhqPaynoICL85ydOlWww177KvfqOHD7xLZRjlPQ7NCm
Wov0SiiPyZMwaMP6VWyHd8dHMiopPdQ34IUHYynH+EvD9UB87BFlsIWJdgTK
WvDo4SFsKWei/kYLvPlY/zQGGKiV+kbKdwcebMQlxY91t0PIc479DVYMdL4w
rvLPMA4SjO9ojFl2Affj3C/a67D66NZOuMTiYGtZsndrfw8cd3qrFP8G82vd
FrvcsbrdDeKLfYnpf5lA95p4PhryiVBWemldAy/kJebdQ0YhXD/VWDiYitj7
m3XbeGuA8e7KzHLxGGCu3ObxKgUZ7+106/MEYDGOW+iKHgdfo511dCcKqjtK
kJ1vqwZyknJjtdMEmLC3cjqPkpFO7mejHEyP5ZiWEhw2N0MDUdWqpZ6BqkqJ
bodOEuAeJVaMV6odhMSu1cvfx94r74OK4yoe+qOK9NgyO+F++ugzIewcum9N
8dUux8NXMckE8o4eEP6ZtLEvnY5EvsmdTPbBwU/VS9+LCSPwR61lNrGEik4s
Po9MlsbB64y7XJFXxsBnhiR6R46K8BlNFsc6auDNM6UxG8VxaOiucJhJpqDd
7GtD3x7VQClb/vd8rgkoNOY24t9OQYdSut4PXCHCGiXPzethG1iqlNk7+zKQ
4SwXbb8QEV7mMvbYLXXA+Yd7ix7tYaCdm/mu13cSwKpw4+sZs24oSsBxu9fQ
kb9k0k1eFTwsXTt9smRiFCxOnz13/RYVneWw3eM5iQPHRS29ie4x+Bz9eWKm
l4KubFmdanqOA9K2qWCdrHFYxxk33apLQZLWPyL2y5KAqfDjAot2B6SXveiI
lmcgJcv4371fiTAkuMKNz+gCjVOl4olddLS6gyct8DsehG+vXDdxG4OdKb96
WDmoSOP15/bmCDysDfCnpOtgn3+K+SvXn4Li5DUTHBdI4Gr/9vD9351gy3wR
8XiGjqzbtA6UxREgcUXn1hhjDNYkCJ71mE7WbOm7fpaeBSb3npy0MS4FH4dq
RVwTE2XgW9/mBqTCx8S8XQVHp+G3AoFPlvEVWapuHJbgqQf/Vfprjew8YLK8
rVi+wUQJX2MM1Pjq4aL6kV8qFrmAn/bakGfMRLZjKQtKN4mQwNNe8e3AOKwP
7Pkq+pSCVp19krzS88CRdMeJfqwGHFLuGjp8ZiJ6laXR+Y85EHmzl3rxxjBo
Nk3Wo1s09HbtG5+pWSF8MrQbb2ZWARCsXBOymCiSKei8SakQCNm7vatzSHD2
ltpItDMTrVM/FNRkkg8+93q/FnkOwYVkhrz1GxpK0uYUOLiQB69a3IVzpkag
skTr2jUmFenn3wyVZi8BKdLZ0PTwCgj+s5uVns1E4XT+icThYtDTSb+lbUaE
3bdNo2+5M9Hz7Y4RtinFALHvuO2aG+FRx/jlF9JM1H7GxiR/ohBOtp/JEvo4
CLSI53ykahra9nvPOMvdQnATT72RvnkEYpg8CsTdNBSmeWvZbbUAVrKKfdj2
jsEHw4AgW8y/vydywWpcGYyaLxzQ1S+D4mXOkCfY88iW1+my3S+DpfcilEc7
CSDBwh7M6clEma9Dj5w8WQZ6VevqXzo1wJs7vuyrx5goHT/xfOZ7KfDUBYaR
XrWCxZFXdVMDmB/ZoSQgZVoC0tFNqe+bBkBqE3dgAJmGSIFSMx9miiG5daVp
g/wwJERsYAs0oKEO67evPO2KQWKnP/Wb2yj4xB/TB8yXvVvbwrKHXAQvsvsd
rBrGgCy69ukP5n+VPMrsOfZUQpp3TlmyTAkIC7+WCMxkIold/jdUf1dA3CAl
tIOMgzhq3GSLFxO5m1Vdzq6pgFrnB/OtovWQdDBxQEaZiYjvg9leu1dAktT8
S1GpFrAWtxFfxXyW4WPzMtOdFaCosVvQ93c7HPDftvA9gIG8g4uePO8og708
Vw/Y/u4H+QiqQvs2OjoQshpkfqUMln/Tx3+aYT7o6eLdmic0hA0v/8aWUnCj
ztwp/jgCxWduWQXTqEhcj0HU0SiF1+Pdb13MxmCfXWwqVZ+KVvXwtboVJaDD
LefBd2scbvrlnHEvpiD+irvBvv/zfyY9rhx9K1IEWn5zcRLpTHQj/8EGt3vV
sIH1iMAArgaSkMPLTm8mKtEnKtUqVUNYKevdpt5aEOOkhamfYSLDWNW1FHoV
9KiV2U+TmmD1tIxjzk8G2ktIORUcXgXUA2py/Wrt4NCLd3wbxUAzR+XW7ThQ
BR+/NoSIbOgCMa4Pq9kHGMh2TfG7sXIlNPbeZ7w91A9v2s8vt8vT0bxf+dzn
kgoIf5hjlRg6CG6HS/e/y6Ah7ntZR6oOVAAHRXHLi45hsJL78HRWhIYaxGu3
HI4rBx3n8LSb30ehVHrxp+MzKnoeEab2eHM5oB7VfRqLY2DsW/Eim4n1N01y
3ZxbGbg/uivlMz0O/MQSFXZDCmL/y1vK/sNbvi0w+rAH8HBEp+RC52I5yL/l
PhP56D++sekv33jyL9/I/yBtrPoKDt566TY8OtoPP3OPn9AS/o8zvPUPZ3h0
aIK8MESA9MqihrFvpaCU9bpd142JLEoP7cLhCKDzOfr0FxE81Lwkxjtgn0/4
y/uN/sP7TU6fac1wxUPAfMfMIec+6Lk8oT+uQEdTIVcv3ZPCA/59j2dF2gB4
bgx/F1/5/+fx5v/yeHzroya//iCCcAZZbue6EmB9byBOwfoV0RaXl9NPBNeE
hZvB2HvwuCiJEDWZ6MixoqWhIiIEt/jszXKvhee36zOO8DHRtr+8nO0/vNzw
lQSVmGACbGzJ7TLI7YXCq+YrRZi+/cV5wtZbmQAnhDikn0/3g5VYssSrYRpK
09938goFD0/LD5U0rw3CJp3b/doWNDT/l3NT/odzE6n4ri6yHnuOBw9d46SK
4B333ANfO+x5RvmV1lFJMHWQ1TJhBUCjSOxNzzkmspxRSt5bT4LlOfd91w1I
8MXS0fIMPxMNB5fK7nhPAtAvqal92QgLx2ZCg7v/49O8/vJp83/5tL2Xz404
xROBPmRq8GO+B1g/N56n29PR7evPsxp0iVD7Dq3c2NcP3rIxa/CbhmDkzzBx
hQCWofS9B9AgLFbtoVwOoKHNr8qS5VMJ4Ku/RZpFZRjum6exdWyiIaG/vBnu
H95svZ7vqyLMT9qZhJU+MCmA6UzuvgMWTMRZWfimbb4WOkXds26tVYHlZo9J
nBo2dyixlrxdtWCj4ZTcpUyEZtM9r2nY99X2qefy6qda4Hl1WKfPtAEcudla
TPoZKPcH5/wRt1oQ5/z6leN2C7DS3qwww/7jxx785cdE/vJj7ofS3QSySGD6
paGbS7UHIgg7dDP96Ciu8jRB6RYJXn1clUGOfUAUvHzsmhAdrWdV7cjdTAKO
QnNOWb8BiPf4+CY5hYYqjy9/1isggm6WM17PewikXVIHCw7RUKYpej5+nQgV
X629/M1H4PByo1xUARWx/OXErv7lxDb/5cSsL4XVqv6qg4ywW+E+gpUgkf0j
8wPWt09sjswv668Dsd1ypQQ5AhDns0R0eZlIjqZwuyanDpJCkuPtlevh11ed
kcxBzHfXcXLQHtcBt41sAMg2g1e4LMknmoEUN2Ya0tTqQI2hlf1gpQ1UmpUS
My/+x33t/8t9ef3lvtAnwR2+xbWwtcRnJAnzWSclXvMLYX6n877f7yKbWrAz
4A9TK+mFby6qgu6H6ahrWWHjL75awG/j7Ruu74dBOqPegkBDza/114lVkkC3
AOc1iR8E73O2J+h6NJTQfcXrqxlW/8EnhlwpwxAwVdy6Y4CKtAK8GwTZsPqv
HJQ0cR6Fc/OTahOmVJT2l+Oa/Mtxkf7huBr/clwzfzku/F+OK/svx0X9y3F1
tJLf9z/PApn9xGq993WADxt4/8IKq2eOnUeXcha8Wa/rdftNMxTEXvmNw+7X
S3vGes2JTLC9Hnr+Zno7XNbvr7uM+TLpWpemVo9M8HB6MXvDqQvuiLLxLJ9j
oJ/PJmQkOTKBj2uzUyx/LxSQFx1Dv9DRaJ/V698hGTAatZWkHtMPtd67vdY0
ML/c+viDLz0dWPczA8/KYrrUrSNEKpSK6rYd2yRokg6OCbUbrfePQ2mPRvzS
AgX1P7xKWmv8BO8M++WVBCZA0f1d1IoRBW2Llq+6ovQJtGiixKtzE9ClT+W8
VU1GWerkJNbUNNhx753o3ZpJ+CM9Wi25i/y/9fyXi/s/+c/KP/lPmImi677r
eTA8WnKreqIJpIOP/zTazkSx7u8q26XyYM36vCVOvR2Ob/2D21rFQJeMJed3
UHLhS+AukaTVTuhlTgyrX2GgLNf7y98+5QLtIkHQL7oHSqQILnnDWH18yOc1
Mb07OpzCESDYDzp/xsW236Kjcy7XM4fUssEt6bbin6Ex4F5WoBhLYrqC4eWZ
EZ0FxwVCJnQbxkHN7q5gQBBWhxGZ9PvfMmE63izDMRWrA3/J+opvZKRlNjdx
8XwmvHM0Lli6PwlKIPHizzUy8qu7zrErIQOkF/QPJh2fAv+tj1dkav7Lf/7d
74sXrCxNaSiAL7YhuZkTbZB8TL7/CpGBxPn38TU9LwCVcSIx6HUn/Bo3dCXf
YqBOMYlzpaoFQJR6cIRdsgd0VQzi/9DpiN/tkqTzXD40vkp8ohvZB/5x51iU
7tHRqTfvUlUP5gHO58MHdu9xKA92NM8toqD0bH1x7ZZcqFFJrV8xmoBZa9xq
hQQFiYX+kJZ1zgW3zq8KLdKT0L7FliswhIzwVmGid7ZhP48uSxGjTgIHNWZt
ZuG//OfffToG4isM3V4Myj4pr9mlOmGji9/6NVsGsouN3G//pQg41Y8V7c/o
hrqNXJWhK3T020rHzsq9CA6F5vOmCfaBzlbx7/cDMZ919xxxUawAjFzEt/Bt
m4BYu8i7TpcoKCLqyLe9RfkwXa6byTY6AVF77WQJlWTUVSTUEXQxH0TPvB1t
T5yEb1+fh5vLkv83//l3H03+blmegFYpFJ8sOTmp2A2ZZ/JL/DYxkJF1iPle
RglQbtjOv4jpBTBP3jSL9St0JApOzBeCFT5IKT1iAp7SX6TjqGRkrte1Kdi/
EEKPVPS3GU5ClVgYe7IJGaH/x37WCz3B+sIb5fAaDgysk+wFnzOPcj6l0VHj
5t6oLUXFoBBOrJPhmgTeR0shpS/JqPdAlDTuCQ6ik/HvN2URIC3e0LNEDzs/
hWIpehY42CRolJBcXA9w/piklzATGTs9v+iijAP9Pw0uaR+b4dFlo4z8Lgba
P84SF78NBzd3aV8/r9AOL0juGacCGUhI3Pqe9WgNXNR74Yaed0K253ph3kMM
lDaE57uZXgNT43xhKaRuWDxvxY+asT7jqv40dwzARKV46MT3QSiQTa3a4k9D
zudb+eONAKqIdVMFbcPw4xnbieXNNMQiuV8Q11YN3wUVs1PejYKo+wVVr9dU
5E46WM+rXg2zo1Jp6cljIF+WcOERDxUVpruef1hUBfOHuLijXMehoun9+4pQ
CrpjecEDt6cK2khPb1kfmwDqAwmNtW0UVOrhsInbHw9FM7Gf/WTrYcuuBLlZ
rN9Ot4+4OBrjYdu678eK15qgN9U4bbWTgS5fOuVbIIeHOJ2jFtP9bUBRyVDG
P2egkOU9UbarONhet4G2flcncAuoPBSTZ6Ax2dZWsVocxKutpmcbdoMtCm/a
0EtHe9oyUyvxNfCHebtLS2sYuK1c2sKkaKiVfqY11rMGbvxmHJDgHgWa+x7T
nkwqSrxfTvl6tAbONXsTtG+Nwa2Tt987H6UiPqF0nGwHwIp/WrW/zDh2Lk7v
3YP5F4Mc4T4JFYBKh9UTK9RxOKSTcjBTiYIib/45T3YjAG3Yc+8m8yY4tJ87
xLGDgYL6vQIfahLgzfSjM60+bZC4xhKgjek03wG37foCBAj4lJN/uLoDcupx
9zeeYCAHS2Hr9cN4eL/+9XtpShf0vBAzDRylI3tb046HwTiwP/rM0i9gBNye
/8oxraeiWyZNe4sQDuq+MIRJwmNwvNCz4tllKppi3+WS8aMGlhny6ODUGFSq
xF9O7aOgV7j+hPrUGnBcMXY4kjIOq7Q7iXduUZDg0xvkTTeJELK6LmZ5H/ac
AVd+TmHP+aFgQf7kPiKoWcRplBl3QHvgRMyIMgNl8mp1SjAIYJRlfmerL/ac
GSHKnTN0FC4u2GGuiQc115El1U+jUOEUwdXhREUqvzxu2v3CgZqxGfl9/BiU
bzJRubRMQStx97nuZuCA1mOSvM10HE5sWdHR9KOgJPnfZieOkUBrrDktYrUd
EKk2uRjrYs8cXNICl4lwqfCyyXXhLhC5tsz5h0ZHpi/faaFVPIQeSFMevDEG
n8LnJA8IU9GAYVHQw0w8VK4PrUzaPg53Pj+TuJJMQUsmG9q010jgIqIutpLf
CR9/qmQLzdHR/vC3Y43pBAix46r60TUGaxcUDkYTKSjRaaNjZ0oeFFqoU7oE
ceD6Merg2kcmGrnuGd/8MgdG751GTZ+HQabPUldMi4Za+LRfnL1eCL9tfw9L
5tfAvvdB7OMJTHSbhWXD46OF4F3Psp/8DNO/orzqe7H528fFTJXUyAeDE24n
dogNg0OV+oU+GxrKlR3PXyXnQXP8SfzRw6Pw6RN75H1MRxnpO8qL/SqGQDkb
kYt6NQAFQiGDsUzEq37uVER7MWgM/R6X3lgLlRHhN0otmWhPeE9xT1wxlLmK
UwxivkAR783jd3cykZowh+yGikJYfxkv8TF0CL4MHih3fUpDrqd/p2UaFsJz
zTUR/8QR+E0UuhHxm4rCWvKIT5gFoKBbIcapNQYnSlly/+fvdIvz2qkVIWUg
/uPTE58JgD5H6e3ropjo8/qh7B6zMjgryHPv9zMSdFkfbzTAfEHJUdo7bpky
cMafVRFZawQTe6L4LnEmOu9DCtWcLYVuJa3qffvbwNPDQutxCwPlFUQcddxT
AhGK0crOHENQOS7quS6BhvqrHj2sKSuG7X7XJsd4R8Ci7exQ6A4aWt9RJ9ut
XQx7fX/Px60bg7qegEKZMCoqRW4Q04/NtRsnC+bIY6AZ8GuJtpGK+kOlDnly
VcLWe5PHO6QBPCZauU1DmSgtbE3+7VgFVKK2YQ0uEmStFZlymTJRq2HCI8W0
CvCusNi5atMI99PSZxqwevZRvh9Wt6gAqTcRLFsTWiHgj3VDWDsDne/5oI/j
rYDpttr0VEPsvvs9tQ96yEDHpsqUTgeUgUc6fTj4ySAEZV8SjC2hIVtlpamt
fGUwWPRmr9GzYdh6gyfQT5GGfhoryCjFlcIR65231e6OYr4goPsy5jvkKeee
5kqVQp+Qt7nGhzF4k/jbcOcBKjI+deioyecSYDu6nGr+GLvvKlfZZj5S0HnZ
m1WlPtVwZLvBLTv3aohPqG9jD2Ei5bQ97PsuV8NW0FacjyTCvqibY3NGTJRy
uWEoRqAa0qTYTSa6GkDUQqHPU4yJTHqrehabq0A4iOv0pbkWOKFAjn2B9XOn
duE+Nc8qkEmakkn62Q51AvdPH/ZmoDNREk4RO6tg9xXum21GXRBb3KAQvJOB
yIRYvOVABXQX6HmurAyASOzLzGstNHTiaRq/B1bP8xfuLP1aHYIbx2SCPPVp
6MBXh3teM+Uwd8yEX3F6BLK5zy44dFBRCs/IdRebckjTVVS4h/WB5scFrfK6
VLRtNW4EzZSBmJfgYMWxcbh4dZqvroGCRGwaTxNul4GZfs5DIssEFASb3mA5
+18O8+/e65uINz6nK/FANoq5HHe3Ema5y7I97v+Xw7T+k8Poekl+LtPGwSf2
AzpqXv2gEVD9/TIHHZ39f+x7rj/9zOxYLwHmW16uzXZWgPHpdrV+eyaqfniT
h1RFgETex8EZ7XgYdmndMnr2vxzm371LGrUrZo8pHmxdlr+XsPbDmH7Lp6vC
dOTLxdtdvQMPp8o55RbpAxD5KVczLvO/HObIPznMd6F8V1MqEV5vTmd+PlEB
V+e0bPHY/VVKaCutbieC6IZ1AZV38MDVrFLkh/nZSJ48XGcuEQwZF8eLperg
psPHxTuc/+Uw/+4tjgZ2hag5ESCoGnf7RXAf8Puqnp7eS0dPjIz0k/YTAE+Z
3X7FZQAKPG4FD1XTkFDTkwq2Mez3qfOcbFYbgt94Gwsj/f9ymNP/5DDy7mDI
XCKB19BGFVxSOVTbLLir3mCijeq70w+PkkBhYtgvfiP2vR21EU+VZ6L3rxO4
RKqxufBRTiD+Uy0IBq0lfNzARFStr3+2vSXB7WQdo4FjX2Ajpg5r/q89Qf9/
cpiS5Pg5wYdEeBgftljJ3weW1yJv8Mljc9zOZdLrCBGGSALPFn72w26/53fi
W2no0Ezs9qqvBBiyzUlpwg3CD9Ez+jnWNFSWWBRiEkuAj2N2Xbyew7Ax9fxt
9l/U/81hCP/kMMtiqUJb19WBK98d2MxbDrc+Rm030WWiaN+vOPWZWtBpS92h
koKDfW/u/blygIn6dZmsoqRaMJXLHGuXqwXJvVpLF9YYaF6/PebHe2w+He3b
8TO5EQKIT9eR6rH3mnpUfMKpFjY3RPccYmmFXQd5p678X3t8j/7JYd72Vqvk
PSaBX5XHgsaHXsifYV/9jujIIOHE0avHSdBpW7c27tkPJaxWXPMjNKR5vro7
i0KEJ9G7upfPDsIv3R/rfR/R0OUvVyPPxBHBsn7f+PXlIWhasN6ivY2GPoya
cEfqEGGLeGrFXOwI7Gbj9WVNpqJ1f3OYa//s6/2fPAH+yRO+s2lbSX2tA4Ef
cWefauDgCqeZ0dvdTFTpcuj5KqkOXg9+izlVTgL83PYjd5cY6J6Z14O2uDqA
8AcfKrc3AoNt6Y8M5hNZ7G4rsDvXgfXGEpUq8xZgXr1gpv2MgYoOuh4UPlkH
XdoNhmnn28GjhcR55wwDxfzNZ2T+2cub5B+PF3tcC41Cdwv3Hsb8yOqlp2Ha
dKSvrcQ8Il8LSpFOVP4N/bBwUHjjHI2G7hWeEx+YJYH+RS+ra/UDoPhjL8tI
MA0dtXuYExtDgtwjRum5j4agWhQG2PbQkOKgMXNBiwR6fUlmm7ePgPPibvXN
lVRUoJeKt1okwl4/sq1r6ii0VO+Lea1HRbj/x97c/wf9h3uh
       "]], GraphicsComplex3DBox[CompressedData["
1:eJx12E1oz3EcwPGFDCkHW5R22E1oDlaK8m8ccBFLqHkIkTB28BRDTZ4PWjmY
4mJqYg9KW5uM0R95WjEOm8UmxDxsajVGfyxvh/en/69+l1efPt9v7+M3d932
wg3DMjIyvv/5h//5j+2/Vn22ojHxcObirLMVlxL7smrmd+2tTCwcLOpZnJkM
/qSh82BbwePgU5qmj5nW/DT41jMlbcUdL4LX7Lp6vnagPXjv0m+b+rJfBa8Y
+rqCN41qOjCr6k3wjt3t6zvq3wb/+e7HgtLk++A5yybl5bR9CD4nOXt8c3dP
8DX5KwdW930OXnahtDOV+hqczrXbxx7O3FkXOtvpbKeznc52OtvpbKeznc52
OtvpbKeznc52OtvpbKfznju9qYKca6Gznc52OtvpbKeznc52OtvpbKeznc52
OtvpbKeznc52OhdMeL63NNkQOtvpbKeznc52OtvpbKeznc52OtvpbKeznc52
OtvpbKfzmC2N/fXF10NnO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U5nO53t
dH7WfK6kL/tm6Gyns53Odjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53Oi0a3
9GevaQmd7XS209lOZzud7XS209lOZzud7XS209lOZzud7XS203nG0HcndLbT
2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U7niasulvzt6s52OtvpbKez
nc52OtvpbKeznc52OtvpbKeznc52Otvp/OvIhJrijruhs53Odjrb6Wyns53O
djrb6Wyns53Odjrb6Wyns53Odjp31x3vOVF7P3S209lOZzud7XS209lOZzud
7XS209lOZzud7XS209lO53vtg5OrDj0Ine10ttPZTmc7ne10ttPZTmc7ne10
ttPZTmc7ne10ttP5yohtG5PLH4XOdjrb6Wyns53Odjrb6Wyns53Odjrb6Wyn
s53Odjrb6Vye9/pC99QnobOdznY62+lsp7OdznY62+lsp7OdznY62+lsp7Od
znY671hR2JVKtYbOdjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53OdjrbR+ZM
yh338Vbi9Mn8U20F1aG/vXfLp821A1+Cs9/O/rJ5FXP7slvDfjv703m6+4f3
1X/zdubT9fG5D4r6d7+sv5GoW3t7SUPx5f/eeDS/cnnp1+DMDz7uLx840Rrm
7XRIt9/3Z3+6+3s/8+neb30u90l3f5/7G/YiAPg=
      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[
           TagBox[Polygon3DBox[CompressedData["
1:eJwBCQX2+iFib1JiAgAAAKgBAAADAAAA4gIRFQUGEgIDEwMEFgYHFwcIGgoL
HAwNGAgJGQkKFAQFKhobGwsMKRkaIxMUIBARIRESJBQVJRUWKBgZ7+XkJhYX
JxcYHQ0OKxscLBwdPy8wRzc4MSEiLR0eMiIjNCQlNycoMyMkNSUmNiYnLx8g
MCAhOCgpOSkqQDAxPCwtPi4vQTEyIhITQjIzRDQ1OiorOyssQzM0RTU2gHBx
RjY3f29wTj4/Sjo7Szs8Tz9AUEBBU0NEVUVGUUFCUkJDTT0+Y1NUVERFYlJT
XExNWEhJWUlKXU1OXk5PYVFSV0dIX09QYFBRVkZHZFRVZVVWd2doSTk6aVla
ZlZXa1tcbV1ecGBhbFxdbl5fb19gZ1dYaFhZcWFicmJjeGhpdWVmdmZnempr
SDg5e2tsfW1uc2NkdGRlfGxtfm5vWkpLgXFyzb2+hnZ3g3N0hHR1nIyNh3d4
inp7i3t8jHx9jX1+hXV2iXl6jn5/kICBlYWGkoKDk4OEloaHmIiJm4uMkYGC
mYmKmoqLj3+A8PjnnY2On4+Qo5OUoJCRoZGSno6PpJSVp5eYqJiZqZmaqpqb
opKTq5ucrJydrZ2er5+gsKChsaGisqKjlISFs6OkuKiprp6ftqant6eotKSl
gnJzuamqu6uswLCxva2uvq6vwbGywrKzxra3yLi5w7O0xbW2v6+w1sbHx7e4
1cXGzr6/y7u8zLy9z7/A0MDB5sXUyrq70cHC0sLDybm618fI2MjJCBgXvKyt
3MzN2cnK3c3O38/Q4+IQ3s7P4NDR7ejS2srL28vMAhIRAxMSCRkYBhYVBxcW
ChoZuqqrCxsaDR0cBBQTBRUUDBwb5B0OECAfESEgEiIhFCQjFSUkFiYlFycm
GCgnGSkoGiopGysqHCwrHS0sHy8uIDAvITEwIjIxIzMyJDQzJTU0JjY1Jzc2
KDg3KTk4Kjo5Kzs6LDw7Lj49Lz8+M0NCMEA/MUFASVlYNERDNkZFN0dGOEhH
OUlIMkJBOkpJO0tKPU1MP09OQFBPQVFQQlJRSFhXQ1NSR1dWPk5NRVVURlZV
RFRTNUVESlpZbn59TV1cTl5dT19eUGBfUWFgUmJhU2NiVGRjVWVkVmZlV2dm
WGhnWWloW2tqXGxrXW1sXm5tX29uYHBvYXFwYnJxY3NyZHRzZXV0ZnZ1Z3d2
bHx7aHh3anp5TFxbbX18b39+cIB/cYGAcoKBa3t6c4OCdISDdYWEd4eGeYmI
eoqJe4uKgZGQfIyLgJCPdoaFfo6Nf4+OfY2MEyMigpKRhJSTiZmYhZWUhpaV
ipqZi5uajp6dkKCfjJybjZ2ciJiXnq6tj5+ena2sl6emk6OilKSjmKinmamo
nKyrkqKhmqqpm6uqkaGgn6+uoLCvssLBu8vKpLSzobGwpra1qLi3q7u6p7e2
qbm4qrq5orKxo7OyrLy7rb28s8PCsMC/scHAtcXElaWktsbFuMjHrr69r7++
t8fGucnIusrJvMzLg5OSwdHQvs7Nv8/OwtLR8Ofmx9fWydnYxdXUxtbVwNDP
yNjXytrZ6+QOzNzbzd3czt7dz9/eHeQe0ODf8u7jy9va7uriEOIR6ODRpZWW
5OUe+fHhvc3M8eno7ObU6Ong8+/r9u4B4uoC9PDs9fHt5ufE0ujR4+7i9+8P
7vIB7PDm7fHo7/MPxebE8PTT7vbq6+/k+PDT8fXh7/fl8fnpl2heKQ==
             "]],
            Annotation[#, "Charting`Private`Tag$3284#1"]& ]],
          Lighting->"Neutral"]}, {}, {}, {}, {}}, 
       {GrayLevel[0], 
        Line3DBox[{246, 1, 242, 227, 16, 31, 46, 61, 76, 91, 106, 121, 136, 
         151, 166, 181, 196, 231, 248, 211, 244, 236, 212, 213, 214, 215, 216,
          217, 218, 219, 220, 221, 222, 223, 224, 233, 249, 225, 245, 237, 
         210, 195, 180, 165, 150, 135, 120, 105, 90, 75, 60, 45, 30, 229, 247,
          15, 243, 235, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 234, 246},
         VertexColors->None]}},
      VertexColors->CompressedData["
1:eJxTTMoPSmVkYGD4CcRpYPDMfpQepUfpUXqUHqVH6aFHAwAuZnMS
       "],
      VertexNormals->CompressedData["
1:eJztyLEJACEURMGPVmIl9nAlCBdfC5ZsanZGgtjCLDwWprTveVNEzFWOvX7+
qJxzzjnnnHPOOeecc845v/0H/ZUifQ==
       "]]}, 
    {RGBColor[1, 0, 0], PointSize[Large], Point3DBox[{0.8, 0.18, 0.15}]}}, 
   {RGBColor[1, 0, 0], Arrow3DBox[{{0.8, 0.18, 0.14}, {0.4, 0.11, 0.04}}], 
    {RGBColor[0, 0, 1], Arrow3DBox[{{0.8, 0.18, 0.15}, {0.6, 0.07, 0.04}}]}, 
    {GrayLevel[0], Arrow3DBox[{{0.8, 0.18, 0.15}, {0.22, 0.23, 0.052}}]}}, 
   {RGBColor[1, 0, 0], PointSize[Large], Point3DBox[{0.8, 0.18, 0.15}]}},
  Axes->True,
  AxesLabel->{
    FormBox["\"efficiency\"", TraditionalForm], 
    FormBox["\"      time\\n      spent\"", TraditionalForm], 
    FormBox["\"effective\\nreturn      \"", TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotLabel->FormBox["\"Effective Return Plateau = 4.%\"", TraditionalForm],
  PlotRange->{All, All, All},
  PlotRangePadding->{Automatic, Automatic, Automatic},
  Ticks->{Automatic, Automatic, {{0.04, 
      FormBox["\"4%\"", TraditionalForm]}, {0.1, 
      FormBox["\"10%\"", TraditionalForm]}, {0.15, 
      FormBox["\"15%\"", TraditionalForm]}, {0.2, 
      FormBox["\"20%\"", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{3.6973215421124325`*^9, 3.697323534124654*^9, 
  3.6980443952161217`*^9, 3.69804483372523*^9, 3.731421559178258*^9},
 TextAlignment->Center,ExpressionUUID->"c0a74a0e-a807-4d94-8e59-1cf1d77d3fae"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.16",
  FontWeight->"Bold"],
 ". Natural downhill path of life from the beginning point"
}], "FigureCaption",
 CellChangeTimes->{{3.6973215709712152`*^9, 3.69732159582032*^9}},
 TextAlignment->Center,ExpressionUUID->"ee222219-a2b5-4907-a10a-fd22f31d0756"],

Cell["Segments of life", "Section",
 CellChangeTimes->{{3.697321954029348*^9, 3.697321956893964*^9}, {
  3.6973220129460864`*^9, 
  3.6973220157996693`*^9}},ExpressionUUID->"36faf07b-aa09-4eed-b776-\
314edb06afda"],

Cell["\<\
Another presentation, related solely to the investor\[CloseCurlyQuote]s age, \
shows various periods or epochs of life during which returns may only be \
achieved in a certain range. The sobering conclusion is that, after a certain \
age, real estate operation becomes impractical due to lack of time and/or \
ability, returns fall below financial assets and the game is over.\
\>", "Text",
 CellChangeTimes->{{3.6240200456918497`*^9, 3.624020077786686*^9}, {
  3.6240202301303997`*^9, 
  3.6240202941400604`*^9}},ExpressionUUID->"f65ee430-6faa-4c1f-a811-\
65752033cbce"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"curve", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"\[Rho]", " ", 
      FractionBox["s", 
       RowBox[{"s", "+", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", ".05", ",", ".25"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Yellow"}], ",", 
     RowBox[{"MeshFunctions", "->", 
      RowBox[{"{", 
       RowBox[{"#3", "&"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{".04", ",", ".1", ",", ".14"}], "}"}], "}"}]}], ",", 
     RowBox[{"MeshStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Red"}], "}"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<efficiency\>\"", ",", "\"\<      time\\n      spent\>\"", ",", 
        "\"\<effective\\nreturn      \>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{".04", ",", "\"\<4%\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{".1", ",", "\"\<10%\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{".15", ",", "\"\<15%\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{".20", ",", "\"\<20%\>\""}], "}"}]}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plain", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{".04", ",", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", ",", ".1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", ".05", ",", ".25"}], "}"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"GrayLevel", "[", ".7", "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<efficiency\>\"", ",", "\"\<      time\\n      spent\>\"", ",", 
        "\"\<effective\\nreturn      \>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{".04", ",", "\"\<4%\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{".1", ",", "\"\<10%\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{".15", ",", "\"\<15%\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{".20", ",", "\"\<20%\>\""}], "}"}]}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"plain", ",", "curve", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<efficiency\>\"", ",", "\"\<      time\\n      spent\>\"", ",", 
      "\"\<effective\\nreturn      \>\""}], "}"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "Automatic", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{".04", ",", "\"\<4%\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{".1", ",", "\"\<10%\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{".15", ",", "\"\<15%\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{".20", ",", "\"\<20%\>\""}], "}"}]}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Framed", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Rotate", "[", 
             RowBox[{"\"\<20-30\\nyears old\>\"", ",", 
              RowBox[{
               RowBox[{"-", "90"}], " ", "Degree"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1"}], "}"}]}], "]"}], ",", "6"}], "]"}], 
          ",", 
          RowBox[{"Background", "\[Rule]", "LightYellow"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{".90", ",", ".64"}], "}"}]}], "]"}], ",", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Framed", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Rotate", "[", 
             RowBox[{"\"\<30-40 years old\>\"", ",", 
              RowBox[{
               RowBox[{"-", "90"}], " ", "Degree"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1"}], "}"}]}], "]"}], ",", "7"}], "]"}], 
          ",", 
          RowBox[{"Background", "\[Rule]", "LightYellow"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{".75", ",", ".52"}], "}"}]}], "]"}], ",", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Framed", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Rotate", "[", 
             RowBox[{"\"\<40-60 years old\>\"", ",", 
              RowBox[{
               RowBox[{"-", "90"}], " ", "Degree"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1.5"}], "}"}]}], "]"}], ",", "7"}], "]"}], 
          ",", 
          RowBox[{"Background", "\[Rule]", "LightYellow"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{".55", ",", ".50"}], "}"}]}], "]"}]}], "}"}]}]}], " ", 
  "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.697321633864538*^9, 3.6973216497046824`*^9}, {
  3.697321745542652*^9, 
  3.6973218719760303`*^9}},ExpressionUUID->"91bb78fa-e611-4739-bcf2-\
aa422c8ce61e"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJx12E1oz3EcwPGFDCkHW5R22E1oDlaK8m8ccBFLqHkIkTB28BRDTZ4PWjmY
4mJqYg9KW5uM0R95WjEOm8UmxDxsajVGfyxvh/en/69+l1efPt9v7+M3d932
wg3DMjIyvv/5h//5j+2/Vn22ojHxcObirLMVlxL7smrmd+2tTCwcLOpZnJkM
/qSh82BbwePgU5qmj5nW/DT41jMlbcUdL4LX7Lp6vnagPXjv0m+b+rJfBa8Y
+rqCN41qOjCr6k3wjt3t6zvq3wb/+e7HgtLk++A5yybl5bR9CD4nOXt8c3dP
8DX5KwdW930OXnahtDOV+hqczrXbxx7O3FkXOtvpbKeznc52OtvpbKeznc52
OtvpbKeznc52OtvpbKfznju9qYKca6Gznc52OtvpbKeznc52OtvpbKeznc52
OtvpbKeznc52OhdMeL63NNkQOtvpbKeznc52OtvpbKeznc52OtvpbKeznc52
OtvpbKfzmC2N/fXF10NnO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U5nO53t
dH7WfK6kL/tm6Gyns53Odjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53Oi0a3
9GevaQmd7XS209lOZzud7XS209lOZzud7XS209lOZzud7XS203nG0HcndLbT
2U5nO53tdLbT2U5nO53tdLbT2U5nO53tdLbT2U7niasulvzt6s52OtvpbKez
nc52OtvpbKeznc52OtvpbKeznc52Otvp/OvIhJrijruhs53Odjrb6Wyns53O
djrb6Wyns53Odjrb6Wyns53Odjp31x3vOVF7P3S209lOZzud7XS209lOZzud
7XS209lOZzud7XS209lO53vtg5OrDj0Ine10ttPZTmc7ne10ttPZTmc7ne10
ttPZTmc7ne10ttP5yohtG5PLH4XOdjrb6Wyns53Odjrb6Wyns53Odjrb6Wyn
s53Odjrb6Vye9/pC99QnobOdznY62+lsp7OdznY62+lsp7OdznY62+lsp7Od
znY671hR2JVKtYbOdjrb6Wyns53Odjrb6Wyns53Odjrb6Wyns53OdjrbR+ZM
yh338Vbi9Mn8U20F1aG/vXfLp821A1+Cs9/O/rJ5FXP7slvDfjv703m6+4f3
1X/zdubT9fG5D4r6d7+sv5GoW3t7SUPx5f/eeDS/cnnp1+DMDz7uLx840Rrm
7XRIt9/3Z3+6+3s/8+neb30u90l3f5/7G/YiAPg=
    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[
         TagBox[Polygon3DBox[CompressedData["
1:eJwBCQX2+iFib1JiAgAAAKgBAAADAAAA4gIRFQUGEgIDEwMEFgYHFwcIGgoL
HAwNGAgJGQkKFAQFKhobGwsMKRkaIxMUIBARIRESJBQVJRUWKBgZ7+XkJhYX
JxcYHQ0OKxscLBwdPy8wRzc4MSEiLR0eMiIjNCQlNycoMyMkNSUmNiYnLx8g
MCAhOCgpOSkqQDAxPCwtPi4vQTEyIhITQjIzRDQ1OiorOyssQzM0RTU2gHBx
RjY3f29wTj4/Sjo7Szs8Tz9AUEBBU0NEVUVGUUFCUkJDTT0+Y1NUVERFYlJT
XExNWEhJWUlKXU1OXk5PYVFSV0dIX09QYFBRVkZHZFRVZVVWd2doSTk6aVla
ZlZXa1tcbV1ecGBhbFxdbl5fb19gZ1dYaFhZcWFicmJjeGhpdWVmdmZnempr
SDg5e2tsfW1uc2NkdGRlfGxtfm5vWkpLgXFyzb2+hnZ3g3N0hHR1nIyNh3d4
inp7i3t8jHx9jX1+hXV2iXl6jn5/kICBlYWGkoKDk4OEloaHmIiJm4uMkYGC
mYmKmoqLj3+A8PjnnY2On4+Qo5OUoJCRoZGSno6PpJSVp5eYqJiZqZmaqpqb
opKTq5ucrJydrZ2er5+gsKChsaGisqKjlISFs6OkuKiprp6ftqant6eotKSl
gnJzuamqu6uswLCxva2uvq6vwbGywrKzxra3yLi5w7O0xbW2v6+w1sbHx7e4
1cXGzr6/y7u8zLy9z7/A0MDB5sXUyrq70cHC0sLDybm618fI2MjJCBgXvKyt
3MzN2cnK3c3O38/Q4+IQ3s7P4NDR7ejS2srL28vMAhIRAxMSCRkYBhYVBxcW
ChoZuqqrCxsaDR0cBBQTBRUUDBwb5B0OECAfESEgEiIhFCQjFSUkFiYlFycm
GCgnGSkoGiopGysqHCwrHS0sHy8uIDAvITEwIjIxIzMyJDQzJTU0JjY1Jzc2
KDg3KTk4Kjo5Kzs6LDw7Lj49Lz8+M0NCMEA/MUFASVlYNERDNkZFN0dGOEhH
OUlIMkJBOkpJO0tKPU1MP09OQFBPQVFQQlJRSFhXQ1NSR1dWPk5NRVVURlZV
RFRTNUVESlpZbn59TV1cTl5dT19eUGBfUWFgUmJhU2NiVGRjVWVkVmZlV2dm
WGhnWWloW2tqXGxrXW1sXm5tX29uYHBvYXFwYnJxY3NyZHRzZXV0ZnZ1Z3d2
bHx7aHh3anp5TFxbbX18b39+cIB/cYGAcoKBa3t6c4OCdISDdYWEd4eGeYmI
eoqJe4uKgZGQfIyLgJCPdoaFfo6Nf4+OfY2MEyMigpKRhJSTiZmYhZWUhpaV
ipqZi5uajp6dkKCfjJybjZ2ciJiXnq6tj5+ena2sl6emk6OilKSjmKinmamo
nKyrkqKhmqqpm6uqkaGgn6+uoLCvssLBu8vKpLSzobGwpra1qLi3q7u6p7e2
qbm4qrq5orKxo7OyrLy7rb28s8PCsMC/scHAtcXElaWktsbFuMjHrr69r7++
t8fGucnIusrJvMzLg5OSwdHQvs7Nv8/OwtLR8Ofmx9fWydnYxdXUxtbVwNDP
yNjXytrZ6+QOzNzbzd3czt7dz9/eHeQe0ODf8u7jy9va7uriEOIR6ODRpZWW
5OUe+fHhvc3M8eno7ObU6Ong8+/r9u4B4uoC9PDs9fHt5ufE0ujR4+7i9+8P
7vIB7PDm7fHo7/MPxebE8PTT7vbq6+/k+PDT8fXh7/fl8fnpl2heKQ==
           "]],
          Annotation[#, "Charting`Private`Tag$3385#1"]& ]],
        Lighting->"Neutral"]}, {}, {}, {}, {}}, 
     {GrayLevel[0], 
      Line3DBox[{246, 1, 242, 227, 16, 31, 46, 61, 76, 91, 106, 121, 136, 151,
        166, 181, 196, 231, 248, 211, 244, 236, 212, 213, 214, 215, 216, 217, 
       218, 219, 220, 221, 222, 223, 224, 233, 249, 225, 245, 237, 210, 195, 
       180, 165, 150, 135, 120, 105, 90, 75, 60, 45, 30, 229, 247, 15, 243, 
       235, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 234, 246},
       VertexColors->None]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGD4CcRpYPDMfpQepUfpUXqUHqVH6aFHAwAuZnMS
     "],
    VertexNormals->CompressedData["
1:eJztyLEJACEURMGPVmIl9nAlCBdfC5ZsanZGgtjCLDwWprTveVNEzFWOvX7+
qJxzzjnnnHPOOeecc845v/0H/ZUifQ==
     "]], GraphicsComplex3DBox[CompressedData["
1:eJxd2Hk0VXsbwHHKTUrphohUcoRKKopUfhkieiuUyFCpUEoZGiRkSCEKKVPK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    "], {{
      {RGBColor[1, 1, 0], EdgeForm[None], 
       StyleBox[GraphicsGroup3DBox[
         TagBox[{Polygon3DBox[CompressedData["
1:eJxNmHWYl1UQhe9VEAQBBQGRkEWkkW6RRUB2BaklFERKDFBRVGzBLrBbVGzs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            "]], Polygon3DBox[CompressedData["
1:eJxNlbdPVmEUh9/XLmBXEKyoFHtB7A0BpSmCDbCAYGFQHKwJOCiWRBexJTgo
URN1wDaoiZVBB+uig0b/EfvzyzmDw5Pvge9+9573tJtev7eyqVsIoRF6QF0M
4TmfL2AKXg2P8UcwAd8KT/CnMAmvhPP4BRiNb4J7+H3IwqvgJn7Lf78WbuDX
/frN0IW/9Ou3wUf8gz+/EA7iB2AAXgvv8Lf+/MnR/Cs04BvgLn4H0vGFkI8v
1/nw9XAFv+rfj4rmZ6ECnw+5+GzohifDKfwSlOOr4QR+EtLw8dHOeg024uOg
M9gz9KwyOIofg+F4CpzBL8MafCmUyyEB/6nroC/M5O/FUIyXQG88FdrwDo93
MLQEu2cpPjLavW/DOnwEXAyWc+W+BA7hh2EYPjBabo9DMV4E+/D9MAQfCq34
OViF94cm/AisxFfAbnwPDMIz4VmwGqlWS6LFXqoz4QWwA9/p9ewOOeoNmIf3
hDx8FizAe0XLjf63yM/Xjp/2/I2N1lvt/51XvagaqVZjotVGPVrp+WoOFrNi
z4ONeBUk4X2iuXKu3Ceq54PVSLUKkMFHMuR6PdQ7qnGZ11exNXs9+kU7q56R
5/2k3lENSjy/6g3lvMjrodwrRwWeb+VWMeTj2dFmRTOiWcmINpuvYQs+RzF4
D0XPfw1e7f2j+DOD9fh877dUyIa5Xg/1vmZmoddDs1Ph+VfNVfsWr/cfPvvB
SM2M10vX1sGyaDVVbTN8nlRT1TbH51HxZgWL6a/mNNou2uX10D117xHwW7+L
5mnwS30SzXWGH96j6tU2nzf1tHq71ftZZ9RZszw/mmnNtmZE8zwRXuEPPZ+6
fwKe6M/T8+VJHo/mXbtGPV/j/ajZ086s9v7TrnsQbD9o33QE21HaVdof+q4r
2C5Uv+js2nmFHo9q+xnqo/Wcei/F86X+rA02k/neD4pdO7fK+1m1b/Tcaqdo
tyR4vjSv2uWdHr/6S7tfO1y7XDVULfUM7Sft2zfB3gF6F8yAb/h72I5PjeZ6
h+hdMg0+Bcup4p8OX4Ldo8Gv167/7r//B/uIl/c=
            "]]},
          Annotation[#, "Charting`Private`Tag$3350#1"]& ]],
        Lighting->Automatic]}, {}, {}, {}, {}}, {
      {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0L1NggEQBuAPf0AE0cZWwwAgA+gEmJhYamcnhbY6gU6gE8gEMIFMAMqf
KBBjDCINPyqN8fkSiyfv3SV3xaVPzg/PIkEQHPBFWI95ZYNtsuyxzzEFLrnm
liJlKrzzQ40pnzyENxx+lHUaNGmxY96WT3TI6Z/lC116DJjTZ8aIKveUuOOG
KzbtX8hTjojr83KXDFu88c06E4akWOOXJAlWw31WiBFlmSUWWeDj/29/Ihgs
UQ==
        "]]}, 
      {RGBColor[1, 0, 0], Thickness[Large], 
       Line3DBox[{254, 308, 253, 307, 252, 306, 250, 305, 251, 311, 257, 310, 
        255, 309, 256, 313, 258, 312, 259, 315, 260, 314, 261, 316, 262, 320, 
        266, 319, 267, 323, 270, 327, 273, 326, 274, 331, 279, 336, 284, 340, 
        288, 345, 292, 344, 293, 349, 297, 354, 302}], 
       Line3DBox[{265, 318, 263, 317, 264, 322, 268, 321, 269, 325, 271, 324, 
        272, 329, 275, 328, 276, 333, 280, 332, 281, 337, 285, 342, 289, 341, 
        290, 346, 294, 351, 298, 350, 299, 355, 303}], 
       Line3DBox[{277, 330, 278, 335, 282, 334, 283, 339, 286, 338, 287, 343, 
        291, 348, 295, 347, 296, 353, 300, 352, 301, 356, 304}]}, {}, {}}},
    VertexNormals->CompressedData["
1:eJwVmXc41f8bxqUIkUSKImQVGVGUeJeVKCEyojJKQ0aFNKSsZCazZEcke6/n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     "]]},
  Axes->True,
  AxesLabel->{
    FormBox["\"efficiency\"", TraditionalForm], 
    FormBox["\"      time\\n      spent\"", TraditionalForm], 
    FormBox["\"effective\\nreturn      \"", TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  Epilog->{
    InsetBox[
     BoxData[
      FormBox[
       FrameBox[
        StyleBox[
         RotationBox[
         "\"20-30\\nyears old\"", BoxRotation -> -1.5707963267948966`, 
          BoxRotationPoint -> {0, 1}], 6, StripOnInput -> False], Background -> 
        RGBColor[1, 1, 0.85], StripOnInput -> False], TraditionalForm]], {0.9,
      0.64}], 
    InsetBox[
     BoxData[
      FormBox[
       FrameBox[
        StyleBox[
         RotationBox[
         "\"30-40 years old\"", BoxRotation -> -1.5707963267948966`, 
          BoxRotationPoint -> {0, 1}], 7, StripOnInput -> False], Background -> 
        RGBColor[1, 1, 0.85], StripOnInput -> False], TraditionalForm]], {
     0.75, 0.52}], 
    InsetBox[
     BoxData[
      FormBox[
       FrameBox[
        StyleBox[
         RotationBox[
         "\"40-60 years old\"", BoxRotation -> -1.5707963267948966`, 
          BoxRotationPoint -> {0, 1.5}], 7, StripOnInput -> False], 
        Background -> RGBColor[1, 1, 0.85], StripOnInput -> False], 
       TraditionalForm]], {0.55, 0.5}]},
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Lighting->"Neutral",
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->All,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, {{0.04, 
      FormBox["\"4%\"", TraditionalForm]}, {0.1, 
      FormBox["\"10%\"", TraditionalForm]}, {0.15, 
      FormBox["\"15%\"", TraditionalForm]}, {0.2, 
      FormBox["\"20%\"", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.69732165197171*^9, {3.697321747205076*^9, 3.69732187237609*^9}, 
   3.6973235342208834`*^9, 3.698044395418676*^9, 3.6980448338786716`*^9, 
   3.7314215593106155`*^9},
 TextAlignment->Center,ExpressionUUID->"adaa0c74-d950-4db5-a1d2-c0def7dc823f"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.17",
  FontWeight->"Bold"],
 ". Subsections of life"
}], "FigureCaption",
 CellChangeTimes->{{3.697321688568073*^9, 3.697321707181629*^9}},
 TextAlignment->Center,ExpressionUUID->"9d1005c2-bbb2-4491-8c05-70812991e4d2"],

Cell["\<\
One might reflect on this and conclude it is a dark view of life. The better \
perspective is to note the efficient and productive use of one\
\[CloseCurlyQuote]s youth while it lasts. Over time some wish to tempt fate. \
Remaining in the game is to retain and maintain one\[CloseCurlyQuote]s \
mastery of one\[CloseCurlyQuote]s field as long as possible. The endurance \
test, for those who enjoy their work, is to attempt to extend the lower band \
to the lowest possible point. Doing so is a measure of vitality. It could be \
proof of the old adage \[OpenCurlyDoubleQuote]Age and cunning overcomes youth \
and enthusiasm every time.\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.6973231992918134`*^9, 
  3.6973234884882135`*^9}},ExpressionUUID->"20ba3c67-18d3-4e58-9ca2-\
637f6ce62aab"]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{1280, 637},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
Visible->True,
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{32000, 32000},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{576, 720}},
ShowSelection->True,
ShowCellLabel->False,
CellLabelAutoDelete->True,
InputAliases->{"notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TagBox["\[SelectionPlaceholder]", "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftRightArrow]", " ", 
       TagBox["\[Placeholder]", "NotationTemplateTag"]}], "]"}], "notation>" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox["\[SelectionPlaceholder]", "NotationTemplateTag"], " ", 
       "\[DoubleLongRightArrow]", " ", 
       TagBox["\[Placeholder]", "NotationTemplateTag"]}], "]"}], "notation<" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox["\[SelectionPlaceholder]", "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftArrow]", " ", 
       TagBox["\[Placeholder]", "NotationTemplateTag"]}], "]"}], "symb" -> 
  RowBox[{"Symbolize", "[", 
     TagBox["\[SelectionPlaceholder]", "NotationTemplateTag"], "]"}], 
  "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TagBox["\[SelectionPlaceholder]", "NotationTemplateTag"], ",", 
       "\[Placeholder]"}], "]"}], "addia" -> RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[SelectionPlaceholder]\"", "\[Rule]", 
       TagBox["\[Placeholder]", "NotationTemplateTag"]}], "]"}], "pattwraper" -> 
  TagBox["\[SelectionPlaceholder]", "NotationPatternTag"], "madeboxeswraper" -> 
  TagBox["\[SelectionPlaceholder]", "NotationMadeBoxesTag"]},
CounterAssignments->{{"BookChapterNumber", 8}},
Magnification:>1.5 Inherited,
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Book"}, "Textbook.nb", CharacterEncoding -> 
       "WindowsANSI"]]], 
   Cell[
    StyleData["BookChapterTitle"], FontColor -> GrayLevel[0.5]], 
   Cell[
    StyleData["Section"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["Subsection"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["TableTitle"], FontColor -> RGBColor[0, 0, 1]], 
   Cell[
    StyleData["PageBreak"], Editable -> True, CellMargins -> {{0, 0}, {1, 1}},
     CellBracketOptions -> {
     "Color" -> RGBColor[0.500008, 0.500008, 1], "Margins" -> {Inherited, 3}, 
      "Thickness" -> 1, "Widths" -> {5, 5}}, 
    CellElementSpacings -> {"CellMinHeight" -> 1}, 
    ConversionRules :> {"TeX" -> {"\n\n\\pagebreak", 
        $CellContext`NoOutput[], ""}, "HTML" -> {"<br class=\"PageBreak\">", 
        $CellContext`NoOutput[], ""}}, PageBreakAbove -> Automatic, 
    CellSize -> {Automatic, 9.120000000000005}, TabFilling -> "- ", 
    TabSpacings -> 1000, FontSize -> 6, FontColor -> GrayLevel[0.700008]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Hyperlink", StyleDefinitions -> StyleData["Link"]], 
       ContextMenu -> FEPrivate`FrontEndResource["ContextMenus", "Hyperlink"],
        FontVariations -> {"Underline" -> True}, FontColor -> 
       RGBColor[0, 0, 1], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["Hyperlink", "Condensed"], FontSize -> 11], 
      Cell[
       StyleData[
       "Hyperlink", "Printout", StyleDefinitions -> StyleData["Link"]], 
       ContextMenu -> FEPrivate`FrontEndResource["ContextMenus", "Hyperlink"],
        FontVariations -> {"Underline" -> True}, FontColor -> 
       RGBColor[0, 0, 1], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ReferenceSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["ReferenceSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["EndnoteSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["EndnoteSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ExerciseSection"], CellMargins -> {{12, 12}, {24, 48}}, 
       PageBreakAbove -> False, FontColor -> GrayLevel[0.5]], 
      Cell[
       StyleData["ExerciseSection", "Printout"], 
       CellMargins -> {{12, 12}, {24, 48}}, PageBreakAbove -> False, 
       FontColor -> GrayLevel[0.5]]}, Open]], 
   Cell[
    StyleData["BookChapterNumber"], Background -> 
    RGBColor[0.9333333333333333, 0.1803921568627451, 0.1411764705882353]], 
   Cell[
    StyleData["EquationNumbered"], CellFrame -> True, CellFrameColor -> 
    RGBColor[0.501961, 0, 0], FontColor -> 
    RGBColor[0.5019607843137255, 0., 0.]], 
   Cell[
    CellGroupData[{
      Cell[
      "Figure", "Subsubsection", FontFamily -> "Times New Roman", FontSize -> 
       12, FontColor -> RGBColor[0, 0, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Figure"], Editable -> False, 
          CellMargins -> {{12, Inherited}, {8, 6}}, CellGroupingRules -> 
          "InputGrouping", ConversionRules :> {"TeX" -> {"\n\\begin{center}", 
              $CellContext`ExtractFigure[], "\n\\end{center}"}}, 
          TaggingRules :> {
           "CounterSettings" -> {"CounterTarget" -> "Style:FigureCaption"}, 
            "ExtraConversionRules" -> {
             "General" -> {
               "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, 
              "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}}, 
          PageBreakAbove -> False, Hyphenation -> True, CounterIncrements -> 
          "Figure", FontFamily -> "Times New Roman", FontSize -> 12, 
          FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["Figure", "Printout"], 
          CellMargins -> {{2, Inherited}, {6, 4}}, Magnification -> 0.8], 
         Cell[
          StyleData["Figure", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, Inherited}, {6, 4}}, Magnification -> 0.8]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FigureCaption"], CellMargins -> {{12, 10}, {6, 2}}, 
          CellGroupingRules -> "OutputGrouping", 
          ConversionRules :> {"TeX" -> {"\n\\caption{", "}"}}, 
          TaggingRules :> {
           "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "Figure"}, 
              "CounterTarget" -> "Cell", "XRefPrefix" -> "Figure"}, 
            "ExtraConversionRules" -> {
             "General" -> {"NestingLevel" -> 90}, 
              "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}}, 
          PageBreakAbove -> False, Hyphenation -> True, CounterIncrements -> 
          "FigureCaption", CounterAssignments -> {{"Nil", 0}}, FontFamily -> 
          "Times New Roman", FontSize -> 12, FontWeight -> "Plain", FontSlant -> 
          "Plain", 
          FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}, 
          FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["FigureCaption", "Printout"], 
          CellMargins -> {{2, 2}, {4, 1}}], 
         Cell[
          StyleData["FigureCaption", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 2}, {4, 1}}, LineSpacing -> {2, 1}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FigureCaptionLabel"], Editable -> False, 
          ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, FontFamily -> "Times New Roman", 
          FontSize -> 12, FontWeight -> "Bold", FontColor -> 
          RGBColor[0, 0, 1]], 
         Cell[
          StyleData["FigureCaptionLabel", "Printout"]], 
         Cell[
          StyleData["FigureCaptionLabel", "DoubleSpacedPrintout"]]}, Open]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell[
      "Tables", "Subsubsection", FontFamily -> "Times New Roman", FontColor -> 
       RGBColor[0, 0, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableTitle"], PageWidth -> 530, 
          CellMargins -> {{12, 10}, {1, 7}}, CellGroupingRules -> 
          "InputGrouping", 
          ConversionRules :> {"TeX" -> {"\n\\caption{", Automatic, "} "}}, 
          TaggingRules :> {
           "ExtraConversionRules" -> {
             "General" -> {
               "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, 
              "TeX" -> {"CellGroupEnvironment" -> "table"}}, 
            "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "TableTitle"}, 
              "CounterTarget" -> "Cell", "XRefPrefix" -> "Table"}}, 
          LineSpacing -> {1, 2}, CounterIncrements -> "TableTitle", 
          FontFamily -> "Times New Roman", FontWeight -> "Plain", FontColor -> 
          RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{40}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableTitle", "Printout"], 
          CellMargins -> {{2, 10}, {1, 5}}, FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["TableTitle", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 10}, {1, 5}}, FontFamily -> "Times New Roman", 
          FontSize -> 10]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableTitleLabel"], Editable -> True, 
          ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, LineSpacing -> {1, 2}, 
          CounterIncrements -> "TableTitleLabel", 
          CounterAssignments -> {{"Nil", 0}}, FontFamily -> "Times New Roman",
           FontWeight -> "Bold", FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{40}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableTitleLabel", "Printout"]], 
         Cell[
          StyleData["TableTitleLabel", "DoubleSpacedPrintout"], FontSize -> 
          10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Table"], Editable -> True, PageWidth -> WindowWidth, 
          CellMargins -> {{12, 10}, {4, 1}}, CellGroupingRules -> 
          "OutputGrouping", 
          ConversionRules :> {
           "TeX" -> {"\n\\begin{tabular}\n", Automatic, "\n\\end{tabular}"}, 
            "HTML" -> {{"", Automatic, ""}, {"", Automatic, ""}}}, 
          TaggingRules :> {
           "ExtraConversionRules" -> {
             "General" -> {"NestingLevel" -> 90}, 
              "TeX" -> {"CellGroupEnvironment" -> "table"}}, 
            "CounterSettings" -> {
             "CounterFormat" -> {"BookChapterNumber", ".", "TableTitle"}, 
              "CounterTarget" -> "CellGroup"}}, CellHorizontalScrolling -> 
          True, CounterIncrements -> "Table", 
          CounterAssignments -> {{"TableNote", 0}}, FontFamily -> 
          "Times New Roman", FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}}, 
            GridBoxDividers -> {
             "Columns" -> {False, {False}, False}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                AbsoluteThickness[2], {False}, 
                AbsoluteThickness[0.5]}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {"Columns" -> {{
                 Scaled[0.503]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}, GridDefaultElement :> 
            Cell["Data", "TableText"]}], 
         Cell[
          StyleData["Table", "Printout"], PageWidth -> PaperWidth, 
          CellMargins -> {{2, 10}, {3, 1}}], 
         Cell[
          StyleData["Table", "DoubleSpacedPrintout"], PageWidth -> PaperWidth,
           CellMargins -> {{2, 10}, {3, 1}}, FontSize -> 10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TableNote"], Editable -> True, 
          CellMargins -> {{12, 10}, {7, -3}}, CellGroupingRules -> 
          "OutputGrouping", ConversionRules :> {"TeX" -> {"", 
              $CellContext`NoOutput[], ""}}, 
          TaggingRules :> {
           "CounterSettings" -> {
             "CounterFormat" -> {"Table"}, "CounterTarget" -> "CellGroup"}}, 
          LineSpacing -> {1, 1}, ParagraphSpacing -> {0.3, 0}, 
          CounterIncrements -> "TableNote", FontFamily -> "Times New Roman", 
          FontSize -> 10, FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          StyleData["TableNote", "Printout"], 
          CellMargins -> {{2, 10}, {5, -2}}], 
         Cell[
          StyleData["TableNote", "DoubleSpacedPrintout"], 
          CellMargins -> {{2, 10}, {5, -2}}, LineSpacing -> {2, 1}, FontSize -> 
          9]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Inline Table Styles", "Subsubsubsection", FontFamily -> 
          "Times New Roman", FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableColumnHead"], Editable -> True, 
             ConversionRules :> {
              "TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic, ""}}}, 
             FontFamily -> "Times New Roman", FontSlant -> "Italic", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableColumnHead", "Printout"]], 
            Cell[
             StyleData["TableColumnHead", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableSpanHead"], Editable -> True, 
             ConversionRules :> {
              "TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic, ""}}}, 
             TextAlignment -> Center, FontFamily -> "Times New Roman", 
             FontSlant -> "Italic", FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableSpanHead", "Printout"]], 
            Cell[
             StyleData["TableSpanHead", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableText"], Editable -> True, TextAlignment -> Left, 
             LineSpacing -> {1, 1}, FontFamily -> "Times New Roman", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              BaselinePosition -> Axis, ColumnsEqual -> False, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
               "\[Placeholder]", RowsEqual -> False}], 
            Cell[
             StyleData["TableText", "Printout"]], 
            Cell[
             StyleData["TableText", "DoubleSpacedPrintout"], 
             LineSpacing -> {2, 1}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TableSpanText"], Editable -> True, TextAlignment -> 
             Center, LineSpacing -> {1, 1}, FontFamily -> "Times New Roman", 
             FontColor -> RGBColor[0, 0, 1], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["TableSpanText", "Printout"]], 
            Cell[
             StyleData["TableSpanText", "DoubleSpacedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          StyleData["TableSubGrid"], FontFamily -> "Times New Roman", 
          FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {
           GridBoxAlignment -> {
             "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}, 
            GridBoxItemSize -> {
             "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {{0.1}}, 
              "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.27999999999999997`]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}, GridDefaultElement :> 
            Cell["Data", "TableText"]}], 
         Cell[
          StyleData["TableMasterGrid"], FontFamily -> "Times New Roman", 
          FontColor -> RGBColor[0, 0, 1], 
          GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                 Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
              "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.004]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TableLineElement"], Editable -> False, 
          CellFrame -> {{0, 0}, {0.5, 0}}, 
          CellElementSpacings -> {"CellMinHeight" -> 1}, 
          ConversionRules :> {"HTML" -> {{"&nbsp;", 
               $CellContext`NoOutput[], ""}, {"", Automatic, ""}}}, 
          CellSize -> {Inherited, 1.25}, TabFilling -> " ", TabSpacings -> 
          1000, FontFamily -> "Times New Roman", FontSize -> 1, FontColor -> 
          RGBColor[0, 0, 1]], 
         Cell[
          StyleData["TableBlankElement"], Editable -> False, 
          CellElementSpacings -> {"CellMinHeight" -> 1}, 
          CellSize -> {Inherited, 1.25}, FontFamily -> "Times New Roman", 
          FontSize -> 1, FontColor -> RGBColor[0, 0, 1]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanLeft"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanLeft", "Printout"]], 
            Cell[
             StyleData["SpanLeft", "DoubleSpacedPrintout"], FontSize -> 14]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanCenter"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanCenter", "Printout"]], 
            Cell[
             StyleData["SpanCenter", "DoubleSpacedPrintout"], FontSize -> 
             14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SpanRight"], Editable -> False, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Plain", 
             FontSlant -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["SpanRight", "Printout"]], 
            Cell[
             StyleData["SpanRight", "DoubleSpacedPrintout"], FontSize -> 14]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AppendixSection"], 
             CellMargins -> {{12, 12}, {24, 48}}, FontColor -> 
             GrayLevel[0.5]], 
            Cell[
             StyleData["AppendixSection", "Printout"], 
             CellMargins -> {{12, 12}, {24, 48}}, FontColor -> 
             GrayLevel[0.5]]}, Open]]}, Open]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> "11.3 for Microsoft Windows (64-bit) (March 6, 2018)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"],
RenderingOptions -> {"ImageCacheDepth" -> "WindowDepth"}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "endnote1"->{
  Cell[725737, 15136, 915, 16, 74, "Endnote",ExpressionUUID->"f68bc0f7-1a04-440c-90bf-6a24dba46404",
   CellTags->"endnote1"]},
 "endnote10"->{
  Cell[732872, 15306, 957, 16, 51, "Endnote",ExpressionUUID->"978581f7-805d-4dc1-9cb6-484851a488c6",
   CellTags->"endnote10"]},
 "endnote11"->{
  Cell[733832, 15324, 592, 12, 51, "Endnote",ExpressionUUID->"12aacaa6-8484-44fc-aed0-81a61e319f5d",
   CellTags->"endnote11"]},
 "endnote12"->{
  Cell[734427, 15338, 630, 12, 28, "Endnote",ExpressionUUID->"c7c77fc5-9975-4245-84b4-207ccd2638a2",
   CellTags->"endnote12"]},
 "endnote2"->{
  Cell[726655, 15154, 545, 11, 28, "Endnote",ExpressionUUID->"2b968c7e-9faf-45dd-8828-ea8812bf2642",
   CellTags->"endnote2"]},
 "endnote3"->{
  Cell[727203, 15167, 674, 13, 28, "Endnote",ExpressionUUID->"75ace251-579c-4f7f-bc0a-0ef1ce878983",
   CellTags->"endnote3"]},
 "endnote4"->{
  Cell[727880, 15182, 606, 11, 28, "Endnote",ExpressionUUID->"2875e4c7-ac06-4cb5-a7c6-04418a12af74",
   CellTags->"endnote4"]},
 "endnote5"->{
  Cell[728489, 15195, 883, 17, 74, "Endnote",ExpressionUUID->"f54e6254-70b6-4079-805f-71fd84d09c38",
   CellTags->"endnote5"]},
 "endnote6"->{
  Cell[729375, 15214, 667, 13, 28, "Endnote",ExpressionUUID->"d382f0e2-8758-4ab9-b9e1-979e1eef6693",
   CellTags->"endnote6"]},
 "endnote7"->{
  Cell[730045, 15229, 657, 16, 28, "Endnote",ExpressionUUID->"e04a9228-ea28-42f4-a553-c23aac899ef5",
   CellTags->"endnote7"]},
 "endnote8"->{
  Cell[730705, 15247, 589, 11, 28, "Endnote",ExpressionUUID->"2346c6e1-bae6-4916-a123-97534217f02a",
   CellTags->"endnote8"]},
 "endnote9"->{
  Cell[731297, 15260, 1572, 44, 84, "Endnote",ExpressionUUID->"5cc4ad3d-c1f4-48a8-802d-1648e6ac9ab0",
   CellTags->"endnote9"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"endnote1", 1216725, 24165},
 {"endnote10", 1216869, 24168},
 {"endnote11", 1217014, 24171},
 {"endnote12", 1217159, 24174},
 {"endnote2", 1217303, 24177},
 {"endnote3", 1217446, 24180},
 {"endnote4", 1217589, 24183},
 {"endnote5", 1217732, 24186},
 {"endnote6", 1217875, 24189},
 {"endnote7", 1218018, 24192},
 {"endnote8", 1218161, 24195},
 {"endnote9", 1218304, 24198}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[1488, 33, 267, 5, 232, "BookChapterNumber",ExpressionUUID->"9535a802-6019-4842-8cdb-15bffde71964"],
Cell[1758, 40, 258, 4, 244, "BookChapterTitle",ExpressionUUID->"8028d1df-3900-4323-ad35-424a4950af20"],
Cell[2019, 46, 418, 7, 78, "Epigraph",ExpressionUUID->"106feaf1-24d7-4c03-848d-36edbc88c1df"],
Cell[2440, 55, 441, 11, 75, "EpigraphAuthor",ExpressionUUID->"b2b84873-f054-41a6-9729-e76979d5b069"],
Cell[2884, 68, 631, 13, 28, "Input",ExpressionUUID->"c096ec2f-aa95-46ec-93e1-62aaecf6b98d",
 CellOpen->False],
Cell[CellGroupData[{
Cell[3540, 85, 181, 2, 87, "Section",ExpressionUUID->"f3cf010e-8e30-4561-a2c1-fe04186d6e72"],
Cell[3724, 89, 1532, 23, 180, "Text",ExpressionUUID->"fc9b614f-f0a3-4f90-9a19-db741db6f391"],
Cell[5259, 114, 163, 2, 33, "Text",ExpressionUUID->"e0ce66f7-d621-4996-b1cc-dd4179572011"],
Cell[5425, 118, 236, 4, 27, "Item1",ExpressionUUID->"00858320-0156-4504-b20e-1f7d12ec7b73"],
Cell[5664, 124, 311, 5, 27, "Item1",ExpressionUUID->"35abf51f-389e-48ac-82f2-4c8996973c70"],
Cell[5978, 131, 222, 2, 27, "Item1",ExpressionUUID->"0fb9ba32-3817-45c0-a083-26b9eb1c77ab"],
Cell[6203, 135, 289, 5, 27, "Item1",ExpressionUUID->"e88287a6-edb8-4373-90b1-bb1ce6166ea1"],
Cell[6495, 142, 204, 2, 51, "Subsection",ExpressionUUID->"2eed8071-71d3-4cfc-a797-238c88619825"],
Cell[6702, 146, 941, 14, 103, "Text",ExpressionUUID->"275372aa-3a46-460d-97f1-8cab57942ceb"],
Cell[7646, 162, 1755, 31, 185, "Text",ExpressionUUID->"79cd8483-f081-4381-a059-0b86a7baf230"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9438, 198, 179, 2, 87, "Section",ExpressionUUID->"6d72b77f-c51b-4b52-a14e-88096201a5a8"],
Cell[9620, 202, 797, 10, 107, "Text",ExpressionUUID->"79784ad8-608b-4c39-a5a8-e3506e1380b6"],
Cell[10420, 214, 865, 13, 107, "Text",ExpressionUUID->"85064e0a-80f2-4f31-bf70-7854d3dcaad2"],
Cell[11288, 229, 1250, 28, 87, "Text",ExpressionUUID->"5597a20d-9b1c-460e-9e53-7c9152687fa9"],
Cell[12541, 259, 738, 18, 38, "Text",ExpressionUUID->"5b81ae20-0a75-4483-9f7d-3e40e2e6febb"],
Cell[13282, 279, 458, 9, 49, "Item1",ExpressionUUID->"0aac8ddc-c22b-444f-ab41-85e7388b1a78"],
Cell[13743, 290, 411, 10, 27, "Item1",ExpressionUUID->"20525edc-8b40-4759-a26e-e6b445f71a4a"],
Cell[14157, 302, 604, 14, 49, "Item1",ExpressionUUID->"e187528b-ff51-4d07-a619-e07f8037ee4d"],
Cell[14764, 318, 1142, 25, 97, "Item1",ExpressionUUID->"3d2d52c2-2da7-423b-8eaf-3a01349fb23b"],
Cell[15909, 345, 1788, 33, 161, "Text",ExpressionUUID->"95e8bd61-fe39-4c31-9ac3-244156a9f8bd"],
Cell[17700, 380, 2103, 42, 185, "Text",ExpressionUUID->"b7a6274f-0806-46d7-99c1-2d5a4be603ec"],
Cell[19806, 424, 1097, 16, 131, "Text",ExpressionUUID->"18945cbd-4d42-4b73-beff-02ecc2d00323"],
Cell[20906, 442, 1464, 25, 156, "Text",ExpressionUUID->"a96eae0c-c0c4-420a-9ace-cc04e387141d"],
Cell[22373, 469, 1471, 26, 156, "Text",ExpressionUUID->"5fbacf7f-7fab-48b8-87b6-d4f85200086f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23881, 500, 219, 4, 87, "Section",ExpressionUUID->"5d0a60df-ee26-4cd9-89b9-d504da008b9c"],
Cell[24103, 506, 793, 19, 82, "Text",ExpressionUUID->"b13366da-f384-48a9-a57d-aa41ba8c8f0c"],
Cell[CellGroupData[{
Cell[24921, 529, 4898, 89, 28, "Input",ExpressionUUID->"a4f5661c-fb32-4b48-9252-fc90ef57edf2",
 CellOpen->False],
Cell[29822, 620, 5174, 85, 477, "Output",ExpressionUUID->"1276b329-2c44-4e2d-a0ed-3864ada459ff"]
}, Open  ]],
Cell[35011, 708, 654, 10, 33, "Text",ExpressionUUID->"7226b059-5a40-4161-a471-ea596c0a4990"],
Cell[CellGroupData[{
Cell[35690, 722, 4875, 85, 28, "Input",ExpressionUUID->"43d1fa1e-f4e9-4896-a192-1382f522e371",
 CellOpen->False],
Cell[40568, 809, 5495, 94, 334, "Output",ExpressionUUID->"19ed8b56-1521-48ab-b0e1-a5b4cb8ce712"]
}, Open  ]],
Cell[46078, 906, 1997, 60, 28, "Input",ExpressionUUID->"53ce0674-9937-4e38-b417-29b6cbad40de",
 CellOpen->False],
Cell[48078, 968, 656, 11, 82, "Text",ExpressionUUID->"269f6773-d627-4bc6-8076-f7a7432d4626"],
Cell[48737, 981, 239, 4, 33, "Text",ExpressionUUID->"6c6dc738-fc68-4692-bf1b-701fb9183172"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49013, 990, 249, 5, 87, "Section",ExpressionUUID->"914472c4-bdc1-4f15-a9e5-3cd3b7926f6c"],
Cell[49265, 997, 296, 6, 33, "Text",ExpressionUUID->"714b7450-217b-4d13-add0-0ce46a885f21"],
Cell[49564, 1005, 243, 4, 51, "Subsection",ExpressionUUID->"595e1512-fd8e-4fed-a86e-5b2f0f6df653"],
Cell[CellGroupData[{
Cell[49832, 1013, 2664, 81, 80, "Text",ExpressionUUID->"3ba88d9d-148f-45d4-a6a9-7d3bc43d1a2c"],
Cell[52499, 1096, 1552, 49, 28, "Input",ExpressionUUID->"914448f3-5b1c-46b7-83c4-297c0befe85e",
 CellOpen->False]
}, Open  ]],
Cell[54066, 1148, 1399, 41, 131, "EquationNumbered",ExpressionUUID->"4b96748b-ebf0-4c9b-939b-b141bdd11a46"],
Cell[55468, 1191, 596, 12, 82, "Text",ExpressionUUID->"20ca46ba-af4d-4757-a1e4-7a870f8809ea"],
Cell[56067, 1205, 938, 24, 58, "Text",ExpressionUUID->"7bf43e75-b10f-4108-aa0e-abe2fac39c90"],
Cell[57008, 1231, 732, 22, 101, "EquationNumbered",ExpressionUUID->"2405a615-a7c5-45e1-9929-79856bdee840"],
Cell[57743, 1255, 1015, 28, 58, "Text",ExpressionUUID->"0f93b82f-04a2-4140-8e65-bd2309e36c57"],
Cell[58761, 1285, 2643, 68, 190, "Text",ExpressionUUID->"b0019a2f-a69f-4008-8bc3-07f8d2d51fdc"],
Cell[CellGroupData[{
Cell[61429, 1357, 2784, 73, 28, "Input",ExpressionUUID->"89d55fa0-d6d9-4f06-9a0e-341eb4be219c",
 CellOpen->False],
Cell[64216, 1432, 24063, 466, 424, "Output",ExpressionUUID->"e2d1b30a-1955-4214-92fb-da1c47d75565"]
}, Open  ]],
Cell[88294, 1901, 579, 12, 32, "FigureCaption",ExpressionUUID->"75076e26-8eda-492b-b2e6-593fdc9495a5"],
Cell[88876, 1915, 1143, 21, 107, "Text",ExpressionUUID->"a4e3f87a-04cb-4bdb-8b7f-2e1cea982bbc"],
Cell[90022, 1938, 236, 4, 51, "Subsection",ExpressionUUID->"d5de173b-f59f-4db0-ad64-4147d8b3ae87"],
Cell[CellGroupData[{
Cell[90283, 1946, 1287, 38, 59, "Text",ExpressionUUID->"3f45682f-8951-4e4a-8f3e-28026c4fd535"],
Cell[91573, 1986, 1273, 41, 28, "Input",ExpressionUUID->"ac734b8d-9450-463f-815c-726eef9d5cc6",
 CellOpen->False]
}, Open  ]],
Cell[92861, 2030, 847, 23, 103, "EquationNumbered",ExpressionUUID->"3625a094-3a52-4203-b3ed-82d2d95bda1d"],
Cell[93711, 2055, 588, 18, 97, "EquationNumbered",ExpressionUUID->"9b624807-203a-4132-b35d-b44fcbaa0eb5"],
Cell[94302, 2075, 1667, 45, 82, "Text",ExpressionUUID->"28e395c6-fe6d-4449-893d-35c027c05e3b"],
Cell[95972, 2122, 1997, 66, 112, "Text",ExpressionUUID->"54ee4f71-5063-48a0-a8a6-6612135e1a50"],
Cell[97972, 2190, 806, 25, 28, "Input",ExpressionUUID->"a9aa596e-888d-4d6d-9355-db785f89db77",
 CellOpen->False],
Cell[98781, 2217, 1848, 51, 155, "EquationNumbered",ExpressionUUID->"70b8af88-53e6-4ea9-99e8-d942028f9c19"],
Cell[100632, 2270, 1627, 31, 161, "Text",ExpressionUUID->"406f98ca-c02c-45c5-a6b5-c918c7de0a62"],
Cell[102262, 2303, 19243, 243, 99, "EquationNumbered",ExpressionUUID->"41382b5c-8fec-4f10-ae84-caaf6b9493c0"],
Cell[121508, 2548, 525, 17, 45, "Text",ExpressionUUID->"5838389c-0206-4b05-9aa2-d1636775b51a"],
Cell[122036, 2567, 2218, 43, 242, "Text",ExpressionUUID->"d0342836-8929-4709-aa8a-cec218a19efb"],
Cell[124257, 2612, 192, 3, 51, "Subsection",ExpressionUUID->"3b1864af-a7ea-4405-8c1c-53c7d7d89508"],
Cell[124452, 2617, 681, 21, 30, "Text",ExpressionUUID->"61216ad9-c71c-4bbf-bdc1-0f2718e44adf"],
Cell[125136, 2640, 918, 21, 58, "Text",ExpressionUUID->"684f047d-e3eb-4551-bdcc-60c1696c2026"],
Cell[126057, 2663, 567, 17, 29, "Item1Numbered",ExpressionUUID->"c658d07b-c834-44f7-8857-2b6d26a92628"],
Cell[126627, 2682, 1246, 39, 51, "Item1Numbered",ExpressionUUID->"61ac7491-fa43-432d-afa9-19b8b06eccc2"],
Cell[127876, 2723, 529, 17, 27, "Item1Numbered",ExpressionUUID->"f4a059aa-510f-4e16-9934-81b6a6e8069c"],
Cell[128408, 2742, 733, 18, 49, "Item1Numbered",ExpressionUUID->"0a1d0382-9cdf-44ae-ad22-6be989800528"],
Cell[129144, 2762, 1731, 62, 49, "Item1Numbered",ExpressionUUID->"a5740faf-838e-48f3-9a48-14d1cd508d13"],
Cell[130878, 2826, 666, 21, 27, "Item1Numbered",ExpressionUUID->"c0ad316c-d881-47f5-b037-ec671b3bd6bc"],
Cell[CellGroupData[{
Cell[131569, 2851, 763, 17, 58, "Text",ExpressionUUID->"b34e02d1-fe20-4c98-8116-483b00b9ec3d"],
Cell[132335, 2870, 2494, 73, 28, "Input",ExpressionUUID->"21575059-11fb-4c9d-a008-f0fa77143464",
 CellOpen->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[134866, 2948, 1038, 31, 28, "Input",ExpressionUUID->"c60b86d5-1fc1-4075-89ff-d2e23e9c11f0",
 CellOpen->False],
Cell[135907, 2981, 1546, 26, 82, "Output",ExpressionUUID->"bec6a76b-c014-4d34-a473-40b34e3ec7fc"]
}, Open  ]],
Cell[137468, 3010, 381, 9, 33, "TableTitle",ExpressionUUID->"7bde0bcc-979c-4053-a59d-4cb529924aec"],
Cell[137852, 3021, 3210, 108, 168, "Text",ExpressionUUID->"47c17fcd-9a0f-4a77-a6f0-7951f24077bd"],
Cell[CellGroupData[{
Cell[141087, 3133, 4020, 109, 28, "Input",ExpressionUUID->"876decd4-06a5-4cd1-a23f-082f3a7ff68d",
 CellOpen->False],
Cell[145110, 3244, 3772, 73, 451, "Output",ExpressionUUID->"08dfd344-7928-43e4-8a42-b95cb645b303"]
}, Open  ]],
Cell[148897, 3320, 1046, 30, 44, "FigureCaption",ExpressionUUID->"a3801237-220a-493c-8fa0-96c056a4af3f"],
Cell[149946, 3352, 2432, 78, 96, "Text",ExpressionUUID->"85776d96-c1c9-490e-881a-109a559b45b3"],
Cell[152381, 3432, 786, 17, 58, "Text",ExpressionUUID->"6a0d1099-d9a6-483d-9351-808c6ed5d4a1"],
Cell[CellGroupData[{
Cell[153192, 3453, 724, 18, 28, "Input",ExpressionUUID->"010a1b96-71fe-4694-8ed4-7a3f83e81f79",
 CellOpen->False],
Cell[153919, 3473, 2824, 60, 380, "Output",ExpressionUUID->"8b8a99d6-11b4-43ac-ac4b-55c9be242632"]
}, Open  ]],
Cell[156758, 3536, 391, 6, 33, "TableTitle",ExpressionUUID->"0710262b-f5dd-4e8a-bbb0-7b13c876fc53"],
Cell[157152, 3544, 192, 3, 51, "Subsection",ExpressionUUID->"01925821-3fc6-4fc8-be3b-2d24f8989b4d"],
Cell[157347, 3549, 1500, 36, 82, "Text",ExpressionUUID->"de58392d-e0b2-46d6-b2f8-56af25574efc"],
Cell[CellGroupData[{
Cell[158872, 3589, 590, 17, 35, "Text",ExpressionUUID->"4e0f4e7a-52e7-40c2-83ee-2c560458c230"],
Cell[159465, 3608, 2424, 71, 28, "Input",ExpressionUUID->"f2c6d4af-dfac-403f-8bdb-c7e844645201",
 CellOpen->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[161926, 3684, 1068, 26, 28, "Input",ExpressionUUID->"a03124c3-b351-4156-9af4-a8b99692105c",
 CellOpen->False],
Cell[162997, 3712, 2379, 53, 82, "Output",ExpressionUUID->"f9cacea5-c508-4618-9b46-18e8c63a7887"]
}, Open  ]],
Cell[165391, 3768, 398, 6, 33, "TableTitle",ExpressionUUID->"a8035b74-1d2e-4765-a12a-38534fc4c5ce"],
Cell[165792, 3776, 557, 17, 28, "Text",ExpressionUUID->"dc595fd5-2685-4314-8f2e-5867fa94da1d",
 CellOpen->False],
Cell[CellGroupData[{
Cell[166374, 3797, 3671, 104, 28, "Input",ExpressionUUID->"86ca7d0b-08e4-41b2-90f8-8d5e55f48390",
 CellOpen->False],
Cell[170048, 3903, 5880, 107, 465, "Output",ExpressionUUID->"515c2646-a0dd-4dcb-b1a2-c961a1981d29"]
}, Open  ]],
Cell[175943, 4013, 487, 10, 32, "FigureCaption",ExpressionUUID->"63ce085d-985d-4973-9da8-2d4abf1f18ce"],
Cell[176433, 4025, 1929, 42, 156, "Text",ExpressionUUID->"25900c8a-05a7-4ad1-aebd-d375b33a1893"],
Cell[178365, 4069, 833, 18, 58, "Text",ExpressionUUID->"4376a32b-e128-469c-a90e-315313fba703"],
Cell[CellGroupData[{
Cell[179223, 4091, 779, 19, 28, "Input",ExpressionUUID->"fe1a56ed-1604-444a-8145-47de0691e589",
 CellOpen->False],
Cell[180005, 4112, 3142, 64, 380, "Output",ExpressionUUID->"7fea851f-6dcb-48d2-8281-dd524882d7a2"]
}, Open  ]],
Cell[183162, 4179, 489, 10, 33, "TableTitle",ExpressionUUID->"765f0885-06da-4f24-9236-49afb0609682"],
Cell[CellGroupData[{
Cell[183676, 4193, 995, 31, 28, "Text",ExpressionUUID->"f1a607c7-ebc5-4d24-9d9e-8f9c09964256",
 CellOpen->False],
Cell[CellGroupData[{
Cell[184696, 4228, 1340, 38, 20547, "Input",ExpressionUUID->"22c974c1-febf-4ec5-aed1-75937b039c67",
 CellOpen->False],
Cell[186039, 4268, 2997, 67, 70, "Output",ExpressionUUID->"838c247b-8c65-40c5-a9c9-dee066be1128"]
}, Open  ]]
}, Closed]],
Cell[189063, 4339, 337, 7, 29, "Text",ExpressionUUID->"2fe10581-3095-45d6-8a10-4623e77d136d"],
Cell[CellGroupData[{
Cell[189425, 4350, 1613, 38, 28, "Input",ExpressionUUID->"abdfcef4-8f68-4ed0-ad9f-47a0bd073ef4",
 CellOpen->False],
Cell[191041, 4390, 17304, 327, 467, "Output",ExpressionUUID->"9b9c4eed-6a5a-462c-b7e9-5975c24ffeab"]
}, Open  ]],
Cell[208360, 4720, 461, 10, 32, "FigureCaption",ExpressionUUID->"ea932c9b-44b4-4209-9602-0fa63e7bcdcc"],
Cell[208824, 4732, 194, 3, 51, "Subsection",ExpressionUUID->"c038a0e6-288b-4b9a-8737-f9d3b41990d8"],
Cell[209021, 4737, 1038, 29, 82, "Text",ExpressionUUID->"408939ab-2f9d-4d6c-bdc2-4747d1653607"],
Cell[CellGroupData[{
Cell[210084, 4770, 1844, 48, 28, "Input",ExpressionUUID->"aecbe69b-bb98-40e4-aa40-6ff0797657f3",
 CellOpen->False],
Cell[211931, 4820, 1956, 39, 82, "Output",ExpressionUUID->"d61b89a6-dceb-468b-a425-f0ae92f79366"]
}, Open  ]],
Cell[213902, 4862, 454, 6, 33, "TableTitle",ExpressionUUID->"aca1e518-3289-42f9-9c41-ad48865c24d7"],
Cell[CellGroupData[{
Cell[214381, 4872, 4743, 143, 28, "Input",ExpressionUUID->"6a3a7d32-4346-4a04-b689-a7330bdc05f6",
 CellOpen->False],
Cell[219127, 5017, 4275, 81, 479, "Output",ExpressionUUID->"a8b88f17-5d70-48e8-8d40-3acdb668bbac"]
}, Open  ]],
Cell[223417, 5101, 570, 11, 32, "FigureCaption",ExpressionUUID->"577788a2-7c12-4160-9d99-91a3a3c1fa7d"],
Cell[CellGroupData[{
Cell[224012, 5116, 734, 19, 28, "Input",ExpressionUUID->"0dc04b2c-075e-434d-9be1-344873c2bae8",
 CellOpen->False],
Cell[224749, 5137, 2556, 58, 380, "Output",ExpressionUUID->"b40ecbeb-4513-4c02-83e6-7d9bcda02798"]
}, Open  ]],
Cell[227320, 5198, 485, 7, 33, "TableTitle",ExpressionUUID->"dde15d06-6a06-4270-8372-994049129284"],
Cell[CellGroupData[{
Cell[227830, 5209, 1033, 31, 28, "Text",ExpressionUUID->"bd2835b8-b670-4860-8e31-8a19e408086d",
 CellOpen->False],
Cell[CellGroupData[{
Cell[228888, 5244, 1272, 37, 20547, "Input",ExpressionUUID->"1de94bf0-1cae-4000-9162-a32c7029dfe2",
 CellOpen->False],
Cell[230163, 5283, 3440, 76, 70, "Output",ExpressionUUID->"7a2fcccc-f9d8-4b18-8999-c06464d586bf",
 CellOpen->False]
}, Open  ]]
}, Closed]],
Cell[233630, 5363, 918, 28, 78, "Text",ExpressionUUID->"9d86eea6-dbc7-48b6-af45-91b055865a0e"],
Cell[CellGroupData[{
Cell[234573, 5395, 1626, 42, 28, "Input",ExpressionUUID->"e60e2e1f-7b0a-471f-be00-a18858dd175c",
 CellOpen->False],
Cell[236202, 5439, 23073, 437, 466, "Output",ExpressionUUID->"6321961c-e688-4828-b754-ab8999268d6a"]
}, Open  ]],
Cell[259290, 5879, 562, 11, 32, "FigureCaption",ExpressionUUID->"7124fc55-345e-4310-841a-c81b12d919d9"],
Cell[259855, 5892, 1556, 42, 84, "Text",ExpressionUUID->"e7ab2f93-cf65-4945-b906-458e3a58992d"],
Cell[CellGroupData[{
Cell[261436, 5938, 2075, 55, 28, "Input",ExpressionUUID->"e5cd0fc3-8193-4436-90cd-366e489b7b7c",
 CellOpen->False],
Cell[263514, 5995, 15238, 305, 372, "Output",ExpressionUUID->"d179ce96-48ce-4a4f-9af6-31d536c54095"]
}, Open  ]],
Cell[278767, 6303, 911, 19, 44, "FigureCaption",ExpressionUUID->"2727a463-7463-4fb4-9c1f-c6a7fe72955a"],
Cell[279681, 6324, 194, 3, 51, "Subsection",ExpressionUUID->"ac9c072d-31c4-4262-ae73-f1e9528c8044"],
Cell[CellGroupData[{
Cell[279900, 6331, 1114, 29, 54, "Text",ExpressionUUID->"652e3398-4257-44f8-891d-393bb8537d89"],
Cell[281017, 6362, 726, 22, 28, "Text",ExpressionUUID->"070dfb63-f4a9-411e-8247-76b23ca556bf",
 CellOpen->False],
Cell[CellGroupData[{
Cell[281768, 6388, 3511, 95, 28, "Input",ExpressionUUID->"1e7d366c-0461-42fe-bc8a-4e8ecfb155eb",
 CellOpen->False],
Cell[285282, 6485, 1855, 37, 82, "Output",ExpressionUUID->"0b29ebab-4012-4ce4-8e95-0720b0d3f3a8"]
}, Open  ]]
}, Open  ]],
Cell[287164, 6526, 479, 7, 33, "TableTitle",ExpressionUUID->"3a031926-04eb-49ab-9fd8-617c4f0cc26f"],
Cell[CellGroupData[{
Cell[287668, 6537, 3965, 111, 28, "Input",ExpressionUUID->"bc8692a4-996d-4cac-a6b7-d6d58e5ed7c9",
 CellOpen->False],
Cell[291636, 6650, 3616, 72, 483, "Output",ExpressionUUID->"0a72f5e5-bb9d-4f69-b00f-84fa6810ba15"]
}, Open  ]],
Cell[295267, 6725, 1065, 26, 44, "FigureCaption",ExpressionUUID->"96da8de0-62d1-4e47-be3c-7df5095dfbb2"],
Cell[296335, 6753, 806, 15, 107, "Text",ExpressionUUID->"0d73b6cd-aee6-4d60-9ba4-8491544aa0ad"],
Cell[CellGroupData[{
Cell[297166, 6772, 4390, 127, 28, "Input",ExpressionUUID->"caa1b828-d8b7-4f55-aac3-ef020d8f9336",
 CellOpen->False],
Cell[301559, 6901, 3077, 61, 284, "Output",ExpressionUUID->"e6f077cf-0894-413f-ac60-fdaf0aa3d125"]
}, Open  ]],
Cell[304651, 6965, 539, 8, 33, "TableTitle",ExpressionUUID->"2256e4e3-7e3a-4b90-a9ae-5ad0cc858e8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305227, 6978, 255, 5, 87, "Section",ExpressionUUID->"3c186938-3ad7-445a-bb30-13268dcab52c"],
Cell[305485, 6985, 535, 9, 82, "Text",ExpressionUUID->"a4ed5ad7-fa0d-4b10-9728-957e8846339a"],
Cell[306023, 6996, 508, 9, 58, "Text",ExpressionUUID->"31fc627c-4f34-48e2-81ed-3c5d809253b2"],
Cell[CellGroupData[{
Cell[306556, 7009, 2878, 55, 28, "Input",ExpressionUUID->"678a20bd-eead-41ef-b5be-1c9e7e815850",
 CellOpen->False],
Cell[309437, 7066, 2958, 52, 186, "Output",ExpressionUUID->"ba2a9c5d-23a4-4b2e-ba23-bcd2b0c9c928"]
}, Open  ]],
Cell[312410, 7121, 1594, 38, 149, "Text",ExpressionUUID->"6af6856d-03c6-4097-a9cc-9aa76fb4b044"],
Cell[314007, 7161, 466, 14, 28, "Input",ExpressionUUID->"0fb15e0e-fa50-4f2b-be02-7ba24c1414d0",
 CellOpen->False],
Cell[314476, 7177, 292, 7, 33, "Text",ExpressionUUID->"8e03c15b-13e5-491f-bfcc-911ed220b624"],
Cell[314771, 7186, 18260, 231, 99, "EquationNumbered",ExpressionUUID->"51de9fb5-c536-4ea0-85f8-345e159d5ad0"],
Cell[333034, 7419, 189, 3, 51, "Subsection",ExpressionUUID->"cf852df5-05af-4c41-ac69-bb949508d07a"],
Cell[CellGroupData[{
Cell[333248, 7426, 997, 29, 29, "Text",ExpressionUUID->"7ef80f12-47e1-47f8-bb78-83bf63a9d8ac"],
Cell[334248, 7457, 1657, 50, 28, "Input",ExpressionUUID->"2fd05c1f-2726-4253-bf03-b7ccf076fa75",
 CellOpen->False]
}, Open  ]],
Cell[335920, 7510, 1258, 36, 142, "EquationNumbered",ExpressionUUID->"a1150500-d15f-487b-b2be-a31663965cb1"],
Cell[337181, 7548, 732, 26, 103, "EquationNumbered",ExpressionUUID->"3e55bf2e-b733-4e33-9e46-4433bebc1d75"],
Cell[337916, 7576, 1386, 32, 107, "Text",ExpressionUUID->"052f66d4-24c9-4321-bda5-0f167da4d3f0"],
Cell[CellGroupData[{
Cell[339327, 7612, 652, 20, 28, "Input",ExpressionUUID->"16df2b7a-5f48-4f40-9035-5910d4baddf4",
 CellOpen->False],
Cell[339982, 7634, 1099, 21, 28, "Output",ExpressionUUID->"9325b167-3a96-4950-8d47-d5a6898e6b74",
 CellOpen->False]
}, Open  ]],
Cell[341096, 7658, 531, 16, 102, "EquationNumbered",ExpressionUUID->"5f44e784-3fe2-4160-83a9-ddc39bba2953"],
Cell[CellGroupData[{
Cell[341652, 7678, 1166, 33, 60, "Text",ExpressionUUID->"3866fedb-b9f5-466f-a5de-7afb92aa68db"],
Cell[342821, 7713, 71, 0, 33, "Text",ExpressionUUID->"9b05a0c4-1400-4a46-b495-ab89ce17c64d"],
Cell[CellGroupData[{
Cell[342917, 7717, 1565, 47, 28, "Input",ExpressionUUID->"13ed8886-8a85-456f-9965-44c8e6829dd0",
 CellOpen->False],
Cell[344485, 7766, 1242, 23, 82, "Output",ExpressionUUID->"c3c22c24-e1f4-46d1-bbd6-5da6803304d3"]
}, Open  ]]
}, Open  ]],
Cell[345754, 7793, 579, 13, 34, "TableTitle",ExpressionUUID->"3d2c9422-71de-445a-bb82-dedcf4ca5c81"],
Cell[CellGroupData[{
Cell[346358, 7810, 800, 22, 28, "Text",ExpressionUUID->"4db81cc8-d286-4a3d-a987-c236827bf165",
 CellOpen->False],
Cell[CellGroupData[{
Cell[347183, 7836, 268, 7, 711, "Input",ExpressionUUID->"2c7ada6a-bf2a-4fee-87aa-9669ecd11c03",
 CellOpen->False],
Cell[347454, 7845, 1980, 47, 70, "Output",ExpressionUUID->"b69e2cc2-f40a-485e-a4f8-2df83fb01d17",
 CellOpen->False]
}, Open  ]],
Cell[349449, 7895, 1182, 24, 711, "Text",ExpressionUUID->"064e3824-bc53-40a1-93f3-d4e4a24d6e9a",
 CellOpen->False],
Cell[CellGroupData[{
Cell[350656, 7923, 402, 12, 711, "Input",ExpressionUUID->"22c81dc7-b8aa-4097-bece-f8194443a929",
 CellOpen->False],
Cell[351061, 7937, 1960, 31, 70, "Message",ExpressionUUID->"700b2413-4d0b-40e6-8318-ce00aed37cd3"],
Cell[353024, 7970, 986, 15, 70, "Output",ExpressionUUID->"fe5b39b6-748a-4ff1-bbb3-4d4b7d0b1e63",
 CellOpen->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[354047, 7990, 402, 12, 711, "Input",ExpressionUUID->"b41e87e8-531f-421a-80b1-d73d64da499c",
 CellOpen->False],
Cell[354452, 8004, 602, 11, 70, "Message",ExpressionUUID->"0f72b65e-dc84-47e2-96d0-5396b316dc80"],
Cell[355057, 8017, 991, 15, 70, "Output",ExpressionUUID->"1aede207-d4e3-426d-9090-543cc44e2702",
 CellOpen->False]
}, Open  ]],
Cell[356063, 8035, 459, 12, 711, "Text",ExpressionUUID->"894bdd84-95de-4548-9ee9-458a081f964e",
 CellOpen->False],
Cell[CellGroupData[{
Cell[356547, 8051, 228, 6, 711, "Input",ExpressionUUID->"5982b20a-cb83-4c79-9863-09467badca65",
 CellOpen->False],
Cell[356778, 8059, 1002, 15, 70, "Output",ExpressionUUID->"9ce0965e-2170-4e70-9d81-d71befa21b07",
 CellOpen->False]
}, Open  ]],
Cell[357795, 8077, 428, 13, 711, "Text",ExpressionUUID->"5e196c3d-e004-498e-b760-1ac8d15c0135",
 CellOpen->False],
Cell[CellGroupData[{
Cell[358248, 8094, 375, 12, 711, "Input",ExpressionUUID->"b701aa64-c246-4867-b514-a343328194d1",
 CellOpen->False],
Cell[358626, 8108, 1861, 44, 70, "Output",ExpressionUUID->"b7d40782-9dbe-4e84-97d2-e6f34eecdb50",
 CellOpen->False]
}, Open  ]],
Cell[360502, 8155, 430, 14, 711, "Text",ExpressionUUID->"c562d311-f5f8-4111-b45d-21d8ddfa4711",
 CellOpen->False]
}, Closed]],
Cell[360947, 8172, 620, 14, 54, "Text",ExpressionUUID->"bee319b2-a514-4738-8685-8bfd28c574f8"],
Cell[CellGroupData[{
Cell[361592, 8190, 2024, 47, 28, "Input",ExpressionUUID->"aabc05d8-8c2b-43bc-bd08-48460f7c5849",
 CellOpen->False],
Cell[363619, 8239, 566, 20, 58, "Text",ExpressionUUID->"79d3cf6d-1af6-4c55-b6f2-0e259ac33945"]
}, Open  ]],
Cell[364200, 8262, 692, 22, 28, "Input",ExpressionUUID->"902936b5-8758-4f52-9cda-e536352c6bf7",
 CellOpen->False],
Cell[364895, 8286, 785, 19, 60, "Text",ExpressionUUID->"3fdf65ce-1dba-4841-ab00-3b9217845ace"],
Cell[CellGroupData[{
Cell[365705, 8309, 418, 13, 45, "Input",ExpressionUUID->"a78a2b86-6c2f-4e5c-99b2-68b25667197c"],
Cell[366126, 8324, 1030, 16, 45, "Output",ExpressionUUID->"5fbe920e-10dd-441b-84c1-d35a8369f597"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367193, 8345, 1081, 28, 28, "Input",ExpressionUUID->"4db3cbfc-76a7-4780-9478-86babad7bfb6",
 CellOpen->False],
Cell[368277, 8375, 420, 10, 58, "Text",ExpressionUUID->"cbb38e44-09a4-4f18-ae4c-45426f2b2c93"]
}, Open  ]],
Cell[368712, 8388, 289, 7, 33, "Text",ExpressionUUID->"297c133e-77cd-449c-be22-67e5375e4ce0"],
Cell[CellGroupData[{
Cell[369026, 8399, 4705, 132, 28, "Input",ExpressionUUID->"f5954a4a-205c-4b22-8eb7-d2c7f62afd9b",
 CellOpen->False],
Cell[373734, 8533, 14851, 307, 352, "Output",ExpressionUUID->"b8d344b7-2e46-433e-8ab2-a7d1ad9b0bcc"]
}, Open  ]],
Cell[388600, 8843, 727, 13, 32, "FigureCaption",ExpressionUUID->"a1152364-5b3d-493e-af9c-92b978d54528"],
Cell[389330, 8858, 893, 21, 58, "Text",ExpressionUUID->"24df2852-9930-4b0a-a7b3-72750c874b34"],
Cell[CellGroupData[{
Cell[390248, 8883, 1222, 33, 28, "Input",ExpressionUUID->"b557ade6-85d0-454a-85e4-45eb9bb66534",
 CellOpen->False],
Cell[391473, 8918, 124282, 2027, 377, "Output",ExpressionUUID->"918c7642-b8fc-492d-8b86-42a8ffc4ccf8"]
}, Open  ]],
Cell[515770, 10948, 1080, 22, 32, "FigureCaption",ExpressionUUID->"57533565-e436-4cfe-9e67-08fd8ffaa532"],
Cell[516853, 10972, 1122, 25, 128, "Text",ExpressionUUID->"c02e4066-6fb3-42ad-a4a6-f96d0ead8561"],
Cell[517978, 10999, 924, 22, 58, "Text",ExpressionUUID->"cfcbfaf5-f06b-49a5-9161-79dc454a8115"],
Cell[CellGroupData[{
Cell[518927, 11025, 1669, 48, 28, "Input",ExpressionUUID->"4a04c331-3e9c-4aed-813e-1a199987c60e",
 CellOpen->False],
Cell[520599, 11075, 128248, 2700, 418, "Output",ExpressionUUID->"064dc942-d7e9-4963-8da1-ba5f670236c8"]
}, Open  ]],
Cell[648862, 13778, 888, 15, 32, "FigureCaption",ExpressionUUID->"00e2658e-abeb-4c22-b681-8fbd1a7a3241"],
Cell[649753, 13795, 789, 17, 58, "Text",ExpressionUUID->"0bed3cb5-505c-480f-8a67-526e81c3fae9"],
Cell[CellGroupData[{
Cell[650567, 13816, 3209, 88, 28, "Input",ExpressionUUID->"3065c018-167e-42ad-b318-3e8dd4d24905",
 CellOpen->False],
Cell[653779, 13906, 20950, 416, 363, "Output",ExpressionUUID->"a21491a1-f04d-4969-a082-06a7388a9934"]
}, Open  ]],
Cell[674744, 14325, 1189, 23, 32, "FigureCaption",ExpressionUUID->"b2761a1f-ed25-4f77-9b75-257ffeec6fd3"],
Cell[675936, 14350, 994, 16, 107, "Text",ExpressionUUID->"ef175ab5-83ec-41b5-98ca-65d849aba579"]
}, Open  ]],
Cell[CellGroupData[{
Cell[676967, 14371, 184, 3, 87, "Section",ExpressionUUID->"f365bdc2-aa83-4c35-83cc-404818cf2c15"],
Cell[677154, 14376, 529, 14, 33, "Text",ExpressionUUID->"9e270397-1349-4afa-913b-ccda3fa465c2"],
Cell[677686, 14392, 417, 13, 102, "EquationNumbered",ExpressionUUID->"6767188b-e4bc-49e8-85cd-c5294be0f028"],
Cell[678106, 14407, 1583, 36, 112, "Text",ExpressionUUID->"1b1b138f-54f8-4b33-9a43-698abf8b7126"],
Cell[679692, 14445, 2074, 47, 136, "Text",ExpressionUUID->"0ad1c484-54cd-4cfe-8083-f548f539b163"],
Cell[681769, 14494, 1644, 35, 140, "Text",ExpressionUUID->"17a316de-5f4f-4d92-aee2-dbba343ca2d1"],
Cell[683416, 14531, 1005, 21, 82, "Text",ExpressionUUID->"8b178931-467e-40e8-9a87-f9e718e59ab4"],
Cell[684424, 14554, 748, 12, 82, "Text",ExpressionUUID->"6fd77d3c-4ce7-4e84-b5c1-5accc9fd90e8"],
Cell[685175, 14568, 767, 12, 82, "Text",ExpressionUUID->"f449ca19-0c69-4c61-b80a-f1a0f04cdebd"],
Cell[685945, 14582, 1544, 31, 131, "Text",ExpressionUUID->"e3509e75-f585-477d-af95-606c0793a7c3"],
Cell[687492, 14615, 31717, 395, 226, "Text",ExpressionUUID->"0c178e9c-5ba4-4c1c-bc4e-ad44a81f1150"],
Cell[719212, 15012, 963, 16, 32, "FigureCaption",ExpressionUUID->"304ac100-663f-4c08-a952-bed1cd557a45"],
Cell[720178, 15030, 279, 5, 33, "Text",ExpressionUUID->"ec351d34-4da9-493c-8748-b66ff6820bf4"],
Cell[720460, 15037, 1047, 16, 113, "Item1",ExpressionUUID->"7674ff4b-d318-4df1-b18d-711a672d486a"],
Cell[721510, 15055, 573, 8, 70, "Item1",ExpressionUUID->"dcc29e75-9bfe-46c9-b700-00f78557a2fb"],
Cell[722086, 15065, 795, 13, 70, "Item1",ExpressionUUID->"0a74c8cf-5f64-4979-9714-fe0776378136"],
Cell[722884, 15080, 602, 10, 49, "Item1",ExpressionUUID->"c2900aac-878b-4d5f-95d3-1fcbc3ded202"],
Cell[723489, 15092, 790, 11, 92, "Item1",ExpressionUUID->"67b757a6-c612-4a40-961d-466a23935b37"],
Cell[724282, 15105, 907, 13, 107, "Text",ExpressionUUID->"88e345a9-180b-401b-9640-1396fe42a2e6"],
Cell[725192, 15120, 290, 5, 58, "Text",ExpressionUUID->"3606a54c-d45b-4700-ba97-2799ee749cce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[725519, 15130, 215, 4, 155, "EndnoteSection",ExpressionUUID->"0444de5b-404a-40ff-a5c0-6f19ec98c55f"],
Cell[725737, 15136, 915, 16, 74, "Endnote",ExpressionUUID->"f68bc0f7-1a04-440c-90bf-6a24dba46404",
 CellTags->"endnote1"],
Cell[726655, 15154, 545, 11, 28, "Endnote",ExpressionUUID->"2b968c7e-9faf-45dd-8828-ea8812bf2642",
 CellTags->"endnote2"],
Cell[727203, 15167, 674, 13, 28, "Endnote",ExpressionUUID->"75ace251-579c-4f7f-bc0a-0ef1ce878983",
 CellTags->"endnote3"],
Cell[727880, 15182, 606, 11, 28, "Endnote",ExpressionUUID->"2875e4c7-ac06-4cb5-a7c6-04418a12af74",
 CellTags->"endnote4"],
Cell[728489, 15195, 883, 17, 74, "Endnote",ExpressionUUID->"f54e6254-70b6-4079-805f-71fd84d09c38",
 CellTags->"endnote5"],
Cell[729375, 15214, 667, 13, 28, "Endnote",ExpressionUUID->"d382f0e2-8758-4ab9-b9e1-979e1eef6693",
 CellTags->"endnote6"],
Cell[730045, 15229, 657, 16, 28, "Endnote",ExpressionUUID->"e04a9228-ea28-42f4-a553-c23aac899ef5",
 CellTags->"endnote7"],
Cell[730705, 15247, 589, 11, 28, "Endnote",ExpressionUUID->"2346c6e1-bae6-4916-a123-97534217f02a",
 CellTags->"endnote8"],
Cell[731297, 15260, 1572, 44, 84, "Endnote",ExpressionUUID->"5cc4ad3d-c1f4-48a8-802d-1648e6ac9ab0",
 CellTags->"endnote9"],
Cell[732872, 15306, 957, 16, 51, "Endnote",ExpressionUUID->"978581f7-805d-4dc1-9cb6-484851a488c6",
 CellTags->"endnote10"],
Cell[733832, 15324, 592, 12, 51, "Endnote",ExpressionUUID->"12aacaa6-8484-44fc-aed0-81a61e319f5d",
 CellTags->"endnote11"],
Cell[734427, 15338, 630, 12, 28, "Endnote",ExpressionUUID->"c7c77fc5-9975-4245-84b4-207ccd2638a2",
 CellTags->"endnote12"]
}, Open  ]],
Cell[CellGroupData[{
Cell[735094, 15355, 215, 4, 155, "ReferenceSection",ExpressionUUID->"3f567f4d-adc2-4e00-9f54-b5c2ab2ed943"],
Cell[735312, 15361, 490, 10, 26, "Reference",ExpressionUUID->"11ce2adf-1d23-4782-aee4-931932dd83ab"],
Cell[735805, 15373, 546, 10, 26, "Reference",ExpressionUUID->"d38b2e9d-820e-421e-916a-b075a7395ab0"],
Cell[736354, 15385, 507, 10, 26, "Reference",ExpressionUUID->"cd64df15-55eb-48fc-9c32-8f7d5d637018"],
Cell[736864, 15397, 420, 9, 26, "Reference",ExpressionUUID->"7d766eb3-9951-463f-92fa-630efd6119af"],
Cell[737287, 15408, 531, 11, 26, "Reference",ExpressionUUID->"a4402b76-f197-4cae-8f7c-8ccb02a2f892"],
Cell[737821, 15421, 473, 8, 26, "Reference",ExpressionUUID->"4a5386c1-1506-4e64-9260-600afc50ce7b"],
Cell[738297, 15431, 505, 9, 26, "Reference",ExpressionUUID->"f71a822d-3980-49ce-8715-4527d335bb4a"],
Cell[738805, 15442, 426, 9, 26, "Reference",ExpressionUUID->"8a052cf5-1830-43ed-b53d-dab192cf6929"],
Cell[739234, 15453, 412, 9, 26, "Reference",ExpressionUUID->"b2069c4f-dac5-468b-a177-3d1a0aa9a4e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[739683, 15467, 212, 4, 155, "ExerciseSection",ExpressionUUID->"4b147275-007f-4ecc-8ea7-67c68dbd1c44"],
Cell[739898, 15473, 876, 17, 70, "Item1Exercise",ExpressionUUID->"3df55ff1-22ad-4189-a0be-92f647829212"],
Cell[740777, 15492, 869, 24, 70, "Item1Exercise",ExpressionUUID->"deb307a0-1640-429a-ac0c-4c6ddab6b395"],
Cell[741649, 15518, 677, 11, 49, "Item1Exercise",ExpressionUUID->"4f1340d6-1538-4268-89c9-df1bf908e6a8"],
Cell[742329, 15531, 605, 11, 49, "Item1Exercise",ExpressionUUID->"24515c02-0c44-424b-86b2-c9b23084da21"],
Cell[CellGroupData[{
Cell[742959, 15546, 2178, 56, 28, "Input",ExpressionUUID->"b4636047-ba9f-4fec-a7d6-981dffd694ba",
 CellOpen->False],
Cell[745140, 15604, 141202, 2774, 547, "Output",ExpressionUUID->"808c4cc9-3060-48b5-b768-b29ee3bd2fad"]
}, Open  ]]
}, Open  ]],
Cell[886369, 18382, 297, 7, 204, "AppendixSection",ExpressionUUID->"1874f153-3406-4957-a754-22a9f8b5751e"],
Cell[886669, 18391, 157, 3, 55, "Section",ExpressionUUID->"73ed7b6b-e378-4c91-8dc3-b47ebb88a846"],
Cell[886829, 18396, 546, 10, 78, "Text",ExpressionUUID->"c320412d-3980-4502-9cf8-6b2c5fe9d875"],
Cell[887378, 18408, 1915, 29, 229, "Text",ExpressionUUID->"f1b5ceb4-1f34-4887-87b1-23543ae733f9"],
Cell[CellGroupData[{
Cell[889318, 18441, 2153, 60, 28, "Input",ExpressionUUID->"ca72d1d2-5ec7-42bf-b3ab-e33f183ccbb4",
 CellOpen->False],
Cell[891474, 18503, 85972, 1415, 416, "Output",ExpressionUUID->"c0920ad2-f9c8-45f8-8132-4769d9c3c044"]
}, Open  ]],
Cell[977461, 19921, 322, 7, 32, "FigureCaption",ExpressionUUID->"d89889e3-76e0-4654-942c-fac77dcd469f"],
Cell[977786, 19930, 158, 3, 87, "Section",ExpressionUUID->"9a536296-2754-423d-ae88-b9f1f79446bf"],
Cell[977947, 19935, 386, 8, 54, "Text",ExpressionUUID->"fa54779c-164b-4ccd-b950-e34c7a34d3ff"],
Cell[CellGroupData[{
Cell[978358, 19947, 1279, 36, 28, "Input",ExpressionUUID->"d2256597-0930-42d7-8194-0154ff8e223d",
 CellOpen->False],
Cell[979640, 19985, 86108, 1414, 416, "Output",ExpressionUUID->"3bdba26b-6891-4cce-b007-8357e7e8d805"]
}, Open  ]],
Cell[1065763, 21402, 399, 8, 32, "FigureCaption",ExpressionUUID->"cde5783c-2fe7-4d3f-b520-75990c8f0f22"],
Cell[1066165, 21412, 215, 4, 87, "Section",ExpressionUUID->"67f0d9b5-91d9-47c3-8da7-8a4e43817cd5"],
Cell[1066383, 21418, 653, 11, 78, "Text",ExpressionUUID->"6d9becb2-4507-4a7a-9bf8-21024042f03c"],
Cell[CellGroupData[{
Cell[1067061, 21433, 1710, 51, 28, "Input",ExpressionUUID->"92e315df-9f5d-4d61-bc48-0e27c10eb0c6",
 CellOpen->False],
Cell[1068774, 21486, 86562, 1418, 416, "Output",ExpressionUUID->"c0a74a0e-a807-4d94-8e59-1cf1d77d3fae"]
}, Open  ]],
Cell[1155351, 22907, 290, 6, 32, "FigureCaption",ExpressionUUID->"ee222219-a2b5-4907-a10a-fd22f31d0756"],
Cell[1155644, 22915, 214, 4, 87, "Section",ExpressionUUID->"36faf07b-aa09-4eed-b776-314edb06afda"],
Cell[1155861, 22921, 581, 10, 78, "Text",ExpressionUUID->"f65ee430-6faa-4c1f-a811-65752033cbce"],
Cell[CellGroupData[{
Cell[1156467, 22935, 5662, 153, 28, "Input",ExpressionUUID->"91bb78fa-e611-4739-bcf2-aa422c8ce61e",
 CellOpen->False],
Cell[1162132, 23090, 28506, 503, 396, "Output",ExpressionUUID->"adaa0c74-d950-4db5-a1d2-c0def7dc823f"]
}, Open  ]],
Cell[1190653, 23596, 254, 6, 32, "FigureCaption",ExpressionUUID->"9d1005c2-bbb2-4491-8c05-70812991e4d2"],
Cell[1190910, 23604, 814, 13, 107, "Text",ExpressionUUID->"20ba3c67-18d3-4e58-9ca2-637f6ce62aab"]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Zx0ngRDTKJidfBKYhgzbYBvP *)
